{% load admin_list %}
{% load i18n %}
<style>
    .paginator{
        display: flex;
        align-items: center;
        gap: 5px;
    }
    .paginator a,
    .paginator span{
        display: flex;
        justify-content: center;
        align-items: center;
        border-radius: .475rem;
        height: 2.5rem;
        min-width: 2.5rem;
        font-weight: 500;
        font-size: 1.075rem;
    }
    .paginator span{
        background-color: #006ae6;
    }
    .paginator a:hover{
        color: #006ae6;
        background-color: #1b1c22;
    }
</style>
<p class="paginator">
{% if pagination_required %}
{% for i in page_range %}
    {% paginator_number cl i %}
{% endfor %}
{% endif %}
{{ cl.result_count }} {% if cl.result_count == 1 %}{{ cl.opts.verbose_name }}{% else %}{{ cl.opts.verbose_name_plural }}{% endif %}
{% if show_all_url %}<a href="{{ show_all_url }}" class="showall">{% translate 'Show all' %}</a>{% endif %}
{% if cl.formset and cl.result_count %}<input type="submit" name="_save" class="default" value="{% translate 'Save' %}">{% endif %}
</p>
