{% load i18n %}
<style>
    .hidden{
        display: none;
    }
    .actions{
        display: flex;
        align-items: center;
        gap: 10px;
    }
    .actions select{
        max-width: 300px;
    }
</style>
<div class="actions">
    {% block actions %}
        {% block actions-form %}
            {% for field in action_form %}{{ field }}{% endfor %}
        {% endblock %}
    {% block actions-submit %}
    <button type="submit" class="badge badge-light-info fs-base py-3 px-5 border-0" title="{% translate " Run the selected action" %}" name="index" value="{{ action_index|default:0 }}">{% translate "Go" %}</button>
    {% endblock %}
    {% block actions-counter %}
    {% if actions_selection_counter %}
    <span class="action-counter" data-actions-icnt="{{ cl.result_list|length }}">{{ selection_note }}</span>
    {% if cl.result_count != cl.result_list|length %}
    <span class="all hidden">{{ selection_note_all }}</span>
    <span class="question hidden">
        <a href="#" title="{% translate " Click here to select the objects across all pages" %}">{% blocktranslate with cl.result_count as total_count %}Select all {{ total_count }} {{ module_name }}{% endblocktranslate %}</a>
    </span>
    <span class="clear hidden"><a href="#">{% translate "Clear selection" %}</a></span>
    {% endif %}
    {% endif %}
    {% endblock %}
    {% endblock %}
</div>