{% extends "admin/index.html" %}
{% load i18n %}
{% block bodyclass %}{{ block.super }} app-{{ app_label }}{% endblock %}

{% block nav-breadcrumbs %}
    <ul class="breadcrumb breadcrumb-separatorless fw-semibold fs-base my-1">
        <li class="breadcrumb-item text-gray-500">
            <a href="{% url 'admin:index' %}" class="text-gray-500 text-hover-primary">Home</a>
        </li>
        {% for app in app_list %}
        <li class="breadcrumb-item">
            <span class="text-gray-500">/</span>
        </li>
        <li class="breadcrumb-item text-gray-500">{{ app.name }}</li>
        {% endfor %}
    </ul>
{% endblock %}

{% block sidebar %}{% endblock %}
