{% load i18n admin_urls %}
<div class="d-flex align-items-center gap-3 mt-4">
    {% block submit-row %}
        {% if show_save %}<input type="submit" value="{% translate 'Save' %}" class="default btn btn-success" name="_save">{% endif %}
        {% if show_save_as_new %}<input type="submit" value="{% translate 'Save as new' %}" name="_saveasnew">{% endif %}
        {% if show_save_and_add_another %}<input type="submit" class="btn btn-info" value="{% translate 'Save and add another' %}"
            name="_addanother">{% endif %}
        {% if show_save_and_continue %}<input type="submit" class="btn btn-warning"
            value="{% if can_change %}{% translate 'Save and continue editing' %}{% else %}{% translate 'Save and view' %}{% endif %}"
            name="_continue">{% endif %}
        {% if show_close %}
        {% url opts|admin_urlname:'changelist' as changelist_url %}
        <a href="{% add_preserved_filters changelist_url %}" class="closelink">{% translate 'Close' %}</a>
        {% endif %}
        {% if show_delete_link and original %}
        {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
        <a href="{% add_preserved_filters delete_url %}" class="deletelink ms-auto btn btn-danger">{% translate "Delete" %}</a>
        {% endif %}
    {% endblock %}
</div>