/*!
 * jQuery JavaScript Library v3.7.1
 * https://jquery.com/
 *
 * Copyright OpenJS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2023-08-28T13:37Z
 */
!function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):function(e){if(!e.document)throw new Error("jQuery requires a window with a document");return t(e)}:t(e)}("undefined"!=typeof window?window:this,(function(e,t){"use strict";var i=[],n=Object.getPrototypeOf,r=i.slice,a=i.flat?function(e){return i.flat.call(e)}:function(e){return i.concat.apply([],e)},s=i.push,o=i.indexOf,l={},c=l.toString,u=l.hasOwnProperty,d=u.toString,h=d.call(Object),f={},p=function(e){return"function"==typeof e&&"number"!=typeof e.nodeType&&"function"!=typeof e.item},m=function(e){return null!=e&&e===e.window},g=e.document,v={type:!0,src:!0,nonce:!0,noModule:!0};function y(e,t,i){var n,r,a=(i=i||g).createElement("script");if(a.text=e,t)for(n in v)(r=t[n]||t.getAttribute&&t.getAttribute(n))&&a.setAttribute(n,r);i.head.appendChild(a).parentNode.removeChild(a)}function b(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?l[c.call(e)]||"object":typeof e}var x="3.7.1",_=/HTML$/i,w=function(e,t){return new w.fn.init(e,t)};function k(e){var t=!!e&&"length"in e&&e.length,i=b(e);return!p(e)&&!m(e)&&("array"===i||0===t||"number"==typeof t&&t>0&&t-1 in e)}function M(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()}w.fn=w.prototype={jquery:x,constructor:w,length:0,toArray:function(){return r.call(this)},get:function(e){return null==e?r.call(this):e<0?this[e+this.length]:this[e]},pushStack:function(e){var t=w.merge(this.constructor(),e);return t.prevObject=this,t},each:function(e){return w.each(this,e)},map:function(e){return this.pushStack(w.map(this,(function(t,i){return e.call(t,i,t)})))},slice:function(){return this.pushStack(r.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},even:function(){return this.pushStack(w.grep(this,(function(e,t){return(t+1)%2})))},odd:function(){return this.pushStack(w.grep(this,(function(e,t){return t%2})))},eq:function(e){var t=this.length,i=+e+(e<0?t:0);return this.pushStack(i>=0&&i<t?[this[i]]:[])},end:function(){return this.prevObject||this.constructor()},push:s,sort:i.sort,splice:i.splice},w.extend=w.fn.extend=function(){var e,t,i,n,r,a,s=arguments[0]||{},o=1,l=arguments.length,c=!1;for("boolean"==typeof s&&(c=s,s=arguments[o]||{},o++),"object"==typeof s||p(s)||(s={}),o===l&&(s=this,o--);o<l;o++)if(null!=(e=arguments[o]))for(t in e)n=e[t],"__proto__"!==t&&s!==n&&(c&&n&&(w.isPlainObject(n)||(r=Array.isArray(n)))?(i=s[t],a=r&&!Array.isArray(i)?[]:r||w.isPlainObject(i)?i:{},r=!1,s[t]=w.extend(c,a,n)):void 0!==n&&(s[t]=n));return s},w.extend({expando:"jQuery"+(x+Math.random()).replace(/\D/g,""),isReady:!0,error:function(e){throw new Error(e)},noop:function(){},isPlainObject:function(e){var t,i;return!(!e||"[object Object]"!==c.call(e))&&(!(t=n(e))||"function"==typeof(i=u.call(t,"constructor")&&t.constructor)&&d.call(i)===h)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},globalEval:function(e,t,i){y(e,{nonce:t&&t.nonce},i)},each:function(e,t){var i,n=0;if(k(e))for(i=e.length;n<i&&!1!==t.call(e[n],n,e[n]);n++);else for(n in e)if(!1===t.call(e[n],n,e[n]))break;return e},text:function(e){var t,i="",n=0,r=e.nodeType;if(!r)for(;t=e[n++];)i+=w.text(t);return 1===r||11===r?e.textContent:9===r?e.documentElement.textContent:3===r||4===r?e.nodeValue:i},makeArray:function(e,t){var i=t||[];return null!=e&&(k(Object(e))?w.merge(i,"string"==typeof e?[e]:e):s.call(i,e)),i},inArray:function(e,t,i){return null==t?-1:o.call(t,e,i)},isXMLDoc:function(e){var t=e&&e.namespaceURI,i=e&&(e.ownerDocument||e).documentElement;return!_.test(t||i&&i.nodeName||"HTML")},merge:function(e,t){for(var i=+t.length,n=0,r=e.length;n<i;n++)e[r++]=t[n];return e.length=r,e},grep:function(e,t,i){for(var n=[],r=0,a=e.length,s=!i;r<a;r++)!t(e[r],r)!==s&&n.push(e[r]);return n},map:function(e,t,i){var n,r,s=0,o=[];if(k(e))for(n=e.length;s<n;s++)null!=(r=t(e[s],s,i))&&o.push(r);else for(s in e)null!=(r=t(e[s],s,i))&&o.push(r);return a(o)},guid:1,support:f}),"function"==typeof Symbol&&(w.fn[Symbol.iterator]=i[Symbol.iterator]),w.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),(function(e,t){l["[object "+t+"]"]=t.toLowerCase()}));var S=i.pop,A=i.sort,L=i.splice,T="[\\x20\\t\\r\\n\\f]",C=new RegExp("^"+T+"+|((?:^|[^\\\\])(?:\\\\.)*)"+T+"+$","g");w.contains=function(e,t){var i=t&&t.parentNode;return e===i||!(!i||1!==i.nodeType||!(e.contains?e.contains(i):e.compareDocumentPosition&&16&e.compareDocumentPosition(i)))};var D=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\x80-\uFFFF\w-]/g;function E(e,t){return t?"\0"===e?"�":e.slice(0,-1)+"\\"+e.charCodeAt(e.length-1).toString(16)+" ":"\\"+e}w.escapeSelector=function(e){return(e+"").replace(D,E)};var O=g,P=s;!function(){var t,n,a,s,l,c,d,h,p,m,g=P,v=w.expando,y=0,b=0,x=ee(),_=ee(),k=ee(),D=ee(),E=function(e,t){return e===t&&(l=!0),0},Y="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",I="(?:\\\\[\\da-fA-F]{1,6}"+T+"?|\\\\[^\\r\\n\\f]|[\\w-]|[^\0-\\x7f])+",N="\\["+T+"*("+I+")(?:"+T+"*([*^$|!~]?=)"+T+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+I+"))|)"+T+"*\\]",j=":("+I+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+N+")*)|.*)\\)|)",H=new RegExp(T+"+","g"),F=new RegExp("^"+T+"*,"+T+"*"),R=new RegExp("^"+T+"*([>+~]|"+T+")"+T+"*"),z=new RegExp(T+"|>"),B=new RegExp(j),V=new RegExp("^"+I+"$"),W={ID:new RegExp("^#("+I+")"),CLASS:new RegExp("^\\.("+I+")"),TAG:new RegExp("^("+I+"|[*])"),ATTR:new RegExp("^"+N),PSEUDO:new RegExp("^"+j),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+T+"*(even|odd|(([+-]|)(\\d*)n|)"+T+"*(?:([+-]|)"+T+"*(\\d+)|))"+T+"*\\)|)","i"),bool:new RegExp("^(?:"+Y+")$","i"),needsContext:new RegExp("^"+T+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+T+"*((?:-\\d)?\\d*)"+T+"*\\)|)(?=[^-]|$)","i")},U=/^(?:input|select|textarea|button)$/i,q=/^h\d$/i,$=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,X=/[+~]/,G=new RegExp("\\\\[\\da-fA-F]{1,6}"+T+"?|\\\\([^\\r\\n\\f])","g"),Z=function(e,t){var i="0x"+e.slice(1)-65536;return t||(i<0?String.fromCharCode(i+65536):String.fromCharCode(i>>10|55296,1023&i|56320))},K=function(){le()},J=he((function(e){return!0===e.disabled&&M(e,"fieldset")}),{dir:"parentNode",next:"legend"});try{g.apply(i=r.call(O.childNodes),O.childNodes),i[O.childNodes.length].nodeType}catch(e){g={apply:function(e,t){P.apply(e,r.call(t))},call:function(e){P.apply(e,r.call(arguments,1))}}}function Q(e,t,i,n){var r,a,s,o,l,u,d,m=t&&t.ownerDocument,y=t?t.nodeType:9;if(i=i||[],"string"!=typeof e||!e||1!==y&&9!==y&&11!==y)return i;if(!n&&(le(t),t=t||c,h)){if(11!==y&&(l=$.exec(e)))if(r=l[1]){if(9===y){if(!(s=t.getElementById(r)))return i;if(s.id===r)return g.call(i,s),i}else if(m&&(s=m.getElementById(r))&&Q.contains(t,s)&&s.id===r)return g.call(i,s),i}else{if(l[2])return g.apply(i,t.getElementsByTagName(e)),i;if((r=l[3])&&t.getElementsByClassName)return g.apply(i,t.getElementsByClassName(r)),i}if(!(D[e+" "]||p&&p.test(e))){if(d=e,m=t,1===y&&(z.test(e)||R.test(e))){for((m=X.test(e)&&oe(t.parentNode)||t)==t&&f.scope||((o=t.getAttribute("id"))?o=w.escapeSelector(o):t.setAttribute("id",o=v)),a=(u=ue(e)).length;a--;)u[a]=(o?"#"+o:":scope")+" "+de(u[a]);d=u.join(",")}try{return g.apply(i,m.querySelectorAll(d)),i}catch(t){D(e,!0)}finally{o===v&&t.removeAttribute("id")}}}return ye(e.replace(C,"$1"),t,i,n)}function ee(){var e=[];return function t(i,r){return e.push(i+" ")>n.cacheLength&&delete t[e.shift()],t[i+" "]=r}}function te(e){return e[v]=!0,e}function ie(e){var t=c.createElement("fieldset");try{return!!e(t)}catch(e){return!1}finally{t.parentNode&&t.parentNode.removeChild(t),t=null}}function ne(e){return function(t){return M(t,"input")&&t.type===e}}function re(e){return function(t){return(M(t,"input")||M(t,"button"))&&t.type===e}}function ae(e){return function(t){return"form"in t?t.parentNode&&!1===t.disabled?"label"in t?"label"in t.parentNode?t.parentNode.disabled===e:t.disabled===e:t.isDisabled===e||t.isDisabled!==!e&&J(t)===e:t.disabled===e:"label"in t&&t.disabled===e}}function se(e){return te((function(t){return t=+t,te((function(i,n){for(var r,a=e([],i.length,t),s=a.length;s--;)i[r=a[s]]&&(i[r]=!(n[r]=i[r]))}))}))}function oe(e){return e&&void 0!==e.getElementsByTagName&&e}function le(e){var t,i=e?e.ownerDocument||e:O;return i!=c&&9===i.nodeType&&i.documentElement?(d=(c=i).documentElement,h=!w.isXMLDoc(c),m=d.matches||d.webkitMatchesSelector||d.msMatchesSelector,d.msMatchesSelector&&O!=c&&(t=c.defaultView)&&t.top!==t&&t.addEventListener("unload",K),f.getById=ie((function(e){return d.appendChild(e).id=w.expando,!c.getElementsByName||!c.getElementsByName(w.expando).length})),f.disconnectedMatch=ie((function(e){return m.call(e,"*")})),f.scope=ie((function(){return c.querySelectorAll(":scope")})),f.cssHas=ie((function(){try{return c.querySelector(":has(*,:jqfake)"),!1}catch(e){return!0}})),f.getById?(n.filter.ID=function(e){var t=e.replace(G,Z);return function(e){return e.getAttribute("id")===t}},n.find.ID=function(e,t){if(void 0!==t.getElementById&&h){var i=t.getElementById(e);return i?[i]:[]}}):(n.filter.ID=function(e){var t=e.replace(G,Z);return function(e){var i=void 0!==e.getAttributeNode&&e.getAttributeNode("id");return i&&i.value===t}},n.find.ID=function(e,t){if(void 0!==t.getElementById&&h){var i,n,r,a=t.getElementById(e);if(a){if((i=a.getAttributeNode("id"))&&i.value===e)return[a];for(r=t.getElementsByName(e),n=0;a=r[n++];)if((i=a.getAttributeNode("id"))&&i.value===e)return[a]}return[]}}),n.find.TAG=function(e,t){return void 0!==t.getElementsByTagName?t.getElementsByTagName(e):t.querySelectorAll(e)},n.find.CLASS=function(e,t){if(void 0!==t.getElementsByClassName&&h)return t.getElementsByClassName(e)},p=[],ie((function(e){var t;d.appendChild(e).innerHTML="<a id='"+v+"' href='' disabled='disabled'></a><select id='"+v+"-\r\\' disabled='disabled'><option selected=''></option></select>",e.querySelectorAll("[selected]").length||p.push("\\["+T+"*(?:value|"+Y+")"),e.querySelectorAll("[id~="+v+"-]").length||p.push("~="),e.querySelectorAll("a#"+v+"+*").length||p.push(".#.+[+~]"),e.querySelectorAll(":checked").length||p.push(":checked"),(t=c.createElement("input")).setAttribute("type","hidden"),e.appendChild(t).setAttribute("name","D"),d.appendChild(e).disabled=!0,2!==e.querySelectorAll(":disabled").length&&p.push(":enabled",":disabled"),(t=c.createElement("input")).setAttribute("name",""),e.appendChild(t),e.querySelectorAll("[name='']").length||p.push("\\["+T+"*name"+T+"*="+T+"*(?:''|\"\")")})),f.cssHas||p.push(":has"),p=p.length&&new RegExp(p.join("|")),E=function(e,t){if(e===t)return l=!0,0;var i=!e.compareDocumentPosition-!t.compareDocumentPosition;return i||(1&(i=(e.ownerDocument||e)==(t.ownerDocument||t)?e.compareDocumentPosition(t):1)||!f.sortDetached&&t.compareDocumentPosition(e)===i?e===c||e.ownerDocument==O&&Q.contains(O,e)?-1:t===c||t.ownerDocument==O&&Q.contains(O,t)?1:s?o.call(s,e)-o.call(s,t):0:4&i?-1:1)},c):c}for(t in Q.matches=function(e,t){return Q(e,null,null,t)},Q.matchesSelector=function(e,t){if(le(e),h&&!D[t+" "]&&(!p||!p.test(t)))try{var i=m.call(e,t);if(i||f.disconnectedMatch||e.document&&11!==e.document.nodeType)return i}catch(e){D(t,!0)}return Q(t,c,null,[e]).length>0},Q.contains=function(e,t){return(e.ownerDocument||e)!=c&&le(e),w.contains(e,t)},Q.attr=function(e,t){(e.ownerDocument||e)!=c&&le(e);var i=n.attrHandle[t.toLowerCase()],r=i&&u.call(n.attrHandle,t.toLowerCase())?i(e,t,!h):void 0;return void 0!==r?r:e.getAttribute(t)},Q.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},w.uniqueSort=function(e){var t,i=[],n=0,a=0;if(l=!f.sortStable,s=!f.sortStable&&r.call(e,0),A.call(e,E),l){for(;t=e[a++];)t===e[a]&&(n=i.push(a));for(;n--;)L.call(e,i[n],1)}return s=null,e},w.fn.uniqueSort=function(){return this.pushStack(w.uniqueSort(r.apply(this)))},n=w.expr={cacheLength:50,createPseudo:te,match:W,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(G,Z),e[3]=(e[3]||e[4]||e[5]||"").replace(G,Z),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1].slice(0,3)?(e[3]||Q.error(e[0]),e[4]=+(e[4]?e[5]+(e[6]||1):2*("even"===e[3]||"odd"===e[3])),e[5]=+(e[7]+e[8]||"odd"===e[3])):e[3]&&Q.error(e[0]),e},PSEUDO:function(e){var t,i=!e[6]&&e[2];return W.CHILD.test(e[0])?null:(e[3]?e[2]=e[4]||e[5]||"":i&&B.test(i)&&(t=ue(i,!0))&&(t=i.indexOf(")",i.length-t)-i.length)&&(e[0]=e[0].slice(0,t),e[2]=i.slice(0,t)),e.slice(0,3))}},filter:{TAG:function(e){var t=e.replace(G,Z).toLowerCase();return"*"===e?function(){return!0}:function(e){return M(e,t)}},CLASS:function(e){var t=x[e+" "];return t||(t=new RegExp("(^|"+T+")"+e+"("+T+"|$)"))&&x(e,(function(e){return t.test("string"==typeof e.className&&e.className||void 0!==e.getAttribute&&e.getAttribute("class")||"")}))},ATTR:function(e,t,i){return function(n){var r=Q.attr(n,e);return null==r?"!="===t:!t||(r+="","="===t?r===i:"!="===t?r!==i:"^="===t?i&&0===r.indexOf(i):"*="===t?i&&r.indexOf(i)>-1:"$="===t?i&&r.slice(-i.length)===i:"~="===t?(" "+r.replace(H," ")+" ").indexOf(i)>-1:"|="===t&&(r===i||r.slice(0,i.length+1)===i+"-"))}},CHILD:function(e,t,i,n,r){var a="nth"!==e.slice(0,3),s="last"!==e.slice(-4),o="of-type"===t;return 1===n&&0===r?function(e){return!!e.parentNode}:function(t,i,l){var c,u,d,h,f,p=a!==s?"nextSibling":"previousSibling",m=t.parentNode,g=o&&t.nodeName.toLowerCase(),b=!l&&!o,x=!1;if(m){if(a){for(;p;){for(d=t;d=d[p];)if(o?M(d,g):1===d.nodeType)return!1;f=p="only"===e&&!f&&"nextSibling"}return!0}if(f=[s?m.firstChild:m.lastChild],s&&b){for(x=(h=(c=(u=m[v]||(m[v]={}))[e]||[])[0]===y&&c[1])&&c[2],d=h&&m.childNodes[h];d=++h&&d&&d[p]||(x=h=0)||f.pop();)if(1===d.nodeType&&++x&&d===t){u[e]=[y,h,x];break}}else if(b&&(x=h=(c=(u=t[v]||(t[v]={}))[e]||[])[0]===y&&c[1]),!1===x)for(;(d=++h&&d&&d[p]||(x=h=0)||f.pop())&&(!(o?M(d,g):1===d.nodeType)||!++x||(b&&((u=d[v]||(d[v]={}))[e]=[y,x]),d!==t)););return(x-=r)===n||x%n==0&&x/n>=0}}},PSEUDO:function(e,t){var i,r=n.pseudos[e]||n.setFilters[e.toLowerCase()]||Q.error("unsupported pseudo: "+e);return r[v]?r(t):r.length>1?(i=[e,e,"",t],n.setFilters.hasOwnProperty(e.toLowerCase())?te((function(e,i){for(var n,a=r(e,t),s=a.length;s--;)e[n=o.call(e,a[s])]=!(i[n]=a[s])})):function(e){return r(e,0,i)}):r}},pseudos:{not:te((function(e){var t=[],i=[],n=ve(e.replace(C,"$1"));return n[v]?te((function(e,t,i,r){for(var a,s=n(e,null,r,[]),o=e.length;o--;)(a=s[o])&&(e[o]=!(t[o]=a))})):function(e,r,a){return t[0]=e,n(t,null,a,i),t[0]=null,!i.pop()}})),has:te((function(e){return function(t){return Q(e,t).length>0}})),contains:te((function(e){return e=e.replace(G,Z),function(t){return(t.textContent||w.text(t)).indexOf(e)>-1}})),lang:te((function(e){return V.test(e||"")||Q.error("unsupported lang: "+e),e=e.replace(G,Z).toLowerCase(),function(t){var i;do{if(i=h?t.lang:t.getAttribute("xml:lang")||t.getAttribute("lang"))return(i=i.toLowerCase())===e||0===i.indexOf(e+"-")}while((t=t.parentNode)&&1===t.nodeType);return!1}})),target:function(t){var i=e.location&&e.location.hash;return i&&i.slice(1)===t.id},root:function(e){return e===d},focus:function(e){return e===function(){try{return c.activeElement}catch(e){}}()&&c.hasFocus()&&!!(e.type||e.href||~e.tabIndex)},enabled:ae(!1),disabled:ae(!0),checked:function(e){return M(e,"input")&&!!e.checked||M(e,"option")&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,!0===e.selected},empty:function(e){for(e=e.firstChild;e;e=e.nextSibling)if(e.nodeType<6)return!1;return!0},parent:function(e){return!n.pseudos.empty(e)},header:function(e){return q.test(e.nodeName)},input:function(e){return U.test(e.nodeName)},button:function(e){return M(e,"input")&&"button"===e.type||M(e,"button")},text:function(e){var t;return M(e,"input")&&"text"===e.type&&(null==(t=e.getAttribute("type"))||"text"===t.toLowerCase())},first:se((function(){return[0]})),last:se((function(e,t){return[t-1]})),eq:se((function(e,t,i){return[i<0?i+t:i]})),even:se((function(e,t){for(var i=0;i<t;i+=2)e.push(i);return e})),odd:se((function(e,t){for(var i=1;i<t;i+=2)e.push(i);return e})),lt:se((function(e,t,i){var n;for(n=i<0?i+t:i>t?t:i;--n>=0;)e.push(n);return e})),gt:se((function(e,t,i){for(var n=i<0?i+t:i;++n<t;)e.push(n);return e}))}},n.pseudos.nth=n.pseudos.eq,{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})n.pseudos[t]=ne(t);for(t in{submit:!0,reset:!0})n.pseudos[t]=re(t);function ce(){}function ue(e,t){var i,r,a,s,o,l,c,u=_[e+" "];if(u)return t?0:u.slice(0);for(o=e,l=[],c=n.preFilter;o;){for(s in i&&!(r=F.exec(o))||(r&&(o=o.slice(r[0].length)||o),l.push(a=[])),i=!1,(r=R.exec(o))&&(i=r.shift(),a.push({value:i,type:r[0].replace(C," ")}),o=o.slice(i.length)),n.filter)!(r=W[s].exec(o))||c[s]&&!(r=c[s](r))||(i=r.shift(),a.push({value:i,type:s,matches:r}),o=o.slice(i.length));if(!i)break}return t?o.length:o?Q.error(e):_(e,l).slice(0)}function de(e){for(var t=0,i=e.length,n="";t<i;t++)n+=e[t].value;return n}function he(e,t,i){var n=t.dir,r=t.next,a=r||n,s=i&&"parentNode"===a,o=b++;return t.first?function(t,i,r){for(;t=t[n];)if(1===t.nodeType||s)return e(t,i,r);return!1}:function(t,i,l){var c,u,d=[y,o];if(l){for(;t=t[n];)if((1===t.nodeType||s)&&e(t,i,l))return!0}else for(;t=t[n];)if(1===t.nodeType||s)if(u=t[v]||(t[v]={}),r&&M(t,r))t=t[n]||t;else{if((c=u[a])&&c[0]===y&&c[1]===o)return d[2]=c[2];if(u[a]=d,d[2]=e(t,i,l))return!0}return!1}}function fe(e){return e.length>1?function(t,i,n){for(var r=e.length;r--;)if(!e[r](t,i,n))return!1;return!0}:e[0]}function pe(e,t,i,n,r){for(var a,s=[],o=0,l=e.length,c=null!=t;o<l;o++)(a=e[o])&&(i&&!i(a,n,r)||(s.push(a),c&&t.push(o)));return s}function me(e,t,i,n,r,a){return n&&!n[v]&&(n=me(n)),r&&!r[v]&&(r=me(r,a)),te((function(a,s,l,c){var u,d,h,f,p=[],m=[],v=s.length,y=a||function(e,t,i){for(var n=0,r=t.length;n<r;n++)Q(e,t[n],i);return i}(t||"*",l.nodeType?[l]:l,[]),b=!e||!a&&t?y:pe(y,p,e,l,c);if(i?i(b,f=r||(a?e:v||n)?[]:s,l,c):f=b,n)for(u=pe(f,m),n(u,[],l,c),d=u.length;d--;)(h=u[d])&&(f[m[d]]=!(b[m[d]]=h));if(a){if(r||e){if(r){for(u=[],d=f.length;d--;)(h=f[d])&&u.push(b[d]=h);r(null,f=[],u,c)}for(d=f.length;d--;)(h=f[d])&&(u=r?o.call(a,h):p[d])>-1&&(a[u]=!(s[u]=h))}}else f=pe(f===s?f.splice(v,f.length):f),r?r(null,s,f,c):g.apply(s,f)}))}function ge(e){for(var t,i,r,s=e.length,l=n.relative[e[0].type],c=l||n.relative[" "],u=l?1:0,d=he((function(e){return e===t}),c,!0),h=he((function(e){return o.call(t,e)>-1}),c,!0),f=[function(e,i,n){var r=!l&&(n||i!=a)||((t=i).nodeType?d(e,i,n):h(e,i,n));return t=null,r}];u<s;u++)if(i=n.relative[e[u].type])f=[he(fe(f),i)];else{if((i=n.filter[e[u].type].apply(null,e[u].matches))[v]){for(r=++u;r<s&&!n.relative[e[r].type];r++);return me(u>1&&fe(f),u>1&&de(e.slice(0,u-1).concat({value:" "===e[u-2].type?"*":""})).replace(C,"$1"),i,u<r&&ge(e.slice(u,r)),r<s&&ge(e=e.slice(r)),r<s&&de(e))}f.push(i)}return fe(f)}function ve(e,t){var i,r=[],s=[],o=k[e+" "];if(!o){for(t||(t=ue(e)),i=t.length;i--;)(o=ge(t[i]))[v]?r.push(o):s.push(o);o=k(e,function(e,t){var i=t.length>0,r=e.length>0,s=function(s,o,l,u,d){var f,p,m,v=0,b="0",x=s&&[],_=[],k=a,M=s||r&&n.find.TAG("*",d),A=y+=null==k?1:Math.random()||.1,L=M.length;for(d&&(a=o==c||o||d);b!==L&&null!=(f=M[b]);b++){if(r&&f){for(p=0,o||f.ownerDocument==c||(le(f),l=!h);m=e[p++];)if(m(f,o||c,l)){g.call(u,f);break}d&&(y=A)}i&&((f=!m&&f)&&v--,s&&x.push(f))}if(v+=b,i&&b!==v){for(p=0;m=t[p++];)m(x,_,o,l);if(s){if(v>0)for(;b--;)x[b]||_[b]||(_[b]=S.call(u));_=pe(_)}g.apply(u,_),d&&!s&&_.length>0&&v+t.length>1&&w.uniqueSort(u)}return d&&(y=A,a=k),x};return i?te(s):s}(s,r)),o.selector=e}return o}function ye(e,t,i,r){var a,s,o,l,c,u="function"==typeof e&&e,d=!r&&ue(e=u.selector||e);if(i=i||[],1===d.length){if((s=d[0]=d[0].slice(0)).length>2&&"ID"===(o=s[0]).type&&9===t.nodeType&&h&&n.relative[s[1].type]){if(!(t=(n.find.ID(o.matches[0].replace(G,Z),t)||[])[0]))return i;u&&(t=t.parentNode),e=e.slice(s.shift().value.length)}for(a=W.needsContext.test(e)?0:s.length;a--&&(o=s[a],!n.relative[l=o.type]);)if((c=n.find[l])&&(r=c(o.matches[0].replace(G,Z),X.test(s[0].type)&&oe(t.parentNode)||t))){if(s.splice(a,1),!(e=r.length&&de(s)))return g.apply(i,r),i;break}}return(u||ve(e,d))(r,t,!h,i,!t||X.test(e)&&oe(t.parentNode)||t),i}ce.prototype=n.filters=n.pseudos,n.setFilters=new ce,f.sortStable=v.split("").sort(E).join("")===v,le(),f.sortDetached=ie((function(e){return 1&e.compareDocumentPosition(c.createElement("fieldset"))})),w.find=Q,w.expr[":"]=w.expr.pseudos,w.unique=w.uniqueSort,Q.compile=ve,Q.select=ye,Q.setDocument=le,Q.tokenize=ue,Q.escape=w.escapeSelector,Q.getText=w.text,Q.isXML=w.isXMLDoc,Q.selectors=w.expr,Q.support=w.support,Q.uniqueSort=w.uniqueSort}();var Y=function(e,t,i){for(var n=[],r=void 0!==i;(e=e[t])&&9!==e.nodeType;)if(1===e.nodeType){if(r&&w(e).is(i))break;n.push(e)}return n},I=function(e,t){for(var i=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&i.push(e);return i},N=w.expr.match.needsContext,j=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function H(e,t,i){return p(t)?w.grep(e,(function(e,n){return!!t.call(e,n,e)!==i})):t.nodeType?w.grep(e,(function(e){return e===t!==i})):"string"!=typeof t?w.grep(e,(function(e){return o.call(t,e)>-1!==i})):w.filter(t,e,i)}w.filter=function(e,t,i){var n=t[0];return i&&(e=":not("+e+")"),1===t.length&&1===n.nodeType?w.find.matchesSelector(n,e)?[n]:[]:w.find.matches(e,w.grep(t,(function(e){return 1===e.nodeType})))},w.fn.extend({find:function(e){var t,i,n=this.length,r=this;if("string"!=typeof e)return this.pushStack(w(e).filter((function(){for(t=0;t<n;t++)if(w.contains(r[t],this))return!0})));for(i=this.pushStack([]),t=0;t<n;t++)w.find(e,r[t],i);return n>1?w.uniqueSort(i):i},filter:function(e){return this.pushStack(H(this,e||[],!1))},not:function(e){return this.pushStack(H(this,e||[],!0))},is:function(e){return!!H(this,"string"==typeof e&&N.test(e)?w(e):e||[],!1).length}});var F,R=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(w.fn.init=function(e,t,i){var n,r;if(!e)return this;if(i=i||F,"string"==typeof e){if(!(n="<"===e[0]&&">"===e[e.length-1]&&e.length>=3?[null,e,null]:R.exec(e))||!n[1]&&t)return!t||t.jquery?(t||i).find(e):this.constructor(t).find(e);if(n[1]){if(t=t instanceof w?t[0]:t,w.merge(this,w.parseHTML(n[1],t&&t.nodeType?t.ownerDocument||t:g,!0)),j.test(n[1])&&w.isPlainObject(t))for(n in t)p(this[n])?this[n](t[n]):this.attr(n,t[n]);return this}return(r=g.getElementById(n[2]))&&(this[0]=r,this.length=1),this}return e.nodeType?(this[0]=e,this.length=1,this):p(e)?void 0!==i.ready?i.ready(e):e(w):w.makeArray(e,this)}).prototype=w.fn,F=w(g);var z=/^(?:parents|prev(?:Until|All))/,B={children:!0,contents:!0,next:!0,prev:!0};function V(e,t){for(;(e=e[t])&&1!==e.nodeType;);return e}w.fn.extend({has:function(e){var t=w(e,this),i=t.length;return this.filter((function(){for(var e=0;e<i;e++)if(w.contains(this,t[e]))return!0}))},closest:function(e,t){var i,n=0,r=this.length,a=[],s="string"!=typeof e&&w(e);if(!N.test(e))for(;n<r;n++)for(i=this[n];i&&i!==t;i=i.parentNode)if(i.nodeType<11&&(s?s.index(i)>-1:1===i.nodeType&&w.find.matchesSelector(i,e))){a.push(i);break}return this.pushStack(a.length>1?w.uniqueSort(a):a)},index:function(e){return e?"string"==typeof e?o.call(w(e),this[0]):o.call(this,e.jquery?e[0]:e):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(e,t){return this.pushStack(w.uniqueSort(w.merge(this.get(),w(e,t))))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),w.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return Y(e,"parentNode")},parentsUntil:function(e,t,i){return Y(e,"parentNode",i)},next:function(e){return V(e,"nextSibling")},prev:function(e){return V(e,"previousSibling")},nextAll:function(e){return Y(e,"nextSibling")},prevAll:function(e){return Y(e,"previousSibling")},nextUntil:function(e,t,i){return Y(e,"nextSibling",i)},prevUntil:function(e,t,i){return Y(e,"previousSibling",i)},siblings:function(e){return I((e.parentNode||{}).firstChild,e)},children:function(e){return I(e.firstChild)},contents:function(e){return null!=e.contentDocument&&n(e.contentDocument)?e.contentDocument:(M(e,"template")&&(e=e.content||e),w.merge([],e.childNodes))}},(function(e,t){w.fn[e]=function(i,n){var r=w.map(this,t,i);return"Until"!==e.slice(-5)&&(n=i),n&&"string"==typeof n&&(r=w.filter(n,r)),this.length>1&&(B[e]||w.uniqueSort(r),z.test(e)&&r.reverse()),this.pushStack(r)}}));var W=/[^\x20\t\r\n\f]+/g;function U(e){return e}function q(e){throw e}function $(e,t,i,n){var r;try{e&&p(r=e.promise)?r.call(e).done(t).fail(i):e&&p(r=e.then)?r.call(e,t,i):t.apply(void 0,[e].slice(n))}catch(e){i.apply(void 0,[e])}}w.Callbacks=function(e){e="string"==typeof e?function(e){var t={};return w.each(e.match(W)||[],(function(e,i){t[i]=!0})),t}(e):w.extend({},e);var t,i,n,r,a=[],s=[],o=-1,l=function(){for(r=r||e.once,n=t=!0;s.length;o=-1)for(i=s.shift();++o<a.length;)!1===a[o].apply(i[0],i[1])&&e.stopOnFalse&&(o=a.length,i=!1);e.memory||(i=!1),t=!1,r&&(a=i?[]:"")},c={add:function(){return a&&(i&&!t&&(o=a.length-1,s.push(i)),function t(i){w.each(i,(function(i,n){p(n)?e.unique&&c.has(n)||a.push(n):n&&n.length&&"string"!==b(n)&&t(n)}))}(arguments),i&&!t&&l()),this},remove:function(){return w.each(arguments,(function(e,t){for(var i;(i=w.inArray(t,a,i))>-1;)a.splice(i,1),i<=o&&o--})),this},has:function(e){return e?w.inArray(e,a)>-1:a.length>0},empty:function(){return a&&(a=[]),this},disable:function(){return r=s=[],a=i="",this},disabled:function(){return!a},lock:function(){return r=s=[],i||t||(a=i=""),this},locked:function(){return!!r},fireWith:function(e,i){return r||(i=[e,(i=i||[]).slice?i.slice():i],s.push(i),t||l()),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!n}};return c},w.extend({Deferred:function(t){var i=[["notify","progress",w.Callbacks("memory"),w.Callbacks("memory"),2],["resolve","done",w.Callbacks("once memory"),w.Callbacks("once memory"),0,"resolved"],["reject","fail",w.Callbacks("once memory"),w.Callbacks("once memory"),1,"rejected"]],n="pending",r={state:function(){return n},always:function(){return a.done(arguments).fail(arguments),this},catch:function(e){return r.then(null,e)},pipe:function(){var e=arguments;return w.Deferred((function(t){w.each(i,(function(i,n){var r=p(e[n[4]])&&e[n[4]];a[n[1]]((function(){var e=r&&r.apply(this,arguments);e&&p(e.promise)?e.promise().progress(t.notify).done(t.resolve).fail(t.reject):t[n[0]+"With"](this,r?[e]:arguments)}))})),e=null})).promise()},then:function(t,n,r){var a=0;function s(t,i,n,r){return function(){var o=this,l=arguments,c=function(){var e,c;if(!(t<a)){if((e=n.apply(o,l))===i.promise())throw new TypeError("Thenable self-resolution");c=e&&("object"==typeof e||"function"==typeof e)&&e.then,p(c)?r?c.call(e,s(a,i,U,r),s(a,i,q,r)):(a++,c.call(e,s(a,i,U,r),s(a,i,q,r),s(a,i,U,i.notifyWith))):(n!==U&&(o=void 0,l=[e]),(r||i.resolveWith)(o,l))}},u=r?c:function(){try{c()}catch(e){w.Deferred.exceptionHook&&w.Deferred.exceptionHook(e,u.error),t+1>=a&&(n!==q&&(o=void 0,l=[e]),i.rejectWith(o,l))}};t?u():(w.Deferred.getErrorHook?u.error=w.Deferred.getErrorHook():w.Deferred.getStackHook&&(u.error=w.Deferred.getStackHook()),e.setTimeout(u))}}return w.Deferred((function(e){i[0][3].add(s(0,e,p(r)?r:U,e.notifyWith)),i[1][3].add(s(0,e,p(t)?t:U)),i[2][3].add(s(0,e,p(n)?n:q))})).promise()},promise:function(e){return null!=e?w.extend(e,r):r}},a={};return w.each(i,(function(e,t){var s=t[2],o=t[5];r[t[1]]=s.add,o&&s.add((function(){n=o}),i[3-e][2].disable,i[3-e][3].disable,i[0][2].lock,i[0][3].lock),s.add(t[3].fire),a[t[0]]=function(){return a[t[0]+"With"](this===a?void 0:this,arguments),this},a[t[0]+"With"]=s.fireWith})),r.promise(a),t&&t.call(a,a),a},when:function(e){var t=arguments.length,i=t,n=Array(i),a=r.call(arguments),s=w.Deferred(),o=function(e){return function(i){n[e]=this,a[e]=arguments.length>1?r.call(arguments):i,--t||s.resolveWith(n,a)}};if(t<=1&&($(e,s.done(o(i)).resolve,s.reject,!t),"pending"===s.state()||p(a[i]&&a[i].then)))return s.then();for(;i--;)$(a[i],o(i),s.reject);return s.promise()}});var X=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;w.Deferred.exceptionHook=function(t,i){e.console&&e.console.warn&&t&&X.test(t.name)&&e.console.warn("jQuery.Deferred exception: "+t.message,t.stack,i)},w.readyException=function(t){e.setTimeout((function(){throw t}))};var G=w.Deferred();function Z(){g.removeEventListener("DOMContentLoaded",Z),e.removeEventListener("load",Z),w.ready()}w.fn.ready=function(e){return G.then(e).catch((function(e){w.readyException(e)})),this},w.extend({isReady:!1,readyWait:1,ready:function(e){(!0===e?--w.readyWait:w.isReady)||(w.isReady=!0,!0!==e&&--w.readyWait>0||G.resolveWith(g,[w]))}}),w.ready.then=G.then,"complete"===g.readyState||"loading"!==g.readyState&&!g.documentElement.doScroll?e.setTimeout(w.ready):(g.addEventListener("DOMContentLoaded",Z),e.addEventListener("load",Z));var K=function(e,t,i,n,r,a,s){var o=0,l=e.length,c=null==i;if("object"===b(i))for(o in r=!0,i)K(e,t,o,i[o],!0,a,s);else if(void 0!==n&&(r=!0,p(n)||(s=!0),c&&(s?(t.call(e,n),t=null):(c=t,t=function(e,t,i){return c.call(w(e),i)})),t))for(;o<l;o++)t(e[o],i,s?n:n.call(e[o],o,t(e[o],i)));return r?e:c?t.call(e):l?t(e[0],i):a},J=/^-ms-/,Q=/-([a-z])/g;function ee(e,t){return t.toUpperCase()}function te(e){return e.replace(J,"ms-").replace(Q,ee)}var ie=function(e){return 1===e.nodeType||9===e.nodeType||!+e.nodeType};function ne(){this.expando=w.expando+ne.uid++}ne.uid=1,ne.prototype={cache:function(e){var t=e[this.expando];return t||(t={},ie(e)&&(e.nodeType?e[this.expando]=t:Object.defineProperty(e,this.expando,{value:t,configurable:!0}))),t},set:function(e,t,i){var n,r=this.cache(e);if("string"==typeof t)r[te(t)]=i;else for(n in t)r[te(n)]=t[n];return r},get:function(e,t){return void 0===t?this.cache(e):e[this.expando]&&e[this.expando][te(t)]},access:function(e,t,i){return void 0===t||t&&"string"==typeof t&&void 0===i?this.get(e,t):(this.set(e,t,i),void 0!==i?i:t)},remove:function(e,t){var i,n=e[this.expando];if(void 0!==n){if(void 0!==t){i=(t=Array.isArray(t)?t.map(te):(t=te(t))in n?[t]:t.match(W)||[]).length;for(;i--;)delete n[t[i]]}(void 0===t||w.isEmptyObject(n))&&(e.nodeType?e[this.expando]=void 0:delete e[this.expando])}},hasData:function(e){var t=e[this.expando];return void 0!==t&&!w.isEmptyObject(t)}};var re=new ne,ae=new ne,se=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,oe=/[A-Z]/g;function le(e,t,i){var n;if(void 0===i&&1===e.nodeType)if(n="data-"+t.replace(oe,"-$&").toLowerCase(),"string"==typeof(i=e.getAttribute(n))){try{i=function(e){return"true"===e||"false"!==e&&("null"===e?null:e===+e+""?+e:se.test(e)?JSON.parse(e):e)}(i)}catch(e){}ae.set(e,t,i)}else i=void 0;return i}w.extend({hasData:function(e){return ae.hasData(e)||re.hasData(e)},data:function(e,t,i){return ae.access(e,t,i)},removeData:function(e,t){ae.remove(e,t)},_data:function(e,t,i){return re.access(e,t,i)},_removeData:function(e,t){re.remove(e,t)}}),w.fn.extend({data:function(e,t){var i,n,r,a=this[0],s=a&&a.attributes;if(void 0===e){if(this.length&&(r=ae.get(a),1===a.nodeType&&!re.get(a,"hasDataAttrs"))){for(i=s.length;i--;)s[i]&&0===(n=s[i].name).indexOf("data-")&&(n=te(n.slice(5)),le(a,n,r[n]));re.set(a,"hasDataAttrs",!0)}return r}return"object"==typeof e?this.each((function(){ae.set(this,e)})):K(this,(function(t){var i;if(a&&void 0===t)return void 0!==(i=ae.get(a,e))||void 0!==(i=le(a,e))?i:void 0;this.each((function(){ae.set(this,e,t)}))}),null,t,arguments.length>1,null,!0)},removeData:function(e){return this.each((function(){ae.remove(this,e)}))}}),w.extend({queue:function(e,t,i){var n;if(e)return t=(t||"fx")+"queue",n=re.get(e,t),i&&(!n||Array.isArray(i)?n=re.access(e,t,w.makeArray(i)):n.push(i)),n||[]},dequeue:function(e,t){t=t||"fx";var i=w.queue(e,t),n=i.length,r=i.shift(),a=w._queueHooks(e,t);"inprogress"===r&&(r=i.shift(),n--),r&&("fx"===t&&i.unshift("inprogress"),delete a.stop,r.call(e,(function(){w.dequeue(e,t)}),a)),!n&&a&&a.empty.fire()},_queueHooks:function(e,t){var i=t+"queueHooks";return re.get(e,i)||re.access(e,i,{empty:w.Callbacks("once memory").add((function(){re.remove(e,[t+"queue",i])}))})}}),w.fn.extend({queue:function(e,t){var i=2;return"string"!=typeof e&&(t=e,e="fx",i--),arguments.length<i?w.queue(this[0],e):void 0===t?this:this.each((function(){var i=w.queue(this,e,t);w._queueHooks(this,e),"fx"===e&&"inprogress"!==i[0]&&w.dequeue(this,e)}))},dequeue:function(e){return this.each((function(){w.dequeue(this,e)}))},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var i,n=1,r=w.Deferred(),a=this,s=this.length,o=function(){--n||r.resolveWith(a,[a])};for("string"!=typeof e&&(t=e,e=void 0),e=e||"fx";s--;)(i=re.get(a[s],e+"queueHooks"))&&i.empty&&(n++,i.empty.add(o));return o(),r.promise(t)}});var ce=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,ue=new RegExp("^(?:([+-])=|)("+ce+")([a-z%]*)$","i"),de=["Top","Right","Bottom","Left"],he=g.documentElement,fe=function(e){return w.contains(e.ownerDocument,e)},pe={composed:!0};he.getRootNode&&(fe=function(e){return w.contains(e.ownerDocument,e)||e.getRootNode(pe)===e.ownerDocument});var me=function(e,t){return"none"===(e=t||e).style.display||""===e.style.display&&fe(e)&&"none"===w.css(e,"display")};function ge(e,t,i,n){var r,a,s=20,o=n?function(){return n.cur()}:function(){return w.css(e,t,"")},l=o(),c=i&&i[3]||(w.cssNumber[t]?"":"px"),u=e.nodeType&&(w.cssNumber[t]||"px"!==c&&+l)&&ue.exec(w.css(e,t));if(u&&u[3]!==c){for(l/=2,c=c||u[3],u=+l||1;s--;)w.style(e,t,u+c),(1-a)*(1-(a=o()/l||.5))<=0&&(s=0),u/=a;u*=2,w.style(e,t,u+c),i=i||[]}return i&&(u=+u||+l||0,r=i[1]?u+(i[1]+1)*i[2]:+i[2],n&&(n.unit=c,n.start=u,n.end=r)),r}var ve={};function ye(e){var t,i=e.ownerDocument,n=e.nodeName,r=ve[n];return r||(t=i.body.appendChild(i.createElement(n)),r=w.css(t,"display"),t.parentNode.removeChild(t),"none"===r&&(r="block"),ve[n]=r,r)}function be(e,t){for(var i,n,r=[],a=0,s=e.length;a<s;a++)(n=e[a]).style&&(i=n.style.display,t?("none"===i&&(r[a]=re.get(n,"display")||null,r[a]||(n.style.display="")),""===n.style.display&&me(n)&&(r[a]=ye(n))):"none"!==i&&(r[a]="none",re.set(n,"display",i)));for(a=0;a<s;a++)null!=r[a]&&(e[a].style.display=r[a]);return e}w.fn.extend({show:function(){return be(this,!0)},hide:function(){return be(this)},toggle:function(e){return"boolean"==typeof e?e?this.show():this.hide():this.each((function(){me(this)?w(this).show():w(this).hide()}))}});var xe,_e,we=/^(?:checkbox|radio)$/i,ke=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,Me=/^$|^module$|\/(?:java|ecma)script/i;xe=g.createDocumentFragment().appendChild(g.createElement("div")),(_e=g.createElement("input")).setAttribute("type","radio"),_e.setAttribute("checked","checked"),_e.setAttribute("name","t"),xe.appendChild(_e),f.checkClone=xe.cloneNode(!0).cloneNode(!0).lastChild.checked,xe.innerHTML="<textarea>x</textarea>",f.noCloneChecked=!!xe.cloneNode(!0).lastChild.defaultValue,xe.innerHTML="<option></option>",f.option=!!xe.lastChild;var Se={thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};function Ae(e,t){var i;return i=void 0!==e.getElementsByTagName?e.getElementsByTagName(t||"*"):void 0!==e.querySelectorAll?e.querySelectorAll(t||"*"):[],void 0===t||t&&M(e,t)?w.merge([e],i):i}function Le(e,t){for(var i=0,n=e.length;i<n;i++)re.set(e[i],"globalEval",!t||re.get(t[i],"globalEval"))}Se.tbody=Se.tfoot=Se.colgroup=Se.caption=Se.thead,Se.th=Se.td,f.option||(Se.optgroup=Se.option=[1,"<select multiple='multiple'>","</select>"]);var Te=/<|&#?\w+;/;function Ce(e,t,i,n,r){for(var a,s,o,l,c,u,d=t.createDocumentFragment(),h=[],f=0,p=e.length;f<p;f++)if((a=e[f])||0===a)if("object"===b(a))w.merge(h,a.nodeType?[a]:a);else if(Te.test(a)){for(s=s||d.appendChild(t.createElement("div")),o=(ke.exec(a)||["",""])[1].toLowerCase(),l=Se[o]||Se._default,s.innerHTML=l[1]+w.htmlPrefilter(a)+l[2],u=l[0];u--;)s=s.lastChild;w.merge(h,s.childNodes),(s=d.firstChild).textContent=""}else h.push(t.createTextNode(a));for(d.textContent="",f=0;a=h[f++];)if(n&&w.inArray(a,n)>-1)r&&r.push(a);else if(c=fe(a),s=Ae(d.appendChild(a),"script"),c&&Le(s),i)for(u=0;a=s[u++];)Me.test(a.type||"")&&i.push(a);return d}var De=/^([^.]*)(?:\.(.+)|)/;function Ee(){return!0}function Oe(){return!1}function Pe(e,t,i,n,r,a){var s,o;if("object"==typeof t){for(o in"string"!=typeof i&&(n=n||i,i=void 0),t)Pe(e,o,i,n,t[o],a);return e}if(null==n&&null==r?(r=i,n=i=void 0):null==r&&("string"==typeof i?(r=n,n=void 0):(r=n,n=i,i=void 0)),!1===r)r=Oe;else if(!r)return e;return 1===a&&(s=r,r=function(e){return w().off(e),s.apply(this,arguments)},r.guid=s.guid||(s.guid=w.guid++)),e.each((function(){w.event.add(this,t,r,n,i)}))}function Ye(e,t,i){i?(re.set(e,t,!1),w.event.add(e,t,{namespace:!1,handler:function(e){var i,n=re.get(this,t);if(1&e.isTrigger&&this[t]){if(n)(w.event.special[t]||{}).delegateType&&e.stopPropagation();else if(n=r.call(arguments),re.set(this,t,n),this[t](),i=re.get(this,t),re.set(this,t,!1),n!==i)return e.stopImmediatePropagation(),e.preventDefault(),i}else n&&(re.set(this,t,w.event.trigger(n[0],n.slice(1),this)),e.stopPropagation(),e.isImmediatePropagationStopped=Ee)}})):void 0===re.get(e,t)&&w.event.add(e,t,Ee)}w.event={global:{},add:function(e,t,i,n,r){var a,s,o,l,c,u,d,h,f,p,m,g=re.get(e);if(ie(e))for(i.handler&&(i=(a=i).handler,r=a.selector),r&&w.find.matchesSelector(he,r),i.guid||(i.guid=w.guid++),(l=g.events)||(l=g.events=Object.create(null)),(s=g.handle)||(s=g.handle=function(t){return void 0!==w&&w.event.triggered!==t.type?w.event.dispatch.apply(e,arguments):void 0}),c=(t=(t||"").match(W)||[""]).length;c--;)f=m=(o=De.exec(t[c])||[])[1],p=(o[2]||"").split(".").sort(),f&&(d=w.event.special[f]||{},f=(r?d.delegateType:d.bindType)||f,d=w.event.special[f]||{},u=w.extend({type:f,origType:m,data:n,handler:i,guid:i.guid,selector:r,needsContext:r&&w.expr.match.needsContext.test(r),namespace:p.join(".")},a),(h=l[f])||((h=l[f]=[]).delegateCount=0,d.setup&&!1!==d.setup.call(e,n,p,s)||e.addEventListener&&e.addEventListener(f,s)),d.add&&(d.add.call(e,u),u.handler.guid||(u.handler.guid=i.guid)),r?h.splice(h.delegateCount++,0,u):h.push(u),w.event.global[f]=!0)},remove:function(e,t,i,n,r){var a,s,o,l,c,u,d,h,f,p,m,g=re.hasData(e)&&re.get(e);if(g&&(l=g.events)){for(c=(t=(t||"").match(W)||[""]).length;c--;)if(f=m=(o=De.exec(t[c])||[])[1],p=(o[2]||"").split(".").sort(),f){for(d=w.event.special[f]||{},h=l[f=(n?d.delegateType:d.bindType)||f]||[],o=o[2]&&new RegExp("(^|\\.)"+p.join("\\.(?:.*\\.|)")+"(\\.|$)"),s=a=h.length;a--;)u=h[a],!r&&m!==u.origType||i&&i.guid!==u.guid||o&&!o.test(u.namespace)||n&&n!==u.selector&&("**"!==n||!u.selector)||(h.splice(a,1),u.selector&&h.delegateCount--,d.remove&&d.remove.call(e,u));s&&!h.length&&(d.teardown&&!1!==d.teardown.call(e,p,g.handle)||w.removeEvent(e,f,g.handle),delete l[f])}else for(f in l)w.event.remove(e,f+t[c],i,n,!0);w.isEmptyObject(l)&&re.remove(e,"handle events")}},dispatch:function(e){var t,i,n,r,a,s,o=new Array(arguments.length),l=w.event.fix(e),c=(re.get(this,"events")||Object.create(null))[l.type]||[],u=w.event.special[l.type]||{};for(o[0]=l,t=1;t<arguments.length;t++)o[t]=arguments[t];if(l.delegateTarget=this,!u.preDispatch||!1!==u.preDispatch.call(this,l)){for(s=w.event.handlers.call(this,l,c),t=0;(r=s[t++])&&!l.isPropagationStopped();)for(l.currentTarget=r.elem,i=0;(a=r.handlers[i++])&&!l.isImmediatePropagationStopped();)l.rnamespace&&!1!==a.namespace&&!l.rnamespace.test(a.namespace)||(l.handleObj=a,l.data=a.data,void 0!==(n=((w.event.special[a.origType]||{}).handle||a.handler).apply(r.elem,o))&&!1===(l.result=n)&&(l.preventDefault(),l.stopPropagation()));return u.postDispatch&&u.postDispatch.call(this,l),l.result}},handlers:function(e,t){var i,n,r,a,s,o=[],l=t.delegateCount,c=e.target;if(l&&c.nodeType&&!("click"===e.type&&e.button>=1))for(;c!==this;c=c.parentNode||this)if(1===c.nodeType&&("click"!==e.type||!0!==c.disabled)){for(a=[],s={},i=0;i<l;i++)void 0===s[r=(n=t[i]).selector+" "]&&(s[r]=n.needsContext?w(r,this).index(c)>-1:w.find(r,this,null,[c]).length),s[r]&&a.push(n);a.length&&o.push({elem:c,handlers:a})}return c=this,l<t.length&&o.push({elem:c,handlers:t.slice(l)}),o},addProp:function(e,t){Object.defineProperty(w.Event.prototype,e,{enumerable:!0,configurable:!0,get:p(t)?function(){if(this.originalEvent)return t(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[e]},set:function(t){Object.defineProperty(this,e,{enumerable:!0,configurable:!0,writable:!0,value:t})}})},fix:function(e){return e[w.expando]?e:new w.Event(e)},special:{load:{noBubble:!0},click:{setup:function(e){var t=this||e;return we.test(t.type)&&t.click&&M(t,"input")&&Ye(t,"click",!0),!1},trigger:function(e){var t=this||e;return we.test(t.type)&&t.click&&M(t,"input")&&Ye(t,"click"),!0},_default:function(e){var t=e.target;return we.test(t.type)&&t.click&&M(t,"input")&&re.get(t,"click")||M(t,"a")}},beforeunload:{postDispatch:function(e){void 0!==e.result&&e.originalEvent&&(e.originalEvent.returnValue=e.result)}}}},w.removeEvent=function(e,t,i){e.removeEventListener&&e.removeEventListener(t,i)},w.Event=function(e,t){if(!(this instanceof w.Event))return new w.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||void 0===e.defaultPrevented&&!1===e.returnValue?Ee:Oe,this.target=e.target&&3===e.target.nodeType?e.target.parentNode:e.target,this.currentTarget=e.currentTarget,this.relatedTarget=e.relatedTarget):this.type=e,t&&w.extend(this,t),this.timeStamp=e&&e.timeStamp||Date.now(),this[w.expando]=!0},w.Event.prototype={constructor:w.Event,isDefaultPrevented:Oe,isPropagationStopped:Oe,isImmediatePropagationStopped:Oe,isSimulated:!1,preventDefault:function(){var e=this.originalEvent;this.isDefaultPrevented=Ee,e&&!this.isSimulated&&e.preventDefault()},stopPropagation:function(){var e=this.originalEvent;this.isPropagationStopped=Ee,e&&!this.isSimulated&&e.stopPropagation()},stopImmediatePropagation:function(){var e=this.originalEvent;this.isImmediatePropagationStopped=Ee,e&&!this.isSimulated&&e.stopImmediatePropagation(),this.stopPropagation()}},w.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:!0},w.event.addProp),w.each({focus:"focusin",blur:"focusout"},(function(e,t){function i(e){if(g.documentMode){var i=re.get(this,"handle"),n=w.event.fix(e);n.type="focusin"===e.type?"focus":"blur",n.isSimulated=!0,i(e),n.target===n.currentTarget&&i(n)}else w.event.simulate(t,e.target,w.event.fix(e))}w.event.special[e]={setup:function(){var n;if(Ye(this,e,!0),!g.documentMode)return!1;(n=re.get(this,t))||this.addEventListener(t,i),re.set(this,t,(n||0)+1)},trigger:function(){return Ye(this,e),!0},teardown:function(){var e;if(!g.documentMode)return!1;(e=re.get(this,t)-1)?re.set(this,t,e):(this.removeEventListener(t,i),re.remove(this,t))},_default:function(t){return re.get(t.target,e)},delegateType:t},w.event.special[t]={setup:function(){var n=this.ownerDocument||this.document||this,r=g.documentMode?this:n,a=re.get(r,t);a||(g.documentMode?this.addEventListener(t,i):n.addEventListener(e,i,!0)),re.set(r,t,(a||0)+1)},teardown:function(){var n=this.ownerDocument||this.document||this,r=g.documentMode?this:n,a=re.get(r,t)-1;a?re.set(r,t,a):(g.documentMode?this.removeEventListener(t,i):n.removeEventListener(e,i,!0),re.remove(r,t))}}})),w.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},(function(e,t){w.event.special[e]={delegateType:t,bindType:t,handle:function(e){var i,n=e.relatedTarget,r=e.handleObj;return n&&(n===this||w.contains(this,n))||(e.type=r.origType,i=r.handler.apply(this,arguments),e.type=t),i}}})),w.fn.extend({on:function(e,t,i,n){return Pe(this,e,t,i,n)},one:function(e,t,i,n){return Pe(this,e,t,i,n,1)},off:function(e,t,i){var n,r;if(e&&e.preventDefault&&e.handleObj)return n=e.handleObj,w(e.delegateTarget).off(n.namespace?n.origType+"."+n.namespace:n.origType,n.selector,n.handler),this;if("object"==typeof e){for(r in e)this.off(r,t,e[r]);return this}return!1!==t&&"function"!=typeof t||(i=t,t=void 0),!1===i&&(i=Oe),this.each((function(){w.event.remove(this,e,i,t)}))}});var Ie=/<script|<style|<link/i,Ne=/checked\s*(?:[^=]|=\s*.checked.)/i,je=/^\s*<!\[CDATA\[|\]\]>\s*$/g;function He(e,t){return M(e,"table")&&M(11!==t.nodeType?t:t.firstChild,"tr")&&w(e).children("tbody")[0]||e}function Fe(e){return e.type=(null!==e.getAttribute("type"))+"/"+e.type,e}function Re(e){return"true/"===(e.type||"").slice(0,5)?e.type=e.type.slice(5):e.removeAttribute("type"),e}function ze(e,t){var i,n,r,a,s,o;if(1===t.nodeType){if(re.hasData(e)&&(o=re.get(e).events))for(r in re.remove(t,"handle events"),o)for(i=0,n=o[r].length;i<n;i++)w.event.add(t,r,o[r][i]);ae.hasData(e)&&(a=ae.access(e),s=w.extend({},a),ae.set(t,s))}}function Be(e,t){var i=t.nodeName.toLowerCase();"input"===i&&we.test(e.type)?t.checked=e.checked:"input"!==i&&"textarea"!==i||(t.defaultValue=e.defaultValue)}function Ve(e,t,i,n){t=a(t);var r,s,o,l,c,u,d=0,h=e.length,m=h-1,g=t[0],v=p(g);if(v||h>1&&"string"==typeof g&&!f.checkClone&&Ne.test(g))return e.each((function(r){var a=e.eq(r);v&&(t[0]=g.call(this,r,a.html())),Ve(a,t,i,n)}));if(h&&(s=(r=Ce(t,e[0].ownerDocument,!1,e,n)).firstChild,1===r.childNodes.length&&(r=s),s||n)){for(l=(o=w.map(Ae(r,"script"),Fe)).length;d<h;d++)c=r,d!==m&&(c=w.clone(c,!0,!0),l&&w.merge(o,Ae(c,"script"))),i.call(e[d],c,d);if(l)for(u=o[o.length-1].ownerDocument,w.map(o,Re),d=0;d<l;d++)c=o[d],Me.test(c.type||"")&&!re.access(c,"globalEval")&&w.contains(u,c)&&(c.src&&"module"!==(c.type||"").toLowerCase()?w._evalUrl&&!c.noModule&&w._evalUrl(c.src,{nonce:c.nonce||c.getAttribute("nonce")},u):y(c.textContent.replace(je,""),c,u))}return e}function We(e,t,i){for(var n,r=t?w.filter(t,e):e,a=0;null!=(n=r[a]);a++)i||1!==n.nodeType||w.cleanData(Ae(n)),n.parentNode&&(i&&fe(n)&&Le(Ae(n,"script")),n.parentNode.removeChild(n));return e}w.extend({htmlPrefilter:function(e){return e},clone:function(e,t,i){var n,r,a,s,o=e.cloneNode(!0),l=fe(e);if(!(f.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||w.isXMLDoc(e)))for(s=Ae(o),n=0,r=(a=Ae(e)).length;n<r;n++)Be(a[n],s[n]);if(t)if(i)for(a=a||Ae(e),s=s||Ae(o),n=0,r=a.length;n<r;n++)ze(a[n],s[n]);else ze(e,o);return(s=Ae(o,"script")).length>0&&Le(s,!l&&Ae(e,"script")),o},cleanData:function(e){for(var t,i,n,r=w.event.special,a=0;void 0!==(i=e[a]);a++)if(ie(i)){if(t=i[re.expando]){if(t.events)for(n in t.events)r[n]?w.event.remove(i,n):w.removeEvent(i,n,t.handle);i[re.expando]=void 0}i[ae.expando]&&(i[ae.expando]=void 0)}}}),w.fn.extend({detach:function(e){return We(this,e,!0)},remove:function(e){return We(this,e)},text:function(e){return K(this,(function(e){return void 0===e?w.text(this):this.empty().each((function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=e)}))}),null,e,arguments.length)},append:function(){return Ve(this,arguments,(function(e){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||He(this,e).appendChild(e)}))},prepend:function(){return Ve(this,arguments,(function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=He(this,e);t.insertBefore(e,t.firstChild)}}))},before:function(){return Ve(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this)}))},after:function(){return Ve(this,arguments,(function(e){this.parentNode&&this.parentNode.insertBefore(e,this.nextSibling)}))},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)1===e.nodeType&&(w.cleanData(Ae(e,!1)),e.textContent="");return this},clone:function(e,t){return e=null!=e&&e,t=null==t?e:t,this.map((function(){return w.clone(this,e,t)}))},html:function(e){return K(this,(function(e){var t=this[0]||{},i=0,n=this.length;if(void 0===e&&1===t.nodeType)return t.innerHTML;if("string"==typeof e&&!Ie.test(e)&&!Se[(ke.exec(e)||["",""])[1].toLowerCase()]){e=w.htmlPrefilter(e);try{for(;i<n;i++)1===(t=this[i]||{}).nodeType&&(w.cleanData(Ae(t,!1)),t.innerHTML=e);t=0}catch(e){}}t&&this.empty().append(e)}),null,e,arguments.length)},replaceWith:function(){var e=[];return Ve(this,arguments,(function(t){var i=this.parentNode;w.inArray(this,e)<0&&(w.cleanData(Ae(this)),i&&i.replaceChild(t,this))}),e)}}),w.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},(function(e,t){w.fn[e]=function(e){for(var i,n=[],r=w(e),a=r.length-1,o=0;o<=a;o++)i=o===a?this:this.clone(!0),w(r[o])[t](i),s.apply(n,i.get());return this.pushStack(n)}}));var Ue=new RegExp("^("+ce+")(?!px)[a-z%]+$","i"),qe=/^--/,$e=function(t){var i=t.ownerDocument.defaultView;return i&&i.opener||(i=e),i.getComputedStyle(t)},Xe=function(e,t,i){var n,r,a={};for(r in t)a[r]=e.style[r],e.style[r]=t[r];for(r in n=i.call(e),t)e.style[r]=a[r];return n},Ge=new RegExp(de.join("|"),"i");function Ze(e,t,i){var n,r,a,s,o=qe.test(t),l=e.style;return(i=i||$e(e))&&(s=i.getPropertyValue(t)||i[t],o&&s&&(s=s.replace(C,"$1")||void 0),""!==s||fe(e)||(s=w.style(e,t)),!f.pixelBoxStyles()&&Ue.test(s)&&Ge.test(t)&&(n=l.width,r=l.minWidth,a=l.maxWidth,l.minWidth=l.maxWidth=l.width=s,s=i.width,l.width=n,l.minWidth=r,l.maxWidth=a)),void 0!==s?s+"":s}function Ke(e,t){return{get:function(){if(!e())return(this.get=t).apply(this,arguments);delete this.get}}}!function(){function t(){if(u){c.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",u.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",he.appendChild(c).appendChild(u);var t=e.getComputedStyle(u);n="1%"!==t.top,l=12===i(t.marginLeft),u.style.right="60%",s=36===i(t.right),r=36===i(t.width),u.style.position="absolute",a=12===i(u.offsetWidth/3),he.removeChild(c),u=null}}function i(e){return Math.round(parseFloat(e))}var n,r,a,s,o,l,c=g.createElement("div"),u=g.createElement("div");u.style&&(u.style.backgroundClip="content-box",u.cloneNode(!0).style.backgroundClip="",f.clearCloneStyle="content-box"===u.style.backgroundClip,w.extend(f,{boxSizingReliable:function(){return t(),r},pixelBoxStyles:function(){return t(),s},pixelPosition:function(){return t(),n},reliableMarginLeft:function(){return t(),l},scrollboxSize:function(){return t(),a},reliableTrDimensions:function(){var t,i,n,r;return null==o&&(t=g.createElement("table"),i=g.createElement("tr"),n=g.createElement("div"),t.style.cssText="position:absolute;left:-11111px;border-collapse:separate",i.style.cssText="box-sizing:content-box;border:1px solid",i.style.height="1px",n.style.height="9px",n.style.display="block",he.appendChild(t).appendChild(i).appendChild(n),r=e.getComputedStyle(i),o=parseInt(r.height,10)+parseInt(r.borderTopWidth,10)+parseInt(r.borderBottomWidth,10)===i.offsetHeight,he.removeChild(t)),o}}))}();var Je=["Webkit","Moz","ms"],Qe=g.createElement("div").style,et={};function tt(e){var t=w.cssProps[e]||et[e];return t||(e in Qe?e:et[e]=function(e){for(var t=e[0].toUpperCase()+e.slice(1),i=Je.length;i--;)if((e=Je[i]+t)in Qe)return e}(e)||e)}var it=/^(none|table(?!-c[ea]).+)/,nt={position:"absolute",visibility:"hidden",display:"block"},rt={letterSpacing:"0",fontWeight:"400"};function at(e,t,i){var n=ue.exec(t);return n?Math.max(0,n[2]-(i||0))+(n[3]||"px"):t}function st(e,t,i,n,r,a){var s="width"===t?1:0,o=0,l=0,c=0;if(i===(n?"border":"content"))return 0;for(;s<4;s+=2)"margin"===i&&(c+=w.css(e,i+de[s],!0,r)),n?("content"===i&&(l-=w.css(e,"padding"+de[s],!0,r)),"margin"!==i&&(l-=w.css(e,"border"+de[s]+"Width",!0,r))):(l+=w.css(e,"padding"+de[s],!0,r),"padding"!==i?l+=w.css(e,"border"+de[s]+"Width",!0,r):o+=w.css(e,"border"+de[s]+"Width",!0,r));return!n&&a>=0&&(l+=Math.max(0,Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-a-l-o-.5))||0),l+c}function ot(e,t,i){var n=$e(e),r=(!f.boxSizingReliable()||i)&&"border-box"===w.css(e,"boxSizing",!1,n),a=r,s=Ze(e,t,n),o="offset"+t[0].toUpperCase()+t.slice(1);if(Ue.test(s)){if(!i)return s;s="auto"}return(!f.boxSizingReliable()&&r||!f.reliableTrDimensions()&&M(e,"tr")||"auto"===s||!parseFloat(s)&&"inline"===w.css(e,"display",!1,n))&&e.getClientRects().length&&(r="border-box"===w.css(e,"boxSizing",!1,n),(a=o in e)&&(s=e[o])),(s=parseFloat(s)||0)+st(e,t,i||(r?"border":"content"),a,n,s)+"px"}function lt(e,t,i,n,r){return new lt.prototype.init(e,t,i,n,r)}w.extend({cssHooks:{opacity:{get:function(e,t){if(t){var i=Ze(e,"opacity");return""===i?"1":i}}}},cssNumber:{animationIterationCount:!0,aspectRatio:!0,borderImageSlice:!0,columnCount:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,scale:!0,widows:!0,zIndex:!0,zoom:!0,fillOpacity:!0,floodOpacity:!0,stopOpacity:!0,strokeMiterlimit:!0,strokeOpacity:!0},cssProps:{},style:function(e,t,i,n){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var r,a,s,o=te(t),l=qe.test(t),c=e.style;if(l||(t=tt(o)),s=w.cssHooks[t]||w.cssHooks[o],void 0===i)return s&&"get"in s&&void 0!==(r=s.get(e,!1,n))?r:c[t];"string"===(a=typeof i)&&(r=ue.exec(i))&&r[1]&&(i=ge(e,t,r),a="number"),null!=i&&i==i&&("number"!==a||l||(i+=r&&r[3]||(w.cssNumber[o]?"":"px")),f.clearCloneStyle||""!==i||0!==t.indexOf("background")||(c[t]="inherit"),s&&"set"in s&&void 0===(i=s.set(e,i,n))||(l?c.setProperty(t,i):c[t]=i))}},css:function(e,t,i,n){var r,a,s,o=te(t);return qe.test(t)||(t=tt(o)),(s=w.cssHooks[t]||w.cssHooks[o])&&"get"in s&&(r=s.get(e,!0,i)),void 0===r&&(r=Ze(e,t,n)),"normal"===r&&t in rt&&(r=rt[t]),""===i||i?(a=parseFloat(r),!0===i||isFinite(a)?a||0:r):r}}),w.each(["height","width"],(function(e,t){w.cssHooks[t]={get:function(e,i,n){if(i)return!it.test(w.css(e,"display"))||e.getClientRects().length&&e.getBoundingClientRect().width?ot(e,t,n):Xe(e,nt,(function(){return ot(e,t,n)}))},set:function(e,i,n){var r,a=$e(e),s=!f.scrollboxSize()&&"absolute"===a.position,o=(s||n)&&"border-box"===w.css(e,"boxSizing",!1,a),l=n?st(e,t,n,o,a):0;return o&&s&&(l-=Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-parseFloat(a[t])-st(e,t,"border",!1,a)-.5)),l&&(r=ue.exec(i))&&"px"!==(r[3]||"px")&&(e.style[t]=i,i=w.css(e,t)),at(0,i,l)}}})),w.cssHooks.marginLeft=Ke(f.reliableMarginLeft,(function(e,t){if(t)return(parseFloat(Ze(e,"marginLeft"))||e.getBoundingClientRect().left-Xe(e,{marginLeft:0},(function(){return e.getBoundingClientRect().left})))+"px"})),w.each({margin:"",padding:"",border:"Width"},(function(e,t){w.cssHooks[e+t]={expand:function(i){for(var n=0,r={},a="string"==typeof i?i.split(" "):[i];n<4;n++)r[e+de[n]+t]=a[n]||a[n-2]||a[0];return r}},"margin"!==e&&(w.cssHooks[e+t].set=at)})),w.fn.extend({css:function(e,t){return K(this,(function(e,t,i){var n,r,a={},s=0;if(Array.isArray(t)){for(n=$e(e),r=t.length;s<r;s++)a[t[s]]=w.css(e,t[s],!1,n);return a}return void 0!==i?w.style(e,t,i):w.css(e,t)}),e,t,arguments.length>1)}}),w.Tween=lt,lt.prototype={constructor:lt,init:function(e,t,i,n,r,a){this.elem=e,this.prop=i,this.easing=r||w.easing._default,this.options=t,this.start=this.now=this.cur(),this.end=n,this.unit=a||(w.cssNumber[i]?"":"px")},cur:function(){var e=lt.propHooks[this.prop];return e&&e.get?e.get(this):lt.propHooks._default.get(this)},run:function(e){var t,i=lt.propHooks[this.prop];return this.options.duration?this.pos=t=w.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),i&&i.set?i.set(this):lt.propHooks._default.set(this),this}},lt.prototype.init.prototype=lt.prototype,lt.propHooks={_default:{get:function(e){var t;return 1!==e.elem.nodeType||null!=e.elem[e.prop]&&null==e.elem.style[e.prop]?e.elem[e.prop]:(t=w.css(e.elem,e.prop,""))&&"auto"!==t?t:0},set:function(e){w.fx.step[e.prop]?w.fx.step[e.prop](e):1!==e.elem.nodeType||!w.cssHooks[e.prop]&&null==e.elem.style[tt(e.prop)]?e.elem[e.prop]=e.now:w.style(e.elem,e.prop,e.now+e.unit)}}},lt.propHooks.scrollTop=lt.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},w.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},_default:"swing"},w.fx=lt.prototype.init,w.fx.step={};var ct,ut,dt=/^(?:toggle|show|hide)$/,ht=/queueHooks$/;function ft(){ut&&(!1===g.hidden&&e.requestAnimationFrame?e.requestAnimationFrame(ft):e.setTimeout(ft,w.fx.interval),w.fx.tick())}function pt(){return e.setTimeout((function(){ct=void 0})),ct=Date.now()}function mt(e,t){var i,n=0,r={height:e};for(t=t?1:0;n<4;n+=2-t)r["margin"+(i=de[n])]=r["padding"+i]=e;return t&&(r.opacity=r.width=e),r}function gt(e,t,i){for(var n,r=(vt.tweeners[t]||[]).concat(vt.tweeners["*"]),a=0,s=r.length;a<s;a++)if(n=r[a].call(i,t,e))return n}function vt(e,t,i){var n,r,a=0,s=vt.prefilters.length,o=w.Deferred().always((function(){delete l.elem})),l=function(){if(r)return!1;for(var t=ct||pt(),i=Math.max(0,c.startTime+c.duration-t),n=1-(i/c.duration||0),a=0,s=c.tweens.length;a<s;a++)c.tweens[a].run(n);return o.notifyWith(e,[c,n,i]),n<1&&s?i:(s||o.notifyWith(e,[c,1,0]),o.resolveWith(e,[c]),!1)},c=o.promise({elem:e,props:w.extend({},t),opts:w.extend(!0,{specialEasing:{},easing:w.easing._default},i),originalProperties:t,originalOptions:i,startTime:ct||pt(),duration:i.duration,tweens:[],createTween:function(t,i){var n=w.Tween(e,c.opts,t,i,c.opts.specialEasing[t]||c.opts.easing);return c.tweens.push(n),n},stop:function(t){var i=0,n=t?c.tweens.length:0;if(r)return this;for(r=!0;i<n;i++)c.tweens[i].run(1);return t?(o.notifyWith(e,[c,1,0]),o.resolveWith(e,[c,t])):o.rejectWith(e,[c,t]),this}}),u=c.props;for(!function(e,t){var i,n,r,a,s;for(i in e)if(r=t[n=te(i)],a=e[i],Array.isArray(a)&&(r=a[1],a=e[i]=a[0]),i!==n&&(e[n]=a,delete e[i]),(s=w.cssHooks[n])&&"expand"in s)for(i in a=s.expand(a),delete e[n],a)i in e||(e[i]=a[i],t[i]=r);else t[n]=r}(u,c.opts.specialEasing);a<s;a++)if(n=vt.prefilters[a].call(c,e,u,c.opts))return p(n.stop)&&(w._queueHooks(c.elem,c.opts.queue).stop=n.stop.bind(n)),n;return w.map(u,gt,c),p(c.opts.start)&&c.opts.start.call(e,c),c.progress(c.opts.progress).done(c.opts.done,c.opts.complete).fail(c.opts.fail).always(c.opts.always),w.fx.timer(w.extend(l,{elem:e,anim:c,queue:c.opts.queue})),c}w.Animation=w.extend(vt,{tweeners:{"*":[function(e,t){var i=this.createTween(e,t);return ge(i.elem,e,ue.exec(t),i),i}]},tweener:function(e,t){p(e)?(t=e,e=["*"]):e=e.match(W);for(var i,n=0,r=e.length;n<r;n++)i=e[n],vt.tweeners[i]=vt.tweeners[i]||[],vt.tweeners[i].unshift(t)},prefilters:[function(e,t,i){var n,r,a,s,o,l,c,u,d="width"in t||"height"in t,h=this,f={},p=e.style,m=e.nodeType&&me(e),g=re.get(e,"fxshow");for(n in i.queue||(null==(s=w._queueHooks(e,"fx")).unqueued&&(s.unqueued=0,o=s.empty.fire,s.empty.fire=function(){s.unqueued||o()}),s.unqueued++,h.always((function(){h.always((function(){s.unqueued--,w.queue(e,"fx").length||s.empty.fire()}))}))),t)if(r=t[n],dt.test(r)){if(delete t[n],a=a||"toggle"===r,r===(m?"hide":"show")){if("show"!==r||!g||void 0===g[n])continue;m=!0}f[n]=g&&g[n]||w.style(e,n)}if((l=!w.isEmptyObject(t))||!w.isEmptyObject(f))for(n in d&&1===e.nodeType&&(i.overflow=[p.overflow,p.overflowX,p.overflowY],null==(c=g&&g.display)&&(c=re.get(e,"display")),"none"===(u=w.css(e,"display"))&&(c?u=c:(be([e],!0),c=e.style.display||c,u=w.css(e,"display"),be([e]))),("inline"===u||"inline-block"===u&&null!=c)&&"none"===w.css(e,"float")&&(l||(h.done((function(){p.display=c})),null==c&&(u=p.display,c="none"===u?"":u)),p.display="inline-block")),i.overflow&&(p.overflow="hidden",h.always((function(){p.overflow=i.overflow[0],p.overflowX=i.overflow[1],p.overflowY=i.overflow[2]}))),l=!1,f)l||(g?"hidden"in g&&(m=g.hidden):g=re.access(e,"fxshow",{display:c}),a&&(g.hidden=!m),m&&be([e],!0),h.done((function(){for(n in m||be([e]),re.remove(e,"fxshow"),f)w.style(e,n,f[n])}))),l=gt(m?g[n]:0,n,h),n in g||(g[n]=l.start,m&&(l.end=l.start,l.start=0))}],prefilter:function(e,t){t?vt.prefilters.unshift(e):vt.prefilters.push(e)}}),w.speed=function(e,t,i){var n=e&&"object"==typeof e?w.extend({},e):{complete:i||!i&&t||p(e)&&e,duration:e,easing:i&&t||t&&!p(t)&&t};return w.fx.off?n.duration=0:"number"!=typeof n.duration&&(n.duration in w.fx.speeds?n.duration=w.fx.speeds[n.duration]:n.duration=w.fx.speeds._default),null!=n.queue&&!0!==n.queue||(n.queue="fx"),n.old=n.complete,n.complete=function(){p(n.old)&&n.old.call(this),n.queue&&w.dequeue(this,n.queue)},n},w.fn.extend({fadeTo:function(e,t,i,n){return this.filter(me).css("opacity",0).show().end().animate({opacity:t},e,i,n)},animate:function(e,t,i,n){var r=w.isEmptyObject(e),a=w.speed(t,i,n),s=function(){var t=vt(this,w.extend({},e),a);(r||re.get(this,"finish"))&&t.stop(!0)};return s.finish=s,r||!1===a.queue?this.each(s):this.queue(a.queue,s)},stop:function(e,t,i){var n=function(e){var t=e.stop;delete e.stop,t(i)};return"string"!=typeof e&&(i=t,t=e,e=void 0),t&&this.queue(e||"fx",[]),this.each((function(){var t=!0,r=null!=e&&e+"queueHooks",a=w.timers,s=re.get(this);if(r)s[r]&&s[r].stop&&n(s[r]);else for(r in s)s[r]&&s[r].stop&&ht.test(r)&&n(s[r]);for(r=a.length;r--;)a[r].elem!==this||null!=e&&a[r].queue!==e||(a[r].anim.stop(i),t=!1,a.splice(r,1));!t&&i||w.dequeue(this,e)}))},finish:function(e){return!1!==e&&(e=e||"fx"),this.each((function(){var t,i=re.get(this),n=i[e+"queue"],r=i[e+"queueHooks"],a=w.timers,s=n?n.length:0;for(i.finish=!0,w.queue(this,e,[]),r&&r.stop&&r.stop.call(this,!0),t=a.length;t--;)a[t].elem===this&&a[t].queue===e&&(a[t].anim.stop(!0),a.splice(t,1));for(t=0;t<s;t++)n[t]&&n[t].finish&&n[t].finish.call(this);delete i.finish}))}}),w.each(["toggle","show","hide"],(function(e,t){var i=w.fn[t];w.fn[t]=function(e,n,r){return null==e||"boolean"==typeof e?i.apply(this,arguments):this.animate(mt(t,!0),e,n,r)}})),w.each({slideDown:mt("show"),slideUp:mt("hide"),slideToggle:mt("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},(function(e,t){w.fn[e]=function(e,i,n){return this.animate(t,e,i,n)}})),w.timers=[],w.fx.tick=function(){var e,t=0,i=w.timers;for(ct=Date.now();t<i.length;t++)(e=i[t])()||i[t]!==e||i.splice(t--,1);i.length||w.fx.stop(),ct=void 0},w.fx.timer=function(e){w.timers.push(e),w.fx.start()},w.fx.interval=13,w.fx.start=function(){ut||(ut=!0,ft())},w.fx.stop=function(){ut=null},w.fx.speeds={slow:600,fast:200,_default:400},w.fn.delay=function(t,i){return t=w.fx&&w.fx.speeds[t]||t,i=i||"fx",this.queue(i,(function(i,n){var r=e.setTimeout(i,t);n.stop=function(){e.clearTimeout(r)}}))},function(){var e=g.createElement("input"),t=g.createElement("select").appendChild(g.createElement("option"));e.type="checkbox",f.checkOn=""!==e.value,f.optSelected=t.selected,(e=g.createElement("input")).value="t",e.type="radio",f.radioValue="t"===e.value}();var yt,bt=w.expr.attrHandle;w.fn.extend({attr:function(e,t){return K(this,w.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each((function(){w.removeAttr(this,e)}))}}),w.extend({attr:function(e,t,i){var n,r,a=e.nodeType;if(3!==a&&8!==a&&2!==a)return void 0===e.getAttribute?w.prop(e,t,i):(1===a&&w.isXMLDoc(e)||(r=w.attrHooks[t.toLowerCase()]||(w.expr.match.bool.test(t)?yt:void 0)),void 0!==i?null===i?void w.removeAttr(e,t):r&&"set"in r&&void 0!==(n=r.set(e,i,t))?n:(e.setAttribute(t,i+""),i):r&&"get"in r&&null!==(n=r.get(e,t))?n:null==(n=w.find.attr(e,t))?void 0:n)},attrHooks:{type:{set:function(e,t){if(!f.radioValue&&"radio"===t&&M(e,"input")){var i=e.value;return e.setAttribute("type",t),i&&(e.value=i),t}}}},removeAttr:function(e,t){var i,n=0,r=t&&t.match(W);if(r&&1===e.nodeType)for(;i=r[n++];)e.removeAttribute(i)}}),yt={set:function(e,t,i){return!1===t?w.removeAttr(e,i):e.setAttribute(i,i),i}},w.each(w.expr.match.bool.source.match(/\w+/g),(function(e,t){var i=bt[t]||w.find.attr;bt[t]=function(e,t,n){var r,a,s=t.toLowerCase();return n||(a=bt[s],bt[s]=r,r=null!=i(e,t,n)?s:null,bt[s]=a),r}}));var xt=/^(?:input|select|textarea|button)$/i,_t=/^(?:a|area)$/i;function wt(e){return(e.match(W)||[]).join(" ")}function kt(e){return e.getAttribute&&e.getAttribute("class")||""}function Mt(e){return Array.isArray(e)?e:"string"==typeof e&&e.match(W)||[]}w.fn.extend({prop:function(e,t){return K(this,w.prop,e,t,arguments.length>1)},removeProp:function(e){return this.each((function(){delete this[w.propFix[e]||e]}))}}),w.extend({prop:function(e,t,i){var n,r,a=e.nodeType;if(3!==a&&8!==a&&2!==a)return 1===a&&w.isXMLDoc(e)||(t=w.propFix[t]||t,r=w.propHooks[t]),void 0!==i?r&&"set"in r&&void 0!==(n=r.set(e,i,t))?n:e[t]=i:r&&"get"in r&&null!==(n=r.get(e,t))?n:e[t]},propHooks:{tabIndex:{get:function(e){var t=w.find.attr(e,"tabindex");return t?parseInt(t,10):xt.test(e.nodeName)||_t.test(e.nodeName)&&e.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),f.optSelected||(w.propHooks.selected={get:function(e){var t=e.parentNode;return t&&t.parentNode&&t.parentNode.selectedIndex,null},set:function(e){var t=e.parentNode;t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex)}}),w.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],(function(){w.propFix[this.toLowerCase()]=this})),w.fn.extend({addClass:function(e){var t,i,n,r,a,s;return p(e)?this.each((function(t){w(this).addClass(e.call(this,t,kt(this)))})):(t=Mt(e)).length?this.each((function(){if(n=kt(this),i=1===this.nodeType&&" "+wt(n)+" "){for(a=0;a<t.length;a++)r=t[a],i.indexOf(" "+r+" ")<0&&(i+=r+" ");s=wt(i),n!==s&&this.setAttribute("class",s)}})):this},removeClass:function(e){var t,i,n,r,a,s;return p(e)?this.each((function(t){w(this).removeClass(e.call(this,t,kt(this)))})):arguments.length?(t=Mt(e)).length?this.each((function(){if(n=kt(this),i=1===this.nodeType&&" "+wt(n)+" "){for(a=0;a<t.length;a++)for(r=t[a];i.indexOf(" "+r+" ")>-1;)i=i.replace(" "+r+" "," ");s=wt(i),n!==s&&this.setAttribute("class",s)}})):this:this.attr("class","")},toggleClass:function(e,t){var i,n,r,a,s=typeof e,o="string"===s||Array.isArray(e);return p(e)?this.each((function(i){w(this).toggleClass(e.call(this,i,kt(this),t),t)})):"boolean"==typeof t&&o?t?this.addClass(e):this.removeClass(e):(i=Mt(e),this.each((function(){if(o)for(a=w(this),r=0;r<i.length;r++)n=i[r],a.hasClass(n)?a.removeClass(n):a.addClass(n);else void 0!==e&&"boolean"!==s||((n=kt(this))&&re.set(this,"__className__",n),this.setAttribute&&this.setAttribute("class",n||!1===e?"":re.get(this,"__className__")||""))})))},hasClass:function(e){var t,i,n=0;for(t=" "+e+" ";i=this[n++];)if(1===i.nodeType&&(" "+wt(kt(i))+" ").indexOf(t)>-1)return!0;return!1}});var St=/\r/g;w.fn.extend({val:function(e){var t,i,n,r=this[0];return arguments.length?(n=p(e),this.each((function(i){var r;1===this.nodeType&&(null==(r=n?e.call(this,i,w(this).val()):e)?r="":"number"==typeof r?r+="":Array.isArray(r)&&(r=w.map(r,(function(e){return null==e?"":e+""}))),(t=w.valHooks[this.type]||w.valHooks[this.nodeName.toLowerCase()])&&"set"in t&&void 0!==t.set(this,r,"value")||(this.value=r))}))):r?(t=w.valHooks[r.type]||w.valHooks[r.nodeName.toLowerCase()])&&"get"in t&&void 0!==(i=t.get(r,"value"))?i:"string"==typeof(i=r.value)?i.replace(St,""):null==i?"":i:void 0}}),w.extend({valHooks:{option:{get:function(e){var t=w.find.attr(e,"value");return null!=t?t:wt(w.text(e))}},select:{get:function(e){var t,i,n,r=e.options,a=e.selectedIndex,s="select-one"===e.type,o=s?null:[],l=s?a+1:r.length;for(n=a<0?l:s?a:0;n<l;n++)if(((i=r[n]).selected||n===a)&&!i.disabled&&(!i.parentNode.disabled||!M(i.parentNode,"optgroup"))){if(t=w(i).val(),s)return t;o.push(t)}return o},set:function(e,t){for(var i,n,r=e.options,a=w.makeArray(t),s=r.length;s--;)((n=r[s]).selected=w.inArray(w.valHooks.option.get(n),a)>-1)&&(i=!0);return i||(e.selectedIndex=-1),a}}}}),w.each(["radio","checkbox"],(function(){w.valHooks[this]={set:function(e,t){if(Array.isArray(t))return e.checked=w.inArray(w(e).val(),t)>-1}},f.checkOn||(w.valHooks[this].get=function(e){return null===e.getAttribute("value")?"on":e.value})}));var At=e.location,Lt={guid:Date.now()},Tt=/\?/;w.parseXML=function(t){var i,n;if(!t||"string"!=typeof t)return null;try{i=(new e.DOMParser).parseFromString(t,"text/xml")}catch(e){}return n=i&&i.getElementsByTagName("parsererror")[0],i&&!n||w.error("Invalid XML: "+(n?w.map(n.childNodes,(function(e){return e.textContent})).join("\n"):t)),i};var Ct=/^(?:focusinfocus|focusoutblur)$/,Dt=function(e){e.stopPropagation()};w.extend(w.event,{trigger:function(t,i,n,r){var a,s,o,l,c,d,h,f,v=[n||g],y=u.call(t,"type")?t.type:t,b=u.call(t,"namespace")?t.namespace.split("."):[];if(s=f=o=n=n||g,3!==n.nodeType&&8!==n.nodeType&&!Ct.test(y+w.event.triggered)&&(y.indexOf(".")>-1&&(b=y.split("."),y=b.shift(),b.sort()),c=y.indexOf(":")<0&&"on"+y,(t=t[w.expando]?t:new w.Event(y,"object"==typeof t&&t)).isTrigger=r?2:3,t.namespace=b.join("."),t.rnamespace=t.namespace?new RegExp("(^|\\.)"+b.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,t.result=void 0,t.target||(t.target=n),i=null==i?[t]:w.makeArray(i,[t]),h=w.event.special[y]||{},r||!h.trigger||!1!==h.trigger.apply(n,i))){if(!r&&!h.noBubble&&!m(n)){for(l=h.delegateType||y,Ct.test(l+y)||(s=s.parentNode);s;s=s.parentNode)v.push(s),o=s;o===(n.ownerDocument||g)&&v.push(o.defaultView||o.parentWindow||e)}for(a=0;(s=v[a++])&&!t.isPropagationStopped();)f=s,t.type=a>1?l:h.bindType||y,(d=(re.get(s,"events")||Object.create(null))[t.type]&&re.get(s,"handle"))&&d.apply(s,i),(d=c&&s[c])&&d.apply&&ie(s)&&(t.result=d.apply(s,i),!1===t.result&&t.preventDefault());return t.type=y,r||t.isDefaultPrevented()||h._default&&!1!==h._default.apply(v.pop(),i)||!ie(n)||c&&p(n[y])&&!m(n)&&((o=n[c])&&(n[c]=null),w.event.triggered=y,t.isPropagationStopped()&&f.addEventListener(y,Dt),n[y](),t.isPropagationStopped()&&f.removeEventListener(y,Dt),w.event.triggered=void 0,o&&(n[c]=o)),t.result}},simulate:function(e,t,i){var n=w.extend(new w.Event,i,{type:e,isSimulated:!0});w.event.trigger(n,null,t)}}),w.fn.extend({trigger:function(e,t){return this.each((function(){w.event.trigger(e,t,this)}))},triggerHandler:function(e,t){var i=this[0];if(i)return w.event.trigger(e,t,i,!0)}});var Et=/\[\]$/,Ot=/\r?\n/g,Pt=/^(?:submit|button|image|reset|file)$/i,Yt=/^(?:input|select|textarea|keygen)/i;function It(e,t,i,n){var r;if(Array.isArray(t))w.each(t,(function(t,r){i||Et.test(e)?n(e,r):It(e+"["+("object"==typeof r&&null!=r?t:"")+"]",r,i,n)}));else if(i||"object"!==b(t))n(e,t);else for(r in t)It(e+"["+r+"]",t[r],i,n)}w.param=function(e,t){var i,n=[],r=function(e,t){var i=p(t)?t():t;n[n.length]=encodeURIComponent(e)+"="+encodeURIComponent(null==i?"":i)};if(null==e)return"";if(Array.isArray(e)||e.jquery&&!w.isPlainObject(e))w.each(e,(function(){r(this.name,this.value)}));else for(i in e)It(i,e[i],t,r);return n.join("&")},w.fn.extend({serialize:function(){return w.param(this.serializeArray())},serializeArray:function(){return this.map((function(){var e=w.prop(this,"elements");return e?w.makeArray(e):this})).filter((function(){var e=this.type;return this.name&&!w(this).is(":disabled")&&Yt.test(this.nodeName)&&!Pt.test(e)&&(this.checked||!we.test(e))})).map((function(e,t){var i=w(this).val();return null==i?null:Array.isArray(i)?w.map(i,(function(e){return{name:t.name,value:e.replace(Ot,"\r\n")}})):{name:t.name,value:i.replace(Ot,"\r\n")}})).get()}});var Nt=/%20/g,jt=/#.*$/,Ht=/([?&])_=[^&]*/,Ft=/^(.*?):[ \t]*([^\r\n]*)$/gm,Rt=/^(?:GET|HEAD)$/,zt=/^\/\//,Bt={},Vt={},Wt="*/".concat("*"),Ut=g.createElement("a");function qt(e){return function(t,i){"string"!=typeof t&&(i=t,t="*");var n,r=0,a=t.toLowerCase().match(W)||[];if(p(i))for(;n=a[r++];)"+"===n[0]?(n=n.slice(1)||"*",(e[n]=e[n]||[]).unshift(i)):(e[n]=e[n]||[]).push(i)}}function $t(e,t,i,n){var r={},a=e===Vt;function s(o){var l;return r[o]=!0,w.each(e[o]||[],(function(e,o){var c=o(t,i,n);return"string"!=typeof c||a||r[c]?a?!(l=c):void 0:(t.dataTypes.unshift(c),s(c),!1)})),l}return s(t.dataTypes[0])||!r["*"]&&s("*")}function Xt(e,t){var i,n,r=w.ajaxSettings.flatOptions||{};for(i in t)void 0!==t[i]&&((r[i]?e:n||(n={}))[i]=t[i]);return n&&w.extend(!0,e,n),e}Ut.href=At.href,w.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:At.href,type:"GET",isLocal:/^(?:about|app|app-storage|.+-extension|file|res|widget):$/.test(At.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":Wt,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":w.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(e,t){return t?Xt(Xt(e,w.ajaxSettings),t):Xt(w.ajaxSettings,e)},ajaxPrefilter:qt(Bt),ajaxTransport:qt(Vt),ajax:function(t,i){"object"==typeof t&&(i=t,t=void 0),i=i||{};var n,r,a,s,o,l,c,u,d,h,f=w.ajaxSetup({},i),p=f.context||f,m=f.context&&(p.nodeType||p.jquery)?w(p):w.event,v=w.Deferred(),y=w.Callbacks("once memory"),b=f.statusCode||{},x={},_={},k="canceled",M={readyState:0,getResponseHeader:function(e){var t;if(c){if(!s)for(s={};t=Ft.exec(a);)s[t[1].toLowerCase()+" "]=(s[t[1].toLowerCase()+" "]||[]).concat(t[2]);t=s[e.toLowerCase()+" "]}return null==t?null:t.join(", ")},getAllResponseHeaders:function(){return c?a:null},setRequestHeader:function(e,t){return null==c&&(e=_[e.toLowerCase()]=_[e.toLowerCase()]||e,x[e]=t),this},overrideMimeType:function(e){return null==c&&(f.mimeType=e),this},statusCode:function(e){var t;if(e)if(c)M.always(e[M.status]);else for(t in e)b[t]=[b[t],e[t]];return this},abort:function(e){var t=e||k;return n&&n.abort(t),S(0,t),this}};if(v.promise(M),f.url=((t||f.url||At.href)+"").replace(zt,At.protocol+"//"),f.type=i.method||i.type||f.method||f.type,f.dataTypes=(f.dataType||"*").toLowerCase().match(W)||[""],null==f.crossDomain){l=g.createElement("a");try{l.href=f.url,l.href=l.href,f.crossDomain=Ut.protocol+"//"+Ut.host!=l.protocol+"//"+l.host}catch(e){f.crossDomain=!0}}if(f.data&&f.processData&&"string"!=typeof f.data&&(f.data=w.param(f.data,f.traditional)),$t(Bt,f,i,M),c)return M;for(d in(u=w.event&&f.global)&&0==w.active++&&w.event.trigger("ajaxStart"),f.type=f.type.toUpperCase(),f.hasContent=!Rt.test(f.type),r=f.url.replace(jt,""),f.hasContent?f.data&&f.processData&&0===(f.contentType||"").indexOf("application/x-www-form-urlencoded")&&(f.data=f.data.replace(Nt,"+")):(h=f.url.slice(r.length),f.data&&(f.processData||"string"==typeof f.data)&&(r+=(Tt.test(r)?"&":"?")+f.data,delete f.data),!1===f.cache&&(r=r.replace(Ht,"$1"),h=(Tt.test(r)?"&":"?")+"_="+Lt.guid+++h),f.url=r+h),f.ifModified&&(w.lastModified[r]&&M.setRequestHeader("If-Modified-Since",w.lastModified[r]),w.etag[r]&&M.setRequestHeader("If-None-Match",w.etag[r])),(f.data&&f.hasContent&&!1!==f.contentType||i.contentType)&&M.setRequestHeader("Content-Type",f.contentType),M.setRequestHeader("Accept",f.dataTypes[0]&&f.accepts[f.dataTypes[0]]?f.accepts[f.dataTypes[0]]+("*"!==f.dataTypes[0]?", "+Wt+"; q=0.01":""):f.accepts["*"]),f.headers)M.setRequestHeader(d,f.headers[d]);if(f.beforeSend&&(!1===f.beforeSend.call(p,M,f)||c))return M.abort();if(k="abort",y.add(f.complete),M.done(f.success),M.fail(f.error),n=$t(Vt,f,i,M)){if(M.readyState=1,u&&m.trigger("ajaxSend",[M,f]),c)return M;f.async&&f.timeout>0&&(o=e.setTimeout((function(){M.abort("timeout")}),f.timeout));try{c=!1,n.send(x,S)}catch(e){if(c)throw e;S(-1,e)}}else S(-1,"No Transport");function S(t,i,s,l){var d,h,g,x,_,k=i;c||(c=!0,o&&e.clearTimeout(o),n=void 0,a=l||"",M.readyState=t>0?4:0,d=t>=200&&t<300||304===t,s&&(x=function(e,t,i){for(var n,r,a,s,o=e.contents,l=e.dataTypes;"*"===l[0];)l.shift(),void 0===n&&(n=e.mimeType||t.getResponseHeader("Content-Type"));if(n)for(r in o)if(o[r]&&o[r].test(n)){l.unshift(r);break}if(l[0]in i)a=l[0];else{for(r in i){if(!l[0]||e.converters[r+" "+l[0]]){a=r;break}s||(s=r)}a=a||s}if(a)return a!==l[0]&&l.unshift(a),i[a]}(f,M,s)),!d&&w.inArray("script",f.dataTypes)>-1&&w.inArray("json",f.dataTypes)<0&&(f.converters["text script"]=function(){}),x=function(e,t,i,n){var r,a,s,o,l,c={},u=e.dataTypes.slice();if(u[1])for(s in e.converters)c[s.toLowerCase()]=e.converters[s];for(a=u.shift();a;)if(e.responseFields[a]&&(i[e.responseFields[a]]=t),!l&&n&&e.dataFilter&&(t=e.dataFilter(t,e.dataType)),l=a,a=u.shift())if("*"===a)a=l;else if("*"!==l&&l!==a){if(!(s=c[l+" "+a]||c["* "+a]))for(r in c)if((o=r.split(" "))[1]===a&&(s=c[l+" "+o[0]]||c["* "+o[0]])){!0===s?s=c[r]:!0!==c[r]&&(a=o[0],u.unshift(o[1]));break}if(!0!==s)if(s&&e.throws)t=s(t);else try{t=s(t)}catch(e){return{state:"parsererror",error:s?e:"No conversion from "+l+" to "+a}}}return{state:"success",data:t}}(f,x,M,d),d?(f.ifModified&&((_=M.getResponseHeader("Last-Modified"))&&(w.lastModified[r]=_),(_=M.getResponseHeader("etag"))&&(w.etag[r]=_)),204===t||"HEAD"===f.type?k="nocontent":304===t?k="notmodified":(k=x.state,h=x.data,d=!(g=x.error))):(g=k,!t&&k||(k="error",t<0&&(t=0))),M.status=t,M.statusText=(i||k)+"",d?v.resolveWith(p,[h,k,M]):v.rejectWith(p,[M,k,g]),M.statusCode(b),b=void 0,u&&m.trigger(d?"ajaxSuccess":"ajaxError",[M,f,d?h:g]),y.fireWith(p,[M,k]),u&&(m.trigger("ajaxComplete",[M,f]),--w.active||w.event.trigger("ajaxStop")))}return M},getJSON:function(e,t,i){return w.get(e,t,i,"json")},getScript:function(e,t){return w.get(e,void 0,t,"script")}}),w.each(["get","post"],(function(e,t){w[t]=function(e,i,n,r){return p(i)&&(r=r||n,n=i,i=void 0),w.ajax(w.extend({url:e,type:t,dataType:r,data:i,success:n},w.isPlainObject(e)&&e))}})),w.ajaxPrefilter((function(e){var t;for(t in e.headers)"content-type"===t.toLowerCase()&&(e.contentType=e.headers[t]||"")})),w._evalUrl=function(e,t,i){return w.ajax({url:e,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(e){w.globalEval(e,t,i)}})},w.fn.extend({wrapAll:function(e){var t;return this[0]&&(p(e)&&(e=e.call(this[0])),t=w(e,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&t.insertBefore(this[0]),t.map((function(){for(var e=this;e.firstElementChild;)e=e.firstElementChild;return e})).append(this)),this},wrapInner:function(e){return p(e)?this.each((function(t){w(this).wrapInner(e.call(this,t))})):this.each((function(){var t=w(this),i=t.contents();i.length?i.wrapAll(e):t.append(e)}))},wrap:function(e){var t=p(e);return this.each((function(i){w(this).wrapAll(t?e.call(this,i):e)}))},unwrap:function(e){return this.parent(e).not("body").each((function(){w(this).replaceWith(this.childNodes)})),this}}),w.expr.pseudos.hidden=function(e){return!w.expr.pseudos.visible(e)},w.expr.pseudos.visible=function(e){return!!(e.offsetWidth||e.offsetHeight||e.getClientRects().length)},w.ajaxSettings.xhr=function(){try{return new e.XMLHttpRequest}catch(e){}};var Gt={0:200,1223:204},Zt=w.ajaxSettings.xhr();f.cors=!!Zt&&"withCredentials"in Zt,f.ajax=Zt=!!Zt,w.ajaxTransport((function(t){var i,n;if(f.cors||Zt&&!t.crossDomain)return{send:function(r,a){var s,o=t.xhr();if(o.open(t.type,t.url,t.async,t.username,t.password),t.xhrFields)for(s in t.xhrFields)o[s]=t.xhrFields[s];for(s in t.mimeType&&o.overrideMimeType&&o.overrideMimeType(t.mimeType),t.crossDomain||r["X-Requested-With"]||(r["X-Requested-With"]="XMLHttpRequest"),r)o.setRequestHeader(s,r[s]);i=function(e){return function(){i&&(i=n=o.onload=o.onerror=o.onabort=o.ontimeout=o.onreadystatechange=null,"abort"===e?o.abort():"error"===e?"number"!=typeof o.status?a(0,"error"):a(o.status,o.statusText):a(Gt[o.status]||o.status,o.statusText,"text"!==(o.responseType||"text")||"string"!=typeof o.responseText?{binary:o.response}:{text:o.responseText},o.getAllResponseHeaders()))}},o.onload=i(),n=o.onerror=o.ontimeout=i("error"),void 0!==o.onabort?o.onabort=n:o.onreadystatechange=function(){4===o.readyState&&e.setTimeout((function(){i&&n()}))},i=i("abort");try{o.send(t.hasContent&&t.data||null)}catch(e){if(i)throw e}},abort:function(){i&&i()}}})),w.ajaxPrefilter((function(e){e.crossDomain&&(e.contents.script=!1)})),w.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(e){return w.globalEval(e),e}}}),w.ajaxPrefilter("script",(function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET")})),w.ajaxTransport("script",(function(e){var t,i;if(e.crossDomain||e.scriptAttrs)return{send:function(n,r){t=w("<script>").attr(e.scriptAttrs||{}).prop({charset:e.scriptCharset,src:e.url}).on("load error",i=function(e){t.remove(),i=null,e&&r("error"===e.type?404:200,e.type)}),g.head.appendChild(t[0])},abort:function(){i&&i()}}}));var Kt,Jt=[],Qt=/(=)\?(?=&|$)|\?\?/;w.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Jt.pop()||w.expando+"_"+Lt.guid++;return this[e]=!0,e}}),w.ajaxPrefilter("json jsonp",(function(t,i,n){var r,a,s,o=!1!==t.jsonp&&(Qt.test(t.url)?"url":"string"==typeof t.data&&0===(t.contentType||"").indexOf("application/x-www-form-urlencoded")&&Qt.test(t.data)&&"data");if(o||"jsonp"===t.dataTypes[0])return r=t.jsonpCallback=p(t.jsonpCallback)?t.jsonpCallback():t.jsonpCallback,o?t[o]=t[o].replace(Qt,"$1"+r):!1!==t.jsonp&&(t.url+=(Tt.test(t.url)?"&":"?")+t.jsonp+"="+r),t.converters["script json"]=function(){return s||w.error(r+" was not called"),s[0]},t.dataTypes[0]="json",a=e[r],e[r]=function(){s=arguments},n.always((function(){void 0===a?w(e).removeProp(r):e[r]=a,t[r]&&(t.jsonpCallback=i.jsonpCallback,Jt.push(r)),s&&p(a)&&a(s[0]),s=a=void 0})),"script"})),f.createHTMLDocument=((Kt=g.implementation.createHTMLDocument("").body).innerHTML="<form></form><form></form>",2===Kt.childNodes.length),w.parseHTML=function(e,t,i){return"string"!=typeof e?[]:("boolean"==typeof t&&(i=t,t=!1),t||(f.createHTMLDocument?((n=(t=g.implementation.createHTMLDocument("")).createElement("base")).href=g.location.href,t.head.appendChild(n)):t=g),a=!i&&[],(r=j.exec(e))?[t.createElement(r[1])]:(r=Ce([e],t,a),a&&a.length&&w(a).remove(),w.merge([],r.childNodes)));var n,r,a},w.fn.load=function(e,t,i){var n,r,a,s=this,o=e.indexOf(" ");return o>-1&&(n=wt(e.slice(o)),e=e.slice(0,o)),p(t)?(i=t,t=void 0):t&&"object"==typeof t&&(r="POST"),s.length>0&&w.ajax({url:e,type:r||"GET",dataType:"html",data:t}).done((function(e){a=arguments,s.html(n?w("<div>").append(w.parseHTML(e)).find(n):e)})).always(i&&function(e,t){s.each((function(){i.apply(this,a||[e.responseText,t,e])}))}),this},w.expr.pseudos.animated=function(e){return w.grep(w.timers,(function(t){return e===t.elem})).length},w.offset={setOffset:function(e,t,i){var n,r,a,s,o,l,c=w.css(e,"position"),u=w(e),d={};"static"===c&&(e.style.position="relative"),o=u.offset(),a=w.css(e,"top"),l=w.css(e,"left"),("absolute"===c||"fixed"===c)&&(a+l).indexOf("auto")>-1?(s=(n=u.position()).top,r=n.left):(s=parseFloat(a)||0,r=parseFloat(l)||0),p(t)&&(t=t.call(e,i,w.extend({},o))),null!=t.top&&(d.top=t.top-o.top+s),null!=t.left&&(d.left=t.left-o.left+r),"using"in t?t.using.call(e,d):u.css(d)}},w.fn.extend({offset:function(e){if(arguments.length)return void 0===e?this:this.each((function(t){w.offset.setOffset(this,e,t)}));var t,i,n=this[0];return n?n.getClientRects().length?(t=n.getBoundingClientRect(),i=n.ownerDocument.defaultView,{top:t.top+i.pageYOffset,left:t.left+i.pageXOffset}):{top:0,left:0}:void 0},position:function(){if(this[0]){var e,t,i,n=this[0],r={top:0,left:0};if("fixed"===w.css(n,"position"))t=n.getBoundingClientRect();else{for(t=this.offset(),i=n.ownerDocument,e=n.offsetParent||i.documentElement;e&&(e===i.body||e===i.documentElement)&&"static"===w.css(e,"position");)e=e.parentNode;e&&e!==n&&1===e.nodeType&&((r=w(e).offset()).top+=w.css(e,"borderTopWidth",!0),r.left+=w.css(e,"borderLeftWidth",!0))}return{top:t.top-r.top-w.css(n,"marginTop",!0),left:t.left-r.left-w.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map((function(){for(var e=this.offsetParent;e&&"static"===w.css(e,"position");)e=e.offsetParent;return e||he}))}}),w.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},(function(e,t){var i="pageYOffset"===t;w.fn[e]=function(n){return K(this,(function(e,n,r){var a;if(m(e)?a=e:9===e.nodeType&&(a=e.defaultView),void 0===r)return a?a[t]:e[n];a?a.scrollTo(i?a.pageXOffset:r,i?r:a.pageYOffset):e[n]=r}),e,n,arguments.length)}})),w.each(["top","left"],(function(e,t){w.cssHooks[t]=Ke(f.pixelPosition,(function(e,i){if(i)return i=Ze(e,t),Ue.test(i)?w(e).position()[t]+"px":i}))})),w.each({Height:"height",Width:"width"},(function(e,t){w.each({padding:"inner"+e,content:t,"":"outer"+e},(function(i,n){w.fn[n]=function(r,a){var s=arguments.length&&(i||"boolean"!=typeof r),o=i||(!0===r||!0===a?"margin":"border");return K(this,(function(t,i,r){var a;return m(t)?0===n.indexOf("outer")?t["inner"+e]:t.document.documentElement["client"+e]:9===t.nodeType?(a=t.documentElement,Math.max(t.body["scroll"+e],a["scroll"+e],t.body["offset"+e],a["offset"+e],a["client"+e])):void 0===r?w.css(t,i,o):w.style(t,i,r,o)}),t,s?r:void 0,s)}}))})),w.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],(function(e,t){w.fn[t]=function(e){return this.on(t,e)}})),w.fn.extend({bind:function(e,t,i){return this.on(e,null,t,i)},unbind:function(e,t){return this.off(e,null,t)},delegate:function(e,t,i,n){return this.on(t,e,i,n)},undelegate:function(e,t,i){return 1===arguments.length?this.off(e,"**"):this.off(t,e||"**",i)},hover:function(e,t){return this.on("mouseenter",e).on("mouseleave",t||e)}}),w.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),(function(e,t){w.fn[t]=function(e,i){return arguments.length>0?this.on(t,null,e,i):this.trigger(t)}}));var ei=/^[\s\uFEFF\xA0]+|([^\s\uFEFF\xA0])[\s\uFEFF\xA0]+$/g;w.proxy=function(e,t){var i,n,a;if("string"==typeof t&&(i=e[t],t=e,e=i),p(e))return n=r.call(arguments,2),a=function(){return e.apply(t||this,n.concat(r.call(arguments)))},a.guid=e.guid=e.guid||w.guid++,a},w.holdReady=function(e){e?w.readyWait++:w.ready(!0)},w.isArray=Array.isArray,w.parseJSON=JSON.parse,w.nodeName=M,w.isFunction=p,w.isWindow=m,w.camelCase=te,w.type=b,w.now=Date.now,w.isNumeric=function(e){var t=w.type(e);return("number"===t||"string"===t)&&!isNaN(e-parseFloat(e))},w.trim=function(e){return null==e?"":(e+"").replace(ei,"$1")},"function"==typeof define&&define.amd&&define("jquery",[],(function(){return w}));var ti=e.jQuery,ii=e.$;return w.noConflict=function(t){return e.$===w&&(e.$=ii),t&&e.jQuery===w&&(e.jQuery=ti),w},void 0===t&&(e.jQuery=e.$=w),w})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).Popper={})}(this,(function(e){"use strict";function t(e){if(null==e)return window;if("[object Window]"!==e.toString()){var t=e.ownerDocument;return t&&t.defaultView||window}return e}function i(e){return e instanceof t(e).Element||e instanceof Element}function n(e){return e instanceof t(e).HTMLElement||e instanceof HTMLElement}function r(e){return"undefined"!=typeof ShadowRoot&&(e instanceof t(e).ShadowRoot||e instanceof ShadowRoot)}var a=Math.max,s=Math.min,o=Math.round;function l(){var e=navigator.userAgentData;return null!=e&&e.brands&&Array.isArray(e.brands)?e.brands.map((function(e){return e.brand+"/"+e.version})).join(" "):navigator.userAgent}function c(){return!/^((?!chrome|android).)*safari/i.test(l())}function u(e,r,a){void 0===r&&(r=!1),void 0===a&&(a=!1);var s=e.getBoundingClientRect(),l=1,u=1;r&&n(e)&&(l=e.offsetWidth>0&&o(s.width)/e.offsetWidth||1,u=e.offsetHeight>0&&o(s.height)/e.offsetHeight||1);var d=(i(e)?t(e):window).visualViewport,h=!c()&&a,f=(s.left+(h&&d?d.offsetLeft:0))/l,p=(s.top+(h&&d?d.offsetTop:0))/u,m=s.width/l,g=s.height/u;return{width:m,height:g,top:p,right:f+m,bottom:p+g,left:f,x:f,y:p}}function d(e){var i=t(e);return{scrollLeft:i.pageXOffset,scrollTop:i.pageYOffset}}function h(e){return e?(e.nodeName||"").toLowerCase():null}function f(e){return((i(e)?e.ownerDocument:e.document)||window.document).documentElement}function p(e){return u(f(e)).left+d(e).scrollLeft}function m(e){return t(e).getComputedStyle(e)}function g(e){var t=m(e),i=t.overflow,n=t.overflowX,r=t.overflowY;return/auto|scroll|overlay|hidden/.test(i+r+n)}function v(e,i,r){void 0===r&&(r=!1);var a,s,l=n(i),c=n(i)&&function(e){var t=e.getBoundingClientRect(),i=o(t.width)/e.offsetWidth||1,n=o(t.height)/e.offsetHeight||1;return 1!==i||1!==n}(i),m=f(i),v=u(e,c,r),y={scrollLeft:0,scrollTop:0},b={x:0,y:0};return(l||!l&&!r)&&(("body"!==h(i)||g(m))&&(y=(a=i)!==t(a)&&n(a)?{scrollLeft:(s=a).scrollLeft,scrollTop:s.scrollTop}:d(a)),n(i)?((b=u(i,!0)).x+=i.clientLeft,b.y+=i.clientTop):m&&(b.x=p(m))),{x:v.left+y.scrollLeft-b.x,y:v.top+y.scrollTop-b.y,width:v.width,height:v.height}}function y(e){var t=u(e),i=e.offsetWidth,n=e.offsetHeight;return Math.abs(t.width-i)<=1&&(i=t.width),Math.abs(t.height-n)<=1&&(n=t.height),{x:e.offsetLeft,y:e.offsetTop,width:i,height:n}}function b(e){return"html"===h(e)?e:e.assignedSlot||e.parentNode||(r(e)?e.host:null)||f(e)}function x(e){return["html","body","#document"].indexOf(h(e))>=0?e.ownerDocument.body:n(e)&&g(e)?e:x(b(e))}function _(e,i){var n;void 0===i&&(i=[]);var r=x(e),a=r===(null==(n=e.ownerDocument)?void 0:n.body),s=t(r),o=a?[s].concat(s.visualViewport||[],g(r)?r:[]):r,l=i.concat(o);return a?l:l.concat(_(b(o)))}function w(e){return["table","td","th"].indexOf(h(e))>=0}function k(e){return n(e)&&"fixed"!==m(e).position?e.offsetParent:null}function M(e){for(var i=t(e),a=k(e);a&&w(a)&&"static"===m(a).position;)a=k(a);return a&&("html"===h(a)||"body"===h(a)&&"static"===m(a).position)?i:a||function(e){var t=/firefox/i.test(l());if(/Trident/i.test(l())&&n(e)&&"fixed"===m(e).position)return null;var i=b(e);for(r(i)&&(i=i.host);n(i)&&["html","body"].indexOf(h(i))<0;){var a=m(i);if("none"!==a.transform||"none"!==a.perspective||"paint"===a.contain||-1!==["transform","perspective"].indexOf(a.willChange)||t&&"filter"===a.willChange||t&&a.filter&&"none"!==a.filter)return i;i=i.parentNode}return null}(e)||i}var S="top",A="bottom",L="right",T="left",C="auto",D=[S,A,L,T],E="start",O="end",P="clippingParents",Y="viewport",I="popper",N="reference",j=D.reduce((function(e,t){return e.concat([t+"-"+E,t+"-"+O])}),[]),H=[].concat(D,[C]).reduce((function(e,t){return e.concat([t,t+"-"+E,t+"-"+O])}),[]),F=["beforeRead","read","afterRead","beforeMain","main","afterMain","beforeWrite","write","afterWrite"];function R(e){var t=new Map,i=new Set,n=[];function r(e){i.add(e.name),[].concat(e.requires||[],e.requiresIfExists||[]).forEach((function(e){if(!i.has(e)){var n=t.get(e);n&&r(n)}})),n.push(e)}return e.forEach((function(e){t.set(e.name,e)})),e.forEach((function(e){i.has(e.name)||r(e)})),n}function z(e,t){var i=t.getRootNode&&t.getRootNode();if(e.contains(t))return!0;if(i&&r(i)){var n=t;do{if(n&&e.isSameNode(n))return!0;n=n.parentNode||n.host}while(n)}return!1}function B(e){return Object.assign({},e,{left:e.x,top:e.y,right:e.x+e.width,bottom:e.y+e.height})}function V(e,n,r){return n===Y?B(function(e,i){var n=t(e),r=f(e),a=n.visualViewport,s=r.clientWidth,o=r.clientHeight,l=0,u=0;if(a){s=a.width,o=a.height;var d=c();(d||!d&&"fixed"===i)&&(l=a.offsetLeft,u=a.offsetTop)}return{width:s,height:o,x:l+p(e),y:u}}(e,r)):i(n)?function(e,t){var i=u(e,!1,"fixed"===t);return i.top=i.top+e.clientTop,i.left=i.left+e.clientLeft,i.bottom=i.top+e.clientHeight,i.right=i.left+e.clientWidth,i.width=e.clientWidth,i.height=e.clientHeight,i.x=i.left,i.y=i.top,i}(n,r):B(function(e){var t,i=f(e),n=d(e),r=null==(t=e.ownerDocument)?void 0:t.body,s=a(i.scrollWidth,i.clientWidth,r?r.scrollWidth:0,r?r.clientWidth:0),o=a(i.scrollHeight,i.clientHeight,r?r.scrollHeight:0,r?r.clientHeight:0),l=-n.scrollLeft+p(e),c=-n.scrollTop;return"rtl"===m(r||i).direction&&(l+=a(i.clientWidth,r?r.clientWidth:0)-s),{width:s,height:o,x:l,y:c}}(f(e)))}function W(e,t,r,o){var l="clippingParents"===t?function(e){var t=_(b(e)),r=["absolute","fixed"].indexOf(m(e).position)>=0&&n(e)?M(e):e;return i(r)?t.filter((function(e){return i(e)&&z(e,r)&&"body"!==h(e)})):[]}(e):[].concat(t),c=[].concat(l,[r]),u=c[0],d=c.reduce((function(t,i){var n=V(e,i,o);return t.top=a(n.top,t.top),t.right=s(n.right,t.right),t.bottom=s(n.bottom,t.bottom),t.left=a(n.left,t.left),t}),V(e,u,o));return d.width=d.right-d.left,d.height=d.bottom-d.top,d.x=d.left,d.y=d.top,d}function U(e){return e.split("-")[0]}function q(e){return e.split("-")[1]}function $(e){return["top","bottom"].indexOf(e)>=0?"x":"y"}function X(e){var t,i=e.reference,n=e.element,r=e.placement,a=r?U(r):null,s=r?q(r):null,o=i.x+i.width/2-n.width/2,l=i.y+i.height/2-n.height/2;switch(a){case S:t={x:o,y:i.y-n.height};break;case A:t={x:o,y:i.y+i.height};break;case L:t={x:i.x+i.width,y:l};break;case T:t={x:i.x-n.width,y:l};break;default:t={x:i.x,y:i.y}}var c=a?$(a):null;if(null!=c){var u="y"===c?"height":"width";switch(s){case E:t[c]=t[c]-(i[u]/2-n[u]/2);break;case O:t[c]=t[c]+(i[u]/2-n[u]/2)}}return t}function G(e){return Object.assign({},{top:0,right:0,bottom:0,left:0},e)}function Z(e,t){return t.reduce((function(t,i){return t[i]=e,t}),{})}function K(e,t){void 0===t&&(t={});var n=t,r=n.placement,a=void 0===r?e.placement:r,s=n.strategy,o=void 0===s?e.strategy:s,l=n.boundary,c=void 0===l?P:l,d=n.rootBoundary,h=void 0===d?Y:d,p=n.elementContext,m=void 0===p?I:p,g=n.altBoundary,v=void 0!==g&&g,y=n.padding,b=void 0===y?0:y,x=G("number"!=typeof b?b:Z(b,D)),_=m===I?N:I,w=e.rects.popper,k=e.elements[v?_:m],M=W(i(k)?k:k.contextElement||f(e.elements.popper),c,h,o),T=u(e.elements.reference),C=X({reference:T,element:w,strategy:"absolute",placement:a}),E=B(Object.assign({},w,C)),O=m===I?E:T,j={top:M.top-O.top+x.top,bottom:O.bottom-M.bottom+x.bottom,left:M.left-O.left+x.left,right:O.right-M.right+x.right},H=e.modifiersData.offset;if(m===I&&H){var F=H[a];Object.keys(j).forEach((function(e){var t=[L,A].indexOf(e)>=0?1:-1,i=[S,A].indexOf(e)>=0?"y":"x";j[e]+=F[i]*t}))}return j}var J={placement:"bottom",modifiers:[],strategy:"absolute"};function Q(){for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];return!t.some((function(e){return!(e&&"function"==typeof e.getBoundingClientRect)}))}function ee(e){void 0===e&&(e={});var t=e,n=t.defaultModifiers,r=void 0===n?[]:n,a=t.defaultOptions,s=void 0===a?J:a;return function(e,t,n){void 0===n&&(n=s);var a,o,l={placement:"bottom",orderedModifiers:[],options:Object.assign({},J,s),modifiersData:{},elements:{reference:e,popper:t},attributes:{},styles:{}},c=[],u=!1,d={state:l,setOptions:function(n){var a="function"==typeof n?n(l.options):n;h(),l.options=Object.assign({},s,l.options,a),l.scrollParents={reference:i(e)?_(e):e.contextElement?_(e.contextElement):[],popper:_(t)};var o,u,f=function(e){var t=R(e);return F.reduce((function(e,i){return e.concat(t.filter((function(e){return e.phase===i})))}),[])}((o=[].concat(r,l.options.modifiers),u=o.reduce((function(e,t){var i=e[t.name];return e[t.name]=i?Object.assign({},i,t,{options:Object.assign({},i.options,t.options),data:Object.assign({},i.data,t.data)}):t,e}),{}),Object.keys(u).map((function(e){return u[e]}))));return l.orderedModifiers=f.filter((function(e){return e.enabled})),l.orderedModifiers.forEach((function(e){var t=e.name,i=e.options,n=void 0===i?{}:i,r=e.effect;if("function"==typeof r){var a=r({state:l,name:t,instance:d,options:n}),s=function(){};c.push(a||s)}})),d.update()},forceUpdate:function(){if(!u){var e=l.elements,t=e.reference,i=e.popper;if(Q(t,i)){l.rects={reference:v(t,M(i),"fixed"===l.options.strategy),popper:y(i)},l.reset=!1,l.placement=l.options.placement,l.orderedModifiers.forEach((function(e){return l.modifiersData[e.name]=Object.assign({},e.data)}));for(var n=0;n<l.orderedModifiers.length;n++)if(!0!==l.reset){var r=l.orderedModifiers[n],a=r.fn,s=r.options,o=void 0===s?{}:s,c=r.name;"function"==typeof a&&(l=a({state:l,options:o,name:c,instance:d})||l)}else l.reset=!1,n=-1}}},update:(a=function(){return new Promise((function(e){d.forceUpdate(),e(l)}))},function(){return o||(o=new Promise((function(e){Promise.resolve().then((function(){o=void 0,e(a())}))}))),o}),destroy:function(){h(),u=!0}};if(!Q(e,t))return d;function h(){c.forEach((function(e){return e()})),c=[]}return d.setOptions(n).then((function(e){!u&&n.onFirstUpdate&&n.onFirstUpdate(e)})),d}}var te={passive:!0};var ie={name:"eventListeners",enabled:!0,phase:"write",fn:function(){},effect:function(e){var i=e.state,n=e.instance,r=e.options,a=r.scroll,s=void 0===a||a,o=r.resize,l=void 0===o||o,c=t(i.elements.popper),u=[].concat(i.scrollParents.reference,i.scrollParents.popper);return s&&u.forEach((function(e){e.addEventListener("scroll",n.update,te)})),l&&c.addEventListener("resize",n.update,te),function(){s&&u.forEach((function(e){e.removeEventListener("scroll",n.update,te)})),l&&c.removeEventListener("resize",n.update,te)}},data:{}};var ne={name:"popperOffsets",enabled:!0,phase:"read",fn:function(e){var t=e.state,i=e.name;t.modifiersData[i]=X({reference:t.rects.reference,element:t.rects.popper,strategy:"absolute",placement:t.placement})},data:{}},re={top:"auto",right:"auto",bottom:"auto",left:"auto"};function ae(e){var i,n=e.popper,r=e.popperRect,a=e.placement,s=e.variation,l=e.offsets,c=e.position,u=e.gpuAcceleration,d=e.adaptive,h=e.roundOffsets,p=e.isFixed,g=l.x,v=void 0===g?0:g,y=l.y,b=void 0===y?0:y,x="function"==typeof h?h({x:v,y:b}):{x:v,y:b};v=x.x,b=x.y;var _=l.hasOwnProperty("x"),w=l.hasOwnProperty("y"),k=T,C=S,D=window;if(d){var E=M(n),P="clientHeight",Y="clientWidth";if(E===t(n)&&"static"!==m(E=f(n)).position&&"absolute"===c&&(P="scrollHeight",Y="scrollWidth"),a===S||(a===T||a===L)&&s===O)C=A,b-=(p&&E===D&&D.visualViewport?D.visualViewport.height:E[P])-r.height,b*=u?1:-1;if(a===T||(a===S||a===A)&&s===O)k=L,v-=(p&&E===D&&D.visualViewport?D.visualViewport.width:E[Y])-r.width,v*=u?1:-1}var I,N=Object.assign({position:c},d&&re),j=!0===h?function(e,t){var i=e.x,n=e.y,r=t.devicePixelRatio||1;return{x:o(i*r)/r||0,y:o(n*r)/r||0}}({x:v,y:b},t(n)):{x:v,y:b};return v=j.x,b=j.y,u?Object.assign({},N,((I={})[C]=w?"0":"",I[k]=_?"0":"",I.transform=(D.devicePixelRatio||1)<=1?"translate("+v+"px, "+b+"px)":"translate3d("+v+"px, "+b+"px, 0)",I)):Object.assign({},N,((i={})[C]=w?b+"px":"",i[k]=_?v+"px":"",i.transform="",i))}var se={name:"computeStyles",enabled:!0,phase:"beforeWrite",fn:function(e){var t=e.state,i=e.options,n=i.gpuAcceleration,r=void 0===n||n,a=i.adaptive,s=void 0===a||a,o=i.roundOffsets,l=void 0===o||o,c={placement:U(t.placement),variation:q(t.placement),popper:t.elements.popper,popperRect:t.rects.popper,gpuAcceleration:r,isFixed:"fixed"===t.options.strategy};null!=t.modifiersData.popperOffsets&&(t.styles.popper=Object.assign({},t.styles.popper,ae(Object.assign({},c,{offsets:t.modifiersData.popperOffsets,position:t.options.strategy,adaptive:s,roundOffsets:l})))),null!=t.modifiersData.arrow&&(t.styles.arrow=Object.assign({},t.styles.arrow,ae(Object.assign({},c,{offsets:t.modifiersData.arrow,position:"absolute",adaptive:!1,roundOffsets:l})))),t.attributes.popper=Object.assign({},t.attributes.popper,{"data-popper-placement":t.placement})},data:{}};var oe={name:"applyStyles",enabled:!0,phase:"write",fn:function(e){var t=e.state;Object.keys(t.elements).forEach((function(e){var i=t.styles[e]||{},r=t.attributes[e]||{},a=t.elements[e];n(a)&&h(a)&&(Object.assign(a.style,i),Object.keys(r).forEach((function(e){var t=r[e];!1===t?a.removeAttribute(e):a.setAttribute(e,!0===t?"":t)})))}))},effect:function(e){var t=e.state,i={popper:{position:t.options.strategy,left:"0",top:"0",margin:"0"},arrow:{position:"absolute"},reference:{}};return Object.assign(t.elements.popper.style,i.popper),t.styles=i,t.elements.arrow&&Object.assign(t.elements.arrow.style,i.arrow),function(){Object.keys(t.elements).forEach((function(e){var r=t.elements[e],a=t.attributes[e]||{},s=Object.keys(t.styles.hasOwnProperty(e)?t.styles[e]:i[e]).reduce((function(e,t){return e[t]="",e}),{});n(r)&&h(r)&&(Object.assign(r.style,s),Object.keys(a).forEach((function(e){r.removeAttribute(e)})))}))}},requires:["computeStyles"]};var le={name:"offset",enabled:!0,phase:"main",requires:["popperOffsets"],fn:function(e){var t=e.state,i=e.options,n=e.name,r=i.offset,a=void 0===r?[0,0]:r,s=H.reduce((function(e,i){return e[i]=function(e,t,i){var n=U(e),r=[T,S].indexOf(n)>=0?-1:1,a="function"==typeof i?i(Object.assign({},t,{placement:e})):i,s=a[0],o=a[1];return s=s||0,o=(o||0)*r,[T,L].indexOf(n)>=0?{x:o,y:s}:{x:s,y:o}}(i,t.rects,a),e}),{}),o=s[t.placement],l=o.x,c=o.y;null!=t.modifiersData.popperOffsets&&(t.modifiersData.popperOffsets.x+=l,t.modifiersData.popperOffsets.y+=c),t.modifiersData[n]=s}},ce={left:"right",right:"left",bottom:"top",top:"bottom"};function ue(e){return e.replace(/left|right|bottom|top/g,(function(e){return ce[e]}))}var de={start:"end",end:"start"};function he(e){return e.replace(/start|end/g,(function(e){return de[e]}))}function fe(e,t){void 0===t&&(t={});var i=t,n=i.placement,r=i.boundary,a=i.rootBoundary,s=i.padding,o=i.flipVariations,l=i.allowedAutoPlacements,c=void 0===l?H:l,u=q(n),d=u?o?j:j.filter((function(e){return q(e)===u})):D,h=d.filter((function(e){return c.indexOf(e)>=0}));0===h.length&&(h=d);var f=h.reduce((function(t,i){return t[i]=K(e,{placement:i,boundary:r,rootBoundary:a,padding:s})[U(i)],t}),{});return Object.keys(f).sort((function(e,t){return f[e]-f[t]}))}var pe={name:"flip",enabled:!0,phase:"main",fn:function(e){var t=e.state,i=e.options,n=e.name;if(!t.modifiersData[n]._skip){for(var r=i.mainAxis,a=void 0===r||r,s=i.altAxis,o=void 0===s||s,l=i.fallbackPlacements,c=i.padding,u=i.boundary,d=i.rootBoundary,h=i.altBoundary,f=i.flipVariations,p=void 0===f||f,m=i.allowedAutoPlacements,g=t.options.placement,v=U(g),y=l||(v===g||!p?[ue(g)]:function(e){if(U(e)===C)return[];var t=ue(e);return[he(e),t,he(t)]}(g)),b=[g].concat(y).reduce((function(e,i){return e.concat(U(i)===C?fe(t,{placement:i,boundary:u,rootBoundary:d,padding:c,flipVariations:p,allowedAutoPlacements:m}):i)}),[]),x=t.rects.reference,_=t.rects.popper,w=new Map,k=!0,M=b[0],D=0;D<b.length;D++){var O=b[D],P=U(O),Y=q(O)===E,I=[S,A].indexOf(P)>=0,N=I?"width":"height",j=K(t,{placement:O,boundary:u,rootBoundary:d,altBoundary:h,padding:c}),H=I?Y?L:T:Y?A:S;x[N]>_[N]&&(H=ue(H));var F=ue(H),R=[];if(a&&R.push(j[P]<=0),o&&R.push(j[H]<=0,j[F]<=0),R.every((function(e){return e}))){M=O,k=!1;break}w.set(O,R)}if(k)for(var z=function(e){var t=b.find((function(t){var i=w.get(t);if(i)return i.slice(0,e).every((function(e){return e}))}));if(t)return M=t,"break"},B=p?3:1;B>0;B--){if("break"===z(B))break}t.placement!==M&&(t.modifiersData[n]._skip=!0,t.placement=M,t.reset=!0)}},requiresIfExists:["offset"],data:{_skip:!1}};function me(e,t,i){return a(e,s(t,i))}var ge={name:"preventOverflow",enabled:!0,phase:"main",fn:function(e){var t=e.state,i=e.options,n=e.name,r=i.mainAxis,o=void 0===r||r,l=i.altAxis,c=void 0!==l&&l,u=i.boundary,d=i.rootBoundary,h=i.altBoundary,f=i.padding,p=i.tether,m=void 0===p||p,g=i.tetherOffset,v=void 0===g?0:g,b=K(t,{boundary:u,rootBoundary:d,padding:f,altBoundary:h}),x=U(t.placement),_=q(t.placement),w=!_,k=$(x),C="x"===k?"y":"x",D=t.modifiersData.popperOffsets,O=t.rects.reference,P=t.rects.popper,Y="function"==typeof v?v(Object.assign({},t.rects,{placement:t.placement})):v,I="number"==typeof Y?{mainAxis:Y,altAxis:Y}:Object.assign({mainAxis:0,altAxis:0},Y),N=t.modifiersData.offset?t.modifiersData.offset[t.placement]:null,j={x:0,y:0};if(D){if(o){var H,F="y"===k?S:T,R="y"===k?A:L,z="y"===k?"height":"width",B=D[k],V=B+b[F],W=B-b[R],X=m?-P[z]/2:0,G=_===E?O[z]:P[z],Z=_===E?-P[z]:-O[z],J=t.elements.arrow,Q=m&&J?y(J):{width:0,height:0},ee=t.modifiersData["arrow#persistent"]?t.modifiersData["arrow#persistent"].padding:{top:0,right:0,bottom:0,left:0},te=ee[F],ie=ee[R],ne=me(0,O[z],Q[z]),re=w?O[z]/2-X-ne-te-I.mainAxis:G-ne-te-I.mainAxis,ae=w?-O[z]/2+X+ne+ie+I.mainAxis:Z+ne+ie+I.mainAxis,se=t.elements.arrow&&M(t.elements.arrow),oe=se?"y"===k?se.clientTop||0:se.clientLeft||0:0,le=null!=(H=null==N?void 0:N[k])?H:0,ce=B+ae-le,ue=me(m?s(V,B+re-le-oe):V,B,m?a(W,ce):W);D[k]=ue,j[k]=ue-B}if(c){var de,he="x"===k?S:T,fe="x"===k?A:L,pe=D[C],ge="y"===C?"height":"width",ve=pe+b[he],ye=pe-b[fe],be=-1!==[S,T].indexOf(x),xe=null!=(de=null==N?void 0:N[C])?de:0,_e=be?ve:pe-O[ge]-P[ge]-xe+I.altAxis,we=be?pe+O[ge]+P[ge]-xe-I.altAxis:ye,ke=m&&be?function(e,t,i){var n=me(e,t,i);return n>i?i:n}(_e,pe,we):me(m?_e:ve,pe,m?we:ye);D[C]=ke,j[C]=ke-pe}t.modifiersData[n]=j}},requiresIfExists:["offset"]};var ve={name:"arrow",enabled:!0,phase:"main",fn:function(e){var t,i=e.state,n=e.name,r=e.options,a=i.elements.arrow,s=i.modifiersData.popperOffsets,o=U(i.placement),l=$(o),c=[T,L].indexOf(o)>=0?"height":"width";if(a&&s){var u=function(e,t){return G("number"!=typeof(e="function"==typeof e?e(Object.assign({},t.rects,{placement:t.placement})):e)?e:Z(e,D))}(r.padding,i),d=y(a),h="y"===l?S:T,f="y"===l?A:L,p=i.rects.reference[c]+i.rects.reference[l]-s[l]-i.rects.popper[c],m=s[l]-i.rects.reference[l],g=M(a),v=g?"y"===l?g.clientHeight||0:g.clientWidth||0:0,b=p/2-m/2,x=u[h],_=v-d[c]-u[f],w=v/2-d[c]/2+b,k=me(x,w,_),C=l;i.modifiersData[n]=((t={})[C]=k,t.centerOffset=k-w,t)}},effect:function(e){var t=e.state,i=e.options.element,n=void 0===i?"[data-popper-arrow]":i;null!=n&&("string"!=typeof n||(n=t.elements.popper.querySelector(n)))&&z(t.elements.popper,n)&&(t.elements.arrow=n)},requires:["popperOffsets"],requiresIfExists:["preventOverflow"]};function ye(e,t,i){return void 0===i&&(i={x:0,y:0}),{top:e.top-t.height-i.y,right:e.right-t.width+i.x,bottom:e.bottom-t.height+i.y,left:e.left-t.width-i.x}}function be(e){return[S,L,A,T].some((function(t){return e[t]>=0}))}var xe={name:"hide",enabled:!0,phase:"main",requiresIfExists:["preventOverflow"],fn:function(e){var t=e.state,i=e.name,n=t.rects.reference,r=t.rects.popper,a=t.modifiersData.preventOverflow,s=K(t,{elementContext:"reference"}),o=K(t,{altBoundary:!0}),l=ye(s,n),c=ye(o,r,a),u=be(l),d=be(c);t.modifiersData[i]={referenceClippingOffsets:l,popperEscapeOffsets:c,isReferenceHidden:u,hasPopperEscaped:d},t.attributes.popper=Object.assign({},t.attributes.popper,{"data-popper-reference-hidden":u,"data-popper-escaped":d})}},_e=ee({defaultModifiers:[ie,ne,se,oe]}),we=[ie,ne,se,oe,le,pe,ge,ve,xe],ke=ee({defaultModifiers:we});e.applyStyles=oe,e.arrow=ve,e.computeStyles=se,e.createPopper=ke,e.createPopperLite=_e,e.defaultModifiers=we,e.detectOverflow=K,e.eventListeners=ie,e.flip=pe,e.hide=xe,e.offset=le,e.popperGenerator=ee,e.popperOffsets=ne,e.preventOverflow=ge,Object.defineProperty(e,"__esModule",{value:!0})})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t(require("@popperjs/core")):"function"==typeof define&&define.amd?define(["@popperjs/core"],t):(e="undefined"!=typeof globalThis?globalThis:e||self).bootstrap=t(e.Popper)}(this,(function(e){"use strict";const t=function(e){const t=Object.create(null,{[Symbol.toStringTag]:{value:"Module"}});if(e)for(const i in e)if("default"!==i){const n=Object.getOwnPropertyDescriptor(e,i);Object.defineProperty(t,i,n.get?n:{enumerable:!0,get:()=>e[i]})}return t.default=e,Object.freeze(t)}(e),i=new Map,n={set(e,t,n){i.has(e)||i.set(e,new Map);const r=i.get(e);r.has(t)||0===r.size?r.set(t,n):console.error(`Bootstrap doesn't allow more than one instance per element. Bound instance: ${Array.from(r.keys())[0]}.`)},get:(e,t)=>i.has(e)&&i.get(e).get(t)||null,remove(e,t){if(!i.has(e))return;const n=i.get(e);n.delete(t),0===n.size&&i.delete(e)}},r="transitionend",a=e=>(e&&window.CSS&&window.CSS.escape&&(e=e.replace(/#([^\s"#']+)/g,((e,t)=>`#${CSS.escape(t)}`))),e),s=e=>{e.dispatchEvent(new Event(r))},o=e=>!(!e||"object"!=typeof e)&&(void 0!==e.jquery&&(e=e[0]),void 0!==e.nodeType),l=e=>o(e)?e.jquery?e[0]:e:"string"==typeof e&&e.length>0?document.querySelector(a(e)):null,c=e=>{if(!o(e)||0===e.getClientRects().length)return!1;const t="visible"===getComputedStyle(e).getPropertyValue("visibility"),i=e.closest("details:not([open])");if(!i)return t;if(i!==e){const t=e.closest("summary");if(t&&t.parentNode!==i)return!1;if(null===t)return!1}return t},u=e=>!e||e.nodeType!==Node.ELEMENT_NODE||!!e.classList.contains("disabled")||(void 0!==e.disabled?e.disabled:e.hasAttribute("disabled")&&"false"!==e.getAttribute("disabled")),d=e=>{if(!document.documentElement.attachShadow)return null;if("function"==typeof e.getRootNode){const t=e.getRootNode();return t instanceof ShadowRoot?t:null}return e instanceof ShadowRoot?e:e.parentNode?d(e.parentNode):null},h=()=>{},f=e=>{e.offsetHeight},p=()=>window.jQuery&&!document.body.hasAttribute("data-bs-no-jquery")?window.jQuery:null,m=[],g=()=>"rtl"===document.documentElement.dir,v=e=>{var t;t=()=>{const t=p();if(t){const i=e.NAME,n=t.fn[i];t.fn[i]=e.jQueryInterface,t.fn[i].Constructor=e,t.fn[i].noConflict=()=>(t.fn[i]=n,e.jQueryInterface)}},"loading"===document.readyState?(m.length||document.addEventListener("DOMContentLoaded",(()=>{for(const e of m)e()})),m.push(t)):t()},y=(e,t=[],i=e)=>"function"==typeof e?e(...t):i,b=(e,t,i=!0)=>{if(!i)return void y(e);const n=(e=>{if(!e)return 0;let{transitionDuration:t,transitionDelay:i}=window.getComputedStyle(e);const n=Number.parseFloat(t),r=Number.parseFloat(i);return n||r?(t=t.split(",")[0],i=i.split(",")[0],1e3*(Number.parseFloat(t)+Number.parseFloat(i))):0})(t)+5;let a=!1;const o=({target:i})=>{i===t&&(a=!0,t.removeEventListener(r,o),y(e))};t.addEventListener(r,o),setTimeout((()=>{a||s(t)}),n)},x=(e,t,i,n)=>{const r=e.length;let a=e.indexOf(t);return-1===a?!i&&n?e[r-1]:e[0]:(a+=i?1:-1,n&&(a=(a+r)%r),e[Math.max(0,Math.min(a,r-1))])},_=/[^.]*(?=\..*)\.|.*/,w=/\..*/,k=/::\d+$/,M={};let S=1;const A={mouseenter:"mouseover",mouseleave:"mouseout"},L=new Set(["click","dblclick","mouseup","mousedown","contextmenu","mousewheel","DOMMouseScroll","mouseover","mouseout","mousemove","selectstart","selectend","keydown","keypress","keyup","orientationchange","touchstart","touchmove","touchend","touchcancel","pointerdown","pointermove","pointerup","pointerleave","pointercancel","gesturestart","gesturechange","gestureend","focus","blur","change","reset","select","submit","focusin","focusout","load","unload","beforeunload","resize","move","DOMContentLoaded","readystatechange","error","abort","scroll"]);function T(e,t){return t&&`${t}::${S++}`||e.uidEvent||S++}function C(e){const t=T(e);return e.uidEvent=t,M[t]=M[t]||{},M[t]}function D(e,t,i=null){return Object.values(e).find((e=>e.callable===t&&e.delegationSelector===i))}function E(e,t,i){const n="string"==typeof t,r=n?i:t||i;let a=I(e);return L.has(a)||(a=e),[n,r,a]}function O(e,t,i,n,r){if("string"!=typeof t||!e)return;let[a,s,o]=E(t,i,n);if(t in A){const e=e=>function(t){if(!t.relatedTarget||t.relatedTarget!==t.delegateTarget&&!t.delegateTarget.contains(t.relatedTarget))return e.call(this,t)};s=e(s)}const l=C(e),c=l[o]||(l[o]={}),u=D(c,s,a?i:null);if(u)return void(u.oneOff=u.oneOff&&r);const d=T(s,t.replace(_,"")),h=a?function(e,t,i){return function n(r){const a=e.querySelectorAll(t);for(let{target:s}=r;s&&s!==this;s=s.parentNode)for(const o of a)if(o===s)return j(r,{delegateTarget:s}),n.oneOff&&N.off(e,r.type,t,i),i.apply(s,[r])}}(e,i,s):function(e,t){return function i(n){return j(n,{delegateTarget:e}),i.oneOff&&N.off(e,n.type,t),t.apply(e,[n])}}(e,s);h.delegationSelector=a?i:null,h.callable=s,h.oneOff=r,h.uidEvent=d,c[d]=h,e.addEventListener(o,h,a)}function P(e,t,i,n,r){const a=D(t[i],n,r);a&&(e.removeEventListener(i,a,Boolean(r)),delete t[i][a.uidEvent])}function Y(e,t,i,n){const r=t[i]||{};for(const[a,s]of Object.entries(r))a.includes(n)&&P(e,t,i,s.callable,s.delegationSelector)}function I(e){return e=e.replace(w,""),A[e]||e}const N={on(e,t,i,n){O(e,t,i,n,!1)},one(e,t,i,n){O(e,t,i,n,!0)},off(e,t,i,n){if("string"!=typeof t||!e)return;const[r,a,s]=E(t,i,n),o=s!==t,l=C(e),c=l[s]||{},u=t.startsWith(".");if(void 0===a){if(u)for(const i of Object.keys(l))Y(e,l,i,t.slice(1));for(const[i,n]of Object.entries(c)){const r=i.replace(k,"");o&&!t.includes(r)||P(e,l,s,n.callable,n.delegationSelector)}}else{if(!Object.keys(c).length)return;P(e,l,s,a,r?i:null)}},trigger(e,t,i){if("string"!=typeof t||!e)return null;const n=p();let r=null,a=!0,s=!0,o=!1;t!==I(t)&&n&&(r=n.Event(t,i),n(e).trigger(r),a=!r.isPropagationStopped(),s=!r.isImmediatePropagationStopped(),o=r.isDefaultPrevented());const l=j(new Event(t,{bubbles:a,cancelable:!0}),i);return o&&l.preventDefault(),s&&e.dispatchEvent(l),l.defaultPrevented&&r&&r.preventDefault(),l}};function j(e,t={}){for(const[i,n]of Object.entries(t))try{e[i]=n}catch(t){Object.defineProperty(e,i,{configurable:!0,get:()=>n})}return e}function H(e){if("true"===e)return!0;if("false"===e)return!1;if(e===Number(e).toString())return Number(e);if(""===e||"null"===e)return null;if("string"!=typeof e)return e;try{return JSON.parse(decodeURIComponent(e))}catch(t){return e}}function F(e){return e.replace(/[A-Z]/g,(e=>`-${e.toLowerCase()}`))}const R={setDataAttribute(e,t,i){e.setAttribute(`data-bs-${F(t)}`,i)},removeDataAttribute(e,t){e.removeAttribute(`data-bs-${F(t)}`)},getDataAttributes(e){if(!e)return{};const t={},i=Object.keys(e.dataset).filter((e=>e.startsWith("bs")&&!e.startsWith("bsConfig")));for(const n of i){let i=n.replace(/^bs/,"");i=i.charAt(0).toLowerCase()+i.slice(1,i.length),t[i]=H(e.dataset[n])}return t},getDataAttribute:(e,t)=>H(e.getAttribute(`data-bs-${F(t)}`))};class z{static get Default(){return{}}static get DefaultType(){return{}}static get NAME(){throw new Error('You have to implement the static method "NAME", for each component!')}_getConfig(e){return e=this._mergeConfigObj(e),e=this._configAfterMerge(e),this._typeCheckConfig(e),e}_configAfterMerge(e){return e}_mergeConfigObj(e,t){const i=o(t)?R.getDataAttribute(t,"config"):{};return{...this.constructor.Default,..."object"==typeof i?i:{},...o(t)?R.getDataAttributes(t):{},..."object"==typeof e?e:{}}}_typeCheckConfig(e,t=this.constructor.DefaultType){for(const[n,r]of Object.entries(t)){const t=e[n],a=o(t)?"element":null==(i=t)?`${i}`:Object.prototype.toString.call(i).match(/\s([a-z]+)/i)[1].toLowerCase();if(!new RegExp(r).test(a))throw new TypeError(`${this.constructor.NAME.toUpperCase()}: Option "${n}" provided type "${a}" but expected type "${r}".`)}var i}}class B extends z{constructor(e,t){super(),(e=l(e))&&(this._element=e,this._config=this._getConfig(t),n.set(this._element,this.constructor.DATA_KEY,this))}dispose(){n.remove(this._element,this.constructor.DATA_KEY),N.off(this._element,this.constructor.EVENT_KEY);for(const e of Object.getOwnPropertyNames(this))this[e]=null}_queueCallback(e,t,i=!0){b(e,t,i)}_getConfig(e){return e=this._mergeConfigObj(e,this._element),e=this._configAfterMerge(e),this._typeCheckConfig(e),e}static getInstance(e){return n.get(l(e),this.DATA_KEY)}static getOrCreateInstance(e,t={}){return this.getInstance(e)||new this(e,"object"==typeof t?t:null)}static get VERSION(){return"5.3.3"}static get DATA_KEY(){return`bs.${this.NAME}`}static get EVENT_KEY(){return`.${this.DATA_KEY}`}static eventName(e){return`${e}${this.EVENT_KEY}`}}const V=e=>{let t=e.getAttribute("data-bs-target");if(!t||"#"===t){let i=e.getAttribute("href");if(!i||!i.includes("#")&&!i.startsWith("."))return null;i.includes("#")&&!i.startsWith("#")&&(i=`#${i.split("#")[1]}`),t=i&&"#"!==i?i.trim():null}return t?t.split(",").map((e=>a(e))).join(","):null},W={find:(e,t=document.documentElement)=>[].concat(...Element.prototype.querySelectorAll.call(t,e)),findOne:(e,t=document.documentElement)=>Element.prototype.querySelector.call(t,e),children:(e,t)=>[].concat(...e.children).filter((e=>e.matches(t))),parents(e,t){const i=[];let n=e.parentNode.closest(t);for(;n;)i.push(n),n=n.parentNode.closest(t);return i},prev(e,t){let i=e.previousElementSibling;for(;i;){if(i.matches(t))return[i];i=i.previousElementSibling}return[]},next(e,t){let i=e.nextElementSibling;for(;i;){if(i.matches(t))return[i];i=i.nextElementSibling}return[]},focusableChildren(e){const t=["a","button","input","textarea","select","details","[tabindex]",'[contenteditable="true"]'].map((e=>`${e}:not([tabindex^="-"])`)).join(",");return this.find(t,e).filter((e=>!u(e)&&c(e)))},getSelectorFromElement(e){const t=V(e);return t&&W.findOne(t)?t:null},getElementFromSelector(e){const t=V(e);return t?W.findOne(t):null},getMultipleElementsFromSelector(e){const t=V(e);return t?W.find(t):[]}},U=(e,t="hide")=>{const i=`click.dismiss${e.EVENT_KEY}`,n=e.NAME;N.on(document,i,`[data-bs-dismiss="${n}"]`,(function(i){if(["A","AREA"].includes(this.tagName)&&i.preventDefault(),u(this))return;const r=W.getElementFromSelector(this)||this.closest(`.${n}`);e.getOrCreateInstance(r)[t]()}))},q=".bs.alert",$=`close${q}`,X=`closed${q}`;class G extends B{static get NAME(){return"alert"}close(){if(N.trigger(this._element,$).defaultPrevented)return;this._element.classList.remove("show");const e=this._element.classList.contains("fade");this._queueCallback((()=>this._destroyElement()),this._element,e)}_destroyElement(){this._element.remove(),N.trigger(this._element,X),this.dispose()}static jQueryInterface(e){return this.each((function(){const t=G.getOrCreateInstance(this);if("string"==typeof e){if(void 0===t[e]||e.startsWith("_")||"constructor"===e)throw new TypeError(`No method named "${e}"`);t[e](this)}}))}}U(G,"close"),v(G);const Z='[data-bs-toggle="button"]';class K extends B{static get NAME(){return"button"}toggle(){this._element.setAttribute("aria-pressed",this._element.classList.toggle("active"))}static jQueryInterface(e){return this.each((function(){const t=K.getOrCreateInstance(this);"toggle"===e&&t[e]()}))}}N.on(document,"click.bs.button.data-api",Z,(e=>{e.preventDefault();const t=e.target.closest(Z);K.getOrCreateInstance(t).toggle()})),v(K);const J=".bs.swipe",Q=`touchstart${J}`,ee=`touchmove${J}`,te=`touchend${J}`,ie=`pointerdown${J}`,ne=`pointerup${J}`,re={endCallback:null,leftCallback:null,rightCallback:null},ae={endCallback:"(function|null)",leftCallback:"(function|null)",rightCallback:"(function|null)"};class se extends z{constructor(e,t){super(),this._element=e,e&&se.isSupported()&&(this._config=this._getConfig(t),this._deltaX=0,this._supportPointerEvents=Boolean(window.PointerEvent),this._initEvents())}static get Default(){return re}static get DefaultType(){return ae}static get NAME(){return"swipe"}dispose(){N.off(this._element,J)}_start(e){this._supportPointerEvents?this._eventIsPointerPenTouch(e)&&(this._deltaX=e.clientX):this._deltaX=e.touches[0].clientX}_end(e){this._eventIsPointerPenTouch(e)&&(this._deltaX=e.clientX-this._deltaX),this._handleSwipe(),y(this._config.endCallback)}_move(e){this._deltaX=e.touches&&e.touches.length>1?0:e.touches[0].clientX-this._deltaX}_handleSwipe(){const e=Math.abs(this._deltaX);if(e<=40)return;const t=e/this._deltaX;this._deltaX=0,t&&y(t>0?this._config.rightCallback:this._config.leftCallback)}_initEvents(){this._supportPointerEvents?(N.on(this._element,ie,(e=>this._start(e))),N.on(this._element,ne,(e=>this._end(e))),this._element.classList.add("pointer-event")):(N.on(this._element,Q,(e=>this._start(e))),N.on(this._element,ee,(e=>this._move(e))),N.on(this._element,te,(e=>this._end(e))))}_eventIsPointerPenTouch(e){return this._supportPointerEvents&&("pen"===e.pointerType||"touch"===e.pointerType)}static isSupported(){return"ontouchstart"in document.documentElement||navigator.maxTouchPoints>0}}const oe=".bs.carousel",le=".data-api",ce="next",ue="prev",de="left",he="right",fe=`slide${oe}`,pe=`slid${oe}`,me=`keydown${oe}`,ge=`mouseenter${oe}`,ve=`mouseleave${oe}`,ye=`dragstart${oe}`,be=`load${oe}${le}`,xe=`click${oe}${le}`,_e="carousel",we="active",ke=".active",Me=".carousel-item",Se=ke+Me,Ae={ArrowLeft:he,ArrowRight:de},Le={interval:5e3,keyboard:!0,pause:"hover",ride:!1,touch:!0,wrap:!0},Te={interval:"(number|boolean)",keyboard:"boolean",pause:"(string|boolean)",ride:"(boolean|string)",touch:"boolean",wrap:"boolean"};class Ce extends B{constructor(e,t){super(e,t),this._interval=null,this._activeElement=null,this._isSliding=!1,this.touchTimeout=null,this._swipeHelper=null,this._indicatorsElement=W.findOne(".carousel-indicators",this._element),this._addEventListeners(),this._config.ride===_e&&this.cycle()}static get Default(){return Le}static get DefaultType(){return Te}static get NAME(){return"carousel"}next(){this._slide(ce)}nextWhenVisible(){!document.hidden&&c(this._element)&&this.next()}prev(){this._slide(ue)}pause(){this._isSliding&&s(this._element),this._clearInterval()}cycle(){this._clearInterval(),this._updateInterval(),this._interval=setInterval((()=>this.nextWhenVisible()),this._config.interval)}_maybeEnableCycle(){this._config.ride&&(this._isSliding?N.one(this._element,pe,(()=>this.cycle())):this.cycle())}to(e){const t=this._getItems();if(e>t.length-1||e<0)return;if(this._isSliding)return void N.one(this._element,pe,(()=>this.to(e)));const i=this._getItemIndex(this._getActive());if(i===e)return;const n=e>i?ce:ue;this._slide(n,t[e])}dispose(){this._swipeHelper&&this._swipeHelper.dispose(),super.dispose()}_configAfterMerge(e){return e.defaultInterval=e.interval,e}_addEventListeners(){this._config.keyboard&&N.on(this._element,me,(e=>this._keydown(e))),"hover"===this._config.pause&&(N.on(this._element,ge,(()=>this.pause())),N.on(this._element,ve,(()=>this._maybeEnableCycle()))),this._config.touch&&se.isSupported()&&this._addTouchEventListeners()}_addTouchEventListeners(){for(const e of W.find(".carousel-item img",this._element))N.on(e,ye,(e=>e.preventDefault()));const e={leftCallback:()=>this._slide(this._directionToOrder(de)),rightCallback:()=>this._slide(this._directionToOrder(he)),endCallback:()=>{"hover"===this._config.pause&&(this.pause(),this.touchTimeout&&clearTimeout(this.touchTimeout),this.touchTimeout=setTimeout((()=>this._maybeEnableCycle()),500+this._config.interval))}};this._swipeHelper=new se(this._element,e)}_keydown(e){if(/input|textarea/i.test(e.target.tagName))return;const t=Ae[e.key];t&&(e.preventDefault(),this._slide(this._directionToOrder(t)))}_getItemIndex(e){return this._getItems().indexOf(e)}_setActiveIndicatorElement(e){if(!this._indicatorsElement)return;const t=W.findOne(ke,this._indicatorsElement);t.classList.remove(we),t.removeAttribute("aria-current");const i=W.findOne(`[data-bs-slide-to="${e}"]`,this._indicatorsElement);i&&(i.classList.add(we),i.setAttribute("aria-current","true"))}_updateInterval(){const e=this._activeElement||this._getActive();if(!e)return;const t=Number.parseInt(e.getAttribute("data-bs-interval"),10);this._config.interval=t||this._config.defaultInterval}_slide(e,t=null){if(this._isSliding)return;const i=this._getActive(),n=e===ce,r=t||x(this._getItems(),i,n,this._config.wrap);if(r===i)return;const a=this._getItemIndex(r),s=t=>N.trigger(this._element,t,{relatedTarget:r,direction:this._orderToDirection(e),from:this._getItemIndex(i),to:a});if(s(fe).defaultPrevented)return;if(!i||!r)return;const o=Boolean(this._interval);this.pause(),this._isSliding=!0,this._setActiveIndicatorElement(a),this._activeElement=r;const l=n?"carousel-item-start":"carousel-item-end",c=n?"carousel-item-next":"carousel-item-prev";r.classList.add(c),f(r),i.classList.add(l),r.classList.add(l),this._queueCallback((()=>{r.classList.remove(l,c),r.classList.add(we),i.classList.remove(we,c,l),this._isSliding=!1,s(pe)}),i,this._isAnimated()),o&&this.cycle()}_isAnimated(){return this._element.classList.contains("slide")}_getActive(){return W.findOne(Se,this._element)}_getItems(){return W.find(Me,this._element)}_clearInterval(){this._interval&&(clearInterval(this._interval),this._interval=null)}_directionToOrder(e){return g()?e===de?ue:ce:e===de?ce:ue}_orderToDirection(e){return g()?e===ue?de:he:e===ue?he:de}static jQueryInterface(e){return this.each((function(){const t=Ce.getOrCreateInstance(this,e);if("number"!=typeof e){if("string"==typeof e){if(void 0===t[e]||e.startsWith("_")||"constructor"===e)throw new TypeError(`No method named "${e}"`);t[e]()}}else t.to(e)}))}}N.on(document,xe,"[data-bs-slide], [data-bs-slide-to]",(function(e){const t=W.getElementFromSelector(this);if(!t||!t.classList.contains(_e))return;e.preventDefault();const i=Ce.getOrCreateInstance(t),n=this.getAttribute("data-bs-slide-to");return n?(i.to(n),void i._maybeEnableCycle()):"next"===R.getDataAttribute(this,"slide")?(i.next(),void i._maybeEnableCycle()):(i.prev(),void i._maybeEnableCycle())})),N.on(window,be,(()=>{const e=W.find('[data-bs-ride="carousel"]');for(const t of e)Ce.getOrCreateInstance(t)})),v(Ce);const De=".bs.collapse",Ee=`show${De}`,Oe=`shown${De}`,Pe=`hide${De}`,Ye=`hidden${De}`,Ie=`click${De}.data-api`,Ne="show",je="collapse",He="collapsing",Fe=`:scope .${je} .${je}`,Re='[data-bs-toggle="collapse"]',ze={parent:null,toggle:!0},Be={parent:"(null|element)",toggle:"boolean"};class Ve extends B{constructor(e,t){super(e,t),this._isTransitioning=!1,this._triggerArray=[];const i=W.find(Re);for(const e of i){const t=W.getSelectorFromElement(e),i=W.find(t).filter((e=>e===this._element));null!==t&&i.length&&this._triggerArray.push(e)}this._initializeChildren(),this._config.parent||this._addAriaAndCollapsedClass(this._triggerArray,this._isShown()),this._config.toggle&&this.toggle()}static get Default(){return ze}static get DefaultType(){return Be}static get NAME(){return"collapse"}toggle(){this._isShown()?this.hide():this.show()}show(){if(this._isTransitioning||this._isShown())return;let e=[];if(this._config.parent&&(e=this._getFirstLevelChildren(".collapse.show, .collapse.collapsing").filter((e=>e!==this._element)).map((e=>Ve.getOrCreateInstance(e,{toggle:!1})))),e.length&&e[0]._isTransitioning)return;if(N.trigger(this._element,Ee).defaultPrevented)return;for(const t of e)t.hide();const t=this._getDimension();this._element.classList.remove(je),this._element.classList.add(He),this._element.style[t]=0,this._addAriaAndCollapsedClass(this._triggerArray,!0),this._isTransitioning=!0;const i=`scroll${t[0].toUpperCase()+t.slice(1)}`;this._queueCallback((()=>{this._isTransitioning=!1,this._element.classList.remove(He),this._element.classList.add(je,Ne),this._element.style[t]="",N.trigger(this._element,Oe)}),this._element,!0),this._element.style[t]=`${this._element[i]}px`}hide(){if(this._isTransitioning||!this._isShown())return;if(N.trigger(this._element,Pe).defaultPrevented)return;const e=this._getDimension();this._element.style[e]=`${this._element.getBoundingClientRect()[e]}px`,f(this._element),this._element.classList.add(He),this._element.classList.remove(je,Ne);for(const e of this._triggerArray){const t=W.getElementFromSelector(e);t&&!this._isShown(t)&&this._addAriaAndCollapsedClass([e],!1)}this._isTransitioning=!0,this._element.style[e]="",this._queueCallback((()=>{this._isTransitioning=!1,this._element.classList.remove(He),this._element.classList.add(je),N.trigger(this._element,Ye)}),this._element,!0)}_isShown(e=this._element){return e.classList.contains(Ne)}_configAfterMerge(e){return e.toggle=Boolean(e.toggle),e.parent=l(e.parent),e}_getDimension(){return this._element.classList.contains("collapse-horizontal")?"width":"height"}_initializeChildren(){if(!this._config.parent)return;const e=this._getFirstLevelChildren(Re);for(const t of e){const e=W.getElementFromSelector(t);e&&this._addAriaAndCollapsedClass([t],this._isShown(e))}}_getFirstLevelChildren(e){const t=W.find(Fe,this._config.parent);return W.find(e,this._config.parent).filter((e=>!t.includes(e)))}_addAriaAndCollapsedClass(e,t){if(e.length)for(const i of e)i.classList.toggle("collapsed",!t),i.setAttribute("aria-expanded",t)}static jQueryInterface(e){const t={};return"string"==typeof e&&/show|hide/.test(e)&&(t.toggle=!1),this.each((function(){const i=Ve.getOrCreateInstance(this,t);if("string"==typeof e){if(void 0===i[e])throw new TypeError(`No method named "${e}"`);i[e]()}}))}}N.on(document,Ie,Re,(function(e){("A"===e.target.tagName||e.delegateTarget&&"A"===e.delegateTarget.tagName)&&e.preventDefault();for(const e of W.getMultipleElementsFromSelector(this))Ve.getOrCreateInstance(e,{toggle:!1}).toggle()})),v(Ve);const We="dropdown",Ue=".bs.dropdown",qe=".data-api",$e="ArrowUp",Xe="ArrowDown",Ge=`hide${Ue}`,Ze=`hidden${Ue}`,Ke=`show${Ue}`,Je=`shown${Ue}`,Qe=`click${Ue}${qe}`,et=`keydown${Ue}${qe}`,tt=`keyup${Ue}${qe}`,it="show",nt='[data-bs-toggle="dropdown"]:not(.disabled):not(:disabled)',rt=`${nt}.${it}`,at=".dropdown-menu",st=g()?"top-end":"top-start",ot=g()?"top-start":"top-end",lt=g()?"bottom-end":"bottom-start",ct=g()?"bottom-start":"bottom-end",ut=g()?"left-start":"right-start",dt=g()?"right-start":"left-start",ht={autoClose:!0,boundary:"clippingParents",display:"dynamic",offset:[0,2],popperConfig:null,reference:"toggle"},ft={autoClose:"(boolean|string)",boundary:"(string|element)",display:"string",offset:"(array|string|function)",popperConfig:"(null|object|function)",reference:"(string|element|object)"};class pt extends B{constructor(e,t){super(e,t),this._popper=null,this._parent=this._element.parentNode,this._menu=W.next(this._element,at)[0]||W.prev(this._element,at)[0]||W.findOne(at,this._parent),this._inNavbar=this._detectNavbar()}static get Default(){return ht}static get DefaultType(){return ft}static get NAME(){return We}toggle(){return this._isShown()?this.hide():this.show()}show(){if(u(this._element)||this._isShown())return;const e={relatedTarget:this._element};if(!N.trigger(this._element,Ke,e).defaultPrevented){if(this._createPopper(),"ontouchstart"in document.documentElement&&!this._parent.closest(".navbar-nav"))for(const e of[].concat(...document.body.children))N.on(e,"mouseover",h);this._element.focus(),this._element.setAttribute("aria-expanded",!0),this._menu.classList.add(it),this._element.classList.add(it),N.trigger(this._element,Je,e)}}hide(){if(u(this._element)||!this._isShown())return;const e={relatedTarget:this._element};this._completeHide(e)}dispose(){this._popper&&this._popper.destroy(),super.dispose()}update(){this._inNavbar=this._detectNavbar(),this._popper&&this._popper.update()}_completeHide(e){if(!N.trigger(this._element,Ge,e).defaultPrevented){if("ontouchstart"in document.documentElement)for(const e of[].concat(...document.body.children))N.off(e,"mouseover",h);this._popper&&this._popper.destroy(),this._menu.classList.remove(it),this._element.classList.remove(it),this._element.setAttribute("aria-expanded","false"),R.removeDataAttribute(this._menu,"popper"),N.trigger(this._element,Ze,e)}}_getConfig(e){if("object"==typeof(e=super._getConfig(e)).reference&&!o(e.reference)&&"function"!=typeof e.reference.getBoundingClientRect)throw new TypeError(`${We.toUpperCase()}: Option "reference" provided type "object" without a required "getBoundingClientRect" method.`);return e}_createPopper(){if(void 0===t)throw new TypeError("Bootstrap's dropdowns require Popper (https://popper.js.org)");let e=this._element;"parent"===this._config.reference?e=this._parent:o(this._config.reference)?e=l(this._config.reference):"object"==typeof this._config.reference&&(e=this._config.reference);const i=this._getPopperConfig();this._popper=t.createPopper(e,this._menu,i)}_isShown(){return this._menu.classList.contains(it)}_getPlacement(){const e=this._parent;if(e.classList.contains("dropend"))return ut;if(e.classList.contains("dropstart"))return dt;if(e.classList.contains("dropup-center"))return"top";if(e.classList.contains("dropdown-center"))return"bottom";const t="end"===getComputedStyle(this._menu).getPropertyValue("--bs-position").trim();return e.classList.contains("dropup")?t?ot:st:t?ct:lt}_detectNavbar(){return null!==this._element.closest(".navbar")}_getOffset(){const{offset:e}=this._config;return"string"==typeof e?e.split(",").map((e=>Number.parseInt(e,10))):"function"==typeof e?t=>e(t,this._element):e}_getPopperConfig(){const e={placement:this._getPlacement(),modifiers:[{name:"preventOverflow",options:{boundary:this._config.boundary}},{name:"offset",options:{offset:this._getOffset()}}]};return(this._inNavbar||"static"===this._config.display)&&(R.setDataAttribute(this._menu,"popper","static"),e.modifiers=[{name:"applyStyles",enabled:!1}]),{...e,...y(this._config.popperConfig,[e])}}_selectMenuItem({key:e,target:t}){const i=W.find(".dropdown-menu .dropdown-item:not(.disabled):not(:disabled)",this._menu).filter((e=>c(e)));i.length&&x(i,t,e===Xe,!i.includes(t)).focus()}static jQueryInterface(e){return this.each((function(){const t=pt.getOrCreateInstance(this,e);if("string"==typeof e){if(void 0===t[e])throw new TypeError(`No method named "${e}"`);t[e]()}}))}static clearMenus(e){if(2===e.button||"keyup"===e.type&&"Tab"!==e.key)return;const t=W.find(rt);for(const i of t){const t=pt.getInstance(i);if(!t||!1===t._config.autoClose)continue;const n=e.composedPath(),r=n.includes(t._menu);if(n.includes(t._element)||"inside"===t._config.autoClose&&!r||"outside"===t._config.autoClose&&r)continue;if(t._menu.contains(e.target)&&("keyup"===e.type&&"Tab"===e.key||/input|select|option|textarea|form/i.test(e.target.tagName)))continue;const a={relatedTarget:t._element};"click"===e.type&&(a.clickEvent=e),t._completeHide(a)}}static dataApiKeydownHandler(e){const t=/input|textarea/i.test(e.target.tagName),i="Escape"===e.key,n=[$e,Xe].includes(e.key);if(!n&&!i)return;if(t&&!i)return;e.preventDefault();const r=this.matches(nt)?this:W.prev(this,nt)[0]||W.next(this,nt)[0]||W.findOne(nt,e.delegateTarget.parentNode),a=pt.getOrCreateInstance(r);if(n)return e.stopPropagation(),a.show(),void a._selectMenuItem(e);a._isShown()&&(e.stopPropagation(),a.hide(),r.focus())}}N.on(document,et,nt,pt.dataApiKeydownHandler),N.on(document,et,at,pt.dataApiKeydownHandler),N.on(document,Qe,pt.clearMenus),N.on(document,tt,pt.clearMenus),N.on(document,Qe,nt,(function(e){e.preventDefault(),pt.getOrCreateInstance(this).toggle()})),v(pt);const mt="backdrop",gt="show",vt=`mousedown.bs.${mt}`,yt={className:"modal-backdrop",clickCallback:null,isAnimated:!1,isVisible:!0,rootElement:"body"},bt={className:"string",clickCallback:"(function|null)",isAnimated:"boolean",isVisible:"boolean",rootElement:"(element|string)"};class xt extends z{constructor(e){super(),this._config=this._getConfig(e),this._isAppended=!1,this._element=null}static get Default(){return yt}static get DefaultType(){return bt}static get NAME(){return mt}show(e){if(!this._config.isVisible)return void y(e);this._append();const t=this._getElement();this._config.isAnimated&&f(t),t.classList.add(gt),this._emulateAnimation((()=>{y(e)}))}hide(e){this._config.isVisible?(this._getElement().classList.remove(gt),this._emulateAnimation((()=>{this.dispose(),y(e)}))):y(e)}dispose(){this._isAppended&&(N.off(this._element,vt),this._element.remove(),this._isAppended=!1)}_getElement(){if(!this._element){const e=document.createElement("div");e.className=this._config.className,this._config.isAnimated&&e.classList.add("fade"),this._element=e}return this._element}_configAfterMerge(e){return e.rootElement=l(e.rootElement),e}_append(){if(this._isAppended)return;const e=this._getElement();this._config.rootElement.append(e),N.on(e,vt,(()=>{y(this._config.clickCallback)})),this._isAppended=!0}_emulateAnimation(e){b(e,this._getElement(),this._config.isAnimated)}}const _t=".bs.focustrap",wt=`focusin${_t}`,kt=`keydown.tab${_t}`,Mt="backward",St={autofocus:!0,trapElement:null},At={autofocus:"boolean",trapElement:"element"};class Lt extends z{constructor(e){super(),this._config=this._getConfig(e),this._isActive=!1,this._lastTabNavDirection=null}static get Default(){return St}static get DefaultType(){return At}static get NAME(){return"focustrap"}activate(){this._isActive||(this._config.autofocus&&this._config.trapElement.focus(),N.off(document,_t),N.on(document,wt,(e=>this._handleFocusin(e))),N.on(document,kt,(e=>this._handleKeydown(e))),this._isActive=!0)}deactivate(){this._isActive&&(this._isActive=!1,N.off(document,_t))}_handleFocusin(e){const{trapElement:t}=this._config;if(e.target===document||e.target===t||t.contains(e.target))return;const i=W.focusableChildren(t);0===i.length?t.focus():this._lastTabNavDirection===Mt?i[i.length-1].focus():i[0].focus()}_handleKeydown(e){"Tab"===e.key&&(this._lastTabNavDirection=e.shiftKey?Mt:"forward")}}const Tt=".fixed-top, .fixed-bottom, .is-fixed, .sticky-top",Ct=".sticky-top",Dt="padding-right",Et="margin-right";class Ot{constructor(){this._element=document.body}getWidth(){const e=document.documentElement.clientWidth;return Math.abs(window.innerWidth-e)}hide(){const e=this.getWidth();this._disableOverFlow(),this._setElementAttributes(this._element,Dt,(t=>t+e)),this._setElementAttributes(Tt,Dt,(t=>t+e)),this._setElementAttributes(Ct,Et,(t=>t-e))}reset(){this._resetElementAttributes(this._element,"overflow"),this._resetElementAttributes(this._element,Dt),this._resetElementAttributes(Tt,Dt),this._resetElementAttributes(Ct,Et)}isOverflowing(){return this.getWidth()>0}_disableOverFlow(){this._saveInitialAttribute(this._element,"overflow"),this._element.style.overflow="hidden"}_setElementAttributes(e,t,i){const n=this.getWidth();this._applyManipulationCallback(e,(e=>{if(e!==this._element&&window.innerWidth>e.clientWidth+n)return;this._saveInitialAttribute(e,t);const r=window.getComputedStyle(e).getPropertyValue(t);e.style.setProperty(t,`${i(Number.parseFloat(r))}px`)}))}_saveInitialAttribute(e,t){const i=e.style.getPropertyValue(t);i&&R.setDataAttribute(e,t,i)}_resetElementAttributes(e,t){this._applyManipulationCallback(e,(e=>{const i=R.getDataAttribute(e,t);null!==i?(R.removeDataAttribute(e,t),e.style.setProperty(t,i)):e.style.removeProperty(t)}))}_applyManipulationCallback(e,t){if(o(e))t(e);else for(const i of W.find(e,this._element))t(i)}}const Pt=".bs.modal",Yt=`hide${Pt}`,It=`hidePrevented${Pt}`,Nt=`hidden${Pt}`,jt=`show${Pt}`,Ht=`shown${Pt}`,Ft=`resize${Pt}`,Rt=`click.dismiss${Pt}`,zt=`mousedown.dismiss${Pt}`,Bt=`keydown.dismiss${Pt}`,Vt=`click${Pt}.data-api`,Wt="modal-open",Ut="show",qt="modal-static",$t={backdrop:!0,focus:!0,keyboard:!0},Xt={backdrop:"(boolean|string)",focus:"boolean",keyboard:"boolean"};class Gt extends B{constructor(e,t){super(e,t),this._dialog=W.findOne(".modal-dialog",this._element),this._backdrop=this._initializeBackDrop(),this._focustrap=this._initializeFocusTrap(),this._isShown=!1,this._isTransitioning=!1,this._scrollBar=new Ot,this._addEventListeners()}static get Default(){return $t}static get DefaultType(){return Xt}static get NAME(){return"modal"}toggle(e){return this._isShown?this.hide():this.show(e)}show(e){this._isShown||this._isTransitioning||N.trigger(this._element,jt,{relatedTarget:e}).defaultPrevented||(this._isShown=!0,this._isTransitioning=!0,this._scrollBar.hide(),document.body.classList.add(Wt),this._adjustDialog(),this._backdrop.show((()=>this._showElement(e))))}hide(){this._isShown&&!this._isTransitioning&&(N.trigger(this._element,Yt).defaultPrevented||(this._isShown=!1,this._isTransitioning=!0,this._focustrap.deactivate(),this._element.classList.remove(Ut),this._queueCallback((()=>this._hideModal()),this._element,this._isAnimated())))}dispose(){N.off(window,Pt),N.off(this._dialog,Pt),this._backdrop.dispose(),this._focustrap.deactivate(),super.dispose()}handleUpdate(){this._adjustDialog()}_initializeBackDrop(){return new xt({isVisible:Boolean(this._config.backdrop),isAnimated:this._isAnimated()})}_initializeFocusTrap(){return new Lt({trapElement:this._element})}_showElement(e){document.body.contains(this._element)||document.body.append(this._element),this._element.style.display="block",this._element.removeAttribute("aria-hidden"),this._element.setAttribute("aria-modal",!0),this._element.setAttribute("role","dialog"),this._element.scrollTop=0;const t=W.findOne(".modal-body",this._dialog);t&&(t.scrollTop=0),f(this._element),this._element.classList.add(Ut),this._queueCallback((()=>{this._config.focus&&this._focustrap.activate(),this._isTransitioning=!1,N.trigger(this._element,Ht,{relatedTarget:e})}),this._dialog,this._isAnimated())}_addEventListeners(){N.on(this._element,Bt,(e=>{"Escape"===e.key&&(this._config.keyboard?this.hide():this._triggerBackdropTransition())})),N.on(window,Ft,(()=>{this._isShown&&!this._isTransitioning&&this._adjustDialog()})),N.on(this._element,zt,(e=>{N.one(this._element,Rt,(t=>{this._element===e.target&&this._element===t.target&&("static"!==this._config.backdrop?this._config.backdrop&&this.hide():this._triggerBackdropTransition())}))}))}_hideModal(){this._element.style.display="none",this._element.setAttribute("aria-hidden",!0),this._element.removeAttribute("aria-modal"),this._element.removeAttribute("role"),this._isTransitioning=!1,this._backdrop.hide((()=>{document.body.classList.remove(Wt),this._resetAdjustments(),this._scrollBar.reset(),N.trigger(this._element,Nt)}))}_isAnimated(){return this._element.classList.contains("fade")}_triggerBackdropTransition(){if(N.trigger(this._element,It).defaultPrevented)return;const e=this._element.scrollHeight>document.documentElement.clientHeight,t=this._element.style.overflowY;"hidden"===t||this._element.classList.contains(qt)||(e||(this._element.style.overflowY="hidden"),this._element.classList.add(qt),this._queueCallback((()=>{this._element.classList.remove(qt),this._queueCallback((()=>{this._element.style.overflowY=t}),this._dialog)}),this._dialog),this._element.focus())}_adjustDialog(){const e=this._element.scrollHeight>document.documentElement.clientHeight,t=this._scrollBar.getWidth(),i=t>0;if(i&&!e){const e=g()?"paddingLeft":"paddingRight";this._element.style[e]=`${t}px`}if(!i&&e){const e=g()?"paddingRight":"paddingLeft";this._element.style[e]=`${t}px`}}_resetAdjustments(){this._element.style.paddingLeft="",this._element.style.paddingRight=""}static jQueryInterface(e,t){return this.each((function(){const i=Gt.getOrCreateInstance(this,e);if("string"==typeof e){if(void 0===i[e])throw new TypeError(`No method named "${e}"`);i[e](t)}}))}}N.on(document,Vt,'[data-bs-toggle="modal"]',(function(e){const t=W.getElementFromSelector(this);["A","AREA"].includes(this.tagName)&&e.preventDefault(),N.one(t,jt,(e=>{e.defaultPrevented||N.one(t,Nt,(()=>{c(this)&&this.focus()}))}));const i=W.findOne(".modal.show");i&&Gt.getInstance(i).hide(),Gt.getOrCreateInstance(t).toggle(this)})),U(Gt),v(Gt);const Zt=".bs.offcanvas",Kt=".data-api",Jt=`load${Zt}${Kt}`,Qt="show",ei="showing",ti="hiding",ii=".offcanvas.show",ni=`show${Zt}`,ri=`shown${Zt}`,ai=`hide${Zt}`,si=`hidePrevented${Zt}`,oi=`hidden${Zt}`,li=`resize${Zt}`,ci=`click${Zt}${Kt}`,ui=`keydown.dismiss${Zt}`,di={backdrop:!0,keyboard:!0,scroll:!1},hi={backdrop:"(boolean|string)",keyboard:"boolean",scroll:"boolean"};class fi extends B{constructor(e,t){super(e,t),this._isShown=!1,this._backdrop=this._initializeBackDrop(),this._focustrap=this._initializeFocusTrap(),this._addEventListeners()}static get Default(){return di}static get DefaultType(){return hi}static get NAME(){return"offcanvas"}toggle(e){return this._isShown?this.hide():this.show(e)}show(e){this._isShown||N.trigger(this._element,ni,{relatedTarget:e}).defaultPrevented||(this._isShown=!0,this._backdrop.show(),this._config.scroll||(new Ot).hide(),this._element.setAttribute("aria-modal",!0),this._element.setAttribute("role","dialog"),this._element.classList.add(ei),this._queueCallback((()=>{this._config.scroll&&!this._config.backdrop||this._focustrap.activate(),this._element.classList.add(Qt),this._element.classList.remove(ei),N.trigger(this._element,ri,{relatedTarget:e})}),this._element,!0))}hide(){this._isShown&&(N.trigger(this._element,ai).defaultPrevented||(this._focustrap.deactivate(),this._element.blur(),this._isShown=!1,this._element.classList.add(ti),this._backdrop.hide(),this._queueCallback((()=>{this._element.classList.remove(Qt,ti),this._element.removeAttribute("aria-modal"),this._element.removeAttribute("role"),this._config.scroll||(new Ot).reset(),N.trigger(this._element,oi)}),this._element,!0)))}dispose(){this._backdrop.dispose(),this._focustrap.deactivate(),super.dispose()}_initializeBackDrop(){const e=Boolean(this._config.backdrop);return new xt({className:"offcanvas-backdrop",isVisible:e,isAnimated:!0,rootElement:this._element.parentNode,clickCallback:e?()=>{"static"!==this._config.backdrop?this.hide():N.trigger(this._element,si)}:null})}_initializeFocusTrap(){return new Lt({trapElement:this._element})}_addEventListeners(){N.on(this._element,ui,(e=>{"Escape"===e.key&&(this._config.keyboard?this.hide():N.trigger(this._element,si))}))}static jQueryInterface(e){return this.each((function(){const t=fi.getOrCreateInstance(this,e);if("string"==typeof e){if(void 0===t[e]||e.startsWith("_")||"constructor"===e)throw new TypeError(`No method named "${e}"`);t[e](this)}}))}}N.on(document,ci,'[data-bs-toggle="offcanvas"]',(function(e){const t=W.getElementFromSelector(this);if(["A","AREA"].includes(this.tagName)&&e.preventDefault(),u(this))return;N.one(t,oi,(()=>{c(this)&&this.focus()}));const i=W.findOne(ii);i&&i!==t&&fi.getInstance(i).hide(),fi.getOrCreateInstance(t).toggle(this)})),N.on(window,Jt,(()=>{for(const e of W.find(ii))fi.getOrCreateInstance(e).show()})),N.on(window,li,(()=>{for(const e of W.find("[aria-modal][class*=show][class*=offcanvas-]"))"fixed"!==getComputedStyle(e).position&&fi.getOrCreateInstance(e).hide()})),U(fi),v(fi);const pi={"*":["class","dir","id","lang","role",/^aria-[\w-]*$/i],a:["target","href","title","rel"],area:[],b:[],br:[],col:[],code:[],dd:[],div:[],dl:[],dt:[],em:[],hr:[],h1:[],h2:[],h3:[],h4:[],h5:[],h6:[],i:[],img:["src","srcset","alt","title","width","height"],li:[],ol:[],p:[],pre:[],s:[],small:[],span:[],sub:[],sup:[],strong:[],u:[],ul:[]},mi=new Set(["background","cite","href","itemtype","longdesc","poster","src","xlink:href"]),gi=/^(?!javascript:)(?:[a-z0-9+.-]+:|[^&:/?#]*(?:[/?#]|$))/i,vi=(e,t)=>{const i=e.nodeName.toLowerCase();return t.includes(i)?!mi.has(i)||Boolean(gi.test(e.nodeValue)):t.filter((e=>e instanceof RegExp)).some((e=>e.test(i)))},yi={allowList:pi,content:{},extraClass:"",html:!1,sanitize:!0,sanitizeFn:null,template:"<div></div>"},bi={allowList:"object",content:"object",extraClass:"(string|function)",html:"boolean",sanitize:"boolean",sanitizeFn:"(null|function)",template:"string"},xi={entry:"(string|element|function|null)",selector:"(string|element)"};class _i extends z{constructor(e){super(),this._config=this._getConfig(e)}static get Default(){return yi}static get DefaultType(){return bi}static get NAME(){return"TemplateFactory"}getContent(){return Object.values(this._config.content).map((e=>this._resolvePossibleFunction(e))).filter(Boolean)}hasContent(){return this.getContent().length>0}changeContent(e){return this._checkContent(e),this._config.content={...this._config.content,...e},this}toHtml(){const e=document.createElement("div");e.innerHTML=this._maybeSanitize(this._config.template);for(const[t,i]of Object.entries(this._config.content))this._setContent(e,i,t);const t=e.children[0],i=this._resolvePossibleFunction(this._config.extraClass);return i&&t.classList.add(...i.split(" ")),t}_typeCheckConfig(e){super._typeCheckConfig(e),this._checkContent(e.content)}_checkContent(e){for(const[t,i]of Object.entries(e))super._typeCheckConfig({selector:t,entry:i},xi)}_setContent(e,t,i){const n=W.findOne(i,e);n&&((t=this._resolvePossibleFunction(t))?o(t)?this._putElementInTemplate(l(t),n):this._config.html?n.innerHTML=this._maybeSanitize(t):n.textContent=t:n.remove())}_maybeSanitize(e){return this._config.sanitize?function(e,t,i){if(!e.length)return e;if(i&&"function"==typeof i)return i(e);const n=(new window.DOMParser).parseFromString(e,"text/html"),r=[].concat(...n.body.querySelectorAll("*"));for(const e of r){const i=e.nodeName.toLowerCase();if(!Object.keys(t).includes(i)){e.remove();continue}const n=[].concat(...e.attributes),r=[].concat(t["*"]||[],t[i]||[]);for(const t of n)vi(t,r)||e.removeAttribute(t.nodeName)}return n.body.innerHTML}(e,this._config.allowList,this._config.sanitizeFn):e}_resolvePossibleFunction(e){return y(e,[this])}_putElementInTemplate(e,t){if(this._config.html)return t.innerHTML="",void t.append(e);t.textContent=e.textContent}}const wi=new Set(["sanitize","allowList","sanitizeFn"]),ki="fade",Mi="show",Si=".modal",Ai="hide.bs.modal",Li="hover",Ti="focus",Ci={AUTO:"auto",TOP:"top",RIGHT:g()?"left":"right",BOTTOM:"bottom",LEFT:g()?"right":"left"},Di={allowList:pi,animation:!0,boundary:"clippingParents",container:!1,customClass:"",delay:0,fallbackPlacements:["top","right","bottom","left"],html:!1,offset:[0,6],placement:"top",popperConfig:null,sanitize:!0,sanitizeFn:null,selector:!1,template:'<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',title:"",trigger:"hover focus"},Ei={allowList:"object",animation:"boolean",boundary:"(string|element)",container:"(string|element|boolean)",customClass:"(string|function)",delay:"(number|object)",fallbackPlacements:"array",html:"boolean",offset:"(array|string|function)",placement:"(string|function)",popperConfig:"(null|object|function)",sanitize:"boolean",sanitizeFn:"(null|function)",selector:"(string|boolean)",template:"string",title:"(string|element|function)",trigger:"string"};class Oi extends B{constructor(e,i){if(void 0===t)throw new TypeError("Bootstrap's tooltips require Popper (https://popper.js.org)");super(e,i),this._isEnabled=!0,this._timeout=0,this._isHovered=null,this._activeTrigger={},this._popper=null,this._templateFactory=null,this._newContent=null,this.tip=null,this._setListeners(),this._config.selector||this._fixTitle()}static get Default(){return Di}static get DefaultType(){return Ei}static get NAME(){return"tooltip"}enable(){this._isEnabled=!0}disable(){this._isEnabled=!1}toggleEnabled(){this._isEnabled=!this._isEnabled}toggle(){this._isEnabled&&(this._activeTrigger.click=!this._activeTrigger.click,this._isShown()?this._leave():this._enter())}dispose(){clearTimeout(this._timeout),N.off(this._element.closest(Si),Ai,this._hideModalHandler),this._element.getAttribute("data-bs-original-title")&&this._element.setAttribute("title",this._element.getAttribute("data-bs-original-title")),this._disposePopper(),super.dispose()}show(){if("none"===this._element.style.display)throw new Error("Please use show on visible elements");if(!this._isWithContent()||!this._isEnabled)return;const e=N.trigger(this._element,this.constructor.eventName("show")),t=(d(this._element)||this._element.ownerDocument.documentElement).contains(this._element);if(e.defaultPrevented||!t)return;this._disposePopper();const i=this._getTipElement();this._element.setAttribute("aria-describedby",i.getAttribute("id"));const{container:n}=this._config;if(this._element.ownerDocument.documentElement.contains(this.tip)||(n.append(i),N.trigger(this._element,this.constructor.eventName("inserted"))),this._popper=this._createPopper(i),i.classList.add(Mi),"ontouchstart"in document.documentElement)for(const e of[].concat(...document.body.children))N.on(e,"mouseover",h);this._queueCallback((()=>{N.trigger(this._element,this.constructor.eventName("shown")),!1===this._isHovered&&this._leave(),this._isHovered=!1}),this.tip,this._isAnimated())}hide(){if(this._isShown()&&!N.trigger(this._element,this.constructor.eventName("hide")).defaultPrevented){if(this._getTipElement().classList.remove(Mi),"ontouchstart"in document.documentElement)for(const e of[].concat(...document.body.children))N.off(e,"mouseover",h);this._activeTrigger.click=!1,this._activeTrigger[Ti]=!1,this._activeTrigger[Li]=!1,this._isHovered=null,this._queueCallback((()=>{this._isWithActiveTrigger()||(this._isHovered||this._disposePopper(),this._element.removeAttribute("aria-describedby"),N.trigger(this._element,this.constructor.eventName("hidden")))}),this.tip,this._isAnimated())}}update(){this._popper&&this._popper.update()}_isWithContent(){return Boolean(this._getTitle())}_getTipElement(){return this.tip||(this.tip=this._createTipElement(this._newContent||this._getContentForTemplate())),this.tip}_createTipElement(e){const t=this._getTemplateFactory(e).toHtml();if(!t)return null;t.classList.remove(ki,Mi),t.classList.add(`bs-${this.constructor.NAME}-auto`);const i=(e=>{do{e+=Math.floor(1e6*Math.random())}while(document.getElementById(e));return e})(this.constructor.NAME).toString();return t.setAttribute("id",i),this._isAnimated()&&t.classList.add(ki),t}setContent(e){this._newContent=e,this._isShown()&&(this._disposePopper(),this.show())}_getTemplateFactory(e){return this._templateFactory?this._templateFactory.changeContent(e):this._templateFactory=new _i({...this._config,content:e,extraClass:this._resolvePossibleFunction(this._config.customClass)}),this._templateFactory}_getContentForTemplate(){return{".tooltip-inner":this._getTitle()}}_getTitle(){return this._resolvePossibleFunction(this._config.title)||this._element.getAttribute("data-bs-original-title")}_initializeOnDelegatedTarget(e){return this.constructor.getOrCreateInstance(e.delegateTarget,this._getDelegateConfig())}_isAnimated(){return this._config.animation||this.tip&&this.tip.classList.contains(ki)}_isShown(){return this.tip&&this.tip.classList.contains(Mi)}_createPopper(e){const i=y(this._config.placement,[this,e,this._element]),n=Ci[i.toUpperCase()];return t.createPopper(this._element,e,this._getPopperConfig(n))}_getOffset(){const{offset:e}=this._config;return"string"==typeof e?e.split(",").map((e=>Number.parseInt(e,10))):"function"==typeof e?t=>e(t,this._element):e}_resolvePossibleFunction(e){return y(e,[this._element])}_getPopperConfig(e){const t={placement:e,modifiers:[{name:"flip",options:{fallbackPlacements:this._config.fallbackPlacements}},{name:"offset",options:{offset:this._getOffset()}},{name:"preventOverflow",options:{boundary:this._config.boundary}},{name:"arrow",options:{element:`.${this.constructor.NAME}-arrow`}},{name:"preSetPlacement",enabled:!0,phase:"beforeMain",fn:e=>{this._getTipElement().setAttribute("data-popper-placement",e.state.placement)}}]};return{...t,...y(this._config.popperConfig,[t])}}_setListeners(){const e=this._config.trigger.split(" ");for(const t of e)if("click"===t)N.on(this._element,this.constructor.eventName("click"),this._config.selector,(e=>{this._initializeOnDelegatedTarget(e).toggle()}));else if("manual"!==t){const e=t===Li?this.constructor.eventName("mouseenter"):this.constructor.eventName("focusin"),i=t===Li?this.constructor.eventName("mouseleave"):this.constructor.eventName("focusout");N.on(this._element,e,this._config.selector,(e=>{const t=this._initializeOnDelegatedTarget(e);t._activeTrigger["focusin"===e.type?Ti:Li]=!0,t._enter()})),N.on(this._element,i,this._config.selector,(e=>{const t=this._initializeOnDelegatedTarget(e);t._activeTrigger["focusout"===e.type?Ti:Li]=t._element.contains(e.relatedTarget),t._leave()}))}this._hideModalHandler=()=>{this._element&&this.hide()},N.on(this._element.closest(Si),Ai,this._hideModalHandler)}_fixTitle(){const e=this._element.getAttribute("title");e&&(this._element.getAttribute("aria-label")||this._element.textContent.trim()||this._element.setAttribute("aria-label",e),this._element.setAttribute("data-bs-original-title",e),this._element.removeAttribute("title"))}_enter(){this._isShown()||this._isHovered?this._isHovered=!0:(this._isHovered=!0,this._setTimeout((()=>{this._isHovered&&this.show()}),this._config.delay.show))}_leave(){this._isWithActiveTrigger()||(this._isHovered=!1,this._setTimeout((()=>{this._isHovered||this.hide()}),this._config.delay.hide))}_setTimeout(e,t){clearTimeout(this._timeout),this._timeout=setTimeout(e,t)}_isWithActiveTrigger(){return Object.values(this._activeTrigger).includes(!0)}_getConfig(e){const t=R.getDataAttributes(this._element);for(const e of Object.keys(t))wi.has(e)&&delete t[e];return e={...t,..."object"==typeof e&&e?e:{}},e=this._mergeConfigObj(e),e=this._configAfterMerge(e),this._typeCheckConfig(e),e}_configAfterMerge(e){return e.container=!1===e.container?document.body:l(e.container),"number"==typeof e.delay&&(e.delay={show:e.delay,hide:e.delay}),"number"==typeof e.title&&(e.title=e.title.toString()),"number"==typeof e.content&&(e.content=e.content.toString()),e}_getDelegateConfig(){const e={};for(const[t,i]of Object.entries(this._config))this.constructor.Default[t]!==i&&(e[t]=i);return e.selector=!1,e.trigger="manual",e}_disposePopper(){this._popper&&(this._popper.destroy(),this._popper=null),this.tip&&(this.tip.remove(),this.tip=null)}static jQueryInterface(e){return this.each((function(){const t=Oi.getOrCreateInstance(this,e);if("string"==typeof e){if(void 0===t[e])throw new TypeError(`No method named "${e}"`);t[e]()}}))}}v(Oi);const Pi={...Oi.Default,content:"",offset:[0,8],placement:"right",template:'<div class="popover" role="tooltip"><div class="popover-arrow"></div><h3 class="popover-header"></h3><div class="popover-body"></div></div>',trigger:"click"},Yi={...Oi.DefaultType,content:"(null|string|element|function)"};class Ii extends Oi{static get Default(){return Pi}static get DefaultType(){return Yi}static get NAME(){return"popover"}_isWithContent(){return this._getTitle()||this._getContent()}_getContentForTemplate(){return{".popover-header":this._getTitle(),".popover-body":this._getContent()}}_getContent(){return this._resolvePossibleFunction(this._config.content)}static jQueryInterface(e){return this.each((function(){const t=Ii.getOrCreateInstance(this,e);if("string"==typeof e){if(void 0===t[e])throw new TypeError(`No method named "${e}"`);t[e]()}}))}}v(Ii);const Ni=".bs.scrollspy",ji=`activate${Ni}`,Hi=`click${Ni}`,Fi=`load${Ni}.data-api`,Ri="active",zi="[href]",Bi=".nav-link",Vi=`${Bi}, .nav-item > ${Bi}, .list-group-item`,Wi={offset:null,rootMargin:"0px 0px -25%",smoothScroll:!1,target:null,threshold:[.1,.5,1]},Ui={offset:"(number|null)",rootMargin:"string",smoothScroll:"boolean",target:"element",threshold:"array"};class qi extends B{constructor(e,t){super(e,t),this._targetLinks=new Map,this._observableSections=new Map,this._rootElement="visible"===getComputedStyle(this._element).overflowY?null:this._element,this._activeTarget=null,this._observer=null,this._previousScrollData={visibleEntryTop:0,parentScrollTop:0},this.refresh()}static get Default(){return Wi}static get DefaultType(){return Ui}static get NAME(){return"scrollspy"}refresh(){this._initializeTargetsAndObservables(),this._maybeEnableSmoothScroll(),this._observer?this._observer.disconnect():this._observer=this._getNewObserver();for(const e of this._observableSections.values())this._observer.observe(e)}dispose(){this._observer.disconnect(),super.dispose()}_configAfterMerge(e){return e.target=l(e.target)||document.body,e.rootMargin=e.offset?`${e.offset}px 0px -30%`:e.rootMargin,"string"==typeof e.threshold&&(e.threshold=e.threshold.split(",").map((e=>Number.parseFloat(e)))),e}_maybeEnableSmoothScroll(){this._config.smoothScroll&&(N.off(this._config.target,Hi),N.on(this._config.target,Hi,zi,(e=>{const t=this._observableSections.get(e.target.hash);if(t){e.preventDefault();const i=this._rootElement||window,n=t.offsetTop-this._element.offsetTop;if(i.scrollTo)return void i.scrollTo({top:n,behavior:"smooth"});i.scrollTop=n}})))}_getNewObserver(){const e={root:this._rootElement,threshold:this._config.threshold,rootMargin:this._config.rootMargin};return new IntersectionObserver((e=>this._observerCallback(e)),e)}_observerCallback(e){const t=e=>this._targetLinks.get(`#${e.target.id}`),i=e=>{this._previousScrollData.visibleEntryTop=e.target.offsetTop,this._process(t(e))},n=(this._rootElement||document.documentElement).scrollTop,r=n>=this._previousScrollData.parentScrollTop;this._previousScrollData.parentScrollTop=n;for(const a of e){if(!a.isIntersecting){this._activeTarget=null,this._clearActiveClass(t(a));continue}const e=a.target.offsetTop>=this._previousScrollData.visibleEntryTop;if(r&&e){if(i(a),!n)return}else r||e||i(a)}}_initializeTargetsAndObservables(){this._targetLinks=new Map,this._observableSections=new Map;const e=W.find(zi,this._config.target);for(const t of e){if(!t.hash||u(t))continue;const e=W.findOne(decodeURI(t.hash),this._element);c(e)&&(this._targetLinks.set(decodeURI(t.hash),t),this._observableSections.set(t.hash,e))}}_process(e){this._activeTarget!==e&&(this._clearActiveClass(this._config.target),this._activeTarget=e,e.classList.add(Ri),this._activateParents(e),N.trigger(this._element,ji,{relatedTarget:e}))}_activateParents(e){if(e.classList.contains("dropdown-item"))W.findOne(".dropdown-toggle",e.closest(".dropdown")).classList.add(Ri);else for(const t of W.parents(e,".nav, .list-group"))for(const e of W.prev(t,Vi))e.classList.add(Ri)}_clearActiveClass(e){e.classList.remove(Ri);const t=W.find(`${zi}.${Ri}`,e);for(const e of t)e.classList.remove(Ri)}static jQueryInterface(e){return this.each((function(){const t=qi.getOrCreateInstance(this,e);if("string"==typeof e){if(void 0===t[e]||e.startsWith("_")||"constructor"===e)throw new TypeError(`No method named "${e}"`);t[e]()}}))}}N.on(window,Fi,(()=>{for(const e of W.find('[data-bs-spy="scroll"]'))qi.getOrCreateInstance(e)})),v(qi);const $i=".bs.tab",Xi=`hide${$i}`,Gi=`hidden${$i}`,Zi=`show${$i}`,Ki=`shown${$i}`,Ji=`click${$i}`,Qi=`keydown${$i}`,en=`load${$i}`,tn="ArrowLeft",nn="ArrowRight",rn="ArrowUp",an="ArrowDown",sn="Home",on="End",ln="active",cn="fade",un="show",dn=".dropdown-toggle",hn=`:not(${dn})`,fn='[data-bs-toggle="tab"], [data-bs-toggle="pill"], [data-bs-toggle="list"]',pn=`.nav-link${hn}, .list-group-item${hn}, [role="tab"]${hn}, ${fn}`,mn=`.${ln}[data-bs-toggle="tab"], .${ln}[data-bs-toggle="pill"], .${ln}[data-bs-toggle="list"]`;class gn extends B{constructor(e){super(e),this._parent=this._element.closest('.list-group, .nav, [role="tablist"]'),this._parent&&(this._setInitialAttributes(this._parent,this._getChildren()),N.on(this._element,Qi,(e=>this._keydown(e))))}static get NAME(){return"tab"}show(){const e=this._element;if(this._elemIsActive(e))return;const t=this._getActiveElem(),i=t?N.trigger(t,Xi,{relatedTarget:e}):null;N.trigger(e,Zi,{relatedTarget:t}).defaultPrevented||i&&i.defaultPrevented||(this._deactivate(t,e),this._activate(e,t))}_activate(e,t){e&&(e.classList.add(ln),this._activate(W.getElementFromSelector(e)),this._queueCallback((()=>{"tab"===e.getAttribute("role")?(e.removeAttribute("tabindex"),e.setAttribute("aria-selected",!0),this._toggleDropDown(e,!0),N.trigger(e,Ki,{relatedTarget:t})):e.classList.add(un)}),e,e.classList.contains(cn)))}_deactivate(e,t){e&&(e.classList.remove(ln),e.blur(),this._deactivate(W.getElementFromSelector(e)),this._queueCallback((()=>{"tab"===e.getAttribute("role")?(e.setAttribute("aria-selected",!1),e.setAttribute("tabindex","-1"),this._toggleDropDown(e,!1),N.trigger(e,Gi,{relatedTarget:t})):e.classList.remove(un)}),e,e.classList.contains(cn)))}_keydown(e){if(![tn,nn,rn,an,sn,on].includes(e.key))return;e.stopPropagation(),e.preventDefault();const t=this._getChildren().filter((e=>!u(e)));let i;if([sn,on].includes(e.key))i=t[e.key===sn?0:t.length-1];else{const n=[nn,an].includes(e.key);i=x(t,e.target,n,!0)}i&&(i.focus({preventScroll:!0}),gn.getOrCreateInstance(i).show())}_getChildren(){return W.find(pn,this._parent)}_getActiveElem(){return this._getChildren().find((e=>this._elemIsActive(e)))||null}_setInitialAttributes(e,t){this._setAttributeIfNotExists(e,"role","tablist");for(const e of t)this._setInitialAttributesOnChild(e)}_setInitialAttributesOnChild(e){e=this._getInnerElement(e);const t=this._elemIsActive(e),i=this._getOuterElement(e);e.setAttribute("aria-selected",t),i!==e&&this._setAttributeIfNotExists(i,"role","presentation"),t||e.setAttribute("tabindex","-1"),this._setAttributeIfNotExists(e,"role","tab"),this._setInitialAttributesOnTargetPanel(e)}_setInitialAttributesOnTargetPanel(e){const t=W.getElementFromSelector(e);t&&(this._setAttributeIfNotExists(t,"role","tabpanel"),e.id&&this._setAttributeIfNotExists(t,"aria-labelledby",`${e.id}`))}_toggleDropDown(e,t){const i=this._getOuterElement(e);if(!i.classList.contains("dropdown"))return;const n=(e,n)=>{const r=W.findOne(e,i);r&&r.classList.toggle(n,t)};n(dn,ln),n(".dropdown-menu",un),i.setAttribute("aria-expanded",t)}_setAttributeIfNotExists(e,t,i){e.hasAttribute(t)||e.setAttribute(t,i)}_elemIsActive(e){return e.classList.contains(ln)}_getInnerElement(e){return e.matches(pn)?e:W.findOne(pn,e)}_getOuterElement(e){return e.closest(".nav-item, .list-group-item")||e}static jQueryInterface(e){return this.each((function(){const t=gn.getOrCreateInstance(this);if("string"==typeof e){if(void 0===t[e]||e.startsWith("_")||"constructor"===e)throw new TypeError(`No method named "${e}"`);t[e]()}}))}}N.on(document,Ji,fn,(function(e){["A","AREA"].includes(this.tagName)&&e.preventDefault(),u(this)||gn.getOrCreateInstance(this).show()})),N.on(window,en,(()=>{for(const e of W.find(mn))gn.getOrCreateInstance(e)})),v(gn);const vn=".bs.toast",yn=`mouseover${vn}`,bn=`mouseout${vn}`,xn=`focusin${vn}`,_n=`focusout${vn}`,wn=`hide${vn}`,kn=`hidden${vn}`,Mn=`show${vn}`,Sn=`shown${vn}`,An="hide",Ln="show",Tn="showing",Cn={animation:"boolean",autohide:"boolean",delay:"number"},Dn={animation:!0,autohide:!0,delay:5e3};class En extends B{constructor(e,t){super(e,t),this._timeout=null,this._hasMouseInteraction=!1,this._hasKeyboardInteraction=!1,this._setListeners()}static get Default(){return Dn}static get DefaultType(){return Cn}static get NAME(){return"toast"}show(){N.trigger(this._element,Mn).defaultPrevented||(this._clearTimeout(),this._config.animation&&this._element.classList.add("fade"),this._element.classList.remove(An),f(this._element),this._element.classList.add(Ln,Tn),this._queueCallback((()=>{this._element.classList.remove(Tn),N.trigger(this._element,Sn),this._maybeScheduleHide()}),this._element,this._config.animation))}hide(){this.isShown()&&(N.trigger(this._element,wn).defaultPrevented||(this._element.classList.add(Tn),this._queueCallback((()=>{this._element.classList.add(An),this._element.classList.remove(Tn,Ln),N.trigger(this._element,kn)}),this._element,this._config.animation)))}dispose(){this._clearTimeout(),this.isShown()&&this._element.classList.remove(Ln),super.dispose()}isShown(){return this._element.classList.contains(Ln)}_maybeScheduleHide(){this._config.autohide&&(this._hasMouseInteraction||this._hasKeyboardInteraction||(this._timeout=setTimeout((()=>{this.hide()}),this._config.delay)))}_onInteraction(e,t){switch(e.type){case"mouseover":case"mouseout":this._hasMouseInteraction=t;break;case"focusin":case"focusout":this._hasKeyboardInteraction=t}if(t)return void this._clearTimeout();const i=e.relatedTarget;this._element===i||this._element.contains(i)||this._maybeScheduleHide()}_setListeners(){N.on(this._element,yn,(e=>this._onInteraction(e,!0))),N.on(this._element,bn,(e=>this._onInteraction(e,!1))),N.on(this._element,xn,(e=>this._onInteraction(e,!0))),N.on(this._element,_n,(e=>this._onInteraction(e,!1)))}_clearTimeout(){clearTimeout(this._timeout),this._timeout=null}static jQueryInterface(e){return this.each((function(){const t=En.getOrCreateInstance(this,e);if("string"==typeof e){if(void 0===t[e])throw new TypeError(`No method named "${e}"`);t[e](this)}}))}}return U(En),v(En),{Alert:G,Button:K,Carousel:Ce,Collapse:Ve,Dropdown:pt,Modal:Gt,Offcanvas:fi,Popover:Ii,ScrollSpy:qi,Tab:gn,Toast:En,Tooltip:Oi}})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):e.moment=t()}(this,(function(){"use strict";var e;function t(){return e.apply(null,arguments)}function i(e){return e instanceof Array||"[object Array]"===Object.prototype.toString.call(e)}function n(e){return null!=e&&"[object Object]"===Object.prototype.toString.call(e)}function r(e,t){return Object.prototype.hasOwnProperty.call(e,t)}function a(e){if(Object.getOwnPropertyNames)return 0===Object.getOwnPropertyNames(e).length;for(var t in e)if(r(e,t))return;return 1}function s(e){return void 0===e}function o(e){return"number"==typeof e||"[object Number]"===Object.prototype.toString.call(e)}function l(e){return e instanceof Date||"[object Date]"===Object.prototype.toString.call(e)}function c(e,t){for(var i=[],n=e.length,r=0;r<n;++r)i.push(t(e[r],r));return i}function u(e,t){for(var i in t)r(t,i)&&(e[i]=t[i]);return r(t,"toString")&&(e.toString=t.toString),r(t,"valueOf")&&(e.valueOf=t.valueOf),e}function d(e,t,i,n){return At(e,t,i,n,!0).utc()}function h(e){return null==e._pf&&(e._pf={empty:!1,unusedTokens:[],unusedInput:[],overflow:-2,charsLeftOver:0,nullInput:!1,invalidEra:null,invalidMonth:null,invalidFormat:!1,userInvalidated:!1,iso:!1,parsedDateParts:[],era:null,meridiem:null,rfc2822:!1,weekdayMismatch:!1}),e._pf}function f(e){var t,i,n=e._d&&!isNaN(e._d.getTime());return n&&(t=h(e),i=m.call(t.parsedDateParts,(function(e){return null!=e})),n=t.overflow<0&&!t.empty&&!t.invalidEra&&!t.invalidMonth&&!t.invalidWeekday&&!t.weekdayMismatch&&!t.nullInput&&!t.invalidFormat&&!t.userInvalidated&&(!t.meridiem||t.meridiem&&i),e._strict)&&(n=n&&0===t.charsLeftOver&&0===t.unusedTokens.length&&void 0===t.bigHour),null!=Object.isFrozen&&Object.isFrozen(e)?n:(e._isValid=n,e._isValid)}function p(e){var t=d(NaN);return null!=e?u(h(t),e):h(t).userInvalidated=!0,t}var m=Array.prototype.some||function(e){for(var t=Object(this),i=t.length>>>0,n=0;n<i;n++)if(n in t&&e.call(this,t[n],n,t))return!0;return!1},g=t.momentProperties=[],v=!1;function y(e,t){var i,n,r,a=g.length;if(s(t._isAMomentObject)||(e._isAMomentObject=t._isAMomentObject),s(t._i)||(e._i=t._i),s(t._f)||(e._f=t._f),s(t._l)||(e._l=t._l),s(t._strict)||(e._strict=t._strict),s(t._tzm)||(e._tzm=t._tzm),s(t._isUTC)||(e._isUTC=t._isUTC),s(t._offset)||(e._offset=t._offset),s(t._pf)||(e._pf=h(t)),s(t._locale)||(e._locale=t._locale),0<a)for(i=0;i<a;i++)s(r=t[n=g[i]])||(e[n]=r);return e}function b(e){y(this,e),this._d=new Date(null!=e._d?e._d.getTime():NaN),this.isValid()||(this._d=new Date(NaN)),!1===v&&(v=!0,t.updateOffset(this),v=!1)}function x(e){return e instanceof b||null!=e&&null!=e._isAMomentObject}function _(e){!1===t.suppressDeprecationWarnings&&"undefined"!=typeof console&&console.warn&&console.warn("Deprecation warning: "+e)}function w(e,i){var n=!0;return u((function(){if(null!=t.deprecationHandler&&t.deprecationHandler(null,e),n){for(var a,s,o=[],l=arguments.length,c=0;c<l;c++){if(a="","object"==typeof arguments[c]){for(s in a+="\n["+c+"] ",arguments[0])r(arguments[0],s)&&(a+=s+": "+arguments[0][s]+", ");a=a.slice(0,-2)}else a=arguments[c];o.push(a)}_(e+"\nArguments: "+Array.prototype.slice.call(o).join("")+"\n"+(new Error).stack),n=!1}return i.apply(this,arguments)}),i)}var k={};function M(e,i){null!=t.deprecationHandler&&t.deprecationHandler(e,i),k[e]||(_(i),k[e]=!0)}function S(e){return"undefined"!=typeof Function&&e instanceof Function||"[object Function]"===Object.prototype.toString.call(e)}function A(e,t){var i,a=u({},e);for(i in t)r(t,i)&&(n(e[i])&&n(t[i])?(a[i]={},u(a[i],e[i]),u(a[i],t[i])):null!=t[i]?a[i]=t[i]:delete a[i]);for(i in e)r(e,i)&&!r(t,i)&&n(e[i])&&(a[i]=u({},a[i]));return a}function L(e){null!=e&&this.set(e)}t.suppressDeprecationWarnings=!1,t.deprecationHandler=null;var T=Object.keys||function(e){var t,i=[];for(t in e)r(e,t)&&i.push(t);return i};function C(e,t,i){var n=""+Math.abs(e);return(0<=e?i?"+":"":"-")+Math.pow(10,Math.max(0,t-n.length)).toString().substr(1)+n}var D=/(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|N{1,5}|YYYYYY|YYYYY|YYYY|YY|y{2,4}|yo?|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|kk?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g,E=/(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g,O={},P={};function Y(e,t,i,n){var r="string"==typeof n?function(){return this[n]()}:n;e&&(P[e]=r),t&&(P[t[0]]=function(){return C(r.apply(this,arguments),t[1],t[2])}),i&&(P[i]=function(){return this.localeData().ordinal(r.apply(this,arguments),e)})}function I(e,t){return e.isValid()?(t=N(t,e.localeData()),O[t]=O[t]||function(e){for(var t,i=e.match(D),n=0,r=i.length;n<r;n++)P[i[n]]?i[n]=P[i[n]]:i[n]=(t=i[n]).match(/\[[\s\S]/)?t.replace(/^\[|\]$/g,""):t.replace(/\\/g,"");return function(t){for(var n="",a=0;a<r;a++)n+=S(i[a])?i[a].call(t,e):i[a];return n}}(t),O[t](e)):e.localeData().invalidDate()}function N(e,t){var i=5;function n(e){return t.longDateFormat(e)||e}for(E.lastIndex=0;0<=i&&E.test(e);)e=e.replace(E,n),E.lastIndex=0,--i;return e}var j={D:"date",dates:"date",date:"date",d:"day",days:"day",day:"day",e:"weekday",weekdays:"weekday",weekday:"weekday",E:"isoWeekday",isoweekdays:"isoWeekday",isoweekday:"isoWeekday",DDD:"dayOfYear",dayofyears:"dayOfYear",dayofyear:"dayOfYear",h:"hour",hours:"hour",hour:"hour",ms:"millisecond",milliseconds:"millisecond",millisecond:"millisecond",m:"minute",minutes:"minute",minute:"minute",M:"month",months:"month",month:"month",Q:"quarter",quarters:"quarter",quarter:"quarter",s:"second",seconds:"second",second:"second",gg:"weekYear",weekyears:"weekYear",weekyear:"weekYear",GG:"isoWeekYear",isoweekyears:"isoWeekYear",isoweekyear:"isoWeekYear",w:"week",weeks:"week",week:"week",W:"isoWeek",isoweeks:"isoWeek",isoweek:"isoWeek",y:"year",years:"year",year:"year"};function H(e){return"string"==typeof e?j[e]||j[e.toLowerCase()]:void 0}function F(e){var t,i,n={};for(i in e)r(e,i)&&(t=H(i))&&(n[t]=e[i]);return n}var R={date:9,day:11,weekday:11,isoWeekday:11,dayOfYear:4,hour:13,millisecond:16,minute:14,month:8,quarter:7,second:15,weekYear:1,isoWeekYear:1,week:5,isoWeek:5,year:1},z=/\d/,B=/\d\d/,V=/\d{3}/,W=/\d{4}/,U=/[+-]?\d{6}/,q=/\d\d?/,$=/\d\d\d\d?/,X=/\d\d\d\d\d\d?/,G=/\d{1,3}/,Z=/\d{1,4}/,K=/[+-]?\d{1,6}/,J=/\d+/,Q=/[+-]?\d+/,ee=/Z|[+-]\d\d:?\d\d/gi,te=/Z|[+-]\d\d(?::?\d\d)?/gi,ie=/[0-9]{0,256}['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFF07\uFF10-\uFFEF]{1,256}|[\u0600-\u06FF\/]{1,256}(\s*?[\u0600-\u06FF]{1,256}){1,2}/i,ne=/^[1-9]\d?/,re=/^([1-9]\d|\d)/;function ae(e,t,i){ue[e]=S(t)?t:function(e,n){return e&&i?i:t}}function se(e,t){return r(ue,e)?ue[e](t._strict,t._locale):new RegExp(oe(e.replace("\\","").replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g,(function(e,t,i,n,r){return t||i||n||r}))))}function oe(e){return e.replace(/[-\/\\^$*+?.()|[\]{}]/g,"\\$&")}function le(e){return e<0?Math.ceil(e)||0:Math.floor(e)}function ce(e){var t=0;return 0!=(e=+e)&&isFinite(e)?le(e):t}var ue={},de={};function he(e,t){var i,n,r=t;for("string"==typeof e&&(e=[e]),o(t)&&(r=function(e,i){i[t]=ce(e)}),n=e.length,i=0;i<n;i++)de[e[i]]=r}function fe(e,t){he(e,(function(e,i,n,r){n._w=n._w||{},t(e,n._w,n,r)}))}function pe(e){return e%4==0&&e%100!=0||e%400==0}var me=0,ge=1,ve=2,ye=3,be=4,xe=5,_e=6,we=7,ke=8;function Me(e){return pe(e)?366:365}Y("Y",0,0,(function(){var e=this.year();return e<=9999?C(e,4):"+"+e})),Y(0,["YY",2],0,(function(){return this.year()%100})),Y(0,["YYYY",4],0,"year"),Y(0,["YYYYY",5],0,"year"),Y(0,["YYYYYY",6,!0],0,"year"),ae("Y",Q),ae("YY",q,B),ae("YYYY",Z,W),ae("YYYYY",K,U),ae("YYYYYY",K,U),he(["YYYYY","YYYYYY"],me),he("YYYY",(function(e,i){i[me]=2===e.length?t.parseTwoDigitYear(e):ce(e)})),he("YY",(function(e,i){i[me]=t.parseTwoDigitYear(e)})),he("Y",(function(e,t){t[me]=parseInt(e,10)})),t.parseTwoDigitYear=function(e){return ce(e)+(68<ce(e)?1900:2e3)};var Se,Ae=Le("FullYear",!0);function Le(e,i){return function(n){return null!=n?(Ce(this,e,n),t.updateOffset(this,i),this):Te(this,e)}}function Te(e,t){if(!e.isValid())return NaN;var i=e._d,n=e._isUTC;switch(t){case"Milliseconds":return n?i.getUTCMilliseconds():i.getMilliseconds();case"Seconds":return n?i.getUTCSeconds():i.getSeconds();case"Minutes":return n?i.getUTCMinutes():i.getMinutes();case"Hours":return n?i.getUTCHours():i.getHours();case"Date":return n?i.getUTCDate():i.getDate();case"Day":return n?i.getUTCDay():i.getDay();case"Month":return n?i.getUTCMonth():i.getMonth();case"FullYear":return n?i.getUTCFullYear():i.getFullYear();default:return NaN}}function Ce(e,t,i){var n,r,a;if(e.isValid()&&!isNaN(i)){switch(n=e._d,r=e._isUTC,t){case"Milliseconds":return r?n.setUTCMilliseconds(i):n.setMilliseconds(i);case"Seconds":return r?n.setUTCSeconds(i):n.setSeconds(i);case"Minutes":return r?n.setUTCMinutes(i):n.setMinutes(i);case"Hours":return r?n.setUTCHours(i):n.setHours(i);case"Date":return r?n.setUTCDate(i):n.setDate(i);case"FullYear":break;default:return}t=i,a=e.month(),e=29!==(e=e.date())||1!==a||pe(t)?e:28,r?n.setUTCFullYear(t,a,e):n.setFullYear(t,a,e)}}function De(e,t){var i;return isNaN(e)||isNaN(t)?NaN:(e+=(t-(i=(t%(i=12)+i)%i))/12,1==i?pe(e)?29:28:31-i%7%2)}Se=Array.prototype.indexOf||function(e){for(var t=0;t<this.length;++t)if(this[t]===e)return t;return-1},Y("M",["MM",2],"Mo",(function(){return this.month()+1})),Y("MMM",0,0,(function(e){return this.localeData().monthsShort(this,e)})),Y("MMMM",0,0,(function(e){return this.localeData().months(this,e)})),ae("M",q,ne),ae("MM",q,B),ae("MMM",(function(e,t){return t.monthsShortRegex(e)})),ae("MMMM",(function(e,t){return t.monthsRegex(e)})),he(["M","MM"],(function(e,t){t[ge]=ce(e)-1})),he(["MMM","MMMM"],(function(e,t,i,n){null!=(n=i._locale.monthsParse(e,n,i._strict))?t[ge]=n:h(i).invalidMonth=e}));var Ee="January_February_March_April_May_June_July_August_September_October_November_December".split("_"),Oe="Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),Pe=/D[oD]?(\[[^\[\]]*\]|\s)+MMMM?/,Ye=ie,Ie=ie;function Ne(e,t){if(e.isValid()){if("string"==typeof t)if(/^\d+$/.test(t))t=ce(t);else if(!o(t=e.localeData().monthsParse(t)))return;var i=(i=e.date())<29?i:Math.min(i,De(e.year(),t));e._isUTC?e._d.setUTCMonth(t,i):e._d.setMonth(t,i)}}function je(e){return null!=e?(Ne(this,e),t.updateOffset(this,!0),this):Te(this,"Month")}function He(){function e(e,t){return t.length-e.length}for(var t,i,n=[],r=[],a=[],s=0;s<12;s++)i=d([2e3,s]),t=oe(this.monthsShort(i,"")),i=oe(this.months(i,"")),n.push(t),r.push(i),a.push(i),a.push(t);n.sort(e),r.sort(e),a.sort(e),this._monthsRegex=new RegExp("^("+a.join("|")+")","i"),this._monthsShortRegex=this._monthsRegex,this._monthsStrictRegex=new RegExp("^("+r.join("|")+")","i"),this._monthsShortStrictRegex=new RegExp("^("+n.join("|")+")","i")}function Fe(e,t,i,n,r,a,s){var o;return e<100&&0<=e?(o=new Date(e+400,t,i,n,r,a,s),isFinite(o.getFullYear())&&o.setFullYear(e)):o=new Date(e,t,i,n,r,a,s),o}function Re(e){var t;return e<100&&0<=e?((t=Array.prototype.slice.call(arguments))[0]=e+400,t=new Date(Date.UTC.apply(null,t)),isFinite(t.getUTCFullYear())&&t.setUTCFullYear(e)):t=new Date(Date.UTC.apply(null,arguments)),t}function ze(e,t,i){return(i=7+t-i)-(7+Re(e,0,i).getUTCDay()-t)%7-1}function Be(e,t,i,n,r){var a;i=(t=1+7*(t-1)+(7+i-n)%7+ze(e,n,r))<=0?Me(a=e-1)+t:t>Me(e)?(a=e+1,t-Me(e)):(a=e,t);return{year:a,dayOfYear:i}}function Ve(e,t,i){var n,r,a=ze(e.year(),t,i);return(a=Math.floor((e.dayOfYear()-a-1)/7)+1)<1?n=a+We(r=e.year()-1,t,i):a>We(e.year(),t,i)?(n=a-We(e.year(),t,i),r=e.year()+1):(r=e.year(),n=a),{week:n,year:r}}function We(e,t,i){var n=ze(e,t,i);t=ze(e+1,t,i);return(Me(e)-n+t)/7}function Ue(e,t){return e.slice(t,7).concat(e.slice(0,t))}Y("w",["ww",2],"wo","week"),Y("W",["WW",2],"Wo","isoWeek"),ae("w",q,ne),ae("ww",q,B),ae("W",q,ne),ae("WW",q,B),fe(["w","ww","W","WW"],(function(e,t,i,n){t[n.substr(0,1)]=ce(e)})),Y("d",0,"do","day"),Y("dd",0,0,(function(e){return this.localeData().weekdaysMin(this,e)})),Y("ddd",0,0,(function(e){return this.localeData().weekdaysShort(this,e)})),Y("dddd",0,0,(function(e){return this.localeData().weekdays(this,e)})),Y("e",0,0,"weekday"),Y("E",0,0,"isoWeekday"),ae("d",q),ae("e",q),ae("E",q),ae("dd",(function(e,t){return t.weekdaysMinRegex(e)})),ae("ddd",(function(e,t){return t.weekdaysShortRegex(e)})),ae("dddd",(function(e,t){return t.weekdaysRegex(e)})),fe(["dd","ddd","dddd"],(function(e,t,i,n){null!=(n=i._locale.weekdaysParse(e,n,i._strict))?t.d=n:h(i).invalidWeekday=e})),fe(["d","e","E"],(function(e,t,i,n){t[n]=ce(e)}));var qe="Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),$e="Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),Xe="Su_Mo_Tu_We_Th_Fr_Sa".split("_"),Ge=ie,Ze=ie,Ke=ie;function Je(){function e(e,t){return t.length-e.length}for(var t,i,n,r=[],a=[],s=[],o=[],l=0;l<7;l++)n=d([2e3,1]).day(l),t=oe(this.weekdaysMin(n,"")),i=oe(this.weekdaysShort(n,"")),n=oe(this.weekdays(n,"")),r.push(t),a.push(i),s.push(n),o.push(t),o.push(i),o.push(n);r.sort(e),a.sort(e),s.sort(e),o.sort(e),this._weekdaysRegex=new RegExp("^("+o.join("|")+")","i"),this._weekdaysShortRegex=this._weekdaysRegex,this._weekdaysMinRegex=this._weekdaysRegex,this._weekdaysStrictRegex=new RegExp("^("+s.join("|")+")","i"),this._weekdaysShortStrictRegex=new RegExp("^("+a.join("|")+")","i"),this._weekdaysMinStrictRegex=new RegExp("^("+r.join("|")+")","i")}function Qe(){return this.hours()%12||12}function et(e,t){Y(e,0,0,(function(){return this.localeData().meridiem(this.hours(),this.minutes(),t)}))}function tt(e,t){return t._meridiemParse}Y("H",["HH",2],0,"hour"),Y("h",["hh",2],0,Qe),Y("k",["kk",2],0,(function(){return this.hours()||24})),Y("hmm",0,0,(function(){return""+Qe.apply(this)+C(this.minutes(),2)})),Y("hmmss",0,0,(function(){return""+Qe.apply(this)+C(this.minutes(),2)+C(this.seconds(),2)})),Y("Hmm",0,0,(function(){return""+this.hours()+C(this.minutes(),2)})),Y("Hmmss",0,0,(function(){return""+this.hours()+C(this.minutes(),2)+C(this.seconds(),2)})),et("a",!0),et("A",!1),ae("a",tt),ae("A",tt),ae("H",q,re),ae("h",q,ne),ae("k",q,ne),ae("HH",q,B),ae("hh",q,B),ae("kk",q,B),ae("hmm",$),ae("hmmss",X),ae("Hmm",$),ae("Hmmss",X),he(["H","HH"],ye),he(["k","kk"],(function(e,t,i){e=ce(e),t[ye]=24===e?0:e})),he(["a","A"],(function(e,t,i){i._isPm=i._locale.isPM(e),i._meridiem=e})),he(["h","hh"],(function(e,t,i){t[ye]=ce(e),h(i).bigHour=!0})),he("hmm",(function(e,t,i){var n=e.length-2;t[ye]=ce(e.substr(0,n)),t[be]=ce(e.substr(n)),h(i).bigHour=!0})),he("hmmss",(function(e,t,i){var n=e.length-4,r=e.length-2;t[ye]=ce(e.substr(0,n)),t[be]=ce(e.substr(n,2)),t[xe]=ce(e.substr(r)),h(i).bigHour=!0})),he("Hmm",(function(e,t,i){var n=e.length-2;t[ye]=ce(e.substr(0,n)),t[be]=ce(e.substr(n))})),he("Hmmss",(function(e,t,i){var n=e.length-4,r=e.length-2;t[ye]=ce(e.substr(0,n)),t[be]=ce(e.substr(n,2)),t[xe]=ce(e.substr(r))})),ie=Le("Hours",!0);var it,nt={calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},longDateFormat:{LTS:"h:mm:ss A",LT:"h:mm A",L:"MM/DD/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"},invalidDate:"Invalid date",ordinal:"%d",dayOfMonthOrdinalParse:/\d{1,2}/,relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",w:"a week",ww:"%d weeks",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},months:Ee,monthsShort:Oe,week:{dow:0,doy:6},weekdays:qe,weekdaysMin:Xe,weekdaysShort:$e,meridiemParse:/[ap]\.?m?\.?/i},rt={},at={};function st(e){return e&&e.toLowerCase().replace("_","-")}function ot(e){var t,i;if(void 0===rt[e]&&"undefined"!=typeof module&&module&&module.exports&&(i=e)&&i.match("^[^/\\\\]*$"))try{t=it._abbr,require("./locale/"+e),lt(t)}catch(t){rt[e]=null}return rt[e]}function lt(e,t){return e&&((t=s(t)?ut(e):ct(e,t))?it=t:"undefined"!=typeof console&&console.warn&&console.warn("Locale "+e+" not found. Did you forget to load it?")),it._abbr}function ct(e,t){if(null===t)return delete rt[e],null;var i,n=nt;if(t.abbr=e,null!=rt[e])M("defineLocaleOverride","use moment.updateLocale(localeName, config) to change an existing locale. moment.defineLocale(localeName, config) should only be used for creating a new locale See http://momentjs.com/guides/#/warnings/define-locale/ for more info."),n=rt[e]._config;else if(null!=t.parentLocale)if(null!=rt[t.parentLocale])n=rt[t.parentLocale]._config;else{if(null==(i=ot(t.parentLocale)))return at[t.parentLocale]||(at[t.parentLocale]=[]),at[t.parentLocale].push({name:e,config:t}),null;n=i._config}return rt[e]=new L(A(n,t)),at[e]&&at[e].forEach((function(e){ct(e.name,e.config)})),lt(e),rt[e]}function ut(e){var t;if(!(e=e&&e._locale&&e._locale._abbr?e._locale._abbr:e))return it;if(!i(e)){if(t=ot(e))return t;e=[e]}return function(e){for(var t,i,n,r,a=0;a<e.length;){for(t=(r=st(e[a]).split("-")).length,i=(i=st(e[a+1]))?i.split("-"):null;0<t;){if(n=ot(r.slice(0,t).join("-")))return n;if(i&&i.length>=t&&function(e,t){for(var i=Math.min(e.length,t.length),n=0;n<i;n+=1)if(e[n]!==t[n])return n;return i}(r,i)>=t-1)break;t--}a++}return it}(e)}function dt(e){var t=e._a;return t&&-2===h(e).overflow&&(t=t[ge]<0||11<t[ge]?ge:t[ve]<1||t[ve]>De(t[me],t[ge])?ve:t[ye]<0||24<t[ye]||24===t[ye]&&(0!==t[be]||0!==t[xe]||0!==t[_e])?ye:t[be]<0||59<t[be]?be:t[xe]<0||59<t[xe]?xe:t[_e]<0||999<t[_e]?_e:-1,h(e)._overflowDayOfYear&&(t<me||ve<t)&&(t=ve),h(e)._overflowWeeks&&-1===t&&(t=we),h(e)._overflowWeekday&&-1===t&&(t=ke),h(e).overflow=t),e}var ht=/^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,ft=/^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d|))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,pt=/Z|[+-]\d\d(?::?\d\d)?/,mt=[["YYYYYY-MM-DD",/[+-]\d{6}-\d\d-\d\d/],["YYYY-MM-DD",/\d{4}-\d\d-\d\d/],["GGGG-[W]WW-E",/\d{4}-W\d\d-\d/],["GGGG-[W]WW",/\d{4}-W\d\d/,!1],["YYYY-DDD",/\d{4}-\d{3}/],["YYYY-MM",/\d{4}-\d\d/,!1],["YYYYYYMMDD",/[+-]\d{10}/],["YYYYMMDD",/\d{8}/],["GGGG[W]WWE",/\d{4}W\d{3}/],["GGGG[W]WW",/\d{4}W\d{2}/,!1],["YYYYDDD",/\d{7}/],["YYYYMM",/\d{6}/,!1],["YYYY",/\d{4}/,!1]],gt=[["HH:mm:ss.SSSS",/\d\d:\d\d:\d\d\.\d+/],["HH:mm:ss,SSSS",/\d\d:\d\d:\d\d,\d+/],["HH:mm:ss",/\d\d:\d\d:\d\d/],["HH:mm",/\d\d:\d\d/],["HHmmss.SSSS",/\d\d\d\d\d\d\.\d+/],["HHmmss,SSSS",/\d\d\d\d\d\d,\d+/],["HHmmss",/\d\d\d\d\d\d/],["HHmm",/\d\d\d\d/],["HH",/\d\d/]],vt=/^\/?Date\((-?\d+)/i,yt=/^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),?\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|([+-]\d{4}))$/,bt={UT:0,GMT:0,EDT:-240,EST:-300,CDT:-300,CST:-360,MDT:-360,MST:-420,PDT:-420,PST:-480};function xt(e){var t,i,n,r,a,s,o=e._i,l=ht.exec(o)||ft.exec(o),c=(o=mt.length,gt.length);if(l){for(h(e).iso=!0,t=0,i=o;t<i;t++)if(mt[t][1].exec(l[1])){r=mt[t][0],n=!1!==mt[t][2];break}if(null==r)e._isValid=!1;else{if(l[3]){for(t=0,i=c;t<i;t++)if(gt[t][1].exec(l[3])){a=(l[2]||" ")+gt[t][0];break}if(null==a)return void(e._isValid=!1)}if(n||null==a){if(l[4]){if(!pt.exec(l[4]))return void(e._isValid=!1);s="Z"}e._f=r+(a||"")+(s||""),Mt(e)}else e._isValid=!1}}else e._isValid=!1}function _t(e){var t,i,n=yt.exec(e._i.replace(/\([^()]*\)|[\n\t]/g," ").replace(/(\s\s+)/g," ").replace(/^\s\s*/,"").replace(/\s\s*$/,""));n?(t=function(e,t,i,n,r,a){return e=[function(e){return(e=parseInt(e,10))<=49?2e3+e:e<=999?1900+e:e}(e),Oe.indexOf(t),parseInt(i,10),parseInt(n,10),parseInt(r,10)],a&&e.push(parseInt(a,10)),e}(n[4],n[3],n[2],n[5],n[6],n[7]),function(e,t,i){if(!e||$e.indexOf(e)===new Date(t[0],t[1],t[2]).getDay())return 1;h(i).weekdayMismatch=!0,i._isValid=!1}(n[1],t,e)&&(e._a=t,e._tzm=(t=n[8],i=n[9],n=n[10],t?bt[t]:i?0:((t=parseInt(n,10))-(i=t%100))/100*60+i),e._d=Re.apply(null,e._a),e._d.setUTCMinutes(e._d.getUTCMinutes()-e._tzm),h(e).rfc2822=!0)):e._isValid=!1}function wt(e,t,i){return null!=e?e:null!=t?t:i}function kt(e){var i,n,r,a,s,o,l,c,u,d,f,p=[];if(!e._d){for(r=e,a=new Date(t.now()),n=r._useUTC?[a.getUTCFullYear(),a.getUTCMonth(),a.getUTCDate()]:[a.getFullYear(),a.getMonth(),a.getDate()],e._w&&null==e._a[ve]&&null==e._a[ge]&&(null!=(a=(r=e)._w).GG||null!=a.W||null!=a.E?(c=1,u=4,s=wt(a.GG,r._a[me],Ve(Lt(),1,4).year),o=wt(a.W,1),((l=wt(a.E,1))<1||7<l)&&(d=!0)):(c=r._locale._week.dow,u=r._locale._week.doy,f=Ve(Lt(),c,u),s=wt(a.gg,r._a[me],f.year),o=wt(a.w,f.week),null!=a.d?((l=a.d)<0||6<l)&&(d=!0):null!=a.e?(l=a.e+c,(a.e<0||6<a.e)&&(d=!0)):l=c),o<1||o>We(s,c,u)?h(r)._overflowWeeks=!0:null!=d?h(r)._overflowWeekday=!0:(f=Be(s,o,l,c,u),r._a[me]=f.year,r._dayOfYear=f.dayOfYear)),null!=e._dayOfYear&&(a=wt(e._a[me],n[me]),(e._dayOfYear>Me(a)||0===e._dayOfYear)&&(h(e)._overflowDayOfYear=!0),d=Re(a,0,e._dayOfYear),e._a[ge]=d.getUTCMonth(),e._a[ve]=d.getUTCDate()),i=0;i<3&&null==e._a[i];++i)e._a[i]=p[i]=n[i];for(;i<7;i++)e._a[i]=p[i]=null==e._a[i]?2===i?1:0:e._a[i];24===e._a[ye]&&0===e._a[be]&&0===e._a[xe]&&0===e._a[_e]&&(e._nextDay=!0,e._a[ye]=0),e._d=(e._useUTC?Re:Fe).apply(null,p),s=e._useUTC?e._d.getUTCDay():e._d.getDay(),null!=e._tzm&&e._d.setUTCMinutes(e._d.getUTCMinutes()-e._tzm),e._nextDay&&(e._a[ye]=24),e._w&&void 0!==e._w.d&&e._w.d!==s&&(h(e).weekdayMismatch=!0)}}function Mt(e){if(e._f===t.ISO_8601)xt(e);else if(e._f===t.RFC_2822)_t(e);else{e._a=[],h(e).empty=!0;for(var i,n,a,s,o,l=""+e._i,c=l.length,u=0,d=N(e._f,e._locale).match(D)||[],f=d.length,p=0;p<f;p++)n=d[p],(i=(l.match(se(n,e))||[])[0])&&(0<(a=l.substr(0,l.indexOf(i))).length&&h(e).unusedInput.push(a),l=l.slice(l.indexOf(i)+i.length),u+=i.length),P[n]?(i?h(e).empty=!1:h(e).unusedTokens.push(n),a=n,o=e,null!=(s=i)&&r(de,a)&&de[a](s,o._a,o,a)):e._strict&&!i&&h(e).unusedTokens.push(n);h(e).charsLeftOver=c-u,0<l.length&&h(e).unusedInput.push(l),e._a[ye]<=12&&!0===h(e).bigHour&&0<e._a[ye]&&(h(e).bigHour=void 0),h(e).parsedDateParts=e._a.slice(0),h(e).meridiem=e._meridiem,e._a[ye]=function(e,t,i){return null==i?t:null!=e.meridiemHour?e.meridiemHour(t,i):null!=e.isPM?((e=e.isPM(i))&&t<12&&(t+=12),t=e||12!==t?t:0):t}(e._locale,e._a[ye],e._meridiem),null!==(c=h(e).era)&&(e._a[me]=e._locale.erasConvertYear(c,e._a[me])),kt(e),dt(e)}}function St(e){var r,a,d,m=e._i,g=e._f;if(e._locale=e._locale||ut(e._l),null===m||void 0===g&&""===m)return p({nullInput:!0});if("string"==typeof m&&(e._i=m=e._locale.preparse(m)),x(m))return new b(dt(m));if(l(m))e._d=m;else if(i(g)){var v,_,w,k,M,S,A=e,L=!1,T=A._f.length;if(0===T)h(A).invalidFormat=!0,A._d=new Date(NaN);else{for(k=0;k<T;k++)M=0,S=!1,v=y({},A),null!=A._useUTC&&(v._useUTC=A._useUTC),v._f=A._f[k],Mt(v),f(v)&&(S=!0),M=(M+=h(v).charsLeftOver)+10*h(v).unusedTokens.length,h(v).score=M,L?M<w&&(w=M,_=v):(null==w||M<w||S)&&(w=M,_=v,S)&&(L=!0);u(A,_||v)}}else g?Mt(e):s(g=(m=e)._i)?m._d=new Date(t.now()):l(g)?m._d=new Date(g.valueOf()):"string"==typeof g?(a=m,null!==(r=vt.exec(a._i))?a._d=new Date(+r[1]):(xt(a),!1===a._isValid&&(delete a._isValid,_t(a),!1===a._isValid)&&(delete a._isValid,a._strict?a._isValid=!1:t.createFromInputFallback(a)))):i(g)?(m._a=c(g.slice(0),(function(e){return parseInt(e,10)})),kt(m)):n(g)?(r=m)._d||(d=void 0===(a=F(r._i)).day?a.date:a.day,r._a=c([a.year,a.month,d,a.hour,a.minute,a.second,a.millisecond],(function(e){return e&&parseInt(e,10)})),kt(r)):o(g)?m._d=new Date(g):t.createFromInputFallback(m);return f(e)||(e._d=null),e}function At(e,t,r,s,o){var l={};return!0!==t&&!1!==t||(s=t,t=void 0),!0!==r&&!1!==r||(s=r,r=void 0),(n(e)&&a(e)||i(e)&&0===e.length)&&(e=void 0),l._isAMomentObject=!0,l._useUTC=l._isUTC=o,l._l=r,l._i=e,l._f=t,l._strict=s,(o=new b(dt(St(o=l))))._nextDay&&(o.add(1,"d"),o._nextDay=void 0),o}function Lt(e,t,i,n){return At(e,t,i,n,!1)}function Tt(e,t){var n,r;if(!(t=1===t.length&&i(t[0])?t[0]:t).length)return Lt();for(n=t[0],r=1;r<t.length;++r)t[r].isValid()&&!t[r][e](n)||(n=t[r]);return n}t.createFromInputFallback=w("value provided is not in a recognized RFC2822 or ISO format. moment construction falls back to js Date(), which is not reliable across all browsers and versions. Non RFC2822/ISO date formats are discouraged. Please refer to http://momentjs.com/guides/#/warnings/js-date/ for more info.",(function(e){e._d=new Date(e._i+(e._useUTC?" UTC":""))})),t.ISO_8601=function(){},t.RFC_2822=function(){},$=w("moment().min is deprecated, use moment.max instead. http://momentjs.com/guides/#/warnings/min-max/",(function(){var e=Lt.apply(null,arguments);return this.isValid()&&e.isValid()?e<this?this:e:p()})),X=w("moment().max is deprecated, use moment.min instead. http://momentjs.com/guides/#/warnings/min-max/",(function(){var e=Lt.apply(null,arguments);return this.isValid()&&e.isValid()?this<e?this:e:p()}));var Ct=["year","quarter","month","week","day","hour","minute","second","millisecond"];function Dt(e){var t=(e=F(e)).year||0,i=e.quarter||0,n=e.month||0,a=e.week||e.isoWeek||0,s=e.day||0,o=e.hour||0,l=e.minute||0,c=e.second||0,u=e.millisecond||0;this._isValid=function(e){var t,i,n=!1,a=Ct.length;for(t in e)if(r(e,t)&&(-1===Se.call(Ct,t)||null!=e[t]&&isNaN(e[t])))return!1;for(i=0;i<a;++i)if(e[Ct[i]]){if(n)return!1;parseFloat(e[Ct[i]])!==ce(e[Ct[i]])&&(n=!0)}return!0}(e),this._milliseconds=+u+1e3*c+6e4*l+1e3*o*60*60,this._days=+s+7*a,this._months=+n+3*i+12*t,this._data={},this._locale=ut(),this._bubble()}function Et(e){return e instanceof Dt}function Ot(e){return e<0?-1*Math.round(-1*e):Math.round(e)}function Pt(e,t){Y(e,0,0,(function(){var e=this.utcOffset(),i="+";return e<0&&(e=-e,i="-"),i+C(~~(e/60),2)+t+C(~~e%60,2)}))}Pt("Z",":"),Pt("ZZ",""),ae("Z",te),ae("ZZ",te),he(["Z","ZZ"],(function(e,t,i){i._useUTC=!0,i._tzm=It(te,e)}));var Yt=/([\+\-]|\d\d)/gi;function It(e,t){return null===(t=(t||"").match(e))?null:0===(t=60*(e=((t[t.length-1]||[])+"").match(Yt)||["-",0,0])[1]+ce(e[2]))?0:"+"===e[0]?t:-t}function Nt(e,i){var n;return i._isUTC?(i=i.clone(),n=(x(e)||l(e)?e:Lt(e)).valueOf()-i.valueOf(),i._d.setTime(i._d.valueOf()+n),t.updateOffset(i,!1),i):Lt(e).local()}function jt(e){return-Math.round(e._d.getTimezoneOffset())}function Ht(){return!!this.isValid()&&this._isUTC&&0===this._offset}t.updateOffset=function(){};var Ft=/^(-|\+)?(?:(\d*)[. ])?(\d+):(\d+)(?::(\d+)(\.\d*)?)?$/,Rt=/^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/;function zt(e,t){var i,n=e;return Et(e)?n={ms:e._milliseconds,d:e._days,M:e._months}:o(e)||!isNaN(+e)?(n={},t?n[t]=+e:n.milliseconds=+e):(t=Ft.exec(e))?(i="-"===t[1]?-1:1,n={y:0,d:ce(t[ve])*i,h:ce(t[ye])*i,m:ce(t[be])*i,s:ce(t[xe])*i,ms:ce(Ot(1e3*t[_e]))*i}):(t=Rt.exec(e))?(i="-"===t[1]?-1:1,n={y:Bt(t[2],i),M:Bt(t[3],i),w:Bt(t[4],i),d:Bt(t[5],i),h:Bt(t[6],i),m:Bt(t[7],i),s:Bt(t[8],i)}):null==n?n={}:"object"==typeof n&&("from"in n||"to"in n)&&(t=function(e,t){var i;return e.isValid()&&t.isValid()?(t=Nt(t,e),e.isBefore(t)?i=Vt(e,t):((i=Vt(t,e)).milliseconds=-i.milliseconds,i.months=-i.months),i):{milliseconds:0,months:0}}(Lt(n.from),Lt(n.to)),(n={}).ms=t.milliseconds,n.M=t.months),i=new Dt(n),Et(e)&&r(e,"_locale")&&(i._locale=e._locale),Et(e)&&r(e,"_isValid")&&(i._isValid=e._isValid),i}function Bt(e,t){return e=e&&parseFloat(e.replace(",",".")),(isNaN(e)?0:e)*t}function Vt(e,t){var i={};return i.months=t.month()-e.month()+12*(t.year()-e.year()),e.clone().add(i.months,"M").isAfter(t)&&--i.months,i.milliseconds=+t-+e.clone().add(i.months,"M"),i}function Wt(e,t){return function(i,n){var r;return null===n||isNaN(+n)||(M(t,"moment()."+t+"(period, number) is deprecated. Please use moment()."+t+"(number, period). See http://momentjs.com/guides/#/warnings/add-inverted-param/ for more info."),r=i,i=n,n=r),Ut(this,zt(i,n),e),this}}function Ut(e,i,n,r){var a=i._milliseconds,s=Ot(i._days);i=Ot(i._months);e.isValid()&&(r=null==r||r,i&&Ne(e,Te(e,"Month")+i*n),s&&Ce(e,"Date",Te(e,"Date")+s*n),a&&e._d.setTime(e._d.valueOf()+a*n),r)&&t.updateOffset(e,s||i)}function qt(e){return"string"==typeof e||e instanceof String}function $t(e,t){var i,n;return e.date()<t.date()?-$t(t,e):-((i=12*(t.year()-e.year())+(t.month()-e.month()))+(t-(n=e.clone().add(i,"months"))<0?(t-n)/(n-e.clone().add(i-1,"months")):(t-n)/(e.clone().add(1+i,"months")-n)))||0}function Xt(e){return void 0===e?this._locale._abbr:(null!=(e=ut(e))&&(this._locale=e),this)}function Gt(){return this._locale}zt.fn=Dt.prototype,zt.invalid=function(){return zt(NaN)},Ee=Wt(1,"add"),qe=Wt(-1,"subtract"),t.defaultFormat="YYYY-MM-DDTHH:mm:ssZ",t.defaultFormatUtc="YYYY-MM-DDTHH:mm:ss[Z]",Xe=w("moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.",(function(e){return void 0===e?this.localeData():this.locale(e)}));var Zt=126227808e5;function Kt(e,t){return(e%t+t)%t}function Jt(e,t,i){return e<100&&0<=e?new Date(e+400,t,i)-Zt:new Date(e,t,i).valueOf()}function Qt(e,t,i){return e<100&&0<=e?Date.UTC(e+400,t,i)-Zt:Date.UTC(e,t,i)}function ei(e,t){return t.erasAbbrRegex(e)}function ti(){for(var e,t,i,n=[],r=[],a=[],s=[],o=this.eras(),l=0,c=o.length;l<c;++l)e=oe(o[l].name),t=oe(o[l].abbr),i=oe(o[l].narrow),r.push(e),n.push(t),a.push(i),s.push(e),s.push(t),s.push(i);this._erasRegex=new RegExp("^("+s.join("|")+")","i"),this._erasNameRegex=new RegExp("^("+r.join("|")+")","i"),this._erasAbbrRegex=new RegExp("^("+n.join("|")+")","i"),this._erasNarrowRegex=new RegExp("^("+a.join("|")+")","i")}function ii(e,t){Y(0,[e,e.length],0,t)}function ni(e,t,i,n,r){var a;return null==e?Ve(this,n,r).year:(a=We(e,n,r),function(e,t,i,n,r){return t=Re((e=Be(e,t,i,n,r)).year,0,e.dayOfYear),this.year(t.getUTCFullYear()),this.month(t.getUTCMonth()),this.date(t.getUTCDate()),this}.call(this,e,t=a<t?a:t,i,n,r))}Y("N",0,0,"eraAbbr"),Y("NN",0,0,"eraAbbr"),Y("NNN",0,0,"eraAbbr"),Y("NNNN",0,0,"eraName"),Y("NNNNN",0,0,"eraNarrow"),Y("y",["y",1],"yo","eraYear"),Y("y",["yy",2],0,"eraYear"),Y("y",["yyy",3],0,"eraYear"),Y("y",["yyyy",4],0,"eraYear"),ae("N",ei),ae("NN",ei),ae("NNN",ei),ae("NNNN",(function(e,t){return t.erasNameRegex(e)})),ae("NNNNN",(function(e,t){return t.erasNarrowRegex(e)})),he(["N","NN","NNN","NNNN","NNNNN"],(function(e,t,i,n){(n=i._locale.erasParse(e,n,i._strict))?h(i).era=n:h(i).invalidEra=e})),ae("y",J),ae("yy",J),ae("yyy",J),ae("yyyy",J),ae("yo",(function(e,t){return t._eraYearOrdinalRegex||J})),he(["y","yy","yyy","yyyy"],me),he(["yo"],(function(e,t,i,n){var r;i._locale._eraYearOrdinalRegex&&(r=e.match(i._locale._eraYearOrdinalRegex)),i._locale.eraYearOrdinalParse?t[me]=i._locale.eraYearOrdinalParse(e,r):t[me]=parseInt(e,10)})),Y(0,["gg",2],0,(function(){return this.weekYear()%100})),Y(0,["GG",2],0,(function(){return this.isoWeekYear()%100})),ii("gggg","weekYear"),ii("ggggg","weekYear"),ii("GGGG","isoWeekYear"),ii("GGGGG","isoWeekYear"),ae("G",Q),ae("g",Q),ae("GG",q,B),ae("gg",q,B),ae("GGGG",Z,W),ae("gggg",Z,W),ae("GGGGG",K,U),ae("ggggg",K,U),fe(["gggg","ggggg","GGGG","GGGGG"],(function(e,t,i,n){t[n.substr(0,2)]=ce(e)})),fe(["gg","GG"],(function(e,i,n,r){i[r]=t.parseTwoDigitYear(e)})),Y("Q",0,"Qo","quarter"),ae("Q",z),he("Q",(function(e,t){t[ge]=3*(ce(e)-1)})),Y("D",["DD",2],"Do","date"),ae("D",q,ne),ae("DD",q,B),ae("Do",(function(e,t){return e?t._dayOfMonthOrdinalParse||t._ordinalParse:t._dayOfMonthOrdinalParseLenient})),he(["D","DD"],ve),he("Do",(function(e,t){t[ve]=ce(e.match(q)[0])})),Z=Le("Date",!0),Y("DDD",["DDDD",3],"DDDo","dayOfYear"),ae("DDD",G),ae("DDDD",V),he(["DDD","DDDD"],(function(e,t,i){i._dayOfYear=ce(e)})),Y("m",["mm",2],0,"minute"),ae("m",q,re),ae("mm",q,B),he(["m","mm"],be);var ri;W=Le("Minutes",!1),Y("s",["ss",2],0,"second"),ae("s",q,re),ae("ss",q,B),he(["s","ss"],xe),K=Le("Seconds",!1);for(Y("S",0,0,(function(){return~~(this.millisecond()/100)})),Y(0,["SS",2],0,(function(){return~~(this.millisecond()/10)})),Y(0,["SSS",3],0,"millisecond"),Y(0,["SSSS",4],0,(function(){return 10*this.millisecond()})),Y(0,["SSSSS",5],0,(function(){return 100*this.millisecond()})),Y(0,["SSSSSS",6],0,(function(){return 1e3*this.millisecond()})),Y(0,["SSSSSSS",7],0,(function(){return 1e4*this.millisecond()})),Y(0,["SSSSSSSS",8],0,(function(){return 1e5*this.millisecond()})),Y(0,["SSSSSSSSS",9],0,(function(){return 1e6*this.millisecond()})),ae("S",G,z),ae("SS",G,B),ae("SSS",G,V),ri="SSSS";ri.length<=9;ri+="S")ae(ri,J);function ai(e,t){t[_e]=ce(1e3*("0."+e))}for(ri="S";ri.length<=9;ri+="S")he(ri,ai);function si(e){return e}function oi(e,t,i,n){var r=ut();n=d().set(n,t);return r[i](n,e)}function li(e,t,i){if(o(e)&&(t=e,e=void 0),e=e||"",null!=t)return oi(e,t,i,"month");for(var n=[],r=0;r<12;r++)n[r]=oi(e,r,i,"month");return n}function ci(e,t,i,n){"boolean"==typeof e?o(t)&&(i=t,t=void 0):(t=e,e=!1,o(i=t)&&(i=t,t=void 0)),t=t||"";var r,a=ut(),s=e?a._week.dow:0,l=[];if(null!=i)return oi(t,(i+s)%7,n,"day");for(r=0;r<7;r++)l[r]=oi(t,(r+s)%7,n,"day");return l}U=Le("Milliseconds",!1),Y("z",0,0,"zoneAbbr"),Y("zz",0,0,"zoneName"),(ne=b.prototype).add=Ee,ne.calendar=function(e,s){1===arguments.length&&(arguments[0]?function(e){return x(e)||l(e)||qt(e)||o(e)||function(e){var t=i(e),n=!1;return t&&(n=0===e.filter((function(t){return!o(t)&&qt(e)})).length),t&&n}(e)||function(e){var t,i=n(e)&&!a(e),s=!1,o=["years","year","y","months","month","M","days","day","d","dates","date","D","hours","hour","h","minutes","minute","m","seconds","second","s","milliseconds","millisecond","ms"],l=o.length;for(t=0;t<l;t+=1)s=s||r(e,o[t]);return i&&s}(e)||null==e}(arguments[0])?(e=arguments[0],s=void 0):function(e){for(var t=n(e)&&!a(e),i=!1,s=["sameDay","nextDay","lastDay","nextWeek","lastWeek","sameElse"],o=0;o<s.length;o+=1)i=i||r(e,s[o]);return t&&i}(arguments[0])&&(s=arguments[0],e=void 0):s=e=void 0);var c=Nt(e=e||Lt(),this).startOf("day");c=t.calendarFormat(this,c)||"sameElse",s=s&&(S(s[c])?s[c].call(this,e):s[c]);return this.format(s||this.localeData().calendar(c,this,Lt(e)))},ne.clone=function(){return new b(this)},ne.diff=function(e,t,i){var n,r,a;if(!this.isValid())return NaN;if(!(n=Nt(e,this)).isValid())return NaN;switch(r=6e4*(n.utcOffset()-this.utcOffset()),t=H(t)){case"year":a=$t(this,n)/12;break;case"month":a=$t(this,n);break;case"quarter":a=$t(this,n)/3;break;case"second":a=(this-n)/1e3;break;case"minute":a=(this-n)/6e4;break;case"hour":a=(this-n)/36e5;break;case"day":a=(this-n-r)/864e5;break;case"week":a=(this-n-r)/6048e5;break;default:a=this-n}return i?a:le(a)},ne.endOf=function(e){var i,n;if(void 0!==(e=H(e))&&"millisecond"!==e&&this.isValid()){switch(n=this._isUTC?Qt:Jt,e){case"year":i=n(this.year()+1,0,1)-1;break;case"quarter":i=n(this.year(),this.month()-this.month()%3+3,1)-1;break;case"month":i=n(this.year(),this.month()+1,1)-1;break;case"week":i=n(this.year(),this.month(),this.date()-this.weekday()+7)-1;break;case"isoWeek":i=n(this.year(),this.month(),this.date()-(this.isoWeekday()-1)+7)-1;break;case"day":case"date":i=n(this.year(),this.month(),this.date()+1)-1;break;case"hour":i=this._d.valueOf(),i+=36e5-Kt(i+(this._isUTC?0:6e4*this.utcOffset()),36e5)-1;break;case"minute":i=this._d.valueOf(),i+=6e4-Kt(i,6e4)-1;break;case"second":i=this._d.valueOf(),i+=1e3-Kt(i,1e3)-1}this._d.setTime(i),t.updateOffset(this,!0)}return this},ne.format=function(e){return e=I(this,e=e||(this.isUtc()?t.defaultFormatUtc:t.defaultFormat)),this.localeData().postformat(e)},ne.from=function(e,t){return this.isValid()&&(x(e)&&e.isValid()||Lt(e).isValid())?zt({to:this,from:e}).locale(this.locale()).humanize(!t):this.localeData().invalidDate()},ne.fromNow=function(e){return this.from(Lt(),e)},ne.to=function(e,t){return this.isValid()&&(x(e)&&e.isValid()||Lt(e).isValid())?zt({from:this,to:e}).locale(this.locale()).humanize(!t):this.localeData().invalidDate()},ne.toNow=function(e){return this.to(Lt(),e)},ne.get=function(e){return S(this[e=H(e)])?this[e]():this},ne.invalidAt=function(){return h(this).overflow},ne.isAfter=function(e,t){return e=x(e)?e:Lt(e),!(!this.isValid()||!e.isValid())&&("millisecond"===(t=H(t)||"millisecond")?this.valueOf()>e.valueOf():e.valueOf()<this.clone().startOf(t).valueOf())},ne.isBefore=function(e,t){return e=x(e)?e:Lt(e),!(!this.isValid()||!e.isValid())&&("millisecond"===(t=H(t)||"millisecond")?this.valueOf()<e.valueOf():this.clone().endOf(t).valueOf()<e.valueOf())},ne.isBetween=function(e,t,i,n){return e=x(e)?e:Lt(e),t=x(t)?t:Lt(t),!!(this.isValid()&&e.isValid()&&t.isValid())&&("("===(n=n||"()")[0]?this.isAfter(e,i):!this.isBefore(e,i))&&(")"===n[1]?this.isBefore(t,i):!this.isAfter(t,i))},ne.isSame=function(e,t){e=x(e)?e:Lt(e);return!(!this.isValid()||!e.isValid())&&("millisecond"===(t=H(t)||"millisecond")?this.valueOf()===e.valueOf():(e=e.valueOf(),this.clone().startOf(t).valueOf()<=e&&e<=this.clone().endOf(t).valueOf()))},ne.isSameOrAfter=function(e,t){return this.isSame(e,t)||this.isAfter(e,t)},ne.isSameOrBefore=function(e,t){return this.isSame(e,t)||this.isBefore(e,t)},ne.isValid=function(){return f(this)},ne.lang=Xe,ne.locale=Xt,ne.localeData=Gt,ne.max=X,ne.min=$,ne.parsingFlags=function(){return u({},h(this))},ne.set=function(e,t){if("object"==typeof e)for(var i=function(e){var t,i=[];for(t in e)r(e,t)&&i.push({unit:t,priority:R[t]});return i.sort((function(e,t){return e.priority-t.priority})),i}(e=F(e)),n=i.length,a=0;a<n;a++)this[i[a].unit](e[i[a].unit]);else if(S(this[e=H(e)]))return this[e](t);return this},ne.startOf=function(e){var i,n;if(void 0!==(e=H(e))&&"millisecond"!==e&&this.isValid()){switch(n=this._isUTC?Qt:Jt,e){case"year":i=n(this.year(),0,1);break;case"quarter":i=n(this.year(),this.month()-this.month()%3,1);break;case"month":i=n(this.year(),this.month(),1);break;case"week":i=n(this.year(),this.month(),this.date()-this.weekday());break;case"isoWeek":i=n(this.year(),this.month(),this.date()-(this.isoWeekday()-1));break;case"day":case"date":i=n(this.year(),this.month(),this.date());break;case"hour":i=this._d.valueOf(),i-=Kt(i+(this._isUTC?0:6e4*this.utcOffset()),36e5);break;case"minute":i=this._d.valueOf(),i-=Kt(i,6e4);break;case"second":i=this._d.valueOf(),i-=Kt(i,1e3)}this._d.setTime(i),t.updateOffset(this,!0)}return this},ne.subtract=qe,ne.toArray=function(){var e=this;return[e.year(),e.month(),e.date(),e.hour(),e.minute(),e.second(),e.millisecond()]},ne.toObject=function(){var e=this;return{years:e.year(),months:e.month(),date:e.date(),hours:e.hours(),minutes:e.minutes(),seconds:e.seconds(),milliseconds:e.milliseconds()}},ne.toDate=function(){return new Date(this.valueOf())},ne.toISOString=function(e){var t;return this.isValid()?(t=(e=!0!==e)?this.clone().utc():this).year()<0||9999<t.year()?I(t,e?"YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYYYY-MM-DD[T]HH:mm:ss.SSSZ"):S(Date.prototype.toISOString)?e?this.toDate().toISOString():new Date(this.valueOf()+60*this.utcOffset()*1e3).toISOString().replace("Z",I(t,"Z")):I(t,e?"YYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYY-MM-DD[T]HH:mm:ss.SSSZ"):null},ne.inspect=function(){var e,t,i;return this.isValid()?(t="moment",e="",this.isLocal()||(t=0===this.utcOffset()?"moment.utc":"moment.parseZone",e="Z"),t="["+t+'("]',i=0<=this.year()&&this.year()<=9999?"YYYY":"YYYYYY",this.format(t+i+"-MM-DD[T]HH:mm:ss.SSS"+e+'[")]')):"moment.invalid(/* "+this._i+" */)"},"undefined"!=typeof Symbol&&null!=Symbol.for&&(ne[Symbol.for("nodejs.util.inspect.custom")]=function(){return"Moment<"+this.format()+">"}),ne.toJSON=function(){return this.isValid()?this.toISOString():null},ne.toString=function(){return this.clone().locale("en").format("ddd MMM DD YYYY HH:mm:ss [GMT]ZZ")},ne.unix=function(){return Math.floor(this.valueOf()/1e3)},ne.valueOf=function(){return this._d.valueOf()-6e4*(this._offset||0)},ne.creationData=function(){return{input:this._i,format:this._f,locale:this._locale,isUTC:this._isUTC,strict:this._strict}},ne.eraName=function(){for(var e,t=this.localeData().eras(),i=0,n=t.length;i<n;++i){if(e=this.clone().startOf("day").valueOf(),t[i].since<=e&&e<=t[i].until)return t[i].name;if(t[i].until<=e&&e<=t[i].since)return t[i].name}return""},ne.eraNarrow=function(){for(var e,t=this.localeData().eras(),i=0,n=t.length;i<n;++i){if(e=this.clone().startOf("day").valueOf(),t[i].since<=e&&e<=t[i].until)return t[i].narrow;if(t[i].until<=e&&e<=t[i].since)return t[i].narrow}return""},ne.eraAbbr=function(){for(var e,t=this.localeData().eras(),i=0,n=t.length;i<n;++i){if(e=this.clone().startOf("day").valueOf(),t[i].since<=e&&e<=t[i].until)return t[i].abbr;if(t[i].until<=e&&e<=t[i].since)return t[i].abbr}return""},ne.eraYear=function(){for(var e,i,n=this.localeData().eras(),r=0,a=n.length;r<a;++r)if(e=n[r].since<=n[r].until?1:-1,i=this.clone().startOf("day").valueOf(),n[r].since<=i&&i<=n[r].until||n[r].until<=i&&i<=n[r].since)return(this.year()-t(n[r].since).year())*e+n[r].offset;return this.year()},ne.year=Ae,ne.isLeapYear=function(){return pe(this.year())},ne.weekYear=function(e){return ni.call(this,e,this.week(),this.weekday()+this.localeData()._week.dow,this.localeData()._week.dow,this.localeData()._week.doy)},ne.isoWeekYear=function(e){return ni.call(this,e,this.isoWeek(),this.isoWeekday(),1,4)},ne.quarter=ne.quarters=function(e){return null==e?Math.ceil((this.month()+1)/3):this.month(3*(e-1)+this.month()%3)},ne.month=je,ne.daysInMonth=function(){return De(this.year(),this.month())},ne.week=ne.weeks=function(e){var t=this.localeData().week(this);return null==e?t:this.add(7*(e-t),"d")},ne.isoWeek=ne.isoWeeks=function(e){var t=Ve(this,1,4).week;return null==e?t:this.add(7*(e-t),"d")},ne.weeksInYear=function(){var e=this.localeData()._week;return We(this.year(),e.dow,e.doy)},ne.weeksInWeekYear=function(){var e=this.localeData()._week;return We(this.weekYear(),e.dow,e.doy)},ne.isoWeeksInYear=function(){return We(this.year(),1,4)},ne.isoWeeksInISOWeekYear=function(){return We(this.isoWeekYear(),1,4)},ne.date=Z,ne.day=ne.days=function(e){var t,i,n;return this.isValid()?(t=Te(this,"Day"),null!=e?(i=e,n=this.localeData(),e="string"!=typeof i?i:isNaN(i)?"number"==typeof(i=n.weekdaysParse(i))?i:null:parseInt(i,10),this.add(e-t,"d")):t):null!=e?this:NaN},ne.weekday=function(e){var t;return this.isValid()?(t=(this.day()+7-this.localeData()._week.dow)%7,null==e?t:this.add(e-t,"d")):null!=e?this:NaN},ne.isoWeekday=function(e){var t,i;return this.isValid()?null!=e?(t=e,i=this.localeData(),i="string"==typeof t?i.weekdaysParse(t)%7||7:isNaN(t)?null:t,this.day(this.day()%7?i:i-7)):this.day()||7:null!=e?this:NaN},ne.dayOfYear=function(e){var t=Math.round((this.clone().startOf("day")-this.clone().startOf("year"))/864e5)+1;return null==e?t:this.add(e-t,"d")},ne.hour=ne.hours=ie,ne.minute=ne.minutes=W,ne.second=ne.seconds=K,ne.millisecond=ne.milliseconds=U,ne.utcOffset=function(e,i,n){var r,a=this._offset||0;if(!this.isValid())return null!=e?this:NaN;if(null==e)return this._isUTC?a:jt(this);if("string"==typeof e){if(null===(e=It(te,e)))return this}else Math.abs(e)<16&&!n&&(e*=60);return!this._isUTC&&i&&(r=jt(this)),this._offset=e,this._isUTC=!0,null!=r&&this.add(r,"m"),a!==e&&(!i||this._changeInProgress?Ut(this,zt(e-a,"m"),1,!1):this._changeInProgress||(this._changeInProgress=!0,t.updateOffset(this,!0),this._changeInProgress=null)),this},ne.utc=function(e){return this.utcOffset(0,e)},ne.local=function(e){return this._isUTC&&(this.utcOffset(0,e),this._isUTC=!1,e)&&this.subtract(jt(this),"m"),this},ne.parseZone=function(){var e;return null!=this._tzm?this.utcOffset(this._tzm,!1,!0):"string"==typeof this._i&&(null!=(e=It(ee,this._i))?this.utcOffset(e):this.utcOffset(0,!0)),this},ne.hasAlignedHourOffset=function(e){return!!this.isValid()&&(e=e?Lt(e).utcOffset():0,(this.utcOffset()-e)%60==0)},ne.isDST=function(){return this.utcOffset()>this.clone().month(0).utcOffset()||this.utcOffset()>this.clone().month(5).utcOffset()},ne.isLocal=function(){return!!this.isValid()&&!this._isUTC},ne.isUtcOffset=function(){return!!this.isValid()&&this._isUTC},ne.isUtc=Ht,ne.isUTC=Ht,ne.zoneAbbr=function(){return this._isUTC?"UTC":""},ne.zoneName=function(){return this._isUTC?"Coordinated Universal Time":""},ne.dates=w("dates accessor is deprecated. Use date instead.",Z),ne.months=w("months accessor is deprecated. Use month instead",je),ne.years=w("years accessor is deprecated. Use year instead",Ae),ne.zone=w("moment().zone is deprecated, use moment().utcOffset instead. http://momentjs.com/guides/#/warnings/zone/",(function(e,t){return null!=e?(this.utcOffset(e="string"!=typeof e?-e:e,t),this):-this.utcOffset()})),ne.isDSTShifted=w("isDSTShifted is deprecated. See http://momentjs.com/guides/#/warnings/dst-shifted/ for more information",(function(){var e,t;return s(this._isDSTShifted)&&(y(e={},this),(e=St(e))._a?(t=(e._isUTC?d:Lt)(e._a),this._isDSTShifted=this.isValid()&&0<function(e,t,i){for(var n=Math.min(e.length,t.length),r=Math.abs(e.length-t.length),a=0,s=0;s<n;s++)ce(e[s])!==ce(t[s])&&a++;return a+r}(e._a,t.toArray())):this._isDSTShifted=!1),this._isDSTShifted})),(re=L.prototype).calendar=function(e,t,i){return S(e=this._calendar[e]||this._calendar.sameElse)?e.call(t,i):e},re.longDateFormat=function(e){var t=this._longDateFormat[e],i=this._longDateFormat[e.toUpperCase()];return t||!i?t:(this._longDateFormat[e]=i.match(D).map((function(e){return"MMMM"===e||"MM"===e||"DD"===e||"dddd"===e?e.slice(1):e})).join(""),this._longDateFormat[e])},re.invalidDate=function(){return this._invalidDate},re.ordinal=function(e){return this._ordinal.replace("%d",e)},re.preparse=si,re.postformat=si,re.relativeTime=function(e,t,i,n){var r=this._relativeTime[i];return S(r)?r(e,t,i,n):r.replace(/%d/i,e)},re.pastFuture=function(e,t){return S(e=this._relativeTime[0<e?"future":"past"])?e(t):e.replace(/%s/i,t)},re.set=function(e){var t,i;for(i in e)r(e,i)&&(S(t=e[i])?this[i]=t:this["_"+i]=t);this._config=e,this._dayOfMonthOrdinalParseLenient=new RegExp((this._dayOfMonthOrdinalParse.source||this._ordinalParse.source)+"|"+/\d{1,2}/.source)},re.eras=function(e,i){for(var n,r=this._eras||ut("en")._eras,a=0,s=r.length;a<s;++a){if("string"==typeof r[a].since)n=t(r[a].since).startOf("day"),r[a].since=n.valueOf();switch(typeof r[a].until){case"undefined":r[a].until=1/0;break;case"string":n=t(r[a].until).startOf("day").valueOf(),r[a].until=n.valueOf()}}return r},re.erasParse=function(e,t,i){var n,r,a,s,o,l=this.eras();for(e=e.toUpperCase(),n=0,r=l.length;n<r;++n)if(a=l[n].name.toUpperCase(),s=l[n].abbr.toUpperCase(),o=l[n].narrow.toUpperCase(),i)switch(t){case"N":case"NN":case"NNN":if(s===e)return l[n];break;case"NNNN":if(a===e)return l[n];break;case"NNNNN":if(o===e)return l[n]}else if(0<=[a,s,o].indexOf(e))return l[n]},re.erasConvertYear=function(e,i){var n=e.since<=e.until?1:-1;return void 0===i?t(e.since).year():t(e.since).year()+(i-e.offset)*n},re.erasAbbrRegex=function(e){return r(this,"_erasAbbrRegex")||ti.call(this),e?this._erasAbbrRegex:this._erasRegex},re.erasNameRegex=function(e){return r(this,"_erasNameRegex")||ti.call(this),e?this._erasNameRegex:this._erasRegex},re.erasNarrowRegex=function(e){return r(this,"_erasNarrowRegex")||ti.call(this),e?this._erasNarrowRegex:this._erasRegex},re.months=function(e,t){return e?(i(this._months)?this._months:this._months[(this._months.isFormat||Pe).test(t)?"format":"standalone"])[e.month()]:i(this._months)?this._months:this._months.standalone},re.monthsShort=function(e,t){return e?(i(this._monthsShort)?this._monthsShort:this._monthsShort[Pe.test(t)?"format":"standalone"])[e.month()]:i(this._monthsShort)?this._monthsShort:this._monthsShort.standalone},re.monthsParse=function(e,t,i){var n,r;if(this._monthsParseExact)return function(e,t,i){var n,r,a;e=e.toLocaleLowerCase();if(!this._monthsParse)for(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[],n=0;n<12;++n)a=d([2e3,n]),this._shortMonthsParse[n]=this.monthsShort(a,"").toLocaleLowerCase(),this._longMonthsParse[n]=this.months(a,"").toLocaleLowerCase();return i?"MMM"===t?-1!==(r=Se.call(this._shortMonthsParse,e))?r:null:-1!==(r=Se.call(this._longMonthsParse,e))?r:null:"MMM"===t?-1!==(r=Se.call(this._shortMonthsParse,e))||-1!==(r=Se.call(this._longMonthsParse,e))?r:null:-1!==(r=Se.call(this._longMonthsParse,e))||-1!==(r=Se.call(this._shortMonthsParse,e))?r:null}.call(this,e,t,i);for(this._monthsParse||(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[]),n=0;n<12;n++){if(r=d([2e3,n]),i&&!this._longMonthsParse[n]&&(this._longMonthsParse[n]=new RegExp("^"+this.months(r,"").replace(".","")+"$","i"),this._shortMonthsParse[n]=new RegExp("^"+this.monthsShort(r,"").replace(".","")+"$","i")),i||this._monthsParse[n]||(r="^"+this.months(r,"")+"|^"+this.monthsShort(r,""),this._monthsParse[n]=new RegExp(r.replace(".",""),"i")),i&&"MMMM"===t&&this._longMonthsParse[n].test(e))return n;if(i&&"MMM"===t&&this._shortMonthsParse[n].test(e))return n;if(!i&&this._monthsParse[n].test(e))return n}},re.monthsRegex=function(e){return this._monthsParseExact?(r(this,"_monthsRegex")||He.call(this),e?this._monthsStrictRegex:this._monthsRegex):(r(this,"_monthsRegex")||(this._monthsRegex=Ie),this._monthsStrictRegex&&e?this._monthsStrictRegex:this._monthsRegex)},re.monthsShortRegex=function(e){return this._monthsParseExact?(r(this,"_monthsRegex")||He.call(this),e?this._monthsShortStrictRegex:this._monthsShortRegex):(r(this,"_monthsShortRegex")||(this._monthsShortRegex=Ye),this._monthsShortStrictRegex&&e?this._monthsShortStrictRegex:this._monthsShortRegex)},re.week=function(e){return Ve(e,this._week.dow,this._week.doy).week},re.firstDayOfYear=function(){return this._week.doy},re.firstDayOfWeek=function(){return this._week.dow},re.weekdays=function(e,t){return t=i(this._weekdays)?this._weekdays:this._weekdays[e&&!0!==e&&this._weekdays.isFormat.test(t)?"format":"standalone"],!0===e?Ue(t,this._week.dow):e?t[e.day()]:t},re.weekdaysMin=function(e){return!0===e?Ue(this._weekdaysMin,this._week.dow):e?this._weekdaysMin[e.day()]:this._weekdaysMin},re.weekdaysShort=function(e){return!0===e?Ue(this._weekdaysShort,this._week.dow):e?this._weekdaysShort[e.day()]:this._weekdaysShort},re.weekdaysParse=function(e,t,i){var n,r;if(this._weekdaysParseExact)return function(e,t,i){var n,r,a;e=e.toLocaleLowerCase();if(!this._weekdaysParse)for(this._weekdaysParse=[],this._shortWeekdaysParse=[],this._minWeekdaysParse=[],n=0;n<7;++n)a=d([2e3,1]).day(n),this._minWeekdaysParse[n]=this.weekdaysMin(a,"").toLocaleLowerCase(),this._shortWeekdaysParse[n]=this.weekdaysShort(a,"").toLocaleLowerCase(),this._weekdaysParse[n]=this.weekdays(a,"").toLocaleLowerCase();return i?"dddd"===t?-1!==(r=Se.call(this._weekdaysParse,e))?r:null:"ddd"===t?-1!==(r=Se.call(this._shortWeekdaysParse,e))?r:null:-1!==(r=Se.call(this._minWeekdaysParse,e))?r:null:"dddd"===t?-1!==(r=Se.call(this._weekdaysParse,e))||-1!==(r=Se.call(this._shortWeekdaysParse,e))||-1!==(r=Se.call(this._minWeekdaysParse,e))?r:null:"ddd"===t?-1!==(r=Se.call(this._shortWeekdaysParse,e))||-1!==(r=Se.call(this._weekdaysParse,e))||-1!==(r=Se.call(this._minWeekdaysParse,e))?r:null:-1!==(r=Se.call(this._minWeekdaysParse,e))||-1!==(r=Se.call(this._weekdaysParse,e))||-1!==(r=Se.call(this._shortWeekdaysParse,e))?r:null}.call(this,e,t,i);for(this._weekdaysParse||(this._weekdaysParse=[],this._minWeekdaysParse=[],this._shortWeekdaysParse=[],this._fullWeekdaysParse=[]),n=0;n<7;n++){if(r=d([2e3,1]).day(n),i&&!this._fullWeekdaysParse[n]&&(this._fullWeekdaysParse[n]=new RegExp("^"+this.weekdays(r,"").replace(".","\\.?")+"$","i"),this._shortWeekdaysParse[n]=new RegExp("^"+this.weekdaysShort(r,"").replace(".","\\.?")+"$","i"),this._minWeekdaysParse[n]=new RegExp("^"+this.weekdaysMin(r,"").replace(".","\\.?")+"$","i")),this._weekdaysParse[n]||(r="^"+this.weekdays(r,"")+"|^"+this.weekdaysShort(r,"")+"|^"+this.weekdaysMin(r,""),this._weekdaysParse[n]=new RegExp(r.replace(".",""),"i")),i&&"dddd"===t&&this._fullWeekdaysParse[n].test(e))return n;if(i&&"ddd"===t&&this._shortWeekdaysParse[n].test(e))return n;if(i&&"dd"===t&&this._minWeekdaysParse[n].test(e))return n;if(!i&&this._weekdaysParse[n].test(e))return n}},re.weekdaysRegex=function(e){return this._weekdaysParseExact?(r(this,"_weekdaysRegex")||Je.call(this),e?this._weekdaysStrictRegex:this._weekdaysRegex):(r(this,"_weekdaysRegex")||(this._weekdaysRegex=Ge),this._weekdaysStrictRegex&&e?this._weekdaysStrictRegex:this._weekdaysRegex)},re.weekdaysShortRegex=function(e){return this._weekdaysParseExact?(r(this,"_weekdaysRegex")||Je.call(this),e?this._weekdaysShortStrictRegex:this._weekdaysShortRegex):(r(this,"_weekdaysShortRegex")||(this._weekdaysShortRegex=Ze),this._weekdaysShortStrictRegex&&e?this._weekdaysShortStrictRegex:this._weekdaysShortRegex)},re.weekdaysMinRegex=function(e){return this._weekdaysParseExact?(r(this,"_weekdaysRegex")||Je.call(this),e?this._weekdaysMinStrictRegex:this._weekdaysMinRegex):(r(this,"_weekdaysMinRegex")||(this._weekdaysMinRegex=Ke),this._weekdaysMinStrictRegex&&e?this._weekdaysMinStrictRegex:this._weekdaysMinRegex)},re.isPM=function(e){return"p"===(e+"").toLowerCase().charAt(0)},re.meridiem=function(e,t,i){return 11<e?i?"pm":"PM":i?"am":"AM"},lt("en",{eras:[{since:"0001-01-01",until:1/0,offset:1,name:"Anno Domini",narrow:"AD",abbr:"AD"},{since:"0000-12-31",until:-1/0,offset:1,name:"Before Christ",narrow:"BC",abbr:"BC"}],dayOfMonthOrdinalParse:/\d{1,2}(th|st|nd|rd)/,ordinal:function(e){var t=e%10;return e+(1===ce(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")}}),t.lang=w("moment.lang is deprecated. Use moment.locale instead.",lt),t.langData=w("moment.langData is deprecated. Use moment.localeData instead.",ut);var ui=Math.abs;function di(e,t,i,n){return t=zt(t,i),e._milliseconds+=n*t._milliseconds,e._days+=n*t._days,e._months+=n*t._months,e._bubble()}function hi(e){return e<0?Math.floor(e):Math.ceil(e)}function fi(e){return 4800*e/146097}function pi(e){return 146097*e/4800}function mi(e){return function(){return this.as(e)}}function gi(e){return function(){return this.isValid()?this._data[e]:NaN}}z=mi("ms"),B=mi("s"),G=mi("m"),V=mi("h"),Ee=mi("d"),X=mi("w"),$=mi("M"),qe=mi("Q"),ie=mi("y"),W=z;K=gi("milliseconds"),U=gi("seconds"),Z=gi("minutes"),Ae=gi("hours"),re=gi("days");var vi=gi("months"),yi=gi("years"),bi=Math.round,xi={ss:44,s:45,m:45,h:22,d:26,w:null,M:11};var _i=Math.abs;function wi(e){return(0<e)-(e<0)||+e}function ki(){var e,t,i,n,r,a,s,o,l,c,u;return this.isValid()?(e=_i(this._milliseconds)/1e3,t=_i(this._days),i=_i(this._months),(o=this.asSeconds())?(n=le(e/60),r=le(n/60),e%=60,n%=60,a=le(i/12),i%=12,s=e?e.toFixed(3).replace(/\.?0+$/,""):"",l=wi(this._months)!==wi(o)?"-":"",c=wi(this._days)!==wi(o)?"-":"",u=wi(this._milliseconds)!==wi(o)?"-":"",(o<0?"-":"")+"P"+(a?l+a+"Y":"")+(i?l+i+"M":"")+(t?c+t+"D":"")+(r||n||e?"T":"")+(r?u+r+"H":"")+(n?u+n+"M":"")+(e?u+s+"S":"")):"P0D"):this.localeData().invalidDate()}function Mi(e){return 0===e?0:1===e?1:2===e?2:3<=e%100&&e%100<=10?3:11<=e%100?4:5}function Si(e){return function(t,i,n,r){var a=Mi(t),s=Di[e][Mi(t)];return(s=2===a?s[i?0:1]:s).replace(/%d/i,t)}}function Ai(e){return 0===e?0:1===e?1:2===e?2:3<=e%100&&e%100<=10?3:11<=e%100?4:5}function Li(e){return function(t,i,n,r){var a=Ai(t),s=Oi[e][Ai(t)];return(s=2===a?s[i?0:1]:s).replace(/%d/i,t)}}function Ti(e){return 0===e?0:1===e?1:2===e?2:3<=e%100&&e%100<=10?3:11<=e%100?4:5}function Ci(e){return function(t,i,n,r){var a=Ti(t),s=Fi[e][Ti(t)];return(s=2===a?s[i?0:1]:s).replace(/%d/i,t)}}var Di=((ln=Dt.prototype).isValid=function(){return this._isValid},ln.abs=function(){var e=this._data;return this._milliseconds=ui(this._milliseconds),this._days=ui(this._days),this._months=ui(this._months),e.milliseconds=ui(e.milliseconds),e.seconds=ui(e.seconds),e.minutes=ui(e.minutes),e.hours=ui(e.hours),e.months=ui(e.months),e.years=ui(e.years),this},ln.add=function(e,t){return di(this,e,t,1)},ln.subtract=function(e,t){return di(this,e,t,-1)},ln.as=function(e){if(!this.isValid())return NaN;var t,i,n=this._milliseconds;if("month"===(e=H(e))||"quarter"===e||"year"===e)switch(t=this._days+n/864e5,i=this._months+fi(t),e){case"month":return i;case"quarter":return i/3;case"year":return i/12}else switch(t=this._days+Math.round(pi(this._months)),e){case"week":return t/7+n/6048e5;case"day":return t+n/864e5;case"hour":return 24*t+n/36e5;case"minute":return 1440*t+n/6e4;case"second":return 86400*t+n/1e3;case"millisecond":return Math.floor(864e5*t)+n;default:throw new Error("Unknown unit "+e)}},ln.asMilliseconds=z,ln.asSeconds=B,ln.asMinutes=G,ln.asHours=V,ln.asDays=Ee,ln.asWeeks=X,ln.asMonths=$,ln.asQuarters=qe,ln.asYears=ie,ln.valueOf=W,ln._bubble=function(){var e=this._milliseconds,t=this._days,i=this._months,n=this._data;return 0<=e&&0<=t&&0<=i||e<=0&&t<=0&&i<=0||(e+=864e5*hi(pi(i)+t),i=t=0),n.milliseconds=e%1e3,e=le(e/1e3),n.seconds=e%60,e=le(e/60),n.minutes=e%60,e=le(e/60),n.hours=e%24,t+=le(e/24),i+=e=le(fi(t)),t-=hi(pi(e)),e=le(i/12),i%=12,n.days=t,n.months=i,n.years=e,this},ln.clone=function(){return zt(this)},ln.get=function(e){return e=H(e),this.isValid()?this[e+"s"]():NaN},ln.milliseconds=K,ln.seconds=U,ln.minutes=Z,ln.hours=Ae,ln.days=re,ln.weeks=function(){return le(this.days()/7)},ln.months=vi,ln.years=yi,ln.humanize=function(e,t){var i,n;return this.isValid()?(i=!1,n=xi,"object"==typeof e&&(t=e,e=!1),"boolean"==typeof e&&(i=e),"object"==typeof t&&(n=Object.assign({},xi,t),null!=t.s)&&null==t.ss&&(n.ss=t.s-1),t=function(e,t,i,n){var r=zt(e).abs(),a=bi(r.as("s")),s=bi(r.as("m")),o=bi(r.as("h")),l=bi(r.as("d")),c=bi(r.as("M")),u=bi(r.as("w"));return r=bi(r.as("y")),a=(a<=i.ss?["s",a]:a<i.s&&["ss",a])||(s<=1?["m"]:s<i.m&&["mm",s])||(o<=1?["h"]:o<i.h&&["hh",o])||(l<=1?["d"]:l<i.d&&["dd",l]),(a=(a=null!=i.w?a||(u<=1?["w"]:u<i.w&&["ww",u]):a)||(c<=1?["M"]:c<i.M&&["MM",c])||(r<=1?["y"]:["yy",r]))[2]=t,a[3]=0<+e,a[4]=n,function(e,t,i,n,r){return r.relativeTime(t||1,!!i,e,n)}.apply(null,a)}(this,!i,n,e=this.localeData()),i&&(t=e.pastFuture(+this,t)),e.postformat(t)):this.localeData().invalidDate()},ln.toISOString=ki,ln.toString=ki,ln.toJSON=ki,ln.locale=Xt,ln.localeData=Gt,ln.toIsoString=w("toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)",ki),ln.lang=Xe,Y("X",0,0,"unix"),Y("x",0,0,"valueOf"),ae("x",Q),ae("X",/[+-]?\d+(\.\d{1,3})?/),he("X",(function(e,t,i){i._d=new Date(1e3*parseFloat(e))})),he("x",(function(e,t,i){i._d=new Date(ce(e))})),t.version="2.30.1",e=Lt,t.fn=ne,t.min=function(){return Tt("isBefore",[].slice.call(arguments,0))},t.max=function(){return Tt("isAfter",[].slice.call(arguments,0))},t.now=function(){return Date.now?Date.now():+new Date},t.utc=d,t.unix=function(e){return Lt(1e3*e)},t.months=function(e,t){return li(e,t,"months")},t.isDate=l,t.locale=lt,t.invalid=p,t.duration=zt,t.isMoment=x,t.weekdays=function(e,t,i){return ci(e,t,i,"weekdays")},t.parseZone=function(){return Lt.apply(null,arguments).parseZone()},t.localeData=ut,t.isDuration=Et,t.monthsShort=function(e,t){return li(e,t,"monthsShort")},t.weekdaysMin=function(e,t,i){return ci(e,t,i,"weekdaysMin")},t.defineLocale=ct,t.updateLocale=function(e,t){var i,n;return null!=t?(n=nt,null!=rt[e]&&null!=rt[e].parentLocale?rt[e].set(A(rt[e]._config,t)):(t=A(n=null!=(i=ot(e))?i._config:n,t),null==i&&(t.abbr=e),(n=new L(t)).parentLocale=rt[e],rt[e]=n),lt(e)):null!=rt[e]&&(null!=rt[e].parentLocale?(rt[e]=rt[e].parentLocale,e===lt()&&lt(e)):null!=rt[e]&&delete rt[e]),rt[e]},t.locales=function(){return T(rt)},t.weekdaysShort=function(e,t,i){return ci(e,t,i,"weekdaysShort")},t.normalizeUnits=H,t.relativeTimeRounding=function(e){return void 0===e?bi:"function"==typeof e&&(bi=e,!0)},t.relativeTimeThreshold=function(e,t){return void 0!==xi[e]&&(void 0===t?xi[e]:(xi[e]=t,"s"===e&&(xi.ss=t-1),!0))},t.calendarFormat=function(e,t){return(e=e.diff(t,"days",!0))<-6?"sameElse":e<-1?"lastWeek":e<0?"lastDay":e<1?"sameDay":e<2?"nextDay":e<7?"nextWeek":"sameElse"},t.prototype=ne,t.HTML5_FMT={DATETIME_LOCAL:"YYYY-MM-DDTHH:mm",DATETIME_LOCAL_SECONDS:"YYYY-MM-DDTHH:mm:ss",DATETIME_LOCAL_MS:"YYYY-MM-DDTHH:mm:ss.SSS",DATE:"YYYY-MM-DD",TIME:"HH:mm",TIME_SECONDS:"HH:mm:ss",TIME_MS:"HH:mm:ss.SSS",WEEK:"GGGG-[W]WW",MONTH:"YYYY-MM"},t.defineLocale("af",{months:"Januarie_Februarie_Maart_April_Mei_Junie_Julie_Augustus_September_Oktober_November_Desember".split("_"),monthsShort:"Jan_Feb_Mrt_Apr_Mei_Jun_Jul_Aug_Sep_Okt_Nov_Des".split("_"),weekdays:"Sondag_Maandag_Dinsdag_Woensdag_Donderdag_Vrydag_Saterdag".split("_"),weekdaysShort:"Son_Maa_Din_Woe_Don_Vry_Sat".split("_"),weekdaysMin:"So_Ma_Di_Wo_Do_Vr_Sa".split("_"),meridiemParse:/vm|nm/i,isPM:function(e){return/^nm$/i.test(e)},meridiem:function(e,t,i){return e<12?i?"vm":"VM":i?"nm":"NM"},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Vandag om] LT",nextDay:"[Môre om] LT",nextWeek:"dddd [om] LT",lastDay:"[Gister om] LT",lastWeek:"[Laas] dddd [om] LT",sameElse:"L"},relativeTime:{future:"oor %s",past:"%s gelede",s:"'n paar sekondes",ss:"%d sekondes",m:"'n minuut",mm:"%d minute",h:"'n uur",hh:"%d ure",d:"'n dag",dd:"%d dae",M:"'n maand",MM:"%d maande",y:"'n jaar",yy:"%d jaar"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||20<=e?"ste":"de")},week:{dow:1,doy:4}}),{s:["أقل من ثانية","ثانية واحدة",["ثانيتان","ثانيتين"],"%d ثوان","%d ثانية","%d ثانية"],m:["أقل من دقيقة","دقيقة واحدة",["دقيقتان","دقيقتين"],"%d دقائق","%d دقيقة","%d دقيقة"],h:["أقل من ساعة","ساعة واحدة",["ساعتان","ساعتين"],"%d ساعات","%d ساعة","%d ساعة"],d:["أقل من يوم","يوم واحد",["يومان","يومين"],"%d أيام","%d يومًا","%d يوم"],M:["أقل من شهر","شهر واحد",["شهران","شهرين"],"%d أشهر","%d شهرا","%d شهر"],y:["أقل من عام","عام واحد",["عامان","عامين"],"%d أعوام","%d عامًا","%d عام"]}),Ei=(z=["جانفي","فيفري","مارس","أفريل","ماي","جوان","جويلية","أوت","سبتمبر","أكتوبر","نوفمبر","ديسمبر"],t.defineLocale("ar-dz",{months:z,monthsShort:z,weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/‏M/‏YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/\u0635|\u0645/,isPM:function(e){return"م"===e},meridiem:function(e,t,i){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم عند الساعة] LT",nextDay:"[غدًا عند الساعة] LT",nextWeek:"dddd [عند الساعة] LT",lastDay:"[أمس عند الساعة] LT",lastWeek:"dddd [عند الساعة] LT",sameElse:"L"},relativeTime:{future:"بعد %s",past:"منذ %s",s:Si("s"),ss:Si("s"),m:Si("m"),mm:Si("m"),h:Si("h"),hh:Si("h"),d:Si("d"),dd:Si("d"),M:Si("M"),MM:Si("M"),y:Si("y"),yy:Si("y")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:0,doy:4}}),t.defineLocale("ar-kw",{months:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),monthsShort:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),weekdays:"الأحد_الإتنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"احد_اتنين_ثلاثاء_اربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},week:{dow:0,doy:12}}),{1:"1",2:"2",3:"3",4:"4",5:"5",6:"6",7:"7",8:"8",9:"9",0:"0"}),Oi={s:["أقل من ثانية","ثانية واحدة",["ثانيتان","ثانيتين"],"%d ثوان","%d ثانية","%d ثانية"],m:["أقل من دقيقة","دقيقة واحدة",["دقيقتان","دقيقتين"],"%d دقائق","%d دقيقة","%d دقيقة"],h:["أقل من ساعة","ساعة واحدة",["ساعتان","ساعتين"],"%d ساعات","%d ساعة","%d ساعة"],d:["أقل من يوم","يوم واحد",["يومان","يومين"],"%d أيام","%d يومًا","%d يوم"],M:["أقل من شهر","شهر واحد",["شهران","شهرين"],"%d أشهر","%d شهرا","%d شهر"],y:["أقل من عام","عام واحد",["عامان","عامين"],"%d أعوام","%d عامًا","%d عام"]},Pi=(B=["يناير","فبراير","مارس","أبريل","مايو","يونيو","يوليو","أغسطس","سبتمبر","أكتوبر","نوفمبر","ديسمبر"],t.defineLocale("ar-ly",{months:B,monthsShort:B,weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/‏M/‏YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/\u0635|\u0645/,isPM:function(e){return"م"===e},meridiem:function(e,t,i){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم عند الساعة] LT",nextDay:"[غدًا عند الساعة] LT",nextWeek:"dddd [عند الساعة] LT",lastDay:"[أمس عند الساعة] LT",lastWeek:"dddd [عند الساعة] LT",sameElse:"L"},relativeTime:{future:"بعد %s",past:"منذ %s",s:Li("s"),ss:Li("s"),m:Li("m"),mm:Li("m"),h:Li("h"),hh:Li("h"),d:Li("d"),dd:Li("d"),M:Li("M"),MM:Li("M"),y:Li("y"),yy:Li("y")},preparse:function(e){return e.replace(/\u060c/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return Ei[e]})).replace(/,/g,"،")},week:{dow:6,doy:12}}),t.defineLocale("ar-ma",{months:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),monthsShort:"يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر".split("_"),weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"احد_اثنين_ثلاثاء_اربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},week:{dow:1,doy:4}}),{1:"١",2:"٢",3:"٣",4:"٤",5:"٥",6:"٦",7:"٧",8:"٨",9:"٩",0:"٠"}),Yi={"١":"1","٢":"2","٣":"3","٤":"4","٥":"5","٦":"6","٧":"7","٨":"8","٩":"9","٠":"0"},Ii=(t.defineLocale("ar-ps",{months:"كانون الثاني_شباط_آذار_نيسان_أيّار_حزيران_تمّوز_آب_أيلول_تشري الأوّل_تشرين الثاني_كانون الأوّل".split("_"),monthsShort:"ك٢_شباط_آذار_نيسان_أيّار_حزيران_تمّوز_آب_أيلول_ت١_ت٢_ك١".split("_"),weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/\u0635|\u0645/,isPM:function(e){return"م"===e},meridiem:function(e,t,i){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},preparse:function(e){return e.replace(/[\u0663\u0664\u0665\u0666\u0667\u0668\u0669\u0660]/g,(function(e){return Yi[e]})).split("").reverse().join("").replace(/[\u0661\u0662](?![\u062a\u0643])/g,(function(e){return Yi[e]})).split("").reverse().join("").replace(/\u060c/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return Pi[e]})).replace(/,/g,"،")},week:{dow:0,doy:6}}),{1:"١",2:"٢",3:"٣",4:"٤",5:"٥",6:"٦",7:"٧",8:"٨",9:"٩",0:"٠"}),Ni={"١":"1","٢":"2","٣":"3","٤":"4","٥":"5","٦":"6","٧":"7","٨":"8","٩":"9","٠":"0"},ji=(t.defineLocale("ar-sa",{months:"يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),monthsShort:"يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/\u0635|\u0645/,isPM:function(e){return"م"===e},meridiem:function(e,t,i){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},preparse:function(e){return e.replace(/[\u0661\u0662\u0663\u0664\u0665\u0666\u0667\u0668\u0669\u0660]/g,(function(e){return Ni[e]})).replace(/\u060c/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return Ii[e]})).replace(/,/g,"،")},week:{dow:0,doy:6}}),t.defineLocale("ar-tn",{months:"جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),monthsShort:"جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر".split("_"),weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[اليوم على الساعة] LT",nextDay:"[غدا على الساعة] LT",nextWeek:"dddd [على الساعة] LT",lastDay:"[أمس على الساعة] LT",lastWeek:"dddd [على الساعة] LT",sameElse:"L"},relativeTime:{future:"في %s",past:"منذ %s",s:"ثوان",ss:"%d ثانية",m:"دقيقة",mm:"%d دقائق",h:"ساعة",hh:"%d ساعات",d:"يوم",dd:"%d أيام",M:"شهر",MM:"%d أشهر",y:"سنة",yy:"%d سنوات"},week:{dow:1,doy:4}}),{1:"١",2:"٢",3:"٣",4:"٤",5:"٥",6:"٦",7:"٧",8:"٨",9:"٩",0:"٠"}),Hi={"١":"1","٢":"2","٣":"3","٤":"4","٥":"5","٦":"6","٧":"7","٨":"8","٩":"9","٠":"0"},Fi={s:["أقل من ثانية","ثانية واحدة",["ثانيتان","ثانيتين"],"%d ثوان","%d ثانية","%d ثانية"],m:["أقل من دقيقة","دقيقة واحدة",["دقيقتان","دقيقتين"],"%d دقائق","%d دقيقة","%d دقيقة"],h:["أقل من ساعة","ساعة واحدة",["ساعتان","ساعتين"],"%d ساعات","%d ساعة","%d ساعة"],d:["أقل من يوم","يوم واحد",["يومان","يومين"],"%d أيام","%d يومًا","%d يوم"],M:["أقل من شهر","شهر واحد",["شهران","شهرين"],"%d أشهر","%d شهرا","%d شهر"],y:["أقل من عام","عام واحد",["عامان","عامين"],"%d أعوام","%d عامًا","%d عام"]},Ri=(G=["يناير","فبراير","مارس","أبريل","مايو","يونيو","يوليو","أغسطس","سبتمبر","أكتوبر","نوفمبر","ديسمبر"],t.defineLocale("ar",{months:G,monthsShort:G,weekdays:"الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت".split("_"),weekdaysShort:"أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت".split("_"),weekdaysMin:"ح_ن_ث_ر_خ_ج_س".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/‏M/‏YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/\u0635|\u0645/,isPM:function(e){return"م"===e},meridiem:function(e,t,i){return e<12?"ص":"م"},calendar:{sameDay:"[اليوم عند الساعة] LT",nextDay:"[غدًا عند الساعة] LT",nextWeek:"dddd [عند الساعة] LT",lastDay:"[أمس عند الساعة] LT",lastWeek:"dddd [عند الساعة] LT",sameElse:"L"},relativeTime:{future:"بعد %s",past:"منذ %s",s:Ci("s"),ss:Ci("s"),m:Ci("m"),mm:Ci("m"),h:Ci("h"),hh:Ci("h"),d:Ci("d"),dd:Ci("d"),M:Ci("M"),MM:Ci("M"),y:Ci("y"),yy:Ci("y")},preparse:function(e){return e.replace(/[\u0661\u0662\u0663\u0664\u0665\u0666\u0667\u0668\u0669\u0660]/g,(function(e){return Hi[e]})).replace(/\u060c/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return ji[e]})).replace(/,/g,"،")},week:{dow:6,doy:12}}),{1:"-inci",5:"-inci",8:"-inci",70:"-inci",80:"-inci",2:"-nci",7:"-nci",20:"-nci",50:"-nci",3:"-üncü",4:"-üncü",100:"-üncü",6:"-ncı",9:"-uncu",10:"-uncu",30:"-uncu",60:"-ıncı",90:"-ıncı"});function zi(e,t,i){return"m"===i?t?"хвіліна":"хвіліну":"h"===i?t?"гадзіна":"гадзіну":e+" "+(e=+e,t=(t={ss:t?"секунда_секунды_секунд":"секунду_секунды_секунд",mm:t?"хвіліна_хвіліны_хвілін":"хвіліну_хвіліны_хвілін",hh:t?"гадзіна_гадзіны_гадзін":"гадзіну_гадзіны_гадзін",dd:"дзень_дні_дзён",MM:"месяц_месяцы_месяцаў",yy:"год_гады_гадоў"}[i]).split("_"),e%10==1&&e%100!=11?t[0]:2<=e%10&&e%10<=4&&(e%100<10||20<=e%100)?t[1]:t[2])}t.defineLocale("az",{months:"yanvar_fevral_mart_aprel_may_iyun_iyul_avqust_sentyabr_oktyabr_noyabr_dekabr".split("_"),monthsShort:"yan_fev_mar_apr_may_iyn_iyl_avq_sen_okt_noy_dek".split("_"),weekdays:"Bazar_Bazar ertəsi_Çərşənbə axşamı_Çərşənbə_Cümə axşamı_Cümə_Şənbə".split("_"),weekdaysShort:"Baz_BzE_ÇAx_Çər_CAx_Cüm_Şən".split("_"),weekdaysMin:"Bz_BE_ÇA_Çə_CA_Cü_Şə".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[bugün saat] LT",nextDay:"[sabah saat] LT",nextWeek:"[gələn həftə] dddd [saat] LT",lastDay:"[dünən] LT",lastWeek:"[keçən həftə] dddd [saat] LT",sameElse:"L"},relativeTime:{future:"%s sonra",past:"%s əvvəl",s:"bir neçə saniyə",ss:"%d saniyə",m:"bir dəqiqə",mm:"%d dəqiqə",h:"bir saat",hh:"%d saat",d:"bir gün",dd:"%d gün",M:"bir ay",MM:"%d ay",y:"bir il",yy:"%d il"},meridiemParse:/gec\u0259|s\u0259h\u0259r|g\xfcnd\xfcz|ax\u015fam/,isPM:function(e){return/^(g\xfcnd\xfcz|ax\u015fam)$/.test(e)},meridiem:function(e,t,i){return e<4?"gecə":e<12?"səhər":e<17?"gündüz":"axşam"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0131nc\u0131|inci|nci|\xfcnc\xfc|nc\u0131|uncu)/,ordinal:function(e){var t;return 0===e?e+"-ıncı":e+(Ri[t=e%10]||Ri[e%100-t]||Ri[100<=e?100:null])},week:{dow:1,doy:7}}),t.defineLocale("be",{months:{format:"студзеня_лютага_сакавіка_красавіка_траўня_чэрвеня_ліпеня_жніўня_верасня_кастрычніка_лістапада_снежня".split("_"),standalone:"студзень_люты_сакавік_красавік_травень_чэрвень_ліпень_жнівень_верасень_кастрычнік_лістапад_снежань".split("_")},monthsShort:"студ_лют_сак_крас_трав_чэрв_ліп_жнів_вер_каст_ліст_снеж".split("_"),weekdays:{format:"нядзелю_панядзелак_аўторак_сераду_чацвер_пятніцу_суботу".split("_"),standalone:"нядзеля_панядзелак_аўторак_серада_чацвер_пятніца_субота".split("_"),isFormat:/\[ ?[\u0423\u0443\u045e] ?(?:\u043c\u0456\u043d\u0443\u043b\u0443\u044e|\u043d\u0430\u0441\u0442\u0443\u043f\u043d\u0443\u044e)? ?\] ?dddd/},weekdaysShort:"нд_пн_ат_ср_чц_пт_сб".split("_"),weekdaysMin:"нд_пн_ат_ср_чц_пт_сб".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY г.",LLL:"D MMMM YYYY г., HH:mm",LLLL:"dddd, D MMMM YYYY г., HH:mm"},calendar:{sameDay:"[Сёння ў] LT",nextDay:"[Заўтра ў] LT",lastDay:"[Учора ў] LT",nextWeek:function(){return"[У] dddd [ў] LT"},lastWeek:function(){switch(this.day()){case 0:case 3:case 5:case 6:return"[У мінулую] dddd [ў] LT";case 1:case 2:case 4:return"[У мінулы] dddd [ў] LT"}},sameElse:"L"},relativeTime:{future:"праз %s",past:"%s таму",s:"некалькі секунд",m:zi,mm:zi,h:zi,hh:zi,d:"дзень",dd:zi,M:"месяц",MM:zi,y:"год",yy:zi},meridiemParse:/\u043d\u043e\u0447\u044b|\u0440\u0430\u043d\u0456\u0446\u044b|\u0434\u043d\u044f|\u0432\u0435\u0447\u0430\u0440\u0430/,isPM:function(e){return/^(\u0434\u043d\u044f|\u0432\u0435\u0447\u0430\u0440\u0430)$/.test(e)},meridiem:function(e,t,i){return e<4?"ночы":e<12?"раніцы":e<17?"дня":"вечара"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0456|\u044b|\u0433\u0430)/,ordinal:function(e,t){switch(t){case"M":case"d":case"DDD":case"w":case"W":return e%10!=2&&e%10!=3||e%100==12||e%100==13?e+"-ы":e+"-і";case"D":return e+"-га";default:return e}},week:{dow:1,doy:7}}),t.defineLocale("bg",{months:"януари_февруари_март_април_май_юни_юли_август_септември_октомври_ноември_декември".split("_"),monthsShort:"яну_фев_мар_апр_май_юни_юли_авг_сеп_окт_ное_дек".split("_"),weekdays:"неделя_понеделник_вторник_сряда_четвъртък_петък_събота".split("_"),weekdaysShort:"нед_пон_вто_сря_чет_пет_съб".split("_"),weekdaysMin:"нд_пн_вт_ср_чт_пт_сб".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY H:mm",LLLL:"dddd, D MMMM YYYY H:mm"},calendar:{sameDay:"[Днес в] LT",nextDay:"[Утре в] LT",nextWeek:"dddd [в] LT",lastDay:"[Вчера в] LT",lastWeek:function(){switch(this.day()){case 0:case 3:case 6:return"[Миналата] dddd [в] LT";case 1:case 2:case 4:case 5:return"[Миналия] dddd [в] LT"}},sameElse:"L"},relativeTime:{future:"след %s",past:"преди %s",s:"няколко секунди",ss:"%d секунди",m:"минута",mm:"%d минути",h:"час",hh:"%d часа",d:"ден",dd:"%d дена",w:"седмица",ww:"%d седмици",M:"месец",MM:"%d месеца",y:"година",yy:"%d години"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0435\u0432|\u0435\u043d|\u0442\u0438|\u0432\u0438|\u0440\u0438|\u043c\u0438)/,ordinal:function(e){var t=e%10,i=e%100;return 0===e?e+"-ев":0==i?e+"-ен":10<i&&i<20?e+"-ти":1==t?e+"-ви":2==t?e+"-ри":7==t||8==t?e+"-ми":e+"-ти"},week:{dow:1,doy:7}}),t.defineLocale("bm",{months:"Zanwuyekalo_Fewuruyekalo_Marisikalo_Awirilikalo_Mɛkalo_Zuwɛnkalo_Zuluyekalo_Utikalo_Sɛtanburukalo_ɔkutɔburukalo_Nowanburukalo_Desanburukalo".split("_"),monthsShort:"Zan_Few_Mar_Awi_Mɛ_Zuw_Zul_Uti_Sɛt_ɔku_Now_Des".split("_"),weekdays:"Kari_Ntɛnɛn_Tarata_Araba_Alamisa_Juma_Sibiri".split("_"),weekdaysShort:"Kar_Ntɛ_Tar_Ara_Ala_Jum_Sib".split("_"),weekdaysMin:"Ka_Nt_Ta_Ar_Al_Ju_Si".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"MMMM [tile] D [san] YYYY",LLL:"MMMM [tile] D [san] YYYY [lɛrɛ] HH:mm",LLLL:"dddd MMMM [tile] D [san] YYYY [lɛrɛ] HH:mm"},calendar:{sameDay:"[Bi lɛrɛ] LT",nextDay:"[Sini lɛrɛ] LT",nextWeek:"dddd [don lɛrɛ] LT",lastDay:"[Kunu lɛrɛ] LT",lastWeek:"dddd [tɛmɛnen lɛrɛ] LT",sameElse:"L"},relativeTime:{future:"%s kɔnɔ",past:"a bɛ %s bɔ",s:"sanga dama dama",ss:"sekondi %d",m:"miniti kelen",mm:"miniti %d",h:"lɛrɛ kelen",hh:"lɛrɛ %d",d:"tile kelen",dd:"tile %d",M:"kalo kelen",MM:"kalo %d",y:"san kelen",yy:"san %d"},week:{dow:1,doy:4}});var Bi={1:"১",2:"২",3:"৩",4:"৪",5:"৫",6:"৬",7:"৭",8:"৮",9:"৯",0:"০"},Vi={"১":"1","২":"2","৩":"3","৪":"4","৫":"5","৬":"6","৭":"7","৮":"8","৯":"9","০":"0"},Wi=(t.defineLocale("bn-bd",{months:"জানুয়ারি_ফেব্রুয়ারি_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্টেম্বর_অক্টোবর_নভেম্বর_ডিসেম্বর".split("_"),monthsShort:"জানু_ফেব্রু_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্ট_অক্টো_নভে_ডিসে".split("_"),weekdays:"রবিবার_সোমবার_মঙ্গলবার_বুধবার_বৃহস্পতিবার_শুক্রবার_শনিবার".split("_"),weekdaysShort:"রবি_সোম_মঙ্গল_বুধ_বৃহস্পতি_শুক্র_শনি".split("_"),weekdaysMin:"রবি_সোম_মঙ্গল_বুধ_বৃহ_শুক্র_শনি".split("_"),longDateFormat:{LT:"A h:mm সময়",LTS:"A h:mm:ss সময়",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm সময়",LLLL:"dddd, D MMMM YYYY, A h:mm সময়"},calendar:{sameDay:"[আজ] LT",nextDay:"[আগামীকাল] LT",nextWeek:"dddd, LT",lastDay:"[গতকাল] LT",lastWeek:"[গত] dddd, LT",sameElse:"L"},relativeTime:{future:"%s পরে",past:"%s আগে",s:"কয়েক সেকেন্ড",ss:"%d সেকেন্ড",m:"এক মিনিট",mm:"%d মিনিট",h:"এক ঘন্টা",hh:"%d ঘন্টা",d:"এক দিন",dd:"%d দিন",M:"এক মাস",MM:"%d মাস",y:"এক বছর",yy:"%d বছর"},preparse:function(e){return e.replace(/[\u09e7\u09e8\u09e9\u09ea\u09eb\u09ec\u09ed\u09ee\u09ef\u09e6]/g,(function(e){return Vi[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return Bi[e]}))},meridiemParse:/\u09b0\u09be\u09a4|\u09ad\u09cb\u09b0|\u09b8\u0995\u09be\u09b2|\u09a6\u09c1\u09aa\u09c1\u09b0|\u09ac\u09bf\u0995\u09be\u09b2|\u09b8\u09a8\u09cd\u09a7\u09cd\u09af\u09be|\u09b0\u09be\u09a4/,meridiemHour:function(e,t){return 12===e&&(e=0),"রাত"===t?e<4?e:e+12:"ভোর"===t||"সকাল"===t?e:"দুপুর"===t?3<=e?e:e+12:"বিকাল"===t||"সন্ধ্যা"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"রাত":e<6?"ভোর":e<12?"সকাল":e<15?"দুপুর":e<18?"বিকাল":e<20?"সন্ধ্যা":"রাত"},week:{dow:0,doy:6}}),{1:"১",2:"২",3:"৩",4:"৪",5:"৫",6:"৬",7:"৭",8:"৮",9:"৯",0:"০"}),Ui={"১":"1","২":"2","৩":"3","৪":"4","৫":"5","৬":"6","৭":"7","৮":"8","৯":"9","০":"0"},qi=(t.defineLocale("bn",{months:"জানুয়ারি_ফেব্রুয়ারি_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্টেম্বর_অক্টোবর_নভেম্বর_ডিসেম্বর".split("_"),monthsShort:"জানু_ফেব্রু_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্ট_অক্টো_নভে_ডিসে".split("_"),weekdays:"রবিবার_সোমবার_মঙ্গলবার_বুধবার_বৃহস্পতিবার_শুক্রবার_শনিবার".split("_"),weekdaysShort:"রবি_সোম_মঙ্গল_বুধ_বৃহস্পতি_শুক্র_শনি".split("_"),weekdaysMin:"রবি_সোম_মঙ্গল_বুধ_বৃহ_শুক্র_শনি".split("_"),longDateFormat:{LT:"A h:mm সময়",LTS:"A h:mm:ss সময়",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm সময়",LLLL:"dddd, D MMMM YYYY, A h:mm সময়"},calendar:{sameDay:"[আজ] LT",nextDay:"[আগামীকাল] LT",nextWeek:"dddd, LT",lastDay:"[গতকাল] LT",lastWeek:"[গত] dddd, LT",sameElse:"L"},relativeTime:{future:"%s পরে",past:"%s আগে",s:"কয়েক সেকেন্ড",ss:"%d সেকেন্ড",m:"এক মিনিট",mm:"%d মিনিট",h:"এক ঘন্টা",hh:"%d ঘন্টা",d:"এক দিন",dd:"%d দিন",M:"এক মাস",MM:"%d মাস",y:"এক বছর",yy:"%d বছর"},preparse:function(e){return e.replace(/[\u09e7\u09e8\u09e9\u09ea\u09eb\u09ec\u09ed\u09ee\u09ef\u09e6]/g,(function(e){return Ui[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return Wi[e]}))},meridiemParse:/\u09b0\u09be\u09a4|\u09b8\u0995\u09be\u09b2|\u09a6\u09c1\u09aa\u09c1\u09b0|\u09ac\u09bf\u0995\u09be\u09b2|\u09b0\u09be\u09a4/,meridiemHour:function(e,t){return 12===e&&(e=0),"রাত"===t&&4<=e||"দুপুর"===t&&e<5||"বিকাল"===t?e+12:e},meridiem:function(e,t,i){return e<4?"রাত":e<10?"সকাল":e<17?"দুপুর":e<20?"বিকাল":"রাত"},week:{dow:0,doy:6}}),{1:"༡",2:"༢",3:"༣",4:"༤",5:"༥",6:"༦",7:"༧",8:"༨",9:"༩",0:"༠"}),$i={"༡":"1","༢":"2","༣":"3","༤":"4","༥":"5","༦":"6","༧":"7","༨":"8","༩":"9","༠":"0"};function Xi(e,t,i){return e+" "+(i={mm:"munutenn",MM:"miz",dd:"devezh"}[i],2!==e?i:void 0!==(e={m:"v",b:"v",d:"z"})[i.charAt(0)]?e[i.charAt(0)]+i.substring(1):i)}function Gi(e,t,i){var n=e+" ";switch(i){case"ss":return n+(1===e?"sekunda":2===e||3===e||4===e?"sekunde":"sekundi");case"mm":return n+(1===e||2!==e&&3!==e&&4!==e?"minuta":"minute");case"h":return"jedan sat";case"hh":return n+(1===e?"sat":2===e||3===e||4===e?"sata":"sati");case"dd":return n+(1===e?"dan":"dana");case"MM":return n+(1===e?"mjesec":2===e||3===e||4===e?"mjeseca":"mjeseci");case"yy":return n+(1===e||2!==e&&3!==e&&4!==e?"godina":"godine")}}function Zi(e){return 1<e&&e<5&&1!=~~(e/10)}function Ki(e,t,i,n){var r=e+" ";switch(i){case"s":return t||n?"pár sekund":"pár sekundami";case"ss":return t||n?r+(Zi(e)?"sekundy":"sekund"):r+"sekundami";case"m":return t?"minuta":n?"minutu":"minutou";case"mm":return t||n?r+(Zi(e)?"minuty":"minut"):r+"minutami";case"h":return t?"hodina":n?"hodinu":"hodinou";case"hh":return t||n?r+(Zi(e)?"hodiny":"hodin"):r+"hodinami";case"d":return t||n?"den":"dnem";case"dd":return t||n?r+(Zi(e)?"dny":"dní"):r+"dny";case"M":return t||n?"měsíc":"měsícem";case"MM":return t||n?r+(Zi(e)?"měsíce":"měsíců"):r+"měsíci";case"y":return t||n?"rok":"rokem";case"yy":return t||n?r+(Zi(e)?"roky":"let"):r+"lety"}}function Ji(e,t,i,n){return e={m:["eine Minute","einer Minute"],h:["eine Stunde","einer Stunde"],d:["ein Tag","einem Tag"],dd:[e+" Tage",e+" Tagen"],w:["eine Woche","einer Woche"],M:["ein Monat","einem Monat"],MM:[e+" Monate",e+" Monaten"],y:["ein Jahr","einem Jahr"],yy:[e+" Jahre",e+" Jahren"]},t?e[i][0]:e[i][1]}function Qi(e,t,i,n){return e={m:["eine Minute","einer Minute"],h:["eine Stunde","einer Stunde"],d:["ein Tag","einem Tag"],dd:[e+" Tage",e+" Tagen"],w:["eine Woche","einer Woche"],M:["ein Monat","einem Monat"],MM:[e+" Monate",e+" Monaten"],y:["ein Jahr","einem Jahr"],yy:[e+" Jahre",e+" Jahren"]},t?e[i][0]:e[i][1]}function en(e,t,i,n){return e={m:["eine Minute","einer Minute"],h:["eine Stunde","einer Stunde"],d:["ein Tag","einem Tag"],dd:[e+" Tage",e+" Tagen"],w:["eine Woche","einer Woche"],M:["ein Monat","einem Monat"],MM:[e+" Monate",e+" Monaten"],y:["ein Jahr","einem Jahr"],yy:[e+" Jahre",e+" Jahren"]},t?e[i][0]:e[i][1]}t.defineLocale("bo",{months:"ཟླ་བ་དང་པོ_ཟླ་བ་གཉིས་པ_ཟླ་བ་གསུམ་པ_ཟླ་བ་བཞི་པ_ཟླ་བ་ལྔ་པ_ཟླ་བ་དྲུག་པ_ཟླ་བ་བདུན་པ_ཟླ་བ་བརྒྱད་པ_ཟླ་བ་དགུ་པ_ཟླ་བ་བཅུ་པ_ཟླ་བ་བཅུ་གཅིག་པ_ཟླ་བ་བཅུ་གཉིས་པ".split("_"),monthsShort:"ཟླ་1_ཟླ་2_ཟླ་3_ཟླ་4_ཟླ་5_ཟླ་6_ཟླ་7_ཟླ་8_ཟླ་9_ཟླ་10_ཟླ་11_ཟླ་12".split("_"),monthsShortRegex:/^(\u0f5f\u0fb3\u0f0b\d{1,2})/,monthsParseExact:!0,weekdays:"གཟའ་ཉི་མ་_གཟའ་ཟླ་བ་_གཟའ་མིག་དམར་_གཟའ་ལྷག་པ་_གཟའ་ཕུར་བུ_གཟའ་པ་སངས་_གཟའ་སྤེན་པ་".split("_"),weekdaysShort:"ཉི་མ་_ཟླ་བ་_མིག་དམར་_ལྷག་པ་_ཕུར་བུ_པ་སངས་_སྤེན་པ་".split("_"),weekdaysMin:"ཉི_ཟླ_མིག_ལྷག_ཕུར_སངས_སྤེན".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm",LLLL:"dddd, D MMMM YYYY, A h:mm"},calendar:{sameDay:"[དི་རིང] LT",nextDay:"[སང་ཉིན] LT",nextWeek:"[བདུན་ཕྲག་རྗེས་མ], LT",lastDay:"[ཁ་སང] LT",lastWeek:"[བདུན་ཕྲག་མཐའ་མ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s ལ་",past:"%s སྔན་ལ",s:"ལམ་སང",ss:"%d སྐར་ཆ།",m:"སྐར་མ་གཅིག",mm:"%d སྐར་མ",h:"ཆུ་ཚོད་གཅིག",hh:"%d ཆུ་ཚོད",d:"ཉིན་གཅིག",dd:"%d ཉིན་",M:"ཟླ་བ་གཅིག",MM:"%d ཟླ་བ",y:"ལོ་གཅིག",yy:"%d ལོ"},preparse:function(e){return e.replace(/[\u0f21\u0f22\u0f23\u0f24\u0f25\u0f26\u0f27\u0f28\u0f29\u0f20]/g,(function(e){return $i[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return qi[e]}))},meridiemParse:/\u0f58\u0f5a\u0f53\u0f0b\u0f58\u0f7c|\u0f5e\u0f7c\u0f42\u0f66\u0f0b\u0f40\u0f66|\u0f49\u0f72\u0f53\u0f0b\u0f42\u0f74\u0f44|\u0f51\u0f42\u0f7c\u0f44\u0f0b\u0f51\u0f42|\u0f58\u0f5a\u0f53\u0f0b\u0f58\u0f7c/,meridiemHour:function(e,t){return 12===e&&(e=0),"མཚན་མོ"===t&&4<=e||"ཉིན་གུང"===t&&e<5||"དགོང་དག"===t?e+12:e},meridiem:function(e,t,i){return e<4?"མཚན་མོ":e<10?"ཞོགས་ཀས":e<17?"ཉིན་གུང":e<20?"དགོང་དག":"མཚན་མོ"},week:{dow:0,doy:6}}),V=[/^gen/i,/^c[\u02bc\']hwe/i,/^meu/i,/^ebr/i,/^mae/i,/^(mez|eve)/i,/^gou/i,/^eos/i,/^gwe/i,/^her/i,/^du/i,/^ker/i],Ee=/^(genver|c[\u02bc\']hwevrer|meurzh|ebrel|mae|mezheven|gouere|eost|gwengolo|here|du|kerzu|gen|c[\u02bc\']hwe|meu|ebr|mae|eve|gou|eos|gwe|her|du|ker)/i,X=[/^Su/i,/^Lu/i,/^Me([^r]|$)/i,/^Mer/i,/^Ya/i,/^Gw/i,/^Sa/i],t.defineLocale("br",{months:"Genver_Cʼhwevrer_Meurzh_Ebrel_Mae_Mezheven_Gouere_Eost_Gwengolo_Here_Du_Kerzu".split("_"),monthsShort:"Gen_Cʼhwe_Meu_Ebr_Mae_Eve_Gou_Eos_Gwe_Her_Du_Ker".split("_"),weekdays:"Sul_Lun_Meurzh_Mercʼher_Yaou_Gwener_Sadorn".split("_"),weekdaysShort:"Sul_Lun_Meu_Mer_Yao_Gwe_Sad".split("_"),weekdaysMin:"Su_Lu_Me_Mer_Ya_Gw_Sa".split("_"),weekdaysParse:X,fullWeekdaysParse:[/^sul/i,/^lun/i,/^meurzh/i,/^merc[\u02bc\']her/i,/^yaou/i,/^gwener/i,/^sadorn/i],shortWeekdaysParse:[/^Sul/i,/^Lun/i,/^Meu/i,/^Mer/i,/^Yao/i,/^Gwe/i,/^Sad/i],minWeekdaysParse:X,monthsRegex:Ee,monthsShortRegex:Ee,monthsStrictRegex:/^(genver|c[\u02bc\']hwevrer|meurzh|ebrel|mae|mezheven|gouere|eost|gwengolo|here|du|kerzu)/i,monthsShortStrictRegex:/^(gen|c[\u02bc\']hwe|meu|ebr|mae|eve|gou|eos|gwe|her|du|ker)/i,monthsParse:V,longMonthsParse:V,shortMonthsParse:V,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [a viz] MMMM YYYY",LLL:"D [a viz] MMMM YYYY HH:mm",LLLL:"dddd, D [a viz] MMMM YYYY HH:mm"},calendar:{sameDay:"[Hiziv da] LT",nextDay:"[Warcʼhoazh da] LT",nextWeek:"dddd [da] LT",lastDay:"[Decʼh da] LT",lastWeek:"dddd [paset da] LT",sameElse:"L"},relativeTime:{future:"a-benn %s",past:"%s ʼzo",s:"un nebeud segondennoù",ss:"%d eilenn",m:"ur vunutenn",mm:Xi,h:"un eur",hh:"%d eur",d:"un devezh",dd:Xi,M:"ur miz",MM:Xi,y:"ur bloaz",yy:function(e){switch(function e(t){return 9<t?e(t%10):t}(e)){case 1:case 3:case 4:case 5:case 9:return e+" bloaz";default:return e+" vloaz"}}},dayOfMonthOrdinalParse:/\d{1,2}(a\xf1|vet)/,ordinal:function(e){return e+(1===e?"añ":"vet")},week:{dow:1,doy:4},meridiemParse:/a.m.|g.m./,isPM:function(e){return"g.m."===e},meridiem:function(e,t,i){return e<12?"a.m.":"g.m."}}),t.defineLocale("bs",{months:"januar_februar_mart_april_maj_juni_juli_august_septembar_oktobar_novembar_decembar".split("_"),monthsShort:"jan._feb._mar._apr._maj._jun._jul._aug._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sri._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedjelju] [u] LT";case 3:return"[u] [srijedu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[jučer u] LT",lastWeek:function(){switch(this.day()){case 0:case 3:return"[prošlu] dddd [u] LT";case 6:return"[prošle] [subote] [u] LT";case 1:case 2:case 4:case 5:return"[prošli] dddd [u] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"prije %s",s:"par sekundi",ss:Gi,m:function(e,t,i,n){if("m"===i)return t?"jedna minuta":n?"jednu minutu":"jedne minute"},mm:Gi,h:Gi,hh:Gi,d:"dan",dd:Gi,M:"mjesec",MM:Gi,y:"godinu",yy:Gi},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}}),t.defineLocale("ca",{months:{standalone:"gener_febrer_març_abril_maig_juny_juliol_agost_setembre_octubre_novembre_desembre".split("_"),format:"de gener_de febrer_de març_d'abril_de maig_de juny_de juliol_d'agost_de setembre_d'octubre_de novembre_de desembre".split("_"),isFormat:/D[oD]?(\s)+MMMM/},monthsShort:"gen._febr._març_abr._maig_juny_jul._ag._set._oct._nov._des.".split("_"),monthsParseExact:!0,weekdays:"diumenge_dilluns_dimarts_dimecres_dijous_divendres_dissabte".split("_"),weekdaysShort:"dg._dl._dt._dc._dj._dv._ds.".split("_"),weekdaysMin:"dg_dl_dt_dc_dj_dv_ds".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM [de] YYYY",ll:"D MMM YYYY",LLL:"D MMMM [de] YYYY [a les] H:mm",lll:"D MMM YYYY, H:mm",LLLL:"dddd D MMMM [de] YYYY [a les] H:mm",llll:"ddd D MMM YYYY, H:mm"},calendar:{sameDay:function(){return"[avui a "+(1!==this.hours()?"les":"la")+"] LT"},nextDay:function(){return"[demà a "+(1!==this.hours()?"les":"la")+"] LT"},nextWeek:function(){return"dddd [a "+(1!==this.hours()?"les":"la")+"] LT"},lastDay:function(){return"[ahir a "+(1!==this.hours()?"les":"la")+"] LT"},lastWeek:function(){return"[el] dddd [passat a "+(1!==this.hours()?"les":"la")+"] LT"},sameElse:"L"},relativeTime:{future:"d'aquí %s",past:"fa %s",s:"uns segons",ss:"%d segons",m:"un minut",mm:"%d minuts",h:"una hora",hh:"%d hores",d:"un dia",dd:"%d dies",M:"un mes",MM:"%d mesos",y:"un any",yy:"%d anys"},dayOfMonthOrdinalParse:/\d{1,2}(r|n|t|\xe8|a)/,ordinal:function(e,t){return e+("w"!==t&&"W"!==t?1===e?"r":2===e?"n":3===e?"r":4===e?"t":"è":"a")},week:{dow:1,doy:4}}),$={standalone:"leden_únor_březen_duben_květen_červen_červenec_srpen_září_říjen_listopad_prosinec".split("_"),format:"ledna_února_března_dubna_května_června_července_srpna_září_října_listopadu_prosince".split("_"),isFormat:/DD?[o.]?(\[[^\[\]]*\]|\s)+MMMM/},qe="led_úno_bře_dub_kvě_čvn_čvc_srp_zář_říj_lis_pro".split("_"),ie=[/^led/i,/^\xfano/i,/^b\u0159e/i,/^dub/i,/^kv\u011b/i,/^(\u010dvn|\u010derven$|\u010dervna)/i,/^(\u010dvc|\u010dervenec|\u010dervence)/i,/^srp/i,/^z\xe1\u0159/i,/^\u0159\xedj/i,/^lis/i,/^pro/i],W=/^(leden|\xfanor|b\u0159ezen|duben|kv\u011bten|\u010dervenec|\u010dervence|\u010derven|\u010dervna|srpen|z\xe1\u0159\xed|\u0159\xedjen|listopad|prosinec|led|\xfano|b\u0159e|dub|kv\u011b|\u010dvn|\u010dvc|srp|z\xe1\u0159|\u0159\xedj|lis|pro)/i,t.defineLocale("cs",{months:$,monthsShort:qe,monthsRegex:W,monthsShortRegex:W,monthsStrictRegex:/^(leden|ledna|\xfanora|\xfanor|b\u0159ezen|b\u0159ezna|duben|dubna|kv\u011bten|kv\u011btna|\u010dervenec|\u010dervence|\u010derven|\u010dervna|srpen|srpna|z\xe1\u0159\xed|\u0159\xedjen|\u0159\xedjna|listopadu|listopad|prosinec|prosince)/i,monthsShortStrictRegex:/^(led|\xfano|b\u0159e|dub|kv\u011b|\u010dvn|\u010dvc|srp|z\xe1\u0159|\u0159\xedj|lis|pro)/i,monthsParse:ie,longMonthsParse:ie,shortMonthsParse:ie,weekdays:"neděle_pondělí_úterý_středa_čtvrtek_pátek_sobota".split("_"),weekdaysShort:"ne_po_út_st_čt_pá_so".split("_"),weekdaysMin:"ne_po_út_st_čt_pá_so".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd D. MMMM YYYY H:mm",l:"D. M. YYYY"},calendar:{sameDay:"[dnes v] LT",nextDay:"[zítra v] LT",nextWeek:function(){switch(this.day()){case 0:return"[v neděli v] LT";case 1:case 2:return"[v] dddd [v] LT";case 3:return"[ve středu v] LT";case 4:return"[ve čtvrtek v] LT";case 5:return"[v pátek v] LT";case 6:return"[v sobotu v] LT"}},lastDay:"[včera v] LT",lastWeek:function(){switch(this.day()){case 0:return"[minulou neděli v] LT";case 1:case 2:return"[minulé] dddd [v] LT";case 3:return"[minulou středu v] LT";case 4:case 5:return"[minulý] dddd [v] LT";case 6:return"[minulou sobotu v] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"před %s",s:Ki,ss:Ki,m:Ki,mm:Ki,h:Ki,hh:Ki,d:Ki,dd:Ki,M:Ki,MM:Ki,y:Ki,yy:Ki},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("cv",{months:"кӑрлач_нарӑс_пуш_ака_май_ҫӗртме_утӑ_ҫурла_авӑн_юпа_чӳк_раштав".split("_"),monthsShort:"кӑр_нар_пуш_ака_май_ҫӗр_утӑ_ҫур_авн_юпа_чӳк_раш".split("_"),weekdays:"вырсарникун_тунтикун_ытларикун_юнкун_кӗҫнерникун_эрнекун_шӑматкун".split("_"),weekdaysShort:"выр_тун_ытл_юн_кӗҫ_эрн_шӑм".split("_"),weekdaysMin:"вр_тн_ыт_юн_кҫ_эр_шм".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ]",LLL:"YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm",LLLL:"dddd, YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm"},calendar:{sameDay:"[Паян] LT [сехетре]",nextDay:"[Ыран] LT [сехетре]",lastDay:"[Ӗнер] LT [сехетре]",nextWeek:"[Ҫитес] dddd LT [сехетре]",lastWeek:"[Иртнӗ] dddd LT [сехетре]",sameElse:"L"},relativeTime:{future:function(e){return e+(/\u0441\u0435\u0445\u0435\u0442$/i.exec(e)?"рен":/\u04ab\u0443\u043b$/i.exec(e)?"тан":"ран")},past:"%s каялла",s:"пӗр-ик ҫеккунт",ss:"%d ҫеккунт",m:"пӗр минут",mm:"%d минут",h:"пӗр сехет",hh:"%d сехет",d:"пӗр кун",dd:"%d кун",M:"пӗр уйӑх",MM:"%d уйӑх",y:"пӗр ҫул",yy:"%d ҫул"},dayOfMonthOrdinalParse:/\d{1,2}-\u043c\u04d7\u0448/,ordinal:"%d-мӗш",week:{dow:1,doy:7}}),t.defineLocale("cy",{months:"Ionawr_Chwefror_Mawrth_Ebrill_Mai_Mehefin_Gorffennaf_Awst_Medi_Hydref_Tachwedd_Rhagfyr".split("_"),monthsShort:"Ion_Chwe_Maw_Ebr_Mai_Meh_Gor_Aws_Med_Hyd_Tach_Rhag".split("_"),weekdays:"Dydd Sul_Dydd Llun_Dydd Mawrth_Dydd Mercher_Dydd Iau_Dydd Gwener_Dydd Sadwrn".split("_"),weekdaysShort:"Sul_Llun_Maw_Mer_Iau_Gwe_Sad".split("_"),weekdaysMin:"Su_Ll_Ma_Me_Ia_Gw_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Heddiw am] LT",nextDay:"[Yfory am] LT",nextWeek:"dddd [am] LT",lastDay:"[Ddoe am] LT",lastWeek:"dddd [diwethaf am] LT",sameElse:"L"},relativeTime:{future:"mewn %s",past:"%s yn ôl",s:"ychydig eiliadau",ss:"%d eiliad",m:"munud",mm:"%d munud",h:"awr",hh:"%d awr",d:"diwrnod",dd:"%d diwrnod",M:"mis",MM:"%d mis",y:"blwyddyn",yy:"%d flynedd"},dayOfMonthOrdinalParse:/\d{1,2}(fed|ain|af|il|ydd|ed|eg)/,ordinal:function(e){var t="";return 20<e?t=40===e||50===e||60===e||80===e||100===e?"fed":"ain":0<e&&(t=["","af","il","ydd","ydd","ed","ed","ed","fed","fed","fed","eg","fed","eg","eg","fed","eg","eg","fed","eg","fed"][e]),e+t},week:{dow:1,doy:4}}),t.defineLocale("da",{months:"januar_februar_marts_april_maj_juni_juli_august_september_oktober_november_december".split("_"),monthsShort:"jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec".split("_"),weekdays:"søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag".split("_"),weekdaysShort:"søn_man_tir_ons_tor_fre_lør".split("_"),weekdaysMin:"sø_ma_ti_on_to_fr_lø".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd [d.] D. MMMM YYYY [kl.] HH:mm"},calendar:{sameDay:"[i dag kl.] LT",nextDay:"[i morgen kl.] LT",nextWeek:"på dddd [kl.] LT",lastDay:"[i går kl.] LT",lastWeek:"[i] dddd[s kl.] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"%s siden",s:"få sekunder",ss:"%d sekunder",m:"et minut",mm:"%d minutter",h:"en time",hh:"%d timer",d:"en dag",dd:"%d dage",M:"en måned",MM:"%d måneder",y:"et år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("de-at",{months:"Jänner_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jän._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So._Mo._Di._Mi._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},calendar:{sameDay:"[heute um] LT [Uhr]",sameElse:"L",nextDay:"[morgen um] LT [Uhr]",nextWeek:"dddd [um] LT [Uhr]",lastDay:"[gestern um] LT [Uhr]",lastWeek:"[letzten] dddd [um] LT [Uhr]"},relativeTime:{future:"in %s",past:"vor %s",s:"ein paar Sekunden",ss:"%d Sekunden",m:Ji,mm:"%d Minuten",h:Ji,hh:"%d Stunden",d:Ji,dd:Ji,w:Ji,ww:"%d Wochen",M:Ji,MM:Ji,y:Ji,yy:Ji},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("de-ch",{months:"Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},calendar:{sameDay:"[heute um] LT [Uhr]",sameElse:"L",nextDay:"[morgen um] LT [Uhr]",nextWeek:"dddd [um] LT [Uhr]",lastDay:"[gestern um] LT [Uhr]",lastWeek:"[letzten] dddd [um] LT [Uhr]"},relativeTime:{future:"in %s",past:"vor %s",s:"ein paar Sekunden",ss:"%d Sekunden",m:Qi,mm:"%d Minuten",h:Qi,hh:"%d Stunden",d:Qi,dd:Qi,w:Qi,ww:"%d Wochen",M:Qi,MM:Qi,y:Qi,yy:Qi},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("de",{months:"Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So._Mo._Di._Mi._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},calendar:{sameDay:"[heute um] LT [Uhr]",sameElse:"L",nextDay:"[morgen um] LT [Uhr]",nextWeek:"dddd [um] LT [Uhr]",lastDay:"[gestern um] LT [Uhr]",lastWeek:"[letzten] dddd [um] LT [Uhr]"},relativeTime:{future:"in %s",past:"vor %s",s:"ein paar Sekunden",ss:"%d Sekunden",m:en,mm:"%d Minuten",h:en,hh:"%d Stunden",d:en,dd:en,w:en,ww:"%d Wochen",M:en,MM:en,y:en,yy:en},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),K=["ޖެނުއަރީ","ފެބްރުއަރީ","މާރިޗު","އޭޕްރީލު","މޭ","ޖޫން","ޖުލައި","އޯގަސްޓު","ސެޕްޓެމްބަރު","އޮކްޓޯބަރު","ނޮވެމްބަރު","ޑިސެމްބަރު"],U=["އާދިއްތަ","ހޯމަ","އަންގާރަ","ބުދަ","ބުރާސްފަތި","ހުކުރު","ހޮނިހިރު"],t.defineLocale("dv",{months:K,monthsShort:K,weekdays:U,weekdaysShort:U,weekdaysMin:"އާދި_ހޯމަ_އަން_ބުދަ_ބުރާ_ހުކު_ހޮނި".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"D/M/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},meridiemParse:/\u0789\u0786|\u0789\u078a/,isPM:function(e){return"މފ"===e},meridiem:function(e,t,i){return e<12?"މކ":"މފ"},calendar:{sameDay:"[މިއަދު] LT",nextDay:"[މާދަމާ] LT",nextWeek:"dddd LT",lastDay:"[އިއްޔެ] LT",lastWeek:"[ފާއިތުވި] dddd LT",sameElse:"L"},relativeTime:{future:"ތެރޭގައި %s",past:"ކުރިން %s",s:"ސިކުންތުކޮޅެއް",ss:"d% ސިކުންތު",m:"މިނިޓެއް",mm:"މިނިޓު %d",h:"ގަޑިއިރެއް",hh:"ގަޑިއިރު %d",d:"ދުވަހެއް",dd:"ދުވަސް %d",M:"މަހެއް",MM:"މަސް %d",y:"އަހަރެއް",yy:"އަހަރު %d"},preparse:function(e){return e.replace(/\u060c/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:7,doy:12}}),t.defineLocale("el",{monthsNominativeEl:"Ιανουάριος_Φεβρουάριος_Μάρτιος_Απρίλιος_Μάιος_Ιούνιος_Ιούλιος_Αύγουστος_Σεπτέμβριος_Οκτώβριος_Νοέμβριος_Δεκέμβριος".split("_"),monthsGenitiveEl:"Ιανουαρίου_Φεβρουαρίου_Μαρτίου_Απριλίου_Μαΐου_Ιουνίου_Ιουλίου_Αυγούστου_Σεπτεμβρίου_Οκτωβρίου_Νοεμβρίου_Δεκεμβρίου".split("_"),months:function(e,t){return e?("string"==typeof t&&/D/.test(t.substring(0,t.indexOf("MMMM")))?this._monthsGenitiveEl:this._monthsNominativeEl)[e.month()]:this._monthsNominativeEl},monthsShort:"Ιαν_Φεβ_Μαρ_Απρ_Μαϊ_Ιουν_Ιουλ_Αυγ_Σεπ_Οκτ_Νοε_Δεκ".split("_"),weekdays:"Κυριακή_Δευτέρα_Τρίτη_Τετάρτη_Πέμπτη_Παρασκευή_Σάββατο".split("_"),weekdaysShort:"Κυρ_Δευ_Τρι_Τετ_Πεμ_Παρ_Σαβ".split("_"),weekdaysMin:"Κυ_Δε_Τρ_Τε_Πε_Πα_Σα".split("_"),meridiem:function(e,t,i){return 11<e?i?"μμ":"ΜΜ":i?"πμ":"ΠΜ"},isPM:function(e){return"μ"===(e+"").toLowerCase()[0]},meridiemParse:/[\u03a0\u039c]\.?\u039c?\.?/i,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendarEl:{sameDay:"[Σήμερα {}] LT",nextDay:"[Αύριο {}] LT",nextWeek:"dddd [{}] LT",lastDay:"[Χθες {}] LT",lastWeek:function(){return 6===this.day()?"[το προηγούμενο] dddd [{}] LT":"[την προηγούμενη] dddd [{}] LT"},sameElse:"L"},calendar:function(e,t){e=this._calendarEl[e];var i,n=t&&t.hours();return i=e,(e="undefined"!=typeof Function&&i instanceof Function||"[object Function]"===Object.prototype.toString.call(i)?e.apply(t):e).replace("{}",n%12==1?"στη":"στις")},relativeTime:{future:"σε %s",past:"%s πριν",s:"λίγα δευτερόλεπτα",ss:"%d δευτερόλεπτα",m:"ένα λεπτό",mm:"%d λεπτά",h:"μία ώρα",hh:"%d ώρες",d:"μία μέρα",dd:"%d μέρες",M:"ένας μήνας",MM:"%d μήνες",y:"ένας χρόνος",yy:"%d χρόνια"},dayOfMonthOrdinalParse:/\d{1,2}\u03b7/,ordinal:"%dη",week:{dow:1,doy:4}}),t.defineLocale("en-au",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:0,doy:4}}),t.defineLocale("en-ca",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"YYYY-MM-DD",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")}}),t.defineLocale("en-gb",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:1,doy:4}}),t.defineLocale("en-ie",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:1,doy:4}}),t.defineLocale("en-il",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")}}),t.defineLocale("en-in",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:0,doy:6}}),t.defineLocale("en-nz",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:1,doy:4}}),t.defineLocale("en-sg",{months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),monthsShort:"Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),weekdaysShort:"Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),weekdaysMin:"Su_Mo_Tu_We_Th_Fr_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:1,doy:4}}),t.defineLocale("eo",{months:"januaro_februaro_marto_aprilo_majo_junio_julio_aŭgusto_septembro_oktobro_novembro_decembro".split("_"),monthsShort:"jan_feb_mart_apr_maj_jun_jul_aŭg_sept_okt_nov_dec".split("_"),weekdays:"dimanĉo_lundo_mardo_merkredo_ĵaŭdo_vendredo_sabato".split("_"),weekdaysShort:"dim_lun_mard_merk_ĵaŭ_ven_sab".split("_"),weekdaysMin:"di_lu_ma_me_ĵa_ve_sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"[la] D[-an de] MMMM, YYYY",LLL:"[la] D[-an de] MMMM, YYYY HH:mm",LLLL:"dddd[n], [la] D[-an de] MMMM, YYYY HH:mm",llll:"ddd, [la] D[-an de] MMM, YYYY HH:mm"},meridiemParse:/[ap]\.t\.m/i,isPM:function(e){return"p"===e.charAt(0).toLowerCase()},meridiem:function(e,t,i){return 11<e?i?"p.t.m.":"P.T.M.":i?"a.t.m.":"A.T.M."},calendar:{sameDay:"[Hodiaŭ je] LT",nextDay:"[Morgaŭ je] LT",nextWeek:"dddd[n je] LT",lastDay:"[Hieraŭ je] LT",lastWeek:"[pasintan] dddd[n je] LT",sameElse:"L"},relativeTime:{future:"post %s",past:"antaŭ %s",s:"kelkaj sekundoj",ss:"%d sekundoj",m:"unu minuto",mm:"%d minutoj",h:"unu horo",hh:"%d horoj",d:"unu tago",dd:"%d tagoj",M:"unu monato",MM:"%d monatoj",y:"unu jaro",yy:"%d jaroj"},dayOfMonthOrdinalParse:/\d{1,2}a/,ordinal:"%da",week:{dow:1,doy:7}});var tn="ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_"),nn="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),rn=(Z=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],Ae=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,t.defineLocale("es-do",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,t){return e?(/-MMM-/.test(t)?nn:tn)[e.month()]:tn},monthsRegex:Ae,monthsShortRegex:Ae,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:Z,longMonthsParse:Z,shortMonthsParse:Z,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY h:mm A",LLLL:"dddd, D [de] MMMM [de] YYYY h:mm A"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4}}),"ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_")),an="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),sn=(re=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],vi=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,t.defineLocale("es-mx",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,t){return e?(/-MMM-/.test(t)?an:rn)[e.month()]:rn},monthsRegex:vi,monthsShortRegex:vi,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:re,longMonthsParse:re,shortMonthsParse:re,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:0,doy:4},invalidDate:"Fecha inválida"}),"ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_")),on="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),ln=(yi=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i),cn=(t.defineLocale("es-us",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,t){return e?(/-MMM-/.test(t)?on:sn)[e.month()]:sn},monthsRegex:ln,monthsShortRegex:ln,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:yi,longMonthsParse:yi,shortMonthsParse:yi,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"MM/DD/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY h:mm A",LLLL:"dddd, D [de] MMMM [de] YYYY h:mm A"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:0,doy:6}}),"ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_")),un="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_");Xe=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],Q=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;function dn(e,t,i,n){return e={s:["mõne sekundi","mõni sekund","paar sekundit"],ss:[e+"sekundi",e+"sekundit"],m:["ühe minuti","üks minut"],mm:[e+" minuti",e+" minutit"],h:["ühe tunni","tund aega","üks tund"],hh:[e+" tunni",e+" tundi"],d:["ühe päeva","üks päev"],M:["kuu aja","kuu aega","üks kuu"],MM:[e+" kuu",e+" kuud"],y:["ühe aasta","aasta","üks aasta"],yy:[e+" aasta",e+" aastat"]},t?e[i][2]||e[i][1]:n?e[i][0]:e[i][1]}t.defineLocale("es",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(e,t){return e?(/-MMM-/.test(t)?un:cn)[e.month()]:cn},monthsRegex:Q,monthsShortRegex:Q,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:Xe,longMonthsParse:Xe,shortMonthsParse:Xe,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4},invalidDate:"Fecha inválida"}),t.defineLocale("et",{months:"jaanuar_veebruar_märts_aprill_mai_juuni_juuli_august_september_oktoober_november_detsember".split("_"),monthsShort:"jaan_veebr_märts_apr_mai_juuni_juuli_aug_sept_okt_nov_dets".split("_"),weekdays:"pühapäev_esmaspäev_teisipäev_kolmapäev_neljapäev_reede_laupäev".split("_"),weekdaysShort:"P_E_T_K_N_R_L".split("_"),weekdaysMin:"P_E_T_K_N_R_L".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[Täna,] LT",nextDay:"[Homme,] LT",nextWeek:"[Järgmine] dddd LT",lastDay:"[Eile,] LT",lastWeek:"[Eelmine] dddd LT",sameElse:"L"},relativeTime:{future:"%s pärast",past:"%s tagasi",s:dn,ss:dn,m:dn,mm:dn,h:dn,hh:dn,d:dn,dd:"%d päeva",M:dn,MM:dn,y:dn,yy:dn},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("eu",{months:"urtarrila_otsaila_martxoa_apirila_maiatza_ekaina_uztaila_abuztua_iraila_urria_azaroa_abendua".split("_"),monthsShort:"urt._ots._mar._api._mai._eka._uzt._abu._ira._urr._aza._abe.".split("_"),monthsParseExact:!0,weekdays:"igandea_astelehena_asteartea_asteazkena_osteguna_ostirala_larunbata".split("_"),weekdaysShort:"ig._al._ar._az._og._ol._lr.".split("_"),weekdaysMin:"ig_al_ar_az_og_ol_lr".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY[ko] MMMM[ren] D[a]",LLL:"YYYY[ko] MMMM[ren] D[a] HH:mm",LLLL:"dddd, YYYY[ko] MMMM[ren] D[a] HH:mm",l:"YYYY-M-D",ll:"YYYY[ko] MMM D[a]",lll:"YYYY[ko] MMM D[a] HH:mm",llll:"ddd, YYYY[ko] MMM D[a] HH:mm"},calendar:{sameDay:"[gaur] LT[etan]",nextDay:"[bihar] LT[etan]",nextWeek:"dddd LT[etan]",lastDay:"[atzo] LT[etan]",lastWeek:"[aurreko] dddd LT[etan]",sameElse:"L"},relativeTime:{future:"%s barru",past:"duela %s",s:"segundo batzuk",ss:"%d segundo",m:"minutu bat",mm:"%d minutu",h:"ordu bat",hh:"%d ordu",d:"egun bat",dd:"%d egun",M:"hilabete bat",MM:"%d hilabete",y:"urte bat",yy:"%d urte"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}});var hn={1:"۱",2:"۲",3:"۳",4:"۴",5:"۵",6:"۶",7:"۷",8:"۸",9:"۹",0:"۰"},fn={"۱":"1","۲":"2","۳":"3","۴":"4","۵":"5","۶":"6","۷":"7","۸":"8","۹":"9","۰":"0"},pn=(t.defineLocale("fa",{months:"ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر".split("_"),monthsShort:"ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر".split("_"),weekdays:"یک‌شنبه_دوشنبه_سه‌شنبه_چهارشنبه_پنج‌شنبه_جمعه_شنبه".split("_"),weekdaysShort:"یک‌شنبه_دوشنبه_سه‌شنبه_چهارشنبه_پنج‌شنبه_جمعه_شنبه".split("_"),weekdaysMin:"ی_د_س_چ_پ_ج_ش".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},meridiemParse:/\u0642\u0628\u0644 \u0627\u0632 \u0638\u0647\u0631|\u0628\u0639\u062f \u0627\u0632 \u0638\u0647\u0631/,isPM:function(e){return/\u0628\u0639\u062f \u0627\u0632 \u0638\u0647\u0631/.test(e)},meridiem:function(e,t,i){return e<12?"قبل از ظهر":"بعد از ظهر"},calendar:{sameDay:"[امروز ساعت] LT",nextDay:"[فردا ساعت] LT",nextWeek:"dddd [ساعت] LT",lastDay:"[دیروز ساعت] LT",lastWeek:"dddd [پیش] [ساعت] LT",sameElse:"L"},relativeTime:{future:"در %s",past:"%s پیش",s:"چند ثانیه",ss:"%d ثانیه",m:"یک دقیقه",mm:"%d دقیقه",h:"یک ساعت",hh:"%d ساعت",d:"یک روز",dd:"%d روز",M:"یک ماه",MM:"%d ماه",y:"یک سال",yy:"%d سال"},preparse:function(e){return e.replace(/[\u06f0-\u06f9]/g,(function(e){return fn[e]})).replace(/\u060c/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return hn[e]})).replace(/,/g,"،")},dayOfMonthOrdinalParse:/\d{1,2}\u0645/,ordinal:"%dم",week:{dow:6,doy:12}}),"nolla yksi kaksi kolme neljä viisi kuusi seitsemän kahdeksan yhdeksän".split(" ")),mn=["nolla","yhden","kahden","kolmen","neljän","viiden","kuuden",pn[7],pn[8],pn[9]];function gn(e,t,i,n){var r="";switch(i){case"s":return n?"muutaman sekunnin":"muutama sekunti";case"ss":r=n?"sekunnin":"sekuntia";break;case"m":return n?"minuutin":"minuutti";case"mm":r=n?"minuutin":"minuuttia";break;case"h":return n?"tunnin":"tunti";case"hh":r=n?"tunnin":"tuntia";break;case"d":return n?"päivän":"päivä";case"dd":r=n?"päivän":"päivää";break;case"M":return n?"kuukauden":"kuukausi";case"MM":r=n?"kuukauden":"kuukautta";break;case"y":return n?"vuoden":"vuosi";case"yy":r=n?"vuoden":"vuotta"}return i=n,(e<10?(i?mn:pn)[e]:e)+" "+r}t.defineLocale("fi",{months:"tammikuu_helmikuu_maaliskuu_huhtikuu_toukokuu_kesäkuu_heinäkuu_elokuu_syyskuu_lokakuu_marraskuu_joulukuu".split("_"),monthsShort:"tammi_helmi_maalis_huhti_touko_kesä_heinä_elo_syys_loka_marras_joulu".split("_"),weekdays:"sunnuntai_maanantai_tiistai_keskiviikko_torstai_perjantai_lauantai".split("_"),weekdaysShort:"su_ma_ti_ke_to_pe_la".split("_"),weekdaysMin:"su_ma_ti_ke_to_pe_la".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD.MM.YYYY",LL:"Do MMMM[ta] YYYY",LLL:"Do MMMM[ta] YYYY, [klo] HH.mm",LLLL:"dddd, Do MMMM[ta] YYYY, [klo] HH.mm",l:"D.M.YYYY",ll:"Do MMM YYYY",lll:"Do MMM YYYY, [klo] HH.mm",llll:"ddd, Do MMM YYYY, [klo] HH.mm"},calendar:{sameDay:"[tänään] [klo] LT",nextDay:"[huomenna] [klo] LT",nextWeek:"dddd [klo] LT",lastDay:"[eilen] [klo] LT",lastWeek:"[viime] dddd[na] [klo] LT",sameElse:"L"},relativeTime:{future:"%s päästä",past:"%s sitten",s:gn,ss:gn,m:gn,mm:gn,h:gn,hh:gn,d:gn,dd:gn,M:gn,MM:gn,y:gn,yy:gn},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("fil",{months:"Enero_Pebrero_Marso_Abril_Mayo_Hunyo_Hulyo_Agosto_Setyembre_Oktubre_Nobyembre_Disyembre".split("_"),monthsShort:"Ene_Peb_Mar_Abr_May_Hun_Hul_Ago_Set_Okt_Nob_Dis".split("_"),weekdays:"Linggo_Lunes_Martes_Miyerkules_Huwebes_Biyernes_Sabado".split("_"),weekdaysShort:"Lin_Lun_Mar_Miy_Huw_Biy_Sab".split("_"),weekdaysMin:"Li_Lu_Ma_Mi_Hu_Bi_Sab".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"MM/D/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY HH:mm",LLLL:"dddd, MMMM DD, YYYY HH:mm"},calendar:{sameDay:"LT [ngayong araw]",nextDay:"[Bukas ng] LT",nextWeek:"LT [sa susunod na] dddd",lastDay:"LT [kahapon]",lastWeek:"LT [noong nakaraang] dddd",sameElse:"L"},relativeTime:{future:"sa loob ng %s",past:"%s ang nakalipas",s:"ilang segundo",ss:"%d segundo",m:"isang minuto",mm:"%d minuto",h:"isang oras",hh:"%d oras",d:"isang araw",dd:"%d araw",M:"isang buwan",MM:"%d buwan",y:"isang taon",yy:"%d taon"},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:function(e){return e},week:{dow:1,doy:4}}),t.defineLocale("fo",{months:"januar_februar_mars_apríl_mai_juni_juli_august_september_oktober_november_desember".split("_"),monthsShort:"jan_feb_mar_apr_mai_jun_jul_aug_sep_okt_nov_des".split("_"),weekdays:"sunnudagur_mánadagur_týsdagur_mikudagur_hósdagur_fríggjadagur_leygardagur".split("_"),weekdaysShort:"sun_mán_týs_mik_hós_frí_ley".split("_"),weekdaysMin:"su_má_tý_mi_hó_fr_le".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D. MMMM, YYYY HH:mm"},calendar:{sameDay:"[Í dag kl.] LT",nextDay:"[Í morgin kl.] LT",nextWeek:"dddd [kl.] LT",lastDay:"[Í gjár kl.] LT",lastWeek:"[síðstu] dddd [kl] LT",sameElse:"L"},relativeTime:{future:"um %s",past:"%s síðani",s:"fá sekund",ss:"%d sekundir",m:"ein minuttur",mm:"%d minuttir",h:"ein tími",hh:"%d tímar",d:"ein dagur",dd:"%d dagar",M:"ein mánaður",MM:"%d mánaðir",y:"eitt ár",yy:"%d ár"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("fr-ca",{months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),monthsParseExact:!0,weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Aujourd’hui à] LT",nextDay:"[Demain à] LT",nextWeek:"dddd [à] LT",lastDay:"[Hier à] LT",lastWeek:"dddd [dernier à] LT",sameElse:"L"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",ss:"%d secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(er|e)/,ordinal:function(e,t){switch(t){default:case"M":case"Q":case"D":case"DDD":case"d":return e+(1===e?"er":"e");case"w":case"W":return e+(1===e?"re":"e")}}}),t.defineLocale("fr-ch",{months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),monthsParseExact:!0,weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Aujourd’hui à] LT",nextDay:"[Demain à] LT",nextWeek:"dddd [à] LT",lastDay:"[Hier à] LT",lastWeek:"dddd [dernier à] LT",sameElse:"L"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",ss:"%d secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(er|e)/,ordinal:function(e,t){switch(t){default:case"M":case"Q":case"D":case"DDD":case"d":return e+(1===e?"er":"e");case"w":case"W":return e+(1===e?"re":"e")}},week:{dow:1,doy:4}});ne=/(janv\.?|f\xe9vr\.?|mars|avr\.?|mai|juin|juil\.?|ao\xfbt|sept\.?|oct\.?|nov\.?|d\xe9c\.?|janvier|f\xe9vrier|mars|avril|mai|juin|juillet|ao\xfbt|septembre|octobre|novembre|d\xe9cembre)/i,z=[/^janv/i,/^f\xe9vr/i,/^mars/i,/^avr/i,/^mai/i,/^juin/i,/^juil/i,/^ao\xfbt/i,/^sept/i,/^oct/i,/^nov/i,/^d\xe9c/i];var vn=(t.defineLocale("fr",{months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),monthsRegex:ne,monthsShortRegex:ne,monthsStrictRegex:/^(janvier|f\xe9vrier|mars|avril|mai|juin|juillet|ao\xfbt|septembre|octobre|novembre|d\xe9cembre)/i,monthsShortStrictRegex:/(janv\.?|f\xe9vr\.?|mars|avr\.?|mai|juin|juil\.?|ao\xfbt|sept\.?|oct\.?|nov\.?|d\xe9c\.?)/i,monthsParse:z,longMonthsParse:z,shortMonthsParse:z,weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Aujourd’hui à] LT",nextDay:"[Demain à] LT",nextWeek:"dddd [à] LT",lastDay:"[Hier à] LT",lastWeek:"dddd [dernier à] LT",sameElse:"L"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",ss:"%d secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",w:"une semaine",ww:"%d semaines",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(er|)/,ordinal:function(e,t){switch(t){case"D":return e+(1===e?"er":"");default:case"M":case"Q":case"DDD":case"d":return e+(1===e?"er":"e");case"w":case"W":return e+(1===e?"re":"e")}},week:{dow:1,doy:4}}),"jan._feb._mrt._apr._mai_jun._jul._aug._sep._okt._nov._des.".split("_")),yn="jan_feb_mrt_apr_mai_jun_jul_aug_sep_okt_nov_des".split("_");function bn(e,t,i,n){return e={s:["थोडया सॅकंडांनी","थोडे सॅकंड"],ss:[e+" सॅकंडांनी",e+" सॅकंड"],m:["एका मिणटान","एक मिनूट"],mm:[e+" मिणटांनी",e+" मिणटां"],h:["एका वरान","एक वर"],hh:[e+" वरांनी",e+" वरां"],d:["एका दिसान","एक दीस"],dd:[e+" दिसांनी",e+" दीस"],M:["एका म्हयन्यान","एक म्हयनो"],MM:[e+" म्हयन्यानी",e+" म्हयने"],y:["एका वर्सान","एक वर्स"],yy:[e+" वर्सांनी",e+" वर्सां"]},n?e[i][0]:e[i][1]}function xn(e,t,i,n){return e={s:["thoddea sekondamni","thodde sekond"],ss:[e+" sekondamni",e+" sekond"],m:["eka mintan","ek minut"],mm:[e+" mintamni",e+" mintam"],h:["eka voran","ek vor"],hh:[e+" voramni",e+" voram"],d:["eka disan","ek dis"],dd:[e+" disamni",e+" dis"],M:["eka mhoinean","ek mhoino"],MM:[e+" mhoineamni",e+" mhoine"],y:["eka vorsan","ek voros"],yy:[e+" vorsamni",e+" vorsam"]},n?e[i][0]:e[i][1]}t.defineLocale("fy",{months:"jannewaris_febrewaris_maart_april_maaie_juny_july_augustus_septimber_oktober_novimber_desimber".split("_"),monthsShort:function(e,t){return e?(/-MMM-/.test(t)?yn:vn)[e.month()]:vn},monthsParseExact:!0,weekdays:"snein_moandei_tiisdei_woansdei_tongersdei_freed_sneon".split("_"),weekdaysShort:"si._mo._ti._wo._to._fr._so.".split("_"),weekdaysMin:"Si_Mo_Ti_Wo_To_Fr_So".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[hjoed om] LT",nextDay:"[moarn om] LT",nextWeek:"dddd [om] LT",lastDay:"[juster om] LT",lastWeek:"[ôfrûne] dddd [om] LT",sameElse:"L"},relativeTime:{future:"oer %s",past:"%s lyn",s:"in pear sekonden",ss:"%d sekonden",m:"ien minút",mm:"%d minuten",h:"ien oere",hh:"%d oeren",d:"ien dei",dd:"%d dagen",M:"ien moanne",MM:"%d moannen",y:"ien jier",yy:"%d jierren"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||20<=e?"ste":"de")},week:{dow:1,doy:4}}),t.defineLocale("ga",{months:["Eanáir","Feabhra","Márta","Aibreán","Bealtaine","Meitheamh","Iúil","Lúnasa","Meán Fómhair","Deireadh Fómhair","Samhain","Nollaig"],monthsShort:["Ean","Feabh","Márt","Aib","Beal","Meith","Iúil","Lún","M.F.","D.F.","Samh","Noll"],monthsParseExact:!0,weekdays:["Dé Domhnaigh","Dé Luain","Dé Máirt","Dé Céadaoin","Déardaoin","Dé hAoine","Dé Sathairn"],weekdaysShort:["Domh","Luan","Máirt","Céad","Déar","Aoine","Sath"],weekdaysMin:["Do","Lu","Má","Cé","Dé","A","Sa"],longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Inniu ag] LT",nextDay:"[Amárach ag] LT",nextWeek:"dddd [ag] LT",lastDay:"[Inné ag] LT",lastWeek:"dddd [seo caite] [ag] LT",sameElse:"L"},relativeTime:{future:"i %s",past:"%s ó shin",s:"cúpla soicind",ss:"%d soicind",m:"nóiméad",mm:"%d nóiméad",h:"uair an chloig",hh:"%d uair an chloig",d:"lá",dd:"%d lá",M:"mí",MM:"%d míonna",y:"bliain",yy:"%d bliain"},dayOfMonthOrdinalParse:/\d{1,2}(d|na|mh)/,ordinal:function(e){return e+(1===e?"d":e%10==2?"na":"mh")},week:{dow:1,doy:4}}),t.defineLocale("gd",{months:["Am Faoilleach","An Gearran","Am Màrt","An Giblean","An Cèitean","An t-Ògmhios","An t-Iuchar","An Lùnastal","An t-Sultain","An Dàmhair","An t-Samhain","An Dùbhlachd"],monthsShort:["Faoi","Gear","Màrt","Gibl","Cèit","Ògmh","Iuch","Lùn","Sult","Dàmh","Samh","Dùbh"],monthsParseExact:!0,weekdays:["Didòmhnaich","Diluain","Dimàirt","Diciadain","Diardaoin","Dihaoine","Disathairne"],weekdaysShort:["Did","Dil","Dim","Dic","Dia","Dih","Dis"],weekdaysMin:["Dò","Lu","Mà","Ci","Ar","Ha","Sa"],longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[An-diugh aig] LT",nextDay:"[A-màireach aig] LT",nextWeek:"dddd [aig] LT",lastDay:"[An-dè aig] LT",lastWeek:"dddd [seo chaidh] [aig] LT",sameElse:"L"},relativeTime:{future:"ann an %s",past:"bho chionn %s",s:"beagan diogan",ss:"%d diogan",m:"mionaid",mm:"%d mionaidean",h:"uair",hh:"%d uairean",d:"latha",dd:"%d latha",M:"mìos",MM:"%d mìosan",y:"bliadhna",yy:"%d bliadhna"},dayOfMonthOrdinalParse:/\d{1,2}(d|na|mh)/,ordinal:function(e){return e+(1===e?"d":e%10==2?"na":"mh")},week:{dow:1,doy:4}}),t.defineLocale("gl",{months:"xaneiro_febreiro_marzo_abril_maio_xuño_xullo_agosto_setembro_outubro_novembro_decembro".split("_"),monthsShort:"xan._feb._mar._abr._mai._xuñ._xul._ago._set._out._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"domingo_luns_martes_mércores_xoves_venres_sábado".split("_"),weekdaysShort:"dom._lun._mar._mér._xov._ven._sáb.".split("_"),weekdaysMin:"do_lu_ma_mé_xo_ve_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},calendar:{sameDay:function(){return"[hoxe "+(1!==this.hours()?"ás":"á")+"] LT"},nextDay:function(){return"[mañá "+(1!==this.hours()?"ás":"á")+"] LT"},nextWeek:function(){return"dddd ["+(1!==this.hours()?"ás":"a")+"] LT"},lastDay:function(){return"[onte "+(1!==this.hours()?"á":"a")+"] LT"},lastWeek:function(){return"[o] dddd [pasado "+(1!==this.hours()?"ás":"a")+"] LT"},sameElse:"L"},relativeTime:{future:function(e){return 0===e.indexOf("un")?"n"+e:"en "+e},past:"hai %s",s:"uns segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"unha hora",hh:"%d horas",d:"un día",dd:"%d días",M:"un mes",MM:"%d meses",y:"un ano",yy:"%d anos"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4}}),t.defineLocale("gom-deva",{months:{standalone:"जानेवारी_फेब्रुवारी_मार्च_एप्रील_मे_जून_जुलय_ऑगस्ट_सप्टेंबर_ऑक्टोबर_नोव्हेंबर_डिसेंबर".split("_"),format:"जानेवारीच्या_फेब्रुवारीच्या_मार्चाच्या_एप्रीलाच्या_मेयाच्या_जूनाच्या_जुलयाच्या_ऑगस्टाच्या_सप्टेंबराच्या_ऑक्टोबराच्या_नोव्हेंबराच्या_डिसेंबराच्या".split("_"),isFormat:/MMMM(\s)+D[oD]?/},monthsShort:"जाने._फेब्रु._मार्च_एप्री._मे_जून_जुल._ऑग._सप्टें._ऑक्टो._नोव्हें._डिसें.".split("_"),monthsParseExact:!0,weekdays:"आयतार_सोमार_मंगळार_बुधवार_बिरेस्तार_सुक्रार_शेनवार".split("_"),weekdaysShort:"आयत._सोम._मंगळ._बुध._ब्रेस्त._सुक्र._शेन.".split("_"),weekdaysMin:"आ_सो_मं_बु_ब्रे_सु_शे".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"A h:mm [वाजतां]",LTS:"A h:mm:ss [वाजतां]",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY A h:mm [वाजतां]",LLLL:"dddd, MMMM Do, YYYY, A h:mm [वाजतां]",llll:"ddd, D MMM YYYY, A h:mm [वाजतां]"},calendar:{sameDay:"[आयज] LT",nextDay:"[फाल्यां] LT",nextWeek:"[फुडलो] dddd[,] LT",lastDay:"[काल] LT",lastWeek:"[फाटलो] dddd[,] LT",sameElse:"L"},relativeTime:{future:"%s",past:"%s आदीं",s:bn,ss:bn,m:bn,mm:bn,h:bn,hh:bn,d:bn,dd:bn,M:bn,MM:bn,y:bn,yy:bn},dayOfMonthOrdinalParse:/\d{1,2}(\u0935\u0947\u0930)/,ordinal:function(e,t){return"D"===t?e+"वेर":e},week:{dow:0,doy:3},meridiemParse:/\u0930\u093e\u0924\u0940|\u0938\u0915\u093e\u0933\u0940\u0902|\u0926\u0928\u092a\u093e\u0930\u093e\u0902|\u0938\u093e\u0902\u091c\u0947/,meridiemHour:function(e,t){return 12===e&&(e=0),"राती"===t?e<4?e:e+12:"सकाळीं"===t?e:"दनपारां"===t?12<e?e:e+12:"सांजे"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"राती":e<12?"सकाळीं":e<16?"दनपारां":e<20?"सांजे":"राती"}}),t.defineLocale("gom-latn",{months:{standalone:"Janer_Febrer_Mars_Abril_Mai_Jun_Julai_Agost_Setembr_Otubr_Novembr_Dezembr".split("_"),format:"Janerachea_Febrerachea_Marsachea_Abrilachea_Maiachea_Junachea_Julaiachea_Agostachea_Setembrachea_Otubrachea_Novembrachea_Dezembrachea".split("_"),isFormat:/MMMM(\s)+D[oD]?/},monthsShort:"Jan._Feb._Mars_Abr._Mai_Jun_Jul._Ago._Set._Otu._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Aitar_Somar_Mongllar_Budhvar_Birestar_Sukrar_Son'var".split("_"),weekdaysShort:"Ait._Som._Mon._Bud._Bre._Suk._Son.".split("_"),weekdaysMin:"Ai_Sm_Mo_Bu_Br_Su_Sn".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"A h:mm [vazta]",LTS:"A h:mm:ss [vazta]",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY A h:mm [vazta]",LLLL:"dddd, MMMM Do, YYYY, A h:mm [vazta]",llll:"ddd, D MMM YYYY, A h:mm [vazta]"},calendar:{sameDay:"[Aiz] LT",nextDay:"[Faleam] LT",nextWeek:"[Fuddlo] dddd[,] LT",lastDay:"[Kal] LT",lastWeek:"[Fattlo] dddd[,] LT",sameElse:"L"},relativeTime:{future:"%s",past:"%s adim",s:xn,ss:xn,m:xn,mm:xn,h:xn,hh:xn,d:xn,dd:xn,M:xn,MM:xn,y:xn,yy:xn},dayOfMonthOrdinalParse:/\d{1,2}(er)/,ordinal:function(e,t){return"D"===t?e+"er":e},week:{dow:0,doy:3},meridiemParse:/rati|sokallim|donparam|sanje/,meridiemHour:function(e,t){return 12===e&&(e=0),"rati"===t?e<4?e:e+12:"sokallim"===t?e:"donparam"===t?12<e?e:e+12:"sanje"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"rati":e<12?"sokallim":e<16?"donparam":e<20?"sanje":"rati"}});var _n={1:"૧",2:"૨",3:"૩",4:"૪",5:"૫",6:"૬",7:"૭",8:"૮",9:"૯",0:"૦"},wn={"૧":"1","૨":"2","૩":"3","૪":"4","૫":"5","૬":"6","૭":"7","૮":"8","૯":"9","૦":"0"},kn=(t.defineLocale("gu",{months:"જાન્યુઆરી_ફેબ્રુઆરી_માર્ચ_એપ્રિલ_મે_જૂન_જુલાઈ_ઑગસ્ટ_સપ્ટેમ્બર_ઑક્ટ્બર_નવેમ્બર_ડિસેમ્બર".split("_"),monthsShort:"જાન્યુ._ફેબ્રુ._માર્ચ_એપ્રિ._મે_જૂન_જુલા._ઑગ._સપ્ટે._ઑક્ટ્._નવે._ડિસે.".split("_"),monthsParseExact:!0,weekdays:"રવિવાર_સોમવાર_મંગળવાર_બુધ્વાર_ગુરુવાર_શુક્રવાર_શનિવાર".split("_"),weekdaysShort:"રવિ_સોમ_મંગળ_બુધ્_ગુરુ_શુક્ર_શનિ".split("_"),weekdaysMin:"ર_સો_મં_બુ_ગુ_શુ_શ".split("_"),longDateFormat:{LT:"A h:mm વાગ્યે",LTS:"A h:mm:ss વાગ્યે",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm વાગ્યે",LLLL:"dddd, D MMMM YYYY, A h:mm વાગ્યે"},calendar:{sameDay:"[આજ] LT",nextDay:"[કાલે] LT",nextWeek:"dddd, LT",lastDay:"[ગઇકાલે] LT",lastWeek:"[પાછલા] dddd, LT",sameElse:"L"},relativeTime:{future:"%s મા",past:"%s પહેલા",s:"અમુક પળો",ss:"%d સેકંડ",m:"એક મિનિટ",mm:"%d મિનિટ",h:"એક કલાક",hh:"%d કલાક",d:"એક દિવસ",dd:"%d દિવસ",M:"એક મહિનો",MM:"%d મહિનો",y:"એક વર્ષ",yy:"%d વર્ષ"},preparse:function(e){return e.replace(/[\u0ae7\u0ae8\u0ae9\u0aea\u0aeb\u0aec\u0aed\u0aee\u0aef\u0ae6]/g,(function(e){return wn[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return _n[e]}))},meridiemParse:/\u0ab0\u0abe\u0aa4|\u0aac\u0aaa\u0acb\u0ab0|\u0ab8\u0ab5\u0abe\u0ab0|\u0ab8\u0abe\u0a82\u0a9c/,meridiemHour:function(e,t){return 12===e&&(e=0),"રાત"===t?e<4?e:e+12:"સવાર"===t?e:"બપોર"===t?10<=e?e:e+12:"સાંજ"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"રાત":e<10?"સવાર":e<17?"બપોર":e<20?"સાંજ":"રાત"},week:{dow:0,doy:6}}),t.defineLocale("he",{months:"ינואר_פברואר_מרץ_אפריל_מאי_יוני_יולי_אוגוסט_ספטמבר_אוקטובר_נובמבר_דצמבר".split("_"),monthsShort:"ינו׳_פבר׳_מרץ_אפר׳_מאי_יוני_יולי_אוג׳_ספט׳_אוק׳_נוב׳_דצמ׳".split("_"),weekdays:"ראשון_שני_שלישי_רביעי_חמישי_שישי_שבת".split("_"),weekdaysShort:"א׳_ב׳_ג׳_ד׳_ה׳_ו׳_ש׳".split("_"),weekdaysMin:"א_ב_ג_ד_ה_ו_ש".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [ב]MMMM YYYY",LLL:"D [ב]MMMM YYYY HH:mm",LLLL:"dddd, D [ב]MMMM YYYY HH:mm",l:"D/M/YYYY",ll:"D MMM YYYY",lll:"D MMM YYYY HH:mm",llll:"ddd, D MMM YYYY HH:mm"},calendar:{sameDay:"[היום ב־]LT",nextDay:"[מחר ב־]LT",nextWeek:"dddd [בשעה] LT",lastDay:"[אתמול ב־]LT",lastWeek:"[ביום] dddd [האחרון בשעה] LT",sameElse:"L"},relativeTime:{future:"בעוד %s",past:"לפני %s",s:"מספר שניות",ss:"%d שניות",m:"דקה",mm:"%d דקות",h:"שעה",hh:function(e){return 2===e?"שעתיים":e+" שעות"},d:"יום",dd:function(e){return 2===e?"יומיים":e+" ימים"},M:"חודש",MM:function(e){return 2===e?"חודשיים":e+" חודשים"},y:"שנה",yy:function(e){return 2===e?"שנתיים":e%10==0&&10!==e?e+" שנה":e+" שנים"}},meridiemParse:/\u05d0\u05d7\u05d4"\u05e6|\u05dc\u05e4\u05e0\u05d4"\u05e6|\u05d0\u05d7\u05e8\u05d9 \u05d4\u05e6\u05d4\u05e8\u05d9\u05d9\u05dd|\u05dc\u05e4\u05e0\u05d9 \u05d4\u05e6\u05d4\u05e8\u05d9\u05d9\u05dd|\u05dc\u05e4\u05e0\u05d5\u05ea \u05d1\u05d5\u05e7\u05e8|\u05d1\u05d1\u05d5\u05e7\u05e8|\u05d1\u05e2\u05e8\u05d1/i,isPM:function(e){return/^(\u05d0\u05d7\u05d4"\u05e6|\u05d0\u05d7\u05e8\u05d9 \u05d4\u05e6\u05d4\u05e8\u05d9\u05d9\u05dd|\u05d1\u05e2\u05e8\u05d1)$/.test(e)},meridiem:function(e,t,i){return e<5?"לפנות בוקר":e<10?"בבוקר":e<12?i?'לפנה"צ':"לפני הצהריים":e<18?i?'אחה"צ':"אחרי הצהריים":"בערב"}}),{1:"१",2:"२",3:"३",4:"४",5:"५",6:"६",7:"७",8:"८",9:"९",0:"०"}),Mn={"१":"1","२":"2","३":"3","४":"4","५":"5","६":"6","७":"7","८":"8","९":"9","०":"0"};B=[/^\u091c\u0928/i,/^\u092b\u093c\u0930|\u092b\u0930/i,/^\u092e\u093e\u0930\u094d\u091a/i,/^\u0905\u092a\u094d\u0930\u0948/i,/^\u092e\u0908/i,/^\u091c\u0942\u0928/i,/^\u091c\u0941\u0932/i,/^\u0905\u0917/i,/^\u0938\u093f\u0924\u0902|\u0938\u093f\u0924/i,/^\u0905\u0915\u094d\u091f\u0942/i,/^\u0928\u0935|\u0928\u0935\u0902/i,/^\u0926\u093f\u0938\u0902|\u0926\u093f\u0938/i];function Sn(e,t,i){var n=e+" ";switch(i){case"ss":return n+(1===e?"sekunda":2===e||3===e||4===e?"sekunde":"sekundi");case"m":return t?"jedna minuta":"jedne minute";case"mm":return n+(1===e||2!==e&&3!==e&&4!==e?"minuta":"minute");case"h":return t?"jedan sat":"jednog sata";case"hh":return n+(1===e?"sat":2===e||3===e||4===e?"sata":"sati");case"dd":return n+(1===e?"dan":"dana");case"MM":return n+(1===e?"mjesec":2===e||3===e||4===e?"mjeseca":"mjeseci");case"yy":return n+(1===e||2!==e&&3!==e&&4!==e?"godina":"godine")}}t.defineLocale("hi",{months:{format:"जनवरी_फ़रवरी_मार्च_अप्रैल_मई_जून_जुलाई_अगस्त_सितम्बर_अक्टूबर_नवम्बर_दिसम्बर".split("_"),standalone:"जनवरी_फरवरी_मार्च_अप्रैल_मई_जून_जुलाई_अगस्त_सितंबर_अक्टूबर_नवंबर_दिसंबर".split("_")},monthsShort:"जन._फ़र._मार्च_अप्रै._मई_जून_जुल._अग._सित._अक्टू._नव._दिस.".split("_"),weekdays:"रविवार_सोमवार_मंगलवार_बुधवार_गुरूवार_शुक्रवार_शनिवार".split("_"),weekdaysShort:"रवि_सोम_मंगल_बुध_गुरू_शुक्र_शनि".split("_"),weekdaysMin:"र_सो_मं_बु_गु_शु_श".split("_"),longDateFormat:{LT:"A h:mm बजे",LTS:"A h:mm:ss बजे",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm बजे",LLLL:"dddd, D MMMM YYYY, A h:mm बजे"},monthsParse:B,longMonthsParse:B,shortMonthsParse:[/^\u091c\u0928/i,/^\u092b\u093c\u0930/i,/^\u092e\u093e\u0930\u094d\u091a/i,/^\u0905\u092a\u094d\u0930\u0948/i,/^\u092e\u0908/i,/^\u091c\u0942\u0928/i,/^\u091c\u0941\u0932/i,/^\u0905\u0917/i,/^\u0938\u093f\u0924/i,/^\u0905\u0915\u094d\u091f\u0942/i,/^\u0928\u0935/i,/^\u0926\u093f\u0938/i],monthsRegex:/^(\u091c\u0928\u0935\u0930\u0940|\u091c\u0928\.?|\u092b\u093c\u0930\u0935\u0930\u0940|\u092b\u0930\u0935\u0930\u0940|\u092b\u093c\u0930\.?|\u092e\u093e\u0930\u094d\u091a?|\u0905\u092a\u094d\u0930\u0948\u0932|\u0905\u092a\u094d\u0930\u0948\.?|\u092e\u0908?|\u091c\u0942\u0928?|\u091c\u0941\u0932\u093e\u0908|\u091c\u0941\u0932\.?|\u0905\u0917\u0938\u094d\u0924|\u0905\u0917\.?|\u0938\u093f\u0924\u092e\u094d\u092c\u0930|\u0938\u093f\u0924\u0902\u092c\u0930|\u0938\u093f\u0924\.?|\u0905\u0915\u094d\u091f\u0942\u092c\u0930|\u0905\u0915\u094d\u091f\u0942\.?|\u0928\u0935\u092e\u094d\u092c\u0930|\u0928\u0935\u0902\u092c\u0930|\u0928\u0935\.?|\u0926\u093f\u0938\u092e\u094d\u092c\u0930|\u0926\u093f\u0938\u0902\u092c\u0930|\u0926\u093f\u0938\.?)/i,monthsShortRegex:/^(\u091c\u0928\u0935\u0930\u0940|\u091c\u0928\.?|\u092b\u093c\u0930\u0935\u0930\u0940|\u092b\u0930\u0935\u0930\u0940|\u092b\u093c\u0930\.?|\u092e\u093e\u0930\u094d\u091a?|\u0905\u092a\u094d\u0930\u0948\u0932|\u0905\u092a\u094d\u0930\u0948\.?|\u092e\u0908?|\u091c\u0942\u0928?|\u091c\u0941\u0932\u093e\u0908|\u091c\u0941\u0932\.?|\u0905\u0917\u0938\u094d\u0924|\u0905\u0917\.?|\u0938\u093f\u0924\u092e\u094d\u092c\u0930|\u0938\u093f\u0924\u0902\u092c\u0930|\u0938\u093f\u0924\.?|\u0905\u0915\u094d\u091f\u0942\u092c\u0930|\u0905\u0915\u094d\u091f\u0942\.?|\u0928\u0935\u092e\u094d\u092c\u0930|\u0928\u0935\u0902\u092c\u0930|\u0928\u0935\.?|\u0926\u093f\u0938\u092e\u094d\u092c\u0930|\u0926\u093f\u0938\u0902\u092c\u0930|\u0926\u093f\u0938\.?)/i,monthsStrictRegex:/^(\u091c\u0928\u0935\u0930\u0940?|\u092b\u093c\u0930\u0935\u0930\u0940|\u092b\u0930\u0935\u0930\u0940?|\u092e\u093e\u0930\u094d\u091a?|\u0905\u092a\u094d\u0930\u0948\u0932?|\u092e\u0908?|\u091c\u0942\u0928?|\u091c\u0941\u0932\u093e\u0908?|\u0905\u0917\u0938\u094d\u0924?|\u0938\u093f\u0924\u092e\u094d\u092c\u0930|\u0938\u093f\u0924\u0902\u092c\u0930|\u0938\u093f\u0924?\.?|\u0905\u0915\u094d\u091f\u0942\u092c\u0930|\u0905\u0915\u094d\u091f\u0942\.?|\u0928\u0935\u092e\u094d\u092c\u0930|\u0928\u0935\u0902\u092c\u0930?|\u0926\u093f\u0938\u092e\u094d\u092c\u0930|\u0926\u093f\u0938\u0902\u092c\u0930?)/i,monthsShortStrictRegex:/^(\u091c\u0928\.?|\u092b\u093c\u0930\.?|\u092e\u093e\u0930\u094d\u091a?|\u0905\u092a\u094d\u0930\u0948\.?|\u092e\u0908?|\u091c\u0942\u0928?|\u091c\u0941\u0932\.?|\u0905\u0917\.?|\u0938\u093f\u0924\.?|\u0905\u0915\u094d\u091f\u0942\.?|\u0928\u0935\.?|\u0926\u093f\u0938\.?)/i,calendar:{sameDay:"[आज] LT",nextDay:"[कल] LT",nextWeek:"dddd, LT",lastDay:"[कल] LT",lastWeek:"[पिछले] dddd, LT",sameElse:"L"},relativeTime:{future:"%s में",past:"%s पहले",s:"कुछ ही क्षण",ss:"%d सेकंड",m:"एक मिनट",mm:"%d मिनट",h:"एक घंटा",hh:"%d घंटे",d:"एक दिन",dd:"%d दिन",M:"एक महीने",MM:"%d महीने",y:"एक वर्ष",yy:"%d वर्ष"},preparse:function(e){return e.replace(/[\u0967\u0968\u0969\u096a\u096b\u096c\u096d\u096e\u096f\u0966]/g,(function(e){return Mn[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return kn[e]}))},meridiemParse:/\u0930\u093e\u0924|\u0938\u0941\u092c\u0939|\u0926\u094b\u092a\u0939\u0930|\u0936\u093e\u092e/,meridiemHour:function(e,t){return 12===e&&(e=0),"रात"===t?e<4?e:e+12:"सुबह"===t?e:"दोपहर"===t?10<=e?e:e+12:"शाम"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"रात":e<10?"सुबह":e<17?"दोपहर":e<20?"शाम":"रात"},week:{dow:0,doy:6}}),t.defineLocale("hr",{months:{format:"siječnja_veljače_ožujka_travnja_svibnja_lipnja_srpnja_kolovoza_rujna_listopada_studenoga_prosinca".split("_"),standalone:"siječanj_veljača_ožujak_travanj_svibanj_lipanj_srpanj_kolovoz_rujan_listopad_studeni_prosinac".split("_")},monthsShort:"sij._velj._ožu._tra._svi._lip._srp._kol._ruj._lis._stu._pro.".split("_"),monthsParseExact:!0,weekdays:"nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sri._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"Do MMMM YYYY",LLL:"Do MMMM YYYY H:mm",LLLL:"dddd, Do MMMM YYYY H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedjelju] [u] LT";case 3:return"[u] [srijedu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[jučer u] LT",lastWeek:function(){switch(this.day()){case 0:return"[prošlu] [nedjelju] [u] LT";case 3:return"[prošlu] [srijedu] [u] LT";case 6:return"[prošle] [subote] [u] LT";case 1:case 2:case 4:case 5:return"[prošli] dddd [u] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"prije %s",s:"par sekundi",ss:Sn,m:Sn,mm:Sn,h:Sn,hh:Sn,d:"dan",dd:Sn,M:"mjesec",MM:Sn,y:"godinu",yy:Sn},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}});var An="vasárnap hétfőn kedden szerdán csütörtökön pénteken szombaton".split(" ");function Ln(e,t,i,n){var r=e;switch(i){case"s":return n||t?"néhány másodperc":"néhány másodperce";case"ss":return r+(n||t)?" másodperc":" másodperce";case"m":return"egy"+(n||t?" perc":" perce");case"mm":return r+(n||t?" perc":" perce");case"h":return"egy"+(n||t?" óra":" órája");case"hh":return r+(n||t?" óra":" órája");case"d":return"egy"+(n||t?" nap":" napja");case"dd":return r+(n||t?" nap":" napja");case"M":return"egy"+(n||t?" hónap":" hónapja");case"MM":return r+(n||t?" hónap":" hónapja");case"y":return"egy"+(n||t?" év":" éve");case"yy":return r+(n||t?" év":" éve")}return""}function Tn(e){return(e?"":"[múlt] ")+"["+An[this.day()]+"] LT[-kor]"}function Cn(e){return e%100==11||e%10!=1}function Dn(e,t,i,n){var r=e+" ";switch(i){case"s":return t||n?"nokkrar sekúndur":"nokkrum sekúndum";case"ss":return Cn(e)?r+(t||n?"sekúndur":"sekúndum"):r+"sekúnda";case"m":return t?"mínúta":"mínútu";case"mm":return Cn(e)?r+(t||n?"mínútur":"mínútum"):t?r+"mínúta":r+"mínútu";case"hh":return Cn(e)?r+(t||n?"klukkustundir":"klukkustundum"):r+"klukkustund";case"d":return t?"dagur":n?"dag":"degi";case"dd":return Cn(e)?t?r+"dagar":r+(n?"daga":"dögum"):t?r+"dagur":r+(n?"dag":"degi");case"M":return t?"mánuður":n?"mánuð":"mánuði";case"MM":return Cn(e)?t?r+"mánuðir":r+(n?"mánuði":"mánuðum"):t?r+"mánuður":r+(n?"mánuð":"mánuði");case"y":return t||n?"ár":"ári";case"yy":return Cn(e)?r+(t||n?"ár":"árum"):r+(t||n?"ár":"ári")}}t.defineLocale("hu",{months:"január_február_március_április_május_június_július_augusztus_szeptember_október_november_december".split("_"),monthsShort:"jan._feb._márc._ápr._máj._jún._júl._aug._szept._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"vasárnap_hétfő_kedd_szerda_csütörtök_péntek_szombat".split("_"),weekdaysShort:"vas_hét_kedd_sze_csüt_pén_szo".split("_"),weekdaysMin:"v_h_k_sze_cs_p_szo".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"YYYY.MM.DD.",LL:"YYYY. MMMM D.",LLL:"YYYY. MMMM D. H:mm",LLLL:"YYYY. MMMM D., dddd H:mm"},meridiemParse:/de|du/i,isPM:function(e){return"u"===e.charAt(1).toLowerCase()},meridiem:function(e,t,i){return e<12?!0===i?"de":"DE":!0===i?"du":"DU"},calendar:{sameDay:"[ma] LT[-kor]",nextDay:"[holnap] LT[-kor]",nextWeek:function(){return Tn.call(this,!0)},lastDay:"[tegnap] LT[-kor]",lastWeek:function(){return Tn.call(this,!1)},sameElse:"L"},relativeTime:{future:"%s múlva",past:"%s",s:Ln,ss:Ln,m:Ln,mm:Ln,h:Ln,hh:Ln,d:Ln,dd:Ln,M:Ln,MM:Ln,y:Ln,yy:Ln},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("hy-am",{months:{format:"հունվարի_փետրվարի_մարտի_ապրիլի_մայիսի_հունիսի_հուլիսի_օգոստոսի_սեպտեմբերի_հոկտեմբերի_նոյեմբերի_դեկտեմբերի".split("_"),standalone:"հունվար_փետրվար_մարտ_ապրիլ_մայիս_հունիս_հուլիս_օգոստոս_սեպտեմբեր_հոկտեմբեր_նոյեմբեր_դեկտեմբեր".split("_")},monthsShort:"հնվ_փտր_մրտ_ապր_մյս_հնս_հլս_օգս_սպտ_հկտ_նմբ_դկտ".split("_"),weekdays:"կիրակի_երկուշաբթի_երեքշաբթի_չորեքշաբթի_հինգշաբթի_ուրբաթ_շաբաթ".split("_"),weekdaysShort:"կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ".split("_"),weekdaysMin:"կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY թ.",LLL:"D MMMM YYYY թ., HH:mm",LLLL:"dddd, D MMMM YYYY թ., HH:mm"},calendar:{sameDay:"[այսօր] LT",nextDay:"[վաղը] LT",lastDay:"[երեկ] LT",nextWeek:function(){return"dddd [օրը ժամը] LT"},lastWeek:function(){return"[անցած] dddd [օրը ժամը] LT"},sameElse:"L"},relativeTime:{future:"%s հետո",past:"%s առաջ",s:"մի քանի վայրկյան",ss:"%d վայրկյան",m:"րոպե",mm:"%d րոպե",h:"ժամ",hh:"%d ժամ",d:"օր",dd:"%d օր",M:"ամիս",MM:"%d ամիս",y:"տարի",yy:"%d տարի"},meridiemParse:/\u0563\u056b\u0577\u0565\u0580\u057e\u0561|\u0561\u057c\u0561\u057e\u0578\u057f\u057e\u0561|\u0581\u0565\u0580\u0565\u056f\u057e\u0561|\u0565\u0580\u0565\u056f\u0578\u0575\u0561\u0576/,isPM:function(e){return/^(\u0581\u0565\u0580\u0565\u056f\u057e\u0561|\u0565\u0580\u0565\u056f\u0578\u0575\u0561\u0576)$/.test(e)},meridiem:function(e){return e<4?"գիշերվա":e<12?"առավոտվա":e<17?"ցերեկվա":"երեկոյան"},dayOfMonthOrdinalParse:/\d{1,2}|\d{1,2}-(\u056b\u0576|\u0580\u0564)/,ordinal:function(e,t){switch(t){case"DDD":case"w":case"W":case"DDDo":return 1===e?e+"-ին":e+"-րդ";default:return e}},week:{dow:1,doy:7}}),t.defineLocale("id",{months:"Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_November_Desember".split("_"),monthsShort:"Jan_Feb_Mar_Apr_Mei_Jun_Jul_Agt_Sep_Okt_Nov_Des".split("_"),weekdays:"Minggu_Senin_Selasa_Rabu_Kamis_Jumat_Sabtu".split("_"),weekdaysShort:"Min_Sen_Sel_Rab_Kam_Jum_Sab".split("_"),weekdaysMin:"Mg_Sn_Sl_Rb_Km_Jm_Sb".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/pagi|siang|sore|malam/,meridiemHour:function(e,t){return 12===e&&(e=0),"pagi"===t?e:"siang"===t?11<=e?e:e+12:"sore"===t||"malam"===t?e+12:void 0},meridiem:function(e,t,i){return e<11?"pagi":e<15?"siang":e<19?"sore":"malam"},calendar:{sameDay:"[Hari ini pukul] LT",nextDay:"[Besok pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kemarin pukul] LT",lastWeek:"dddd [lalu pukul] LT",sameElse:"L"},relativeTime:{future:"dalam %s",past:"%s yang lalu",s:"beberapa detik",ss:"%d detik",m:"semenit",mm:"%d menit",h:"sejam",hh:"%d jam",d:"sehari",dd:"%d hari",M:"sebulan",MM:"%d bulan",y:"setahun",yy:"%d tahun"},week:{dow:0,doy:6}}),t.defineLocale("is",{months:"janúar_febrúar_mars_apríl_maí_júní_júlí_ágúst_september_október_nóvember_desember".split("_"),monthsShort:"jan_feb_mar_apr_maí_jún_júl_ágú_sep_okt_nóv_des".split("_"),weekdays:"sunnudagur_mánudagur_þriðjudagur_miðvikudagur_fimmtudagur_föstudagur_laugardagur".split("_"),weekdaysShort:"sun_mán_þri_mið_fim_fös_lau".split("_"),weekdaysMin:"Su_Má_Þr_Mi_Fi_Fö_La".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY [kl.] H:mm",LLLL:"dddd, D. MMMM YYYY [kl.] H:mm"},calendar:{sameDay:"[í dag kl.] LT",nextDay:"[á morgun kl.] LT",nextWeek:"dddd [kl.] LT",lastDay:"[í gær kl.] LT",lastWeek:"[síðasta] dddd [kl.] LT",sameElse:"L"},relativeTime:{future:"eftir %s",past:"fyrir %s síðan",s:Dn,ss:Dn,m:Dn,mm:Dn,h:"klukkustund",hh:Dn,d:Dn,dd:Dn,M:Dn,MM:Dn,y:Dn,yy:Dn},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("it-ch",{months:"gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre".split("_"),monthsShort:"gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic".split("_"),weekdays:"domenica_lunedì_martedì_mercoledì_giovedì_venerdì_sabato".split("_"),weekdaysShort:"dom_lun_mar_mer_gio_ven_sab".split("_"),weekdaysMin:"do_lu_ma_me_gi_ve_sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Oggi alle] LT",nextDay:"[Domani alle] LT",nextWeek:"dddd [alle] LT",lastDay:"[Ieri alle] LT",lastWeek:function(){return 0===this.day()?"[la scorsa] dddd [alle] LT":"[lo scorso] dddd [alle] LT"},sameElse:"L"},relativeTime:{future:function(e){return(/^[0-9].+$/.test(e)?"tra":"in")+" "+e},past:"%s fa",s:"alcuni secondi",ss:"%d secondi",m:"un minuto",mm:"%d minuti",h:"un'ora",hh:"%d ore",d:"un giorno",dd:"%d giorni",M:"un mese",MM:"%d mesi",y:"un anno",yy:"%d anni"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4}}),t.defineLocale("it",{months:"gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre".split("_"),monthsShort:"gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic".split("_"),weekdays:"domenica_lunedì_martedì_mercoledì_giovedì_venerdì_sabato".split("_"),weekdaysShort:"dom_lun_mar_mer_gio_ven_sab".split("_"),weekdaysMin:"do_lu_ma_me_gi_ve_sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:function(){return"[Oggi a"+(1<this.hours()?"lle ":0===this.hours()?" ":"ll'")+"]LT"},nextDay:function(){return"[Domani a"+(1<this.hours()?"lle ":0===this.hours()?" ":"ll'")+"]LT"},nextWeek:function(){return"dddd [a"+(1<this.hours()?"lle ":0===this.hours()?" ":"ll'")+"]LT"},lastDay:function(){return"[Ieri a"+(1<this.hours()?"lle ":0===this.hours()?" ":"ll'")+"]LT"},lastWeek:function(){return 0===this.day()?"[La scorsa] dddd [a"+(1<this.hours()?"lle ":0===this.hours()?" ":"ll'")+"]LT":"[Lo scorso] dddd [a"+(1<this.hours()?"lle ":0===this.hours()?" ":"ll'")+"]LT"},sameElse:"L"},relativeTime:{future:"tra %s",past:"%s fa",s:"alcuni secondi",ss:"%d secondi",m:"un minuto",mm:"%d minuti",h:"un'ora",hh:"%d ore",d:"un giorno",dd:"%d giorni",w:"una settimana",ww:"%d settimane",M:"un mese",MM:"%d mesi",y:"un anno",yy:"%d anni"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4}}),t.defineLocale("ja",{eras:[{since:"2019-05-01",offset:1,name:"令和",narrow:"㋿",abbr:"R"},{since:"1989-01-08",until:"2019-04-30",offset:1,name:"平成",narrow:"㍻",abbr:"H"},{since:"1926-12-25",until:"1989-01-07",offset:1,name:"昭和",narrow:"㍼",abbr:"S"},{since:"1912-07-30",until:"1926-12-24",offset:1,name:"大正",narrow:"㍽",abbr:"T"},{since:"1873-01-01",until:"1912-07-29",offset:6,name:"明治",narrow:"㍾",abbr:"M"},{since:"0001-01-01",until:"1873-12-31",offset:1,name:"西暦",narrow:"AD",abbr:"AD"},{since:"0000-12-31",until:-1/0,offset:1,name:"紀元前",narrow:"BC",abbr:"BC"}],eraYearOrdinalRegex:/(\u5143|\d+)\u5e74/,eraYearOrdinalParse:function(e,t){return"元"===t[1]?1:parseInt(t[1]||e,10)},months:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"日曜日_月曜日_火曜日_水曜日_木曜日_金曜日_土曜日".split("_"),weekdaysShort:"日_月_火_水_木_金_土".split("_"),weekdaysMin:"日_月_火_水_木_金_土".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日 dddd HH:mm",l:"YYYY/MM/DD",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日(ddd) HH:mm"},meridiemParse:/\u5348\u524d|\u5348\u5f8c/i,isPM:function(e){return"午後"===e},meridiem:function(e,t,i){return e<12?"午前":"午後"},calendar:{sameDay:"[今日] LT",nextDay:"[明日] LT",nextWeek:function(e){return e.week()!==this.week()?"[来週]dddd LT":"dddd LT"},lastDay:"[昨日] LT",lastWeek:function(e){return this.week()!==e.week()?"[先週]dddd LT":"dddd LT"},sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}\u65e5/,ordinal:function(e,t){switch(t){case"y":return 1===e?"元年":e+"年";case"d":case"D":case"DDD":return e+"日";default:return e}},relativeTime:{future:"%s後",past:"%s前",s:"数秒",ss:"%d秒",m:"1分",mm:"%d分",h:"1時間",hh:"%d時間",d:"1日",dd:"%d日",M:"1ヶ月",MM:"%dヶ月",y:"1年",yy:"%d年"}}),t.defineLocale("jv",{months:"Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_Nopember_Desember".split("_"),monthsShort:"Jan_Feb_Mar_Apr_Mei_Jun_Jul_Ags_Sep_Okt_Nop_Des".split("_"),weekdays:"Minggu_Senen_Seloso_Rebu_Kemis_Jemuwah_Septu".split("_"),weekdaysShort:"Min_Sen_Sel_Reb_Kem_Jem_Sep".split("_"),weekdaysMin:"Mg_Sn_Sl_Rb_Km_Jm_Sp".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/enjing|siyang|sonten|ndalu/,meridiemHour:function(e,t){return 12===e&&(e=0),"enjing"===t?e:"siyang"===t?11<=e?e:e+12:"sonten"===t||"ndalu"===t?e+12:void 0},meridiem:function(e,t,i){return e<11?"enjing":e<15?"siyang":e<19?"sonten":"ndalu"},calendar:{sameDay:"[Dinten puniko pukul] LT",nextDay:"[Mbenjang pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kala wingi pukul] LT",lastWeek:"dddd [kepengker pukul] LT",sameElse:"L"},relativeTime:{future:"wonten ing %s",past:"%s ingkang kepengker",s:"sawetawis detik",ss:"%d detik",m:"setunggal menit",mm:"%d menit",h:"setunggal jam",hh:"%d jam",d:"sedinten",dd:"%d dinten",M:"sewulan",MM:"%d wulan",y:"setaun",yy:"%d taun"},week:{dow:1,doy:7}}),t.defineLocale("ka",{months:"იანვარი_თებერვალი_მარტი_აპრილი_მაისი_ივნისი_ივლისი_აგვისტო_სექტემბერი_ოქტომბერი_ნოემბერი_დეკემბერი".split("_"),monthsShort:"იან_თებ_მარ_აპრ_მაი_ივნ_ივლ_აგვ_სექ_ოქტ_ნოე_დეკ".split("_"),weekdays:{standalone:"კვირა_ორშაბათი_სამშაბათი_ოთხშაბათი_ხუთშაბათი_პარასკევი_შაბათი".split("_"),format:"კვირას_ორშაბათს_სამშაბათს_ოთხშაბათს_ხუთშაბათს_პარასკევს_შაბათს".split("_"),isFormat:/(\u10ec\u10d8\u10dc\u10d0|\u10e8\u10d4\u10db\u10d3\u10d4\u10d2)/},weekdaysShort:"კვი_ორშ_სამ_ოთხ_ხუთ_პარ_შაბ".split("_"),weekdaysMin:"კვ_ორ_სა_ოთ_ხუ_პა_შა".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[დღეს] LT[-ზე]",nextDay:"[ხვალ] LT[-ზე]",lastDay:"[გუშინ] LT[-ზე]",nextWeek:"[შემდეგ] dddd LT[-ზე]",lastWeek:"[წინა] dddd LT-ზე",sameElse:"L"},relativeTime:{future:function(e){return e.replace(/(\u10ec\u10d0\u10db|\u10ec\u10e3\u10d7|\u10e1\u10d0\u10d0\u10d7|\u10ec\u10d4\u10da|\u10d3\u10e6|\u10d7\u10d5)(\u10d8|\u10d4)/,(function(e,t,i){return"ი"===i?t+"ში":t+i+"ში"}))},past:function(e){return/(\u10ec\u10d0\u10db\u10d8|\u10ec\u10e3\u10d7\u10d8|\u10e1\u10d0\u10d0\u10d7\u10d8|\u10d3\u10e6\u10d4|\u10d7\u10d5\u10d4)/.test(e)?e.replace(/(\u10d8|\u10d4)$/,"ის წინ"):/\u10ec\u10d4\u10da\u10d8/.test(e)?e.replace(/\u10ec\u10d4\u10da\u10d8$/,"წლის წინ"):e},s:"რამდენიმე წამი",ss:"%d წამი",m:"წუთი",mm:"%d წუთი",h:"საათი",hh:"%d საათი",d:"დღე",dd:"%d დღე",M:"თვე",MM:"%d თვე",y:"წელი",yy:"%d წელი"},dayOfMonthOrdinalParse:/0|1-\u10da\u10d8|\u10db\u10d4-\d{1,2}|\d{1,2}-\u10d4/,ordinal:function(e){return 0===e?e:1===e?e+"-ლი":e<20||e<=100&&e%20==0||e%100==0?"მე-"+e:e+"-ე"},week:{dow:1,doy:7}});var En={0:"-ші",1:"-ші",2:"-ші",3:"-ші",4:"-ші",5:"-ші",6:"-шы",7:"-ші",8:"-ші",9:"-шы",10:"-шы",20:"-шы",30:"-шы",40:"-шы",50:"-ші",60:"-шы",70:"-ші",80:"-ші",90:"-шы",100:"-ші"},On=(t.defineLocale("kk",{months:"қаңтар_ақпан_наурыз_сәуір_мамыр_маусым_шілде_тамыз_қыркүйек_қазан_қараша_желтоқсан".split("_"),monthsShort:"қаң_ақп_нау_сәу_мам_мау_шіл_там_қыр_қаз_қар_жел".split("_"),weekdays:"жексенбі_дүйсенбі_сейсенбі_сәрсенбі_бейсенбі_жұма_сенбі".split("_"),weekdaysShort:"жек_дүй_сей_сәр_бей_жұм_сен".split("_"),weekdaysMin:"жк_дй_сй_ср_бй_жм_сн".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Бүгін сағат] LT",nextDay:"[Ертең сағат] LT",nextWeek:"dddd [сағат] LT",lastDay:"[Кеше сағат] LT",lastWeek:"[Өткен аптаның] dddd [сағат] LT",sameElse:"L"},relativeTime:{future:"%s ішінде",past:"%s бұрын",s:"бірнеше секунд",ss:"%d секунд",m:"бір минут",mm:"%d минут",h:"бір сағат",hh:"%d сағат",d:"бір күн",dd:"%d күн",M:"бір ай",MM:"%d ай",y:"бір жыл",yy:"%d жыл"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0448\u0456|\u0448\u044b)/,ordinal:function(e){return e+(En[e]||En[e%10]||En[100<=e?100:null])},week:{dow:1,doy:7}}),{1:"១",2:"២",3:"៣",4:"៤",5:"៥",6:"៦",7:"៧",8:"៨",9:"៩",0:"០"}),Pn={"១":"1","២":"2","៣":"3","៤":"4","៥":"5","៦":"6","៧":"7","៨":"8","៩":"9","០":"0"},Yn=(t.defineLocale("km",{months:"មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ".split("_"),monthsShort:"មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ".split("_"),weekdays:"អាទិត្យ_ច័ន្ទ_អង្គារ_ពុធ_ព្រហស្បតិ៍_សុក្រ_សៅរ៍".split("_"),weekdaysShort:"អា_ច_អ_ព_ព្រ_សុ_ស".split("_"),weekdaysMin:"អា_ច_អ_ព_ព្រ_សុ_ស".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},meridiemParse:/\u1796\u17d2\u179a\u17b9\u1780|\u179b\u17d2\u1784\u17b6\u1785/,isPM:function(e){return"ល្ងាច"===e},meridiem:function(e,t,i){return e<12?"ព្រឹក":"ល្ងាច"},calendar:{sameDay:"[ថ្ងៃនេះ ម៉ោង] LT",nextDay:"[ស្អែក ម៉ោង] LT",nextWeek:"dddd [ម៉ោង] LT",lastDay:"[ម្សិលមិញ ម៉ោង] LT",lastWeek:"dddd [សប្តាហ៍មុន] [ម៉ោង] LT",sameElse:"L"},relativeTime:{future:"%sទៀត",past:"%sមុន",s:"ប៉ុន្មានវិនាទី",ss:"%d វិនាទី",m:"មួយនាទី",mm:"%d នាទី",h:"មួយម៉ោង",hh:"%d ម៉ោង",d:"មួយថ្ងៃ",dd:"%d ថ្ងៃ",M:"មួយខែ",MM:"%d ខែ",y:"មួយឆ្នាំ",yy:"%d ឆ្នាំ"},dayOfMonthOrdinalParse:/\u1791\u17b8\d{1,2}/,ordinal:"ទី%d",preparse:function(e){return e.replace(/[\u17e1\u17e2\u17e3\u17e4\u17e5\u17e6\u17e7\u17e8\u17e9\u17e0]/g,(function(e){return Pn[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return On[e]}))},week:{dow:1,doy:4}}),{1:"೧",2:"೨",3:"೩",4:"೪",5:"೫",6:"೬",7:"೭",8:"೮",9:"೯",0:"೦"}),In={"೧":"1","೨":"2","೩":"3","೪":"4","೫":"5","೬":"6","೭":"7","೮":"8","೯":"9","೦":"0"};function Nn(e,t,i,n){return e={s:["çend sanîye","çend sanîyeyan"],ss:[e+" sanîye",e+" sanîyeyan"],m:["deqîqeyek","deqîqeyekê"],mm:[e+" deqîqe",e+" deqîqeyan"],h:["saetek","saetekê"],hh:[e+" saet",e+" saetan"],d:["rojek","rojekê"],dd:[e+" roj",e+" rojan"],w:["hefteyek","hefteyekê"],ww:[e+" hefte",e+" hefteyan"],M:["mehek","mehekê"],MM:[e+" meh",e+" mehan"],y:["salek","salekê"],yy:[e+" sal",e+" salan"]},t?e[i][0]:e[i][1]}t.defineLocale("kn",{months:"ಜನವರಿ_ಫೆಬ್ರವರಿ_ಮಾರ್ಚ್_ಏಪ್ರಿಲ್_ಮೇ_ಜೂನ್_ಜುಲೈ_ಆಗಸ್ಟ್_ಸೆಪ್ಟೆಂಬರ್_ಅಕ್ಟೋಬರ್_ನವೆಂಬರ್_ಡಿಸೆಂಬರ್".split("_"),monthsShort:"ಜನ_ಫೆಬ್ರ_ಮಾರ್ಚ್_ಏಪ್ರಿಲ್_ಮೇ_ಜೂನ್_ಜುಲೈ_ಆಗಸ್ಟ್_ಸೆಪ್ಟೆಂ_ಅಕ್ಟೋ_ನವೆಂ_ಡಿಸೆಂ".split("_"),monthsParseExact:!0,weekdays:"ಭಾನುವಾರ_ಸೋಮವಾರ_ಮಂಗಳವಾರ_ಬುಧವಾರ_ಗುರುವಾರ_ಶುಕ್ರವಾರ_ಶನಿವಾರ".split("_"),weekdaysShort:"ಭಾನು_ಸೋಮ_ಮಂಗಳ_ಬುಧ_ಗುರು_ಶುಕ್ರ_ಶನಿ".split("_"),weekdaysMin:"ಭಾ_ಸೋ_ಮಂ_ಬು_ಗು_ಶು_ಶ".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm",LLLL:"dddd, D MMMM YYYY, A h:mm"},calendar:{sameDay:"[ಇಂದು] LT",nextDay:"[ನಾಳೆ] LT",nextWeek:"dddd, LT",lastDay:"[ನಿನ್ನೆ] LT",lastWeek:"[ಕೊನೆಯ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s ನಂತರ",past:"%s ಹಿಂದೆ",s:"ಕೆಲವು ಕ್ಷಣಗಳು",ss:"%d ಸೆಕೆಂಡುಗಳು",m:"ಒಂದು ನಿಮಿಷ",mm:"%d ನಿಮಿಷ",h:"ಒಂದು ಗಂಟೆ",hh:"%d ಗಂಟೆ",d:"ಒಂದು ದಿನ",dd:"%d ದಿನ",M:"ಒಂದು ತಿಂಗಳು",MM:"%d ತಿಂಗಳು",y:"ಒಂದು ವರ್ಷ",yy:"%d ವರ್ಷ"},preparse:function(e){return e.replace(/[\u0ce7\u0ce8\u0ce9\u0cea\u0ceb\u0cec\u0ced\u0cee\u0cef\u0ce6]/g,(function(e){return In[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return Yn[e]}))},meridiemParse:/\u0cb0\u0cbe\u0ca4\u0ccd\u0cb0\u0cbf|\u0cac\u0cc6\u0cb3\u0cbf\u0c97\u0ccd\u0c97\u0cc6|\u0cae\u0ca7\u0ccd\u0caf\u0cbe\u0cb9\u0ccd\u0ca8|\u0cb8\u0c82\u0c9c\u0cc6/,meridiemHour:function(e,t){return 12===e&&(e=0),"ರಾತ್ರಿ"===t?e<4?e:e+12:"ಬೆಳಿಗ್ಗೆ"===t?e:"ಮಧ್ಯಾಹ್ನ"===t?10<=e?e:e+12:"ಸಂಜೆ"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"ರಾತ್ರಿ":e<10?"ಬೆಳಿಗ್ಗೆ":e<17?"ಮಧ್ಯಾಹ್ನ":e<20?"ಸಂಜೆ":"ರಾತ್ರಿ"},dayOfMonthOrdinalParse:/\d{1,2}(\u0ca8\u0cc6\u0cd5)/,ordinal:function(e){return e+"ನೇ"},week:{dow:0,doy:6}}),t.defineLocale("ko",{months:"1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월".split("_"),monthsShort:"1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월".split("_"),weekdays:"일요일_월요일_화요일_수요일_목요일_금요일_토요일".split("_"),weekdaysShort:"일_월_화_수_목_금_토".split("_"),weekdaysMin:"일_월_화_수_목_금_토".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"YYYY.MM.DD.",LL:"YYYY년 MMMM D일",LLL:"YYYY년 MMMM D일 A h:mm",LLLL:"YYYY년 MMMM D일 dddd A h:mm",l:"YYYY.MM.DD.",ll:"YYYY년 MMMM D일",lll:"YYYY년 MMMM D일 A h:mm",llll:"YYYY년 MMMM D일 dddd A h:mm"},calendar:{sameDay:"오늘 LT",nextDay:"내일 LT",nextWeek:"dddd LT",lastDay:"어제 LT",lastWeek:"지난주 dddd LT",sameElse:"L"},relativeTime:{future:"%s 후",past:"%s 전",s:"몇 초",ss:"%d초",m:"1분",mm:"%d분",h:"한 시간",hh:"%d시간",d:"하루",dd:"%d일",M:"한 달",MM:"%d달",y:"일 년",yy:"%d년"},dayOfMonthOrdinalParse:/\d{1,2}(\uc77c|\uc6d4|\uc8fc)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"일";case"M":return e+"월";case"w":case"W":return e+"주";default:return e}},meridiemParse:/\uc624\uc804|\uc624\ud6c4/,isPM:function(e){return"오후"===e},meridiem:function(e,t,i){return e<12?"오전":"오후"}}),t.defineLocale("ku-kmr",{months:"Rêbendan_Sibat_Adar_Nîsan_Gulan_Hezîran_Tîrmeh_Tebax_Îlon_Cotmeh_Mijdar_Berfanbar".split("_"),monthsShort:"Rêb_Sib_Ada_Nîs_Gul_Hez_Tîr_Teb_Îlo_Cot_Mij_Ber".split("_"),monthsParseExact:!0,weekdays:"Yekşem_Duşem_Sêşem_Çarşem_Pêncşem_În_Şemî".split("_"),weekdaysShort:"Yek_Du_Sê_Çar_Pên_În_Şem".split("_"),weekdaysMin:"Ye_Du_Sê_Ça_Pê_În_Şe".split("_"),meridiem:function(e,t,i){return e<12?i?"bn":"BN":i?"pn":"PN"},meridiemParse:/bn|BN|pn|PN/,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"Do MMMM[a] YYYY[an]",LLL:"Do MMMM[a] YYYY[an] HH:mm",LLLL:"dddd, Do MMMM[a] YYYY[an] HH:mm",ll:"Do MMM[.] YYYY[an]",lll:"Do MMM[.] YYYY[an] HH:mm",llll:"ddd[.], Do MMM[.] YYYY[an] HH:mm"},calendar:{sameDay:"[Îro di saet] LT [de]",nextDay:"[Sibê di saet] LT [de]",nextWeek:"dddd [di saet] LT [de]",lastDay:"[Duh di saet] LT [de]",lastWeek:"dddd[a borî di saet] LT [de]",sameElse:"L"},relativeTime:{future:"di %s de",past:"berî %s",s:Nn,ss:Nn,m:Nn,mm:Nn,h:Nn,hh:Nn,d:Nn,dd:Nn,w:Nn,ww:Nn,M:Nn,MM:Nn,y:Nn,yy:Nn},dayOfMonthOrdinalParse:/\d{1,2}(?:y\xea|\xea|\.)/,ordinal:function(e,t){return(t=t.toLowerCase()).includes("w")||t.includes("m")?e+".":e+(e=(t=""+(t=e)).substring(t.length-1),12==(t=1<t.length?t.substring(t.length-2):"")||13==t||"2"!=e&&"3"!=e&&"50"!=t&&"70"!=e&&"80"!=e?"ê":"yê")},week:{dow:1,doy:4}});var jn={1:"١",2:"٢",3:"٣",4:"٤",5:"٥",6:"٦",7:"٧",8:"٨",9:"٩",0:"٠"},Hn={"١":"1","٢":"2","٣":"3","٤":"4","٥":"5","٦":"6","٧":"7","٨":"8","٩":"9","٠":"0"},Fn=(G=["کانونی دووەم","شوبات","ئازار","نیسان","ئایار","حوزەیران","تەمموز","ئاب","ئەیلوول","تشرینی یەكەم","تشرینی دووەم","كانونی یەکەم"],t.defineLocale("ku",{months:G,monthsShort:G,weekdays:"یه‌كشه‌ممه‌_دووشه‌ممه‌_سێشه‌ممه‌_چوارشه‌ممه‌_پێنجشه‌ممه‌_هه‌ینی_شه‌ممه‌".split("_"),weekdaysShort:"یه‌كشه‌م_دووشه‌م_سێشه‌م_چوارشه‌م_پێنجشه‌م_هه‌ینی_شه‌ممه‌".split("_"),weekdaysMin:"ی_د_س_چ_پ_ه_ش".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},meridiemParse:/\u0626\u06ce\u0648\u0627\u0631\u0647\u200c|\u0628\u0647\u200c\u06cc\u0627\u0646\u06cc/,isPM:function(e){return/\u0626\u06ce\u0648\u0627\u0631\u0647\u200c/.test(e)},meridiem:function(e,t,i){return e<12?"به‌یانی":"ئێواره‌"},calendar:{sameDay:"[ئه‌مرۆ كاتژمێر] LT",nextDay:"[به‌یانی كاتژمێر] LT",nextWeek:"dddd [كاتژمێر] LT",lastDay:"[دوێنێ كاتژمێر] LT",lastWeek:"dddd [كاتژمێر] LT",sameElse:"L"},relativeTime:{future:"له‌ %s",past:"%s",s:"چه‌ند چركه‌یه‌ك",ss:"چركه‌ %d",m:"یه‌ك خوله‌ك",mm:"%d خوله‌ك",h:"یه‌ك كاتژمێر",hh:"%d كاتژمێر",d:"یه‌ك ڕۆژ",dd:"%d ڕۆژ",M:"یه‌ك مانگ",MM:"%d مانگ",y:"یه‌ك ساڵ",yy:"%d ساڵ"},preparse:function(e){return e.replace(/[\u0661\u0662\u0663\u0664\u0665\u0666\u0667\u0668\u0669\u0660]/g,(function(e){return Hn[e]})).replace(/\u060c/g,",")},postformat:function(e){return e.replace(/\d/g,(function(e){return jn[e]})).replace(/,/g,"،")},week:{dow:6,doy:12}}),{0:"-чү",1:"-чи",2:"-чи",3:"-чү",4:"-чү",5:"-чи",6:"-чы",7:"-чи",8:"-чи",9:"-чу",10:"-чу",20:"-чы",30:"-чу",40:"-чы",50:"-чү",60:"-чы",70:"-чи",80:"-чи",90:"-чу",100:"-чү"});function Rn(e,t,i,n){var r={m:["eng Minutt","enger Minutt"],h:["eng Stonn","enger Stonn"],d:["een Dag","engem Dag"],M:["ee Mount","engem Mount"],y:["ee Joer","engem Joer"]};return t?r[i][0]:r[i][1]}function zn(e){if(e=parseInt(e,10),isNaN(e))return!1;if(e<0)return!0;if(e<10)return 4<=e&&e<=7;var t;if(e<100)return zn(0==(t=e%10)?e/10:t);if(e<1e4){for(;10<=e;)e/=10;return zn(e)}return zn(e/=1e3)}t.defineLocale("ky",{months:"январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь".split("_"),monthsShort:"янв_фев_март_апр_май_июнь_июль_авг_сен_окт_ноя_дек".split("_"),weekdays:"Жекшемби_Дүйшөмбү_Шейшемби_Шаршемби_Бейшемби_Жума_Ишемби".split("_"),weekdaysShort:"Жек_Дүй_Шей_Шар_Бей_Жум_Ише".split("_"),weekdaysMin:"Жк_Дй_Шй_Шр_Бй_Жм_Иш".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Бүгүн саат] LT",nextDay:"[Эртең саат] LT",nextWeek:"dddd [саат] LT",lastDay:"[Кечээ саат] LT",lastWeek:"[Өткөн аптанын] dddd [күнү] [саат] LT",sameElse:"L"},relativeTime:{future:"%s ичинде",past:"%s мурун",s:"бирнече секунд",ss:"%d секунд",m:"бир мүнөт",mm:"%d мүнөт",h:"бир саат",hh:"%d саат",d:"бир күн",dd:"%d күн",M:"бир ай",MM:"%d ай",y:"бир жыл",yy:"%d жыл"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0447\u0438|\u0447\u044b|\u0447\u04af|\u0447\u0443)/,ordinal:function(e){return e+(Fn[e]||Fn[e%10]||Fn[100<=e?100:null])},week:{dow:1,doy:7}}),t.defineLocale("lb",{months:"Januar_Februar_Mäerz_Abrëll_Mee_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Febr._Mrz._Abr._Mee_Jun._Jul._Aug._Sept._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonndeg_Méindeg_Dënschdeg_Mëttwoch_Donneschdeg_Freideg_Samschdeg".split("_"),weekdaysShort:"So._Mé._Dë._Më._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mé_Dë_Më_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm [Auer]",LTS:"H:mm:ss [Auer]",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm [Auer]",LLLL:"dddd, D. MMMM YYYY H:mm [Auer]"},calendar:{sameDay:"[Haut um] LT",sameElse:"L",nextDay:"[Muer um] LT",nextWeek:"dddd [um] LT",lastDay:"[Gëschter um] LT",lastWeek:function(){switch(this.day()){case 2:case 4:return"[Leschten] dddd [um] LT";default:return"[Leschte] dddd [um] LT"}}},relativeTime:{future:function(e){return zn(e.substr(0,e.indexOf(" ")))?"a "+e:"an "+e},past:function(e){return zn(e.substr(0,e.indexOf(" ")))?"viru "+e:"virun "+e},s:"e puer Sekonnen",ss:"%d Sekonnen",m:Rn,mm:"%d Minutten",h:Rn,hh:"%d Stonnen",d:Rn,dd:"%d Deeg",M:Rn,MM:"%d Méint",y:Rn,yy:"%d Joer"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("lo",{months:"ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ".split("_"),monthsShort:"ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ".split("_"),weekdays:"ອາທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ".split("_"),weekdaysShort:"ທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ".split("_"),weekdaysMin:"ທ_ຈ_ອຄ_ພ_ພຫ_ສກ_ສ".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"ວັນdddd D MMMM YYYY HH:mm"},meridiemParse:/\u0e95\u0ead\u0e99\u0ec0\u0e8a\u0ebb\u0ec9\u0eb2|\u0e95\u0ead\u0e99\u0ec1\u0ea5\u0e87/,isPM:function(e){return"ຕອນແລງ"===e},meridiem:function(e,t,i){return e<12?"ຕອນເຊົ້າ":"ຕອນແລງ"},calendar:{sameDay:"[ມື້ນີ້ເວລາ] LT",nextDay:"[ມື້ອື່ນເວລາ] LT",nextWeek:"[ວັນ]dddd[ໜ້າເວລາ] LT",lastDay:"[ມື້ວານນີ້ເວລາ] LT",lastWeek:"[ວັນ]dddd[ແລ້ວນີ້ເວລາ] LT",sameElse:"L"},relativeTime:{future:"ອີກ %s",past:"%sຜ່ານມາ",s:"ບໍ່ເທົ່າໃດວິນາທີ",ss:"%d ວິນາທີ",m:"1 ນາທີ",mm:"%d ນາທີ",h:"1 ຊົ່ວໂມງ",hh:"%d ຊົ່ວໂມງ",d:"1 ມື້",dd:"%d ມື້",M:"1 ເດືອນ",MM:"%d ເດືອນ",y:"1 ປີ",yy:"%d ປີ"},dayOfMonthOrdinalParse:/(\u0e97\u0eb5\u0ec8)\d{1,2}/,ordinal:function(e){return"ທີ່"+e}});var Bn={ss:"sekundė_sekundžių_sekundes",m:"minutė_minutės_minutę",mm:"minutės_minučių_minutes",h:"valanda_valandos_valandą",hh:"valandos_valandų_valandas",d:"diena_dienos_dieną",dd:"dienos_dienų_dienas",M:"mėnuo_mėnesio_mėnesį",MM:"mėnesiai_mėnesių_mėnesius",y:"metai_metų_metus",yy:"metai_metų_metus"};function Vn(e,t,i,n){return t?Un(i)[0]:n?Un(i)[1]:Un(i)[2]}function Wn(e){return e%10==0||10<e&&e<20}function Un(e){return Bn[e].split("_")}function qn(e,t,i,n){var r=e+" ";return 1===e?r+Vn(0,t,i[0],n):t?r+(Wn(e)?Un(i)[1]:Un(i)[0]):n?r+Un(i)[1]:r+(Wn(e)?Un(i)[1]:Un(i)[2])}t.defineLocale("lt",{months:{format:"sausio_vasario_kovo_balandžio_gegužės_birželio_liepos_rugpjūčio_rugsėjo_spalio_lapkričio_gruodžio".split("_"),standalone:"sausis_vasaris_kovas_balandis_gegužė_birželis_liepa_rugpjūtis_rugsėjis_spalis_lapkritis_gruodis".split("_"),isFormat:/D[oD]?(\[[^\[\]]*\]|\s)+MMMM?|MMMM?(\[[^\[\]]*\]|\s)+D[oD]?/},monthsShort:"sau_vas_kov_bal_geg_bir_lie_rgp_rgs_spa_lap_grd".split("_"),weekdays:{format:"sekmadienį_pirmadienį_antradienį_trečiadienį_ketvirtadienį_penktadienį_šeštadienį".split("_"),standalone:"sekmadienis_pirmadienis_antradienis_trečiadienis_ketvirtadienis_penktadienis_šeštadienis".split("_"),isFormat:/dddd HH:mm/},weekdaysShort:"Sek_Pir_Ant_Tre_Ket_Pen_Šeš".split("_"),weekdaysMin:"S_P_A_T_K_Pn_Š".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY [m.] MMMM D [d.]",LLL:"YYYY [m.] MMMM D [d.], HH:mm [val.]",LLLL:"YYYY [m.] MMMM D [d.], dddd, HH:mm [val.]",l:"YYYY-MM-DD",ll:"YYYY [m.] MMMM D [d.]",lll:"YYYY [m.] MMMM D [d.], HH:mm [val.]",llll:"YYYY [m.] MMMM D [d.], ddd, HH:mm [val.]"},calendar:{sameDay:"[Šiandien] LT",nextDay:"[Rytoj] LT",nextWeek:"dddd LT",lastDay:"[Vakar] LT",lastWeek:"[Praėjusį] dddd LT",sameElse:"L"},relativeTime:{future:"po %s",past:"prieš %s",s:function(e,t,i,n){return t?"kelios sekundės":n?"kelių sekundžių":"kelias sekundes"},ss:qn,m:Vn,mm:qn,h:Vn,hh:qn,d:Vn,dd:qn,M:Vn,MM:qn,y:Vn,yy:qn},dayOfMonthOrdinalParse:/\d{1,2}-oji/,ordinal:function(e){return e+"-oji"},week:{dow:1,doy:4}});var $n={ss:"sekundes_sekundēm_sekunde_sekundes".split("_"),m:"minūtes_minūtēm_minūte_minūtes".split("_"),mm:"minūtes_minūtēm_minūte_minūtes".split("_"),h:"stundas_stundām_stunda_stundas".split("_"),hh:"stundas_stundām_stunda_stundas".split("_"),d:"dienas_dienām_diena_dienas".split("_"),dd:"dienas_dienām_diena_dienas".split("_"),M:"mēneša_mēnešiem_mēnesis_mēneši".split("_"),MM:"mēneša_mēnešiem_mēnesis_mēneši".split("_"),y:"gada_gadiem_gads_gadi".split("_"),yy:"gada_gadiem_gads_gadi".split("_")};function Xn(e,t,i){return i?t%10==1&&t%100!=11?e[2]:e[3]:t%10==1&&t%100!=11?e[0]:e[1]}function Gn(e,t,i){return e+" "+Xn($n[i],e,t)}function Zn(e,t,i){return Xn($n[i],e,t)}t.defineLocale("lv",{months:"janvāris_februāris_marts_aprīlis_maijs_jūnijs_jūlijs_augusts_septembris_oktobris_novembris_decembris".split("_"),monthsShort:"jan_feb_mar_apr_mai_jūn_jūl_aug_sep_okt_nov_dec".split("_"),weekdays:"svētdiena_pirmdiena_otrdiena_trešdiena_ceturtdiena_piektdiena_sestdiena".split("_"),weekdaysShort:"Sv_P_O_T_C_Pk_S".split("_"),weekdaysMin:"Sv_P_O_T_C_Pk_S".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY.",LL:"YYYY. [gada] D. MMMM",LLL:"YYYY. [gada] D. MMMM, HH:mm",LLLL:"YYYY. [gada] D. MMMM, dddd, HH:mm"},calendar:{sameDay:"[Šodien pulksten] LT",nextDay:"[Rīt pulksten] LT",nextWeek:"dddd [pulksten] LT",lastDay:"[Vakar pulksten] LT",lastWeek:"[Pagājušā] dddd [pulksten] LT",sameElse:"L"},relativeTime:{future:"pēc %s",past:"pirms %s",s:function(e,t){return t?"dažas sekundes":"dažām sekundēm"},ss:Gn,m:Zn,mm:Gn,h:Zn,hh:Gn,d:Zn,dd:Gn,M:Zn,MM:Gn,y:Zn,yy:Gn},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}});var Kn={words:{ss:["sekund","sekunda","sekundi"],m:["jedan minut","jednog minuta"],mm:["minut","minuta","minuta"],h:["jedan sat","jednog sata"],hh:["sat","sata","sati"],dd:["dan","dana","dana"],MM:["mjesec","mjeseca","mjeseci"],yy:["godina","godine","godina"]},correctGrammaticalCase:function(e,t){return 1===e?t[0]:2<=e&&e<=4?t[1]:t[2]},translate:function(e,t,i){var n=Kn.words[i];return 1===i.length?t?n[0]:n[1]:e+" "+Kn.correctGrammaticalCase(e,n)}};function Jn(e,t,i,n){switch(i){case"s":return t?"хэдхэн секунд":"хэдхэн секундын";case"ss":return e+(t?" секунд":" секундын");case"m":case"mm":return e+(t?" минут":" минутын");case"h":case"hh":return e+(t?" цаг":" цагийн");case"d":case"dd":return e+(t?" өдөр":" өдрийн");case"M":case"MM":return e+(t?" сар":" сарын");case"y":case"yy":return e+(t?" жил":" жилийн");default:return e}}t.defineLocale("me",{months:"januar_februar_mart_april_maj_jun_jul_avgust_septembar_oktobar_novembar_decembar".split("_"),monthsShort:"jan._feb._mar._apr._maj_jun_jul_avg._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sri._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sjutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedjelju] [u] LT";case 3:return"[u] [srijedu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[juče u] LT",lastWeek:function(){return["[prošle] [nedjelje] [u] LT","[prošlog] [ponedjeljka] [u] LT","[prošlog] [utorka] [u] LT","[prošle] [srijede] [u] LT","[prošlog] [četvrtka] [u] LT","[prošlog] [petka] [u] LT","[prošle] [subote] [u] LT"][this.day()]},sameElse:"L"},relativeTime:{future:"za %s",past:"prije %s",s:"nekoliko sekundi",ss:Kn.translate,m:Kn.translate,mm:Kn.translate,h:Kn.translate,hh:Kn.translate,d:"dan",dd:Kn.translate,M:"mjesec",MM:Kn.translate,y:"godinu",yy:Kn.translate},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}}),t.defineLocale("mi",{months:"Kohi-tāte_Hui-tanguru_Poutū-te-rangi_Paenga-whāwhā_Haratua_Pipiri_Hōngoingoi_Here-turi-kōkā_Mahuru_Whiringa-ā-nuku_Whiringa-ā-rangi_Hakihea".split("_"),monthsShort:"Kohi_Hui_Pou_Pae_Hara_Pipi_Hōngoi_Here_Mahu_Whi-nu_Whi-ra_Haki".split("_"),monthsRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,monthsStrictRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,monthsShortRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,monthsShortStrictRegex:/(?:['a-z\u0101\u014D\u016B]+\-?){1,2}/i,weekdays:"Rātapu_Mane_Tūrei_Wenerei_Tāite_Paraire_Hātarei".split("_"),weekdaysShort:"Ta_Ma_Tū_We_Tāi_Pa_Hā".split("_"),weekdaysMin:"Ta_Ma_Tū_We_Tāi_Pa_Hā".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [i] HH:mm",LLLL:"dddd, D MMMM YYYY [i] HH:mm"},calendar:{sameDay:"[i teie mahana, i] LT",nextDay:"[apopo i] LT",nextWeek:"dddd [i] LT",lastDay:"[inanahi i] LT",lastWeek:"dddd [whakamutunga i] LT",sameElse:"L"},relativeTime:{future:"i roto i %s",past:"%s i mua",s:"te hēkona ruarua",ss:"%d hēkona",m:"he meneti",mm:"%d meneti",h:"te haora",hh:"%d haora",d:"he ra",dd:"%d ra",M:"he marama",MM:"%d marama",y:"he tau",yy:"%d tau"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4}}),t.defineLocale("mk",{months:"јануари_февруари_март_април_мај_јуни_јули_август_септември_октомври_ноември_декември".split("_"),monthsShort:"јан_фев_мар_апр_мај_јун_јул_авг_сеп_окт_ное_дек".split("_"),weekdays:"недела_понеделник_вторник_среда_четврток_петок_сабота".split("_"),weekdaysShort:"нед_пон_вто_сре_чет_пет_саб".split("_"),weekdaysMin:"нe_пo_вт_ср_че_пе_сa".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY H:mm",LLLL:"dddd, D MMMM YYYY H:mm"},calendar:{sameDay:"[Денес во] LT",nextDay:"[Утре во] LT",nextWeek:"[Во] dddd [во] LT",lastDay:"[Вчера во] LT",lastWeek:function(){switch(this.day()){case 0:case 3:case 6:return"[Изминатата] dddd [во] LT";case 1:case 2:case 4:case 5:return"[Изминатиот] dddd [во] LT"}},sameElse:"L"},relativeTime:{future:"за %s",past:"пред %s",s:"неколку секунди",ss:"%d секунди",m:"една минута",mm:"%d минути",h:"еден час",hh:"%d часа",d:"еден ден",dd:"%d дена",M:"еден месец",MM:"%d месеци",y:"една година",yy:"%d години"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0435\u0432|\u0435\u043d|\u0442\u0438|\u0432\u0438|\u0440\u0438|\u043c\u0438)/,ordinal:function(e){var t=e%10,i=e%100;return 0===e?e+"-ев":0==i?e+"-ен":10<i&&i<20?e+"-ти":1==t?e+"-ви":2==t?e+"-ри":7==t||8==t?e+"-ми":e+"-ти"},week:{dow:1,doy:7}}),t.defineLocale("ml",{months:"ജനുവരി_ഫെബ്രുവരി_മാർച്ച്_ഏപ്രിൽ_മേയ്_ജൂൺ_ജൂലൈ_ഓഗസ്റ്റ്_സെപ്റ്റംബർ_ഒക്ടോബർ_നവംബർ_ഡിസംബർ".split("_"),monthsShort:"ജനു._ഫെബ്രു._മാർ._ഏപ്രി._മേയ്_ജൂൺ_ജൂലൈ._ഓഗ._സെപ്റ്റ._ഒക്ടോ._നവം._ഡിസം.".split("_"),monthsParseExact:!0,weekdays:"ഞായറാഴ്ച_തിങ്കളാഴ്ച_ചൊവ്വാഴ്ച_ബുധനാഴ്ച_വ്യാഴാഴ്ച_വെള്ളിയാഴ്ച_ശനിയാഴ്ച".split("_"),weekdaysShort:"ഞായർ_തിങ്കൾ_ചൊവ്വ_ബുധൻ_വ്യാഴം_വെള്ളി_ശനി".split("_"),weekdaysMin:"ഞാ_തി_ചൊ_ബു_വ്യാ_വെ_ശ".split("_"),longDateFormat:{LT:"A h:mm -നു",LTS:"A h:mm:ss -നു",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm -നു",LLLL:"dddd, D MMMM YYYY, A h:mm -നു"},calendar:{sameDay:"[ഇന്ന്] LT",nextDay:"[നാളെ] LT",nextWeek:"dddd, LT",lastDay:"[ഇന്നലെ] LT",lastWeek:"[കഴിഞ്ഞ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s കഴിഞ്ഞ്",past:"%s മുൻപ്",s:"അൽപ നിമിഷങ്ങൾ",ss:"%d സെക്കൻഡ്",m:"ഒരു മിനിറ്റ്",mm:"%d മിനിറ്റ്",h:"ഒരു മണിക്കൂർ",hh:"%d മണിക്കൂർ",d:"ഒരു ദിവസം",dd:"%d ദിവസം",M:"ഒരു മാസം",MM:"%d മാസം",y:"ഒരു വർഷം",yy:"%d വർഷം"},meridiemParse:/\u0d30\u0d3e\u0d24\u0d4d\u0d30\u0d3f|\u0d30\u0d3e\u0d35\u0d3f\u0d32\u0d46|\u0d09\u0d1a\u0d4d\u0d1a \u0d15\u0d34\u0d3f\u0d1e\u0d4d\u0d1e\u0d4d|\u0d35\u0d48\u0d15\u0d41\u0d28\u0d4d\u0d28\u0d47\u0d30\u0d02|\u0d30\u0d3e\u0d24\u0d4d\u0d30\u0d3f/i,meridiemHour:function(e,t){return 12===e&&(e=0),"രാത്രി"===t&&4<=e||"ഉച്ച കഴിഞ്ഞ്"===t||"വൈകുന്നേരം"===t?e+12:e},meridiem:function(e,t,i){return e<4?"രാത്രി":e<12?"രാവിലെ":e<17?"ഉച്ച കഴിഞ്ഞ്":e<20?"വൈകുന്നേരം":"രാത്രി"}}),t.defineLocale("mn",{months:"Нэгдүгээр сар_Хоёрдугаар сар_Гуравдугаар сар_Дөрөвдүгээр сар_Тавдугаар сар_Зургадугаар сар_Долдугаар сар_Наймдугаар сар_Есдүгээр сар_Аравдугаар сар_Арван нэгдүгээр сар_Арван хоёрдугаар сар".split("_"),monthsShort:"1 сар_2 сар_3 сар_4 сар_5 сар_6 сар_7 сар_8 сар_9 сар_10 сар_11 сар_12 сар".split("_"),monthsParseExact:!0,weekdays:"Ням_Даваа_Мягмар_Лхагва_Пүрэв_Баасан_Бямба".split("_"),weekdaysShort:"Ням_Дав_Мяг_Лха_Пүр_Баа_Бям".split("_"),weekdaysMin:"Ня_Да_Мя_Лх_Пү_Ба_Бя".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY оны MMMMын D",LLL:"YYYY оны MMMMын D HH:mm",LLLL:"dddd, YYYY оны MMMMын D HH:mm"},meridiemParse:/\u04ae\u04e8|\u04ae\u0425/i,isPM:function(e){return"ҮХ"===e},meridiem:function(e,t,i){return e<12?"ҮӨ":"ҮХ"},calendar:{sameDay:"[Өнөөдөр] LT",nextDay:"[Маргааш] LT",nextWeek:"[Ирэх] dddd LT",lastDay:"[Өчигдөр] LT",lastWeek:"[Өнгөрсөн] dddd LT",sameElse:"L"},relativeTime:{future:"%s дараа",past:"%s өмнө",s:Jn,ss:Jn,m:Jn,mm:Jn,h:Jn,hh:Jn,d:Jn,dd:Jn,M:Jn,MM:Jn,y:Jn,yy:Jn},dayOfMonthOrdinalParse:/\d{1,2} \u04e9\u0434\u04e9\u0440/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+" өдөр";default:return e}}});var Qn={1:"१",2:"२",3:"३",4:"४",5:"५",6:"६",7:"७",8:"८",9:"९",0:"०"},er={"१":"1","२":"2","३":"3","४":"4","५":"5","६":"6","७":"7","८":"8","९":"9","०":"0"};function tr(e,t,i,n){var r="";if(t)switch(i){case"s":r="काही सेकंद";break;case"ss":r="%d सेकंद";break;case"m":r="एक मिनिट";break;case"mm":r="%d मिनिटे";break;case"h":r="एक तास";break;case"hh":r="%d तास";break;case"d":r="एक दिवस";break;case"dd":r="%d दिवस";break;case"M":r="एक महिना";break;case"MM":r="%d महिने";break;case"y":r="एक वर्ष";break;case"yy":r="%d वर्षे"}else switch(i){case"s":r="काही सेकंदां";break;case"ss":r="%d सेकंदां";break;case"m":r="एका मिनिटा";break;case"mm":r="%d मिनिटां";break;case"h":r="एका तासा";break;case"hh":r="%d तासां";break;case"d":r="एका दिवसा";break;case"dd":r="%d दिवसां";break;case"M":r="एका महिन्या";break;case"MM":r="%d महिन्यां";break;case"y":r="एका वर्षा";break;case"yy":r="%d वर्षां"}return r.replace(/%d/i,e)}t.defineLocale("mr",{months:"जानेवारी_फेब्रुवारी_मार्च_एप्रिल_मे_जून_जुलै_ऑगस्ट_सप्टेंबर_ऑक्टोबर_नोव्हेंबर_डिसेंबर".split("_"),monthsShort:"जाने._फेब्रु._मार्च._एप्रि._मे._जून._जुलै._ऑग._सप्टें._ऑक्टो._नोव्हें._डिसें.".split("_"),monthsParseExact:!0,weekdays:"रविवार_सोमवार_मंगळवार_बुधवार_गुरूवार_शुक्रवार_शनिवार".split("_"),weekdaysShort:"रवि_सोम_मंगळ_बुध_गुरू_शुक्र_शनि".split("_"),weekdaysMin:"र_सो_मं_बु_गु_शु_श".split("_"),longDateFormat:{LT:"A h:mm वाजता",LTS:"A h:mm:ss वाजता",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm वाजता",LLLL:"dddd, D MMMM YYYY, A h:mm वाजता"},calendar:{sameDay:"[आज] LT",nextDay:"[उद्या] LT",nextWeek:"dddd, LT",lastDay:"[काल] LT",lastWeek:"[मागील] dddd, LT",sameElse:"L"},relativeTime:{future:"%sमध्ये",past:"%sपूर्वी",s:tr,ss:tr,m:tr,mm:tr,h:tr,hh:tr,d:tr,dd:tr,M:tr,MM:tr,y:tr,yy:tr},preparse:function(e){return e.replace(/[\u0967\u0968\u0969\u096a\u096b\u096c\u096d\u096e\u096f\u0966]/g,(function(e){return er[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return Qn[e]}))},meridiemParse:/\u092a\u0939\u093e\u091f\u0947|\u0938\u0915\u093e\u0933\u0940|\u0926\u0941\u092a\u093e\u0930\u0940|\u0938\u093e\u092f\u0902\u0915\u093e\u0933\u0940|\u0930\u093e\u0924\u094d\u0930\u0940/,meridiemHour:function(e,t){return 12===e&&(e=0),"पहाटे"===t||"सकाळी"===t?e:"दुपारी"===t||"सायंकाळी"===t||"रात्री"===t?12<=e?e:e+12:void 0},meridiem:function(e,t,i){return 0<=e&&e<6?"पहाटे":e<12?"सकाळी":e<17?"दुपारी":e<20?"सायंकाळी":"रात्री"},week:{dow:0,doy:6}}),t.defineLocale("ms-my",{months:"Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember".split("_"),monthsShort:"Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis".split("_"),weekdays:"Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu".split("_"),weekdaysShort:"Ahd_Isn_Sel_Rab_Kha_Jum_Sab".split("_"),weekdaysMin:"Ah_Is_Sl_Rb_Km_Jm_Sb".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/pagi|tengahari|petang|malam/,meridiemHour:function(e,t){return 12===e&&(e=0),"pagi"===t?e:"tengahari"===t?11<=e?e:e+12:"petang"===t||"malam"===t?e+12:void 0},meridiem:function(e,t,i){return e<11?"pagi":e<15?"tengahari":e<19?"petang":"malam"},calendar:{sameDay:"[Hari ini pukul] LT",nextDay:"[Esok pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kelmarin pukul] LT",lastWeek:"dddd [lepas pukul] LT",sameElse:"L"},relativeTime:{future:"dalam %s",past:"%s yang lepas",s:"beberapa saat",ss:"%d saat",m:"seminit",mm:"%d minit",h:"sejam",hh:"%d jam",d:"sehari",dd:"%d hari",M:"sebulan",MM:"%d bulan",y:"setahun",yy:"%d tahun"},week:{dow:1,doy:7}}),t.defineLocale("ms",{months:"Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember".split("_"),monthsShort:"Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis".split("_"),weekdays:"Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu".split("_"),weekdaysShort:"Ahd_Isn_Sel_Rab_Kha_Jum_Sab".split("_"),weekdaysMin:"Ah_Is_Sl_Rb_Km_Jm_Sb".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [pukul] HH.mm",LLLL:"dddd, D MMMM YYYY [pukul] HH.mm"},meridiemParse:/pagi|tengahari|petang|malam/,meridiemHour:function(e,t){return 12===e&&(e=0),"pagi"===t?e:"tengahari"===t?11<=e?e:e+12:"petang"===t||"malam"===t?e+12:void 0},meridiem:function(e,t,i){return e<11?"pagi":e<15?"tengahari":e<19?"petang":"malam"},calendar:{sameDay:"[Hari ini pukul] LT",nextDay:"[Esok pukul] LT",nextWeek:"dddd [pukul] LT",lastDay:"[Kelmarin pukul] LT",lastWeek:"dddd [lepas pukul] LT",sameElse:"L"},relativeTime:{future:"dalam %s",past:"%s yang lepas",s:"beberapa saat",ss:"%d saat",m:"seminit",mm:"%d minit",h:"sejam",hh:"%d jam",d:"sehari",dd:"%d hari",M:"sebulan",MM:"%d bulan",y:"setahun",yy:"%d tahun"},week:{dow:1,doy:7}}),t.defineLocale("mt",{months:"Jannar_Frar_Marzu_April_Mejju_Ġunju_Lulju_Awwissu_Settembru_Ottubru_Novembru_Diċembru".split("_"),monthsShort:"Jan_Fra_Mar_Apr_Mej_Ġun_Lul_Aww_Set_Ott_Nov_Diċ".split("_"),weekdays:"Il-Ħadd_It-Tnejn_It-Tlieta_L-Erbgħa_Il-Ħamis_Il-Ġimgħa_Is-Sibt".split("_"),weekdaysShort:"Ħad_Tne_Tli_Erb_Ħam_Ġim_Sib".split("_"),weekdaysMin:"Ħa_Tn_Tl_Er_Ħa_Ġi_Si".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Illum fil-]LT",nextDay:"[Għada fil-]LT",nextWeek:"dddd [fil-]LT",lastDay:"[Il-bieraħ fil-]LT",lastWeek:"dddd [li għadda] [fil-]LT",sameElse:"L"},relativeTime:{future:"f’ %s",past:"%s ilu",s:"ftit sekondi",ss:"%d sekondi",m:"minuta",mm:"%d minuti",h:"siegħa",hh:"%d siegħat",d:"ġurnata",dd:"%d ġranet",M:"xahar",MM:"%d xhur",y:"sena",yy:"%d sni"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4}});var ir={1:"၁",2:"၂",3:"၃",4:"၄",5:"၅",6:"၆",7:"၇",8:"၈",9:"၉",0:"၀"},nr={"၁":"1","၂":"2","၃":"3","၄":"4","၅":"5","၆":"6","၇":"7","၈":"8","၉":"9","၀":"0"},rr=(t.defineLocale("my",{months:"ဇန်နဝါရီ_ဖေဖော်ဝါရီ_မတ်_ဧပြီ_မေ_ဇွန်_ဇူလိုင်_သြဂုတ်_စက်တင်ဘာ_အောက်တိုဘာ_နိုဝင်ဘာ_ဒီဇင်ဘာ".split("_"),monthsShort:"ဇန်_ဖေ_မတ်_ပြီ_မေ_ဇွန်_လိုင်_သြ_စက်_အောက်_နို_ဒီ".split("_"),weekdays:"တနင်္ဂနွေ_တနင်္လာ_အင်္ဂါ_ဗုဒ္ဓဟူး_ကြာသပတေး_သောကြာ_စနေ".split("_"),weekdaysShort:"နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ".split("_"),weekdaysMin:"နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[ယနေ.] LT [မှာ]",nextDay:"[မနက်ဖြန်] LT [မှာ]",nextWeek:"dddd LT [မှာ]",lastDay:"[မနေ.က] LT [မှာ]",lastWeek:"[ပြီးခဲ့သော] dddd LT [မှာ]",sameElse:"L"},relativeTime:{future:"လာမည့် %s မှာ",past:"လွန်ခဲ့သော %s က",s:"စက္ကန်.အနည်းငယ်",ss:"%d စက္ကန့်",m:"တစ်မိနစ်",mm:"%d မိနစ်",h:"တစ်နာရီ",hh:"%d နာရီ",d:"တစ်ရက်",dd:"%d ရက်",M:"တစ်လ",MM:"%d လ",y:"တစ်နှစ်",yy:"%d နှစ်"},preparse:function(e){return e.replace(/[\u1041\u1042\u1043\u1044\u1045\u1046\u1047\u1048\u1049\u1040]/g,(function(e){return nr[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return ir[e]}))},week:{dow:1,doy:4}}),t.defineLocale("nb",{months:"januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember".split("_"),monthsShort:"jan._feb._mars_apr._mai_juni_juli_aug._sep._okt._nov._des.".split("_"),monthsParseExact:!0,weekdays:"søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag".split("_"),weekdaysShort:"sø._ma._ti._on._to._fr._lø.".split("_"),weekdaysMin:"sø_ma_ti_on_to_fr_lø".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY [kl.] HH:mm",LLLL:"dddd D. MMMM YYYY [kl.] HH:mm"},calendar:{sameDay:"[i dag kl.] LT",nextDay:"[i morgen kl.] LT",nextWeek:"dddd [kl.] LT",lastDay:"[i går kl.] LT",lastWeek:"[forrige] dddd [kl.] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"%s siden",s:"noen sekunder",ss:"%d sekunder",m:"ett minutt",mm:"%d minutter",h:"én time",hh:"%d timer",d:"én dag",dd:"%d dager",w:"én uke",ww:"%d uker",M:"én måned",MM:"%d måneder",y:"ett år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),{1:"१",2:"२",3:"३",4:"४",5:"५",6:"६",7:"७",8:"८",9:"९",0:"०"}),ar={"१":"1","२":"2","३":"3","४":"4","५":"5","६":"6","७":"7","८":"8","९":"9","०":"0"},sr=(t.defineLocale("ne",{months:"जनवरी_फेब्रुवरी_मार्च_अप्रिल_मई_जुन_जुलाई_अगष्ट_सेप्टेम्बर_अक्टोबर_नोभेम्बर_डिसेम्बर".split("_"),monthsShort:"जन._फेब्रु._मार्च_अप्रि._मई_जुन_जुलाई._अग._सेप्ट._अक्टो._नोभे._डिसे.".split("_"),monthsParseExact:!0,weekdays:"आइतबार_सोमबार_मङ्गलबार_बुधबार_बिहिबार_शुक्रबार_शनिबार".split("_"),weekdaysShort:"आइत._सोम._मङ्गल._बुध._बिहि._शुक्र._शनि.".split("_"),weekdaysMin:"आ._सो._मं._बु._बि._शु._श.".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"Aको h:mm बजे",LTS:"Aको h:mm:ss बजे",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, Aको h:mm बजे",LLLL:"dddd, D MMMM YYYY, Aको h:mm बजे"},preparse:function(e){return e.replace(/[\u0967\u0968\u0969\u096a\u096b\u096c\u096d\u096e\u096f\u0966]/g,(function(e){return ar[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return rr[e]}))},meridiemParse:/\u0930\u093e\u0924\u093f|\u092c\u093f\u0939\u093e\u0928|\u0926\u093f\u0909\u0901\u0938\u094b|\u0938\u093e\u0901\u091d/,meridiemHour:function(e,t){return 12===e&&(e=0),"राति"===t?e<4?e:e+12:"बिहान"===t?e:"दिउँसो"===t?10<=e?e:e+12:"साँझ"===t?e+12:void 0},meridiem:function(e,t,i){return e<3?"राति":e<12?"बिहान":e<16?"दिउँसो":e<20?"साँझ":"राति"},calendar:{sameDay:"[आज] LT",nextDay:"[भोलि] LT",nextWeek:"[आउँदो] dddd[,] LT",lastDay:"[हिजो] LT",lastWeek:"[गएको] dddd[,] LT",sameElse:"L"},relativeTime:{future:"%sमा",past:"%s अगाडि",s:"केही क्षण",ss:"%d सेकेण्ड",m:"एक मिनेट",mm:"%d मिनेट",h:"एक घण्टा",hh:"%d घण्टा",d:"एक दिन",dd:"%d दिन",M:"एक महिना",MM:"%d महिना",y:"एक बर्ष",yy:"%d बर्ष"},week:{dow:0,doy:6}}),"jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.".split("_")),or="jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec".split("_"),lr=(X=[/^jan/i,/^feb/i,/^(maart|mrt\.?)$/i,/^apr/i,/^mei$/i,/^jun[i.]?$/i,/^jul[i.]?$/i,/^aug/i,/^sep/i,/^okt/i,/^nov/i,/^dec/i],Ee=/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december|jan\.?|feb\.?|mrt\.?|apr\.?|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,t.defineLocale("nl-be",{months:"januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december".split("_"),monthsShort:function(e,t){return e?(/-MMM-/.test(t)?or:sr)[e.month()]:sr},monthsRegex:Ee,monthsShortRegex:Ee,monthsStrictRegex:/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december)/i,monthsShortStrictRegex:/^(jan\.?|feb\.?|mrt\.?|apr\.?|mei|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,monthsParse:X,longMonthsParse:X,shortMonthsParse:X,weekdays:"zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag".split("_"),weekdaysShort:"zo._ma._di._wo._do._vr._za.".split("_"),weekdaysMin:"zo_ma_di_wo_do_vr_za".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[vandaag om] LT",nextDay:"[morgen om] LT",nextWeek:"dddd [om] LT",lastDay:"[gisteren om] LT",lastWeek:"[afgelopen] dddd [om] LT",sameElse:"L"},relativeTime:{future:"over %s",past:"%s geleden",s:"een paar seconden",ss:"%d seconden",m:"één minuut",mm:"%d minuten",h:"één uur",hh:"%d uur",d:"één dag",dd:"%d dagen",M:"één maand",MM:"%d maanden",y:"één jaar",yy:"%d jaar"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||20<=e?"ste":"de")},week:{dow:1,doy:4}}),"jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.".split("_")),cr="jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec".split("_"),ur=(V=[/^jan/i,/^feb/i,/^(maart|mrt\.?)$/i,/^apr/i,/^mei$/i,/^jun[i.]?$/i,/^jul[i.]?$/i,/^aug/i,/^sep/i,/^okt/i,/^nov/i,/^dec/i],$=/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december|jan\.?|feb\.?|mrt\.?|apr\.?|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,t.defineLocale("nl",{months:"januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december".split("_"),monthsShort:function(e,t){return e?(/-MMM-/.test(t)?cr:lr)[e.month()]:lr},monthsRegex:$,monthsShortRegex:$,monthsStrictRegex:/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december)/i,monthsShortStrictRegex:/^(jan\.?|feb\.?|mrt\.?|apr\.?|mei|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,monthsParse:V,longMonthsParse:V,shortMonthsParse:V,weekdays:"zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag".split("_"),weekdaysShort:"zo._ma._di._wo._do._vr._za.".split("_"),weekdaysMin:"zo_ma_di_wo_do_vr_za".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[vandaag om] LT",nextDay:"[morgen om] LT",nextWeek:"dddd [om] LT",lastDay:"[gisteren om] LT",lastWeek:"[afgelopen] dddd [om] LT",sameElse:"L"},relativeTime:{future:"over %s",past:"%s geleden",s:"een paar seconden",ss:"%d seconden",m:"één minuut",mm:"%d minuten",h:"één uur",hh:"%d uur",d:"één dag",dd:"%d dagen",w:"één week",ww:"%d weken",M:"één maand",MM:"%d maanden",y:"één jaar",yy:"%d jaar"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(e){return e+(1===e||8===e||20<=e?"ste":"de")},week:{dow:1,doy:4}}),t.defineLocale("nn",{months:"januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember".split("_"),monthsShort:"jan._feb._mars_apr._mai_juni_juli_aug._sep._okt._nov._des.".split("_"),monthsParseExact:!0,weekdays:"sundag_måndag_tysdag_onsdag_torsdag_fredag_laurdag".split("_"),weekdaysShort:"su._må._ty._on._to._fr._lau.".split("_"),weekdaysMin:"su_må_ty_on_to_fr_la".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY [kl.] H:mm",LLLL:"dddd D. MMMM YYYY [kl.] HH:mm"},calendar:{sameDay:"[I dag klokka] LT",nextDay:"[I morgon klokka] LT",nextWeek:"dddd [klokka] LT",lastDay:"[I går klokka] LT",lastWeek:"[Føregåande] dddd [klokka] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"%s sidan",s:"nokre sekund",ss:"%d sekund",m:"eit minutt",mm:"%d minutt",h:"ein time",hh:"%d timar",d:"ein dag",dd:"%d dagar",w:"ei veke",ww:"%d veker",M:"ein månad",MM:"%d månader",y:"eit år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("oc-lnc",{months:{standalone:"genièr_febrièr_març_abril_mai_junh_julhet_agost_setembre_octòbre_novembre_decembre".split("_"),format:"de genièr_de febrièr_de març_d'abril_de mai_de junh_de julhet_d'agost_de setembre_d'octòbre_de novembre_de decembre".split("_"),isFormat:/D[oD]?(\s)+MMMM/},monthsShort:"gen._febr._març_abr._mai_junh_julh._ago._set._oct._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"dimenge_diluns_dimars_dimècres_dijòus_divendres_dissabte".split("_"),weekdaysShort:"dg._dl._dm._dc._dj._dv._ds.".split("_"),weekdaysMin:"dg_dl_dm_dc_dj_dv_ds".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM [de] YYYY",ll:"D MMM YYYY",LLL:"D MMMM [de] YYYY [a] H:mm",lll:"D MMM YYYY, H:mm",LLLL:"dddd D MMMM [de] YYYY [a] H:mm",llll:"ddd D MMM YYYY, H:mm"},calendar:{sameDay:"[uèi a] LT",nextDay:"[deman a] LT",nextWeek:"dddd [a] LT",lastDay:"[ièr a] LT",lastWeek:"dddd [passat a] LT",sameElse:"L"},relativeTime:{future:"d'aquí %s",past:"fa %s",s:"unas segondas",ss:"%d segondas",m:"una minuta",mm:"%d minutas",h:"una ora",hh:"%d oras",d:"un jorn",dd:"%d jorns",M:"un mes",MM:"%d meses",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(r|n|t|\xe8|a)/,ordinal:function(e,t){return e+("w"!==t&&"W"!==t?1===e?"r":2===e?"n":3===e?"r":4===e?"t":"è":"a")},week:{dow:1,doy:4}}),{1:"੧",2:"੨",3:"੩",4:"੪",5:"੫",6:"੬",7:"੭",8:"੮",9:"੯",0:"੦"}),dr={"੧":"1","੨":"2","੩":"3","੪":"4","੫":"5","੬":"6","੭":"7","੮":"8","੯":"9","੦":"0"},hr=(t.defineLocale("pa-in",{months:"ਜਨਵਰੀ_ਫ਼ਰਵਰੀ_ਮਾਰਚ_ਅਪ੍ਰੈਲ_ਮਈ_ਜੂਨ_ਜੁਲਾਈ_ਅਗਸਤ_ਸਤੰਬਰ_ਅਕਤੂਬਰ_ਨਵੰਬਰ_ਦਸੰਬਰ".split("_"),monthsShort:"ਜਨਵਰੀ_ਫ਼ਰਵਰੀ_ਮਾਰਚ_ਅਪ੍ਰੈਲ_ਮਈ_ਜੂਨ_ਜੁਲਾਈ_ਅਗਸਤ_ਸਤੰਬਰ_ਅਕਤੂਬਰ_ਨਵੰਬਰ_ਦਸੰਬਰ".split("_"),weekdays:"ਐਤਵਾਰ_ਸੋਮਵਾਰ_ਮੰਗਲਵਾਰ_ਬੁਧਵਾਰ_ਵੀਰਵਾਰ_ਸ਼ੁੱਕਰਵਾਰ_ਸ਼ਨੀਚਰਵਾਰ".split("_"),weekdaysShort:"ਐਤ_ਸੋਮ_ਮੰਗਲ_ਬੁਧ_ਵੀਰ_ਸ਼ੁਕਰ_ਸ਼ਨੀ".split("_"),weekdaysMin:"ਐਤ_ਸੋਮ_ਮੰਗਲ_ਬੁਧ_ਵੀਰ_ਸ਼ੁਕਰ_ਸ਼ਨੀ".split("_"),longDateFormat:{LT:"A h:mm ਵਜੇ",LTS:"A h:mm:ss ਵਜੇ",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm ਵਜੇ",LLLL:"dddd, D MMMM YYYY, A h:mm ਵਜੇ"},calendar:{sameDay:"[ਅਜ] LT",nextDay:"[ਕਲ] LT",nextWeek:"[ਅਗਲਾ] dddd, LT",lastDay:"[ਕਲ] LT",lastWeek:"[ਪਿਛਲੇ] dddd, LT",sameElse:"L"},relativeTime:{future:"%s ਵਿੱਚ",past:"%s ਪਿਛਲੇ",s:"ਕੁਝ ਸਕਿੰਟ",ss:"%d ਸਕਿੰਟ",m:"ਇਕ ਮਿੰਟ",mm:"%d ਮਿੰਟ",h:"ਇੱਕ ਘੰਟਾ",hh:"%d ਘੰਟੇ",d:"ਇੱਕ ਦਿਨ",dd:"%d ਦਿਨ",M:"ਇੱਕ ਮਹੀਨਾ",MM:"%d ਮਹੀਨੇ",y:"ਇੱਕ ਸਾਲ",yy:"%d ਸਾਲ"},preparse:function(e){return e.replace(/[\u0a67\u0a68\u0a69\u0a6a\u0a6b\u0a6c\u0a6d\u0a6e\u0a6f\u0a66]/g,(function(e){return dr[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return ur[e]}))},meridiemParse:/\u0a30\u0a3e\u0a24|\u0a38\u0a35\u0a47\u0a30|\u0a26\u0a41\u0a2a\u0a39\u0a3f\u0a30|\u0a38\u0a3c\u0a3e\u0a2e/,meridiemHour:function(e,t){return 12===e&&(e=0),"ਰਾਤ"===t?e<4?e:e+12:"ਸਵੇਰ"===t?e:"ਦੁਪਹਿਰ"===t?10<=e?e:e+12:"ਸ਼ਾਮ"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"ਰਾਤ":e<10?"ਸਵੇਰ":e<17?"ਦੁਪਹਿਰ":e<20?"ਸ਼ਾਮ":"ਰਾਤ"},week:{dow:0,doy:6}}),"styczeń_luty_marzec_kwiecień_maj_czerwiec_lipiec_sierpień_wrzesień_październik_listopad_grudzień".split("_")),fr="stycznia_lutego_marca_kwietnia_maja_czerwca_lipca_sierpnia_września_października_listopada_grudnia".split("_");qe=[/^sty/i,/^lut/i,/^mar/i,/^kwi/i,/^maj/i,/^cze/i,/^lip/i,/^sie/i,/^wrz/i,/^pa\u017a/i,/^lis/i,/^gru/i];function pr(e){return e%10<5&&1<e%10&&~~(e/10)%10!=1}function mr(e,t,i){var n=e+" ";switch(i){case"ss":return n+(pr(e)?"sekundy":"sekund");case"m":return t?"minuta":"minutę";case"mm":return n+(pr(e)?"minuty":"minut");case"h":return t?"godzina":"godzinę";case"hh":return n+(pr(e)?"godziny":"godzin");case"ww":return n+(pr(e)?"tygodnie":"tygodni");case"MM":return n+(pr(e)?"miesiące":"miesięcy");case"yy":return n+(pr(e)?"lata":"lat")}}function gr(e,t,i){return e+(20<=e%100||100<=e&&e%100==0?" de ":" ")+{ss:"secunde",mm:"minute",hh:"ore",dd:"zile",ww:"săptămâni",MM:"luni",yy:"ani"}[i]}function vr(e,t,i){return"m"===i?t?"минута":"минуту":e+" "+(e=+e,t=(t={ss:t?"секунда_секунды_секунд":"секунду_секунды_секунд",mm:t?"минута_минуты_минут":"минуту_минуты_минут",hh:"час_часа_часов",dd:"день_дня_дней",ww:"неделя_недели_недель",MM:"месяц_месяца_месяцев",yy:"год_года_лет"}[i]).split("_"),e%10==1&&e%100!=11?t[0]:2<=e%10&&e%10<=4&&(e%100<10||20<=e%100)?t[1]:t[2])}function yr(e){return 1<e&&e<5}function br(e,t,i,n){var r=e+" ";switch(i){case"s":return t||n?"pár sekúnd":"pár sekundami";case"ss":return t||n?r+(yr(e)?"sekundy":"sekúnd"):r+"sekundami";case"m":return t?"minúta":n?"minútu":"minútou";case"mm":return t||n?r+(yr(e)?"minúty":"minút"):r+"minútami";case"h":return t?"hodina":n?"hodinu":"hodinou";case"hh":return t||n?r+(yr(e)?"hodiny":"hodín"):r+"hodinami";case"d":return t||n?"deň":"dňom";case"dd":return t||n?r+(yr(e)?"dni":"dní"):r+"dňami";case"M":return t||n?"mesiac":"mesiacom";case"MM":return t||n?r+(yr(e)?"mesiace":"mesiacov"):r+"mesiacmi";case"y":return t||n?"rok":"rokom";case"yy":return t||n?r+(yr(e)?"roky":"rokov"):r+"rokmi"}}function xr(e,t,i,n){var r=e+" ";switch(i){case"s":return t||n?"nekaj sekund":"nekaj sekundami";case"ss":return r+(1===e?t?"sekundo":"sekundi":2===e?t||n?"sekundi":"sekundah":e<5?t||n?"sekunde":"sekundah":"sekund");case"m":return t?"ena minuta":"eno minuto";case"mm":return r+(1===e?t?"minuta":"minuto":2===e?t||n?"minuti":"minutama":e<5?t||n?"minute":"minutami":t||n?"minut":"minutami");case"h":return t?"ena ura":"eno uro";case"hh":return r+(1===e?t?"ura":"uro":2===e?t||n?"uri":"urama":e<5?t||n?"ure":"urami":t||n?"ur":"urami");case"d":return t||n?"en dan":"enim dnem";case"dd":return r+(1===e?t||n?"dan":"dnem":2===e?t||n?"dni":"dnevoma":t||n?"dni":"dnevi");case"M":return t||n?"en mesec":"enim mesecem";case"MM":return r+(1===e?t||n?"mesec":"mesecem":2===e?t||n?"meseca":"mesecema":e<5?t||n?"mesece":"meseci":t||n?"mesecev":"meseci");case"y":return t||n?"eno leto":"enim letom";case"yy":return r+(1===e?t||n?"leto":"letom":2===e?t||n?"leti":"letoma":e<5?t||n?"leta":"leti":t||n?"let":"leti")}}t.defineLocale("pl",{months:function(e,t){return e?(/D MMMM/.test(t)?fr:hr)[e.month()]:hr},monthsShort:"sty_lut_mar_kwi_maj_cze_lip_sie_wrz_paź_lis_gru".split("_"),monthsParse:qe,longMonthsParse:qe,shortMonthsParse:qe,weekdays:"niedziela_poniedziałek_wtorek_środa_czwartek_piątek_sobota".split("_"),weekdaysShort:"ndz_pon_wt_śr_czw_pt_sob".split("_"),weekdaysMin:"Nd_Pn_Wt_Śr_Cz_Pt_So".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Dziś o] LT",nextDay:"[Jutro o] LT",nextWeek:function(){switch(this.day()){case 0:return"[W niedzielę o] LT";case 2:return"[We wtorek o] LT";case 3:return"[W środę o] LT";case 6:return"[W sobotę o] LT";default:return"[W] dddd [o] LT"}},lastDay:"[Wczoraj o] LT",lastWeek:function(){switch(this.day()){case 0:return"[W zeszłą niedzielę o] LT";case 3:return"[W zeszłą środę o] LT";case 6:return"[W zeszłą sobotę o] LT";default:return"[W zeszły] dddd [o] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"%s temu",s:"kilka sekund",ss:mr,m:mr,mm:mr,h:mr,hh:mr,d:"1 dzień",dd:"%d dni",w:"tydzień",ww:mr,M:"miesiąc",MM:mr,y:"rok",yy:mr},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("pt-br",{months:"janeiro_fevereiro_março_abril_maio_junho_julho_agosto_setembro_outubro_novembro_dezembro".split("_"),monthsShort:"jan_fev_mar_abr_mai_jun_jul_ago_set_out_nov_dez".split("_"),weekdays:"domingo_segunda-feira_terça-feira_quarta-feira_quinta-feira_sexta-feira_sábado".split("_"),weekdaysShort:"dom_seg_ter_qua_qui_sex_sáb".split("_"),weekdaysMin:"do_2ª_3ª_4ª_5ª_6ª_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY [às] HH:mm",LLLL:"dddd, D [de] MMMM [de] YYYY [às] HH:mm"},calendar:{sameDay:"[Hoje às] LT",nextDay:"[Amanhã às] LT",nextWeek:"dddd [às] LT",lastDay:"[Ontem às] LT",lastWeek:function(){return 0===this.day()||6===this.day()?"[Último] dddd [às] LT":"[Última] dddd [às] LT"},sameElse:"L"},relativeTime:{future:"em %s",past:"há %s",s:"poucos segundos",ss:"%d segundos",m:"um minuto",mm:"%d minutos",h:"uma hora",hh:"%d horas",d:"um dia",dd:"%d dias",M:"um mês",MM:"%d meses",y:"um ano",yy:"%d anos"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",invalidDate:"Data inválida"}),t.defineLocale("pt",{months:"janeiro_fevereiro_março_abril_maio_junho_julho_agosto_setembro_outubro_novembro_dezembro".split("_"),monthsShort:"jan_fev_mar_abr_mai_jun_jul_ago_set_out_nov_dez".split("_"),weekdays:"Domingo_Segunda-feira_Terça-feira_Quarta-feira_Quinta-feira_Sexta-feira_Sábado".split("_"),weekdaysShort:"Dom_Seg_Ter_Qua_Qui_Sex_Sáb".split("_"),weekdaysMin:"Do_2ª_3ª_4ª_5ª_6ª_Sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY HH:mm",LLLL:"dddd, D [de] MMMM [de] YYYY HH:mm"},calendar:{sameDay:"[Hoje às] LT",nextDay:"[Amanhã às] LT",nextWeek:"dddd [às] LT",lastDay:"[Ontem às] LT",lastWeek:function(){return 0===this.day()||6===this.day()?"[Último] dddd [às] LT":"[Última] dddd [às] LT"},sameElse:"L"},relativeTime:{future:"em %s",past:"há %s",s:"segundos",ss:"%d segundos",m:"um minuto",mm:"%d minutos",h:"uma hora",hh:"%d horas",d:"um dia",dd:"%d dias",w:"uma semana",ww:"%d semanas",M:"um mês",MM:"%d meses",y:"um ano",yy:"%d anos"},dayOfMonthOrdinalParse:/\d{1,2}\xba/,ordinal:"%dº",week:{dow:1,doy:4}}),t.defineLocale("ro",{months:"ianuarie_februarie_martie_aprilie_mai_iunie_iulie_august_septembrie_octombrie_noiembrie_decembrie".split("_"),monthsShort:"ian._feb._mart._apr._mai_iun._iul._aug._sept._oct._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"duminică_luni_marți_miercuri_joi_vineri_sâmbătă".split("_"),weekdaysShort:"Dum_Lun_Mar_Mie_Joi_Vin_Sâm".split("_"),weekdaysMin:"Du_Lu_Ma_Mi_Jo_Vi_Sâ".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY H:mm",LLLL:"dddd, D MMMM YYYY H:mm"},calendar:{sameDay:"[azi la] LT",nextDay:"[mâine la] LT",nextWeek:"dddd [la] LT",lastDay:"[ieri la] LT",lastWeek:"[fosta] dddd [la] LT",sameElse:"L"},relativeTime:{future:"peste %s",past:"%s în urmă",s:"câteva secunde",ss:gr,m:"un minut",mm:gr,h:"o oră",hh:gr,d:"o zi",dd:gr,w:"o săptămână",ww:gr,M:"o lună",MM:gr,y:"un an",yy:gr},week:{dow:1,doy:7}}),W=[/^\u044f\u043d\u0432/i,/^\u0444\u0435\u0432/i,/^\u043c\u0430\u0440/i,/^\u0430\u043f\u0440/i,/^\u043c\u0430[\u0439\u044f]/i,/^\u0438\u044e\u043d/i,/^\u0438\u044e\u043b/i,/^\u0430\u0432\u0433/i,/^\u0441\u0435\u043d/i,/^\u043e\u043a\u0442/i,/^\u043d\u043e\u044f/i,/^\u0434\u0435\u043a/i],t.defineLocale("ru",{months:{format:"января_февраля_марта_апреля_мая_июня_июля_августа_сентября_октября_ноября_декабря".split("_"),standalone:"январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь".split("_")},monthsShort:{format:"янв._февр._мар._апр._мая_июня_июля_авг._сент._окт._нояб._дек.".split("_"),standalone:"янв._февр._март_апр._май_июнь_июль_авг._сент._окт._нояб._дек.".split("_")},weekdays:{standalone:"воскресенье_понедельник_вторник_среда_четверг_пятница_суббота".split("_"),format:"воскресенье_понедельник_вторник_среду_четверг_пятницу_субботу".split("_"),isFormat:/\[ ?[\u0412\u0432] ?(?:\u043f\u0440\u043e\u0448\u043b\u0443\u044e|\u0441\u043b\u0435\u0434\u0443\u044e\u0449\u0443\u044e|\u044d\u0442\u0443)? ?] ?dddd/},weekdaysShort:"вс_пн_вт_ср_чт_пт_сб".split("_"),weekdaysMin:"вс_пн_вт_ср_чт_пт_сб".split("_"),monthsParse:W,longMonthsParse:W,shortMonthsParse:W,monthsRegex:/^(\u044f\u043d\u0432\u0430\u0440[\u044c\u044f]|\u044f\u043d\u0432\.?|\u0444\u0435\u0432\u0440\u0430\u043b[\u044c\u044f]|\u0444\u0435\u0432\u0440?\.?|\u043c\u0430\u0440\u0442\u0430?|\u043c\u0430\u0440\.?|\u0430\u043f\u0440\u0435\u043b[\u044c\u044f]|\u0430\u043f\u0440\.?|\u043c\u0430[\u0439\u044f]|\u0438\u044e\u043d[\u044c\u044f]|\u0438\u044e\u043d\.?|\u0438\u044e\u043b[\u044c\u044f]|\u0438\u044e\u043b\.?|\u0430\u0432\u0433\u0443\u0441\u0442\u0430?|\u0430\u0432\u0433\.?|\u0441\u0435\u043d\u0442\u044f\u0431\u0440[\u044c\u044f]|\u0441\u0435\u043d\u0442?\.?|\u043e\u043a\u0442\u044f\u0431\u0440[\u044c\u044f]|\u043e\u043a\u0442\.?|\u043d\u043e\u044f\u0431\u0440[\u044c\u044f]|\u043d\u043e\u044f\u0431?\.?|\u0434\u0435\u043a\u0430\u0431\u0440[\u044c\u044f]|\u0434\u0435\u043a\.?)/i,monthsShortRegex:/^(\u044f\u043d\u0432\u0430\u0440[\u044c\u044f]|\u044f\u043d\u0432\.?|\u0444\u0435\u0432\u0440\u0430\u043b[\u044c\u044f]|\u0444\u0435\u0432\u0440?\.?|\u043c\u0430\u0440\u0442\u0430?|\u043c\u0430\u0440\.?|\u0430\u043f\u0440\u0435\u043b[\u044c\u044f]|\u0430\u043f\u0440\.?|\u043c\u0430[\u0439\u044f]|\u0438\u044e\u043d[\u044c\u044f]|\u0438\u044e\u043d\.?|\u0438\u044e\u043b[\u044c\u044f]|\u0438\u044e\u043b\.?|\u0430\u0432\u0433\u0443\u0441\u0442\u0430?|\u0430\u0432\u0433\.?|\u0441\u0435\u043d\u0442\u044f\u0431\u0440[\u044c\u044f]|\u0441\u0435\u043d\u0442?\.?|\u043e\u043a\u0442\u044f\u0431\u0440[\u044c\u044f]|\u043e\u043a\u0442\.?|\u043d\u043e\u044f\u0431\u0440[\u044c\u044f]|\u043d\u043e\u044f\u0431?\.?|\u0434\u0435\u043a\u0430\u0431\u0440[\u044c\u044f]|\u0434\u0435\u043a\.?)/i,monthsStrictRegex:/^(\u044f\u043d\u0432\u0430\u0440[\u044f\u044c]|\u0444\u0435\u0432\u0440\u0430\u043b[\u044f\u044c]|\u043c\u0430\u0440\u0442\u0430?|\u0430\u043f\u0440\u0435\u043b[\u044f\u044c]|\u043c\u0430[\u044f\u0439]|\u0438\u044e\u043d[\u044f\u044c]|\u0438\u044e\u043b[\u044f\u044c]|\u0430\u0432\u0433\u0443\u0441\u0442\u0430?|\u0441\u0435\u043d\u0442\u044f\u0431\u0440[\u044f\u044c]|\u043e\u043a\u0442\u044f\u0431\u0440[\u044f\u044c]|\u043d\u043e\u044f\u0431\u0440[\u044f\u044c]|\u0434\u0435\u043a\u0430\u0431\u0440[\u044f\u044c])/i,monthsShortStrictRegex:/^(\u044f\u043d\u0432\.|\u0444\u0435\u0432\u0440?\.|\u043c\u0430\u0440[\u0442.]|\u0430\u043f\u0440\.|\u043c\u0430[\u044f\u0439]|\u0438\u044e\u043d[\u044c\u044f.]|\u0438\u044e\u043b[\u044c\u044f.]|\u0430\u0432\u0433\.|\u0441\u0435\u043d\u0442?\.|\u043e\u043a\u0442\.|\u043d\u043e\u044f\u0431?\.|\u0434\u0435\u043a\.)/i,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY г.",LLL:"D MMMM YYYY г., H:mm",LLLL:"dddd, D MMMM YYYY г., H:mm"},calendar:{sameDay:"[Сегодня, в] LT",nextDay:"[Завтра, в] LT",lastDay:"[Вчера, в] LT",nextWeek:function(e){if(e.week()===this.week())return 2===this.day()?"[Во] dddd, [в] LT":"[В] dddd, [в] LT";switch(this.day()){case 0:return"[В следующее] dddd, [в] LT";case 1:case 2:case 4:return"[В следующий] dddd, [в] LT";case 3:case 5:case 6:return"[В следующую] dddd, [в] LT"}},lastWeek:function(e){if(e.week()===this.week())return 2===this.day()?"[Во] dddd, [в] LT":"[В] dddd, [в] LT";switch(this.day()){case 0:return"[В прошлое] dddd, [в] LT";case 1:case 2:case 4:return"[В прошлый] dddd, [в] LT";case 3:case 5:case 6:return"[В прошлую] dddd, [в] LT"}},sameElse:"L"},relativeTime:{future:"через %s",past:"%s назад",s:"несколько секунд",ss:vr,m:vr,mm:vr,h:"час",hh:vr,d:"день",dd:vr,w:"неделя",ww:vr,M:"месяц",MM:vr,y:"год",yy:vr},meridiemParse:/\u043d\u043e\u0447\u0438|\u0443\u0442\u0440\u0430|\u0434\u043d\u044f|\u0432\u0435\u0447\u0435\u0440\u0430/i,isPM:function(e){return/^(\u0434\u043d\u044f|\u0432\u0435\u0447\u0435\u0440\u0430)$/.test(e)},meridiem:function(e,t,i){return e<4?"ночи":e<12?"утра":e<17?"дня":"вечера"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0439|\u0433\u043e|\u044f)/,ordinal:function(e,t){switch(t){case"M":case"d":case"DDD":return e+"-й";case"D":return e+"-го";case"w":case"W":return e+"-я";default:return e}},week:{dow:1,doy:4}}),ie=["جنوري","فيبروري","مارچ","اپريل","مئي","جون","جولاءِ","آگسٽ","سيپٽمبر","آڪٽوبر","نومبر","ڊسمبر"],K=["آچر","سومر","اڱارو","اربع","خميس","جمع","ڇنڇر"],t.defineLocale("sd",{months:ie,monthsShort:ie,weekdays:K,weekdaysShort:K,weekdaysMin:K,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd، D MMMM YYYY HH:mm"},meridiemParse:/\u0635\u0628\u062d|\u0634\u0627\u0645/,isPM:function(e){return"شام"===e},meridiem:function(e,t,i){return e<12?"صبح":"شام"},calendar:{sameDay:"[اڄ] LT",nextDay:"[سڀاڻي] LT",nextWeek:"dddd [اڳين هفتي تي] LT",lastDay:"[ڪالهه] LT",lastWeek:"[گزريل هفتي] dddd [تي] LT",sameElse:"L"},relativeTime:{future:"%s پوء",past:"%s اڳ",s:"چند سيڪنڊ",ss:"%d سيڪنڊ",m:"هڪ منٽ",mm:"%d منٽ",h:"هڪ ڪلاڪ",hh:"%d ڪلاڪ",d:"هڪ ڏينهن",dd:"%d ڏينهن",M:"هڪ مهينو",MM:"%d مهينا",y:"هڪ سال",yy:"%d سال"},preparse:function(e){return e.replace(/\u060c/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:1,doy:4}}),t.defineLocale("se",{months:"ođđajagemánnu_guovvamánnu_njukčamánnu_cuoŋománnu_miessemánnu_geassemánnu_suoidnemánnu_borgemánnu_čakčamánnu_golggotmánnu_skábmamánnu_juovlamánnu".split("_"),monthsShort:"ođđj_guov_njuk_cuo_mies_geas_suoi_borg_čakč_golg_skáb_juov".split("_"),weekdays:"sotnabeaivi_vuossárga_maŋŋebárga_gaskavahkku_duorastat_bearjadat_lávvardat".split("_"),weekdaysShort:"sotn_vuos_maŋ_gask_duor_bear_láv".split("_"),weekdaysMin:"s_v_m_g_d_b_L".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"MMMM D. [b.] YYYY",LLL:"MMMM D. [b.] YYYY [ti.] HH:mm",LLLL:"dddd, MMMM D. [b.] YYYY [ti.] HH:mm"},calendar:{sameDay:"[otne ti] LT",nextDay:"[ihttin ti] LT",nextWeek:"dddd [ti] LT",lastDay:"[ikte ti] LT",lastWeek:"[ovddit] dddd [ti] LT",sameElse:"L"},relativeTime:{future:"%s geažes",past:"maŋit %s",s:"moadde sekunddat",ss:"%d sekunddat",m:"okta minuhta",mm:"%d minuhtat",h:"okta diimmu",hh:"%d diimmut",d:"okta beaivi",dd:"%d beaivvit",M:"okta mánnu",MM:"%d mánut",y:"okta jahki",yy:"%d jagit"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("si",{months:"ජනවාරි_පෙබරවාරි_මාර්තු_අප්‍රේල්_මැයි_ජූනි_ජූලි_අගෝස්තු_සැප්තැම්බර්_ඔක්තෝබර්_නොවැම්බර්_දෙසැම්බර්".split("_"),monthsShort:"ජන_පෙබ_මාර්_අප්_මැයි_ජූනි_ජූලි_අගෝ_සැප්_ඔක්_නොවැ_දෙසැ".split("_"),weekdays:"ඉරිදා_සඳුදා_අඟහරුවාදා_බදාදා_බ්‍රහස්පතින්දා_සිකුරාදා_සෙනසුරාදා".split("_"),weekdaysShort:"ඉරි_සඳු_අඟ_බදා_බ්‍රහ_සිකු_සෙන".split("_"),weekdaysMin:"ඉ_ස_අ_බ_බ්‍ර_සි_සෙ".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"a h:mm",LTS:"a h:mm:ss",L:"YYYY/MM/DD",LL:"YYYY MMMM D",LLL:"YYYY MMMM D, a h:mm",LLLL:"YYYY MMMM D [වැනි] dddd, a h:mm:ss"},calendar:{sameDay:"[අද] LT[ට]",nextDay:"[හෙට] LT[ට]",nextWeek:"dddd LT[ට]",lastDay:"[ඊයේ] LT[ට]",lastWeek:"[පසුගිය] dddd LT[ට]",sameElse:"L"},relativeTime:{future:"%sකින්",past:"%sකට පෙර",s:"තත්පර කිහිපය",ss:"තත්පර %d",m:"මිනිත්තුව",mm:"මිනිත්තු %d",h:"පැය",hh:"පැය %d",d:"දිනය",dd:"දින %d",M:"මාසය",MM:"මාස %d",y:"වසර",yy:"වසර %d"},dayOfMonthOrdinalParse:/\d{1,2} \u0dc0\u0dd0\u0db1\u0dd2/,ordinal:function(e){return e+" වැනි"},meridiemParse:/\u0db4\u0dd9\u0dbb \u0dc0\u0dbb\u0dd4|\u0db4\u0dc3\u0dca \u0dc0\u0dbb\u0dd4|\u0db4\u0dd9.\u0dc0|\u0db4.\u0dc0./,isPM:function(e){return"ප.ව."===e||"පස් වරු"===e},meridiem:function(e,t,i){return 11<e?i?"ප.ව.":"පස් වරු":i?"පෙ.ව.":"පෙර වරු"}}),U="január_február_marec_apríl_máj_jún_júl_august_september_október_november_december".split("_"),Ae="jan_feb_mar_apr_máj_jún_júl_aug_sep_okt_nov_dec".split("_"),t.defineLocale("sk",{months:U,monthsShort:Ae,weekdays:"nedeľa_pondelok_utorok_streda_štvrtok_piatok_sobota".split("_"),weekdaysShort:"ne_po_ut_st_št_pi_so".split("_"),weekdaysMin:"ne_po_ut_st_št_pi_so".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd D. MMMM YYYY H:mm"},calendar:{sameDay:"[dnes o] LT",nextDay:"[zajtra o] LT",nextWeek:function(){switch(this.day()){case 0:return"[v nedeľu o] LT";case 1:case 2:return"[v] dddd [o] LT";case 3:return"[v stredu o] LT";case 4:return"[vo štvrtok o] LT";case 5:return"[v piatok o] LT";case 6:return"[v sobotu o] LT"}},lastDay:"[včera o] LT",lastWeek:function(){switch(this.day()){case 0:return"[minulú nedeľu o] LT";case 1:case 2:case 4:case 5:return"[minulý] dddd [o] LT";case 3:return"[minulú stredu o] LT";case 6:return"[minulú sobotu o] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"pred %s",s:br,ss:br,m:br,mm:br,h:br,hh:br,d:br,dd:br,M:br,MM:br,y:br,yy:br},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("sl",{months:"januar_februar_marec_april_maj_junij_julij_avgust_september_oktober_november_december".split("_"),monthsShort:"jan._feb._mar._apr._maj._jun._jul._avg._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedelja_ponedeljek_torek_sreda_četrtek_petek_sobota".split("_"),weekdaysShort:"ned._pon._tor._sre._čet._pet._sob.".split("_"),weekdaysMin:"ne_po_to_sr_če_pe_so".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD. MM. YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd, D. MMMM YYYY H:mm"},calendar:{sameDay:"[danes ob] LT",nextDay:"[jutri ob] LT",nextWeek:function(){switch(this.day()){case 0:return"[v] [nedeljo] [ob] LT";case 3:return"[v] [sredo] [ob] LT";case 6:return"[v] [soboto] [ob] LT";case 1:case 2:case 4:case 5:return"[v] dddd [ob] LT"}},lastDay:"[včeraj ob] LT",lastWeek:function(){switch(this.day()){case 0:return"[prejšnjo] [nedeljo] [ob] LT";case 3:return"[prejšnjo] [sredo] [ob] LT";case 6:return"[prejšnjo] [soboto] [ob] LT";case 1:case 2:case 4:case 5:return"[prejšnji] dddd [ob] LT"}},sameElse:"L"},relativeTime:{future:"čez %s",past:"pred %s",s:xr,ss:xr,m:xr,mm:xr,h:xr,hh:xr,d:xr,dd:xr,M:xr,MM:xr,y:xr,yy:xr},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}}),t.defineLocale("sq",{months:"Janar_Shkurt_Mars_Prill_Maj_Qershor_Korrik_Gusht_Shtator_Tetor_Nëntor_Dhjetor".split("_"),monthsShort:"Jan_Shk_Mar_Pri_Maj_Qer_Kor_Gus_Sht_Tet_Nën_Dhj".split("_"),weekdays:"E Diel_E Hënë_E Martë_E Mërkurë_E Enjte_E Premte_E Shtunë".split("_"),weekdaysShort:"Die_Hën_Mar_Mër_Enj_Pre_Sht".split("_"),weekdaysMin:"D_H_Ma_Më_E_P_Sh".split("_"),weekdaysParseExact:!0,meridiemParse:/PD|MD/,isPM:function(e){return"M"===e.charAt(0)},meridiem:function(e,t,i){return e<12?"PD":"MD"},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Sot në] LT",nextDay:"[Nesër në] LT",nextWeek:"dddd [në] LT",lastDay:"[Dje në] LT",lastWeek:"dddd [e kaluar në] LT",sameElse:"L"},relativeTime:{future:"në %s",past:"%s më parë",s:"disa sekonda",ss:"%d sekonda",m:"një minutë",mm:"%d minuta",h:"një orë",hh:"%d orë",d:"një ditë",dd:"%d ditë",M:"një muaj",MM:"%d muaj",y:"një vit",yy:"%d vite"},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}});var _r={words:{ss:["секунда","секунде","секунди"],m:["један минут","једног минута"],mm:["минут","минута","минута"],h:["један сат","једног сата"],hh:["сат","сата","сати"],d:["један дан","једног дана"],dd:["дан","дана","дана"],M:["један месец","једног месеца"],MM:["месец","месеца","месеци"],y:["једну годину","једне године"],yy:["годину","године","година"]},correctGrammaticalCase:function(e,t){return 1<=e%10&&e%10<=4&&(e%100<10||20<=e%100)?e%10==1?t[0]:t[1]:t[2]},translate:function(e,t,i,n){var r=_r.words[i];return 1===i.length?"y"===i&&t?"једна година":n||t?r[0]:r[1]:(n=_r.correctGrammaticalCase(e,r),"yy"===i&&t&&"годину"===n?e+" година":e+" "+n)}},wr=(t.defineLocale("sr-cyrl",{months:"јануар_фебруар_март_април_мај_јун_јул_август_септембар_октобар_новембар_децембар".split("_"),monthsShort:"јан._феб._мар._апр._мај_јун_јул_авг._сеп._окт._нов._дец.".split("_"),monthsParseExact:!0,weekdays:"недеља_понедељак_уторак_среда_четвртак_петак_субота".split("_"),weekdaysShort:"нед._пон._уто._сре._чет._пет._суб.".split("_"),weekdaysMin:"не_по_ут_ср_че_пе_су".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D. M. YYYY.",LL:"D. MMMM YYYY.",LLL:"D. MMMM YYYY. H:mm",LLLL:"dddd, D. MMMM YYYY. H:mm"},calendar:{sameDay:"[данас у] LT",nextDay:"[сутра у] LT",nextWeek:function(){switch(this.day()){case 0:return"[у] [недељу] [у] LT";case 3:return"[у] [среду] [у] LT";case 6:return"[у] [суботу] [у] LT";case 1:case 2:case 4:case 5:return"[у] dddd [у] LT"}},lastDay:"[јуче у] LT",lastWeek:function(){return["[прошле] [недеље] [у] LT","[прошлог] [понедељка] [у] LT","[прошлог] [уторка] [у] LT","[прошле] [среде] [у] LT","[прошлог] [четвртка] [у] LT","[прошлог] [петка] [у] LT","[прошле] [суботе] [у] LT"][this.day()]},sameElse:"L"},relativeTime:{future:"за %s",past:"пре %s",s:"неколико секунди",ss:_r.translate,m:_r.translate,mm:_r.translate,h:_r.translate,hh:_r.translate,d:_r.translate,dd:_r.translate,M:_r.translate,MM:_r.translate,y:_r.translate,yy:_r.translate},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}}),{words:{ss:["sekunda","sekunde","sekundi"],m:["jedan minut","jednog minuta"],mm:["minut","minuta","minuta"],h:["jedan sat","jednog sata"],hh:["sat","sata","sati"],d:["jedan dan","jednog dana"],dd:["dan","dana","dana"],M:["jedan mesec","jednog meseca"],MM:["mesec","meseca","meseci"],y:["jednu godinu","jedne godine"],yy:["godinu","godine","godina"]},correctGrammaticalCase:function(e,t){return 1<=e%10&&e%10<=4&&(e%100<10||20<=e%100)?e%10==1?t[0]:t[1]:t[2]},translate:function(e,t,i,n){var r=wr.words[i];return 1===i.length?"y"===i&&t?"jedna godina":n||t?r[0]:r[1]:(n=wr.correctGrammaticalCase(e,r),"yy"===i&&t&&"godinu"===n?e+" godina":e+" "+n)}}),kr=(t.defineLocale("sr",{months:"januar_februar_mart_april_maj_jun_jul_avgust_septembar_oktobar_novembar_decembar".split("_"),monthsShort:"jan._feb._mar._apr._maj_jun_jul_avg._sep._okt._nov._dec.".split("_"),monthsParseExact:!0,weekdays:"nedelja_ponedeljak_utorak_sreda_četvrtak_petak_subota".split("_"),weekdaysShort:"ned._pon._uto._sre._čet._pet._sub.".split("_"),weekdaysMin:"ne_po_ut_sr_če_pe_su".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"D. M. YYYY.",LL:"D. MMMM YYYY.",LLL:"D. MMMM YYYY. H:mm",LLLL:"dddd, D. MMMM YYYY. H:mm"},calendar:{sameDay:"[danas u] LT",nextDay:"[sutra u] LT",nextWeek:function(){switch(this.day()){case 0:return"[u] [nedelju] [u] LT";case 3:return"[u] [sredu] [u] LT";case 6:return"[u] [subotu] [u] LT";case 1:case 2:case 4:case 5:return"[u] dddd [u] LT"}},lastDay:"[juče u] LT",lastWeek:function(){return["[prošle] [nedelje] [u] LT","[prošlog] [ponedeljka] [u] LT","[prošlog] [utorka] [u] LT","[prošle] [srede] [u] LT","[prošlog] [četvrtka] [u] LT","[prošlog] [petka] [u] LT","[prošle] [subote] [u] LT"][this.day()]},sameElse:"L"},relativeTime:{future:"za %s",past:"pre %s",s:"nekoliko sekundi",ss:wr.translate,m:wr.translate,mm:wr.translate,h:wr.translate,hh:wr.translate,d:wr.translate,dd:wr.translate,M:wr.translate,MM:wr.translate,y:wr.translate,yy:wr.translate},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:7}}),t.defineLocale("ss",{months:"Bhimbidvwane_Indlovana_Indlov'lenkhulu_Mabasa_Inkhwekhweti_Inhlaba_Kholwane_Ingci_Inyoni_Imphala_Lweti_Ingongoni".split("_"),monthsShort:"Bhi_Ina_Inu_Mab_Ink_Inh_Kho_Igc_Iny_Imp_Lwe_Igo".split("_"),weekdays:"Lisontfo_Umsombuluko_Lesibili_Lesitsatfu_Lesine_Lesihlanu_Umgcibelo".split("_"),weekdaysShort:"Lis_Umb_Lsb_Les_Lsi_Lsh_Umg".split("_"),weekdaysMin:"Li_Us_Lb_Lt_Ls_Lh_Ug".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Namuhla nga] LT",nextDay:"[Kusasa nga] LT",nextWeek:"dddd [nga] LT",lastDay:"[Itolo nga] LT",lastWeek:"dddd [leliphelile] [nga] LT",sameElse:"L"},relativeTime:{future:"nga %s",past:"wenteka nga %s",s:"emizuzwana lomcane",ss:"%d mzuzwana",m:"umzuzu",mm:"%d emizuzu",h:"lihora",hh:"%d emahora",d:"lilanga",dd:"%d emalanga",M:"inyanga",MM:"%d tinyanga",y:"umnyaka",yy:"%d iminyaka"},meridiemParse:/ekuseni|emini|entsambama|ebusuku/,meridiem:function(e,t,i){return e<11?"ekuseni":e<15?"emini":e<19?"entsambama":"ebusuku"},meridiemHour:function(e,t){return 12===e&&(e=0),"ekuseni"===t?e:"emini"===t?11<=e?e:e+12:"entsambama"===t||"ebusuku"===t?0===e?0:e+12:void 0},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:"%d",week:{dow:1,doy:4}}),t.defineLocale("sv",{months:"januari_februari_mars_april_maj_juni_juli_augusti_september_oktober_november_december".split("_"),monthsShort:"jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec".split("_"),weekdays:"söndag_måndag_tisdag_onsdag_torsdag_fredag_lördag".split("_"),weekdaysShort:"sön_mån_tis_ons_tor_fre_lör".split("_"),weekdaysMin:"sö_må_ti_on_to_fr_lö".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"D MMMM YYYY",LLL:"D MMMM YYYY [kl.] HH:mm",LLLL:"dddd D MMMM YYYY [kl.] HH:mm",lll:"D MMM YYYY HH:mm",llll:"ddd D MMM YYYY HH:mm"},calendar:{sameDay:"[Idag] LT",nextDay:"[Imorgon] LT",lastDay:"[Igår] LT",nextWeek:"[På] dddd LT",lastWeek:"[I] dddd[s] LT",sameElse:"L"},relativeTime:{future:"om %s",past:"för %s sedan",s:"några sekunder",ss:"%d sekunder",m:"en minut",mm:"%d minuter",h:"en timme",hh:"%d timmar",d:"en dag",dd:"%d dagar",M:"en månad",MM:"%d månader",y:"ett år",yy:"%d år"},dayOfMonthOrdinalParse:/\d{1,2}(\:e|\:a)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)||1!=t&&2!=t?":e":":a")},week:{dow:1,doy:4}}),t.defineLocale("sw",{months:"Januari_Februari_Machi_Aprili_Mei_Juni_Julai_Agosti_Septemba_Oktoba_Novemba_Desemba".split("_"),monthsShort:"Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ago_Sep_Okt_Nov_Des".split("_"),weekdays:"Jumapili_Jumatatu_Jumanne_Jumatano_Alhamisi_Ijumaa_Jumamosi".split("_"),weekdaysShort:"Jpl_Jtat_Jnne_Jtan_Alh_Ijm_Jmos".split("_"),weekdaysMin:"J2_J3_J4_J5_Al_Ij_J1".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"hh:mm A",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[leo saa] LT",nextDay:"[kesho saa] LT",nextWeek:"[wiki ijayo] dddd [saat] LT",lastDay:"[jana] LT",lastWeek:"[wiki iliyopita] dddd [saat] LT",sameElse:"L"},relativeTime:{future:"%s baadaye",past:"tokea %s",s:"hivi punde",ss:"sekunde %d",m:"dakika moja",mm:"dakika %d",h:"saa limoja",hh:"masaa %d",d:"siku moja",dd:"siku %d",M:"mwezi mmoja",MM:"miezi %d",y:"mwaka mmoja",yy:"miaka %d"},week:{dow:1,doy:7}}),{1:"௧",2:"௨",3:"௩",4:"௪",5:"௫",6:"௬",7:"௭",8:"௮",9:"௯",0:"௦"}),Mr={"௧":"1","௨":"2","௩":"3","௪":"4","௫":"5","௬":"6","௭":"7","௮":"8","௯":"9","௦":"0"},Sr=(t.defineLocale("ta",{months:"ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்".split("_"),monthsShort:"ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்".split("_"),weekdays:"ஞாயிற்றுக்கிழமை_திங்கட்கிழமை_செவ்வாய்கிழமை_புதன்கிழமை_வியாழக்கிழமை_வெள்ளிக்கிழமை_சனிக்கிழமை".split("_"),weekdaysShort:"ஞாயிறு_திங்கள்_செவ்வாய்_புதன்_வியாழன்_வெள்ளி_சனி".split("_"),weekdaysMin:"ஞா_தி_செ_பு_வி_வெ_ச".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, HH:mm",LLLL:"dddd, D MMMM YYYY, HH:mm"},calendar:{sameDay:"[இன்று] LT",nextDay:"[நாளை] LT",nextWeek:"dddd, LT",lastDay:"[நேற்று] LT",lastWeek:"[கடந்த வாரம்] dddd, LT",sameElse:"L"},relativeTime:{future:"%s இல்",past:"%s முன்",s:"ஒரு சில விநாடிகள்",ss:"%d விநாடிகள்",m:"ஒரு நிமிடம்",mm:"%d நிமிடங்கள்",h:"ஒரு மணி நேரம்",hh:"%d மணி நேரம்",d:"ஒரு நாள்",dd:"%d நாட்கள்",M:"ஒரு மாதம்",MM:"%d மாதங்கள்",y:"ஒரு வருடம்",yy:"%d ஆண்டுகள்"},dayOfMonthOrdinalParse:/\d{1,2}\u0bb5\u0ba4\u0bc1/,ordinal:function(e){return e+"வது"},preparse:function(e){return e.replace(/[\u0be7\u0be8\u0be9\u0bea\u0beb\u0bec\u0bed\u0bee\u0bef\u0be6]/g,(function(e){return Mr[e]}))},postformat:function(e){return e.replace(/\d/g,(function(e){return kr[e]}))},meridiemParse:/\u0baf\u0bbe\u0bae\u0bae\u0bcd|\u0bb5\u0bc8\u0b95\u0bb1\u0bc8|\u0b95\u0bbe\u0bb2\u0bc8|\u0ba8\u0ba3\u0bcd\u0baa\u0b95\u0bb2\u0bcd|\u0b8e\u0bb1\u0bcd\u0baa\u0bbe\u0b9f\u0bc1|\u0bae\u0bbe\u0bb2\u0bc8/,meridiem:function(e,t,i){return e<2?" யாமம்":e<6?" வைகறை":e<10?" காலை":e<14?" நண்பகல்":e<18?" எற்பாடு":e<22?" மாலை":" யாமம்"},meridiemHour:function(e,t){return 12===e&&(e=0),"யாமம்"===t?e<2?e:e+12:"வைகறை"===t||"காலை"===t||"நண்பகல்"===t&&10<=e?e:e+12},week:{dow:0,doy:6}}),t.defineLocale("te",{months:"జనవరి_ఫిబ్రవరి_మార్చి_ఏప్రిల్_మే_జూన్_జులై_ఆగస్టు_సెప్టెంబర్_అక్టోబర్_నవంబర్_డిసెంబర్".split("_"),monthsShort:"జన._ఫిబ్ర._మార్చి_ఏప్రి._మే_జూన్_జులై_ఆగ._సెప్._అక్టో._నవ._డిసె.".split("_"),monthsParseExact:!0,weekdays:"ఆదివారం_సోమవారం_మంగళవారం_బుధవారం_గురువారం_శుక్రవారం_శనివారం".split("_"),weekdaysShort:"ఆది_సోమ_మంగళ_బుధ_గురు_శుక్ర_శని".split("_"),weekdaysMin:"ఆ_సో_మం_బు_గు_శు_శ".split("_"),longDateFormat:{LT:"A h:mm",LTS:"A h:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY, A h:mm",LLLL:"dddd, D MMMM YYYY, A h:mm"},calendar:{sameDay:"[నేడు] LT",nextDay:"[రేపు] LT",nextWeek:"dddd, LT",lastDay:"[నిన్న] LT",lastWeek:"[గత] dddd, LT",sameElse:"L"},relativeTime:{future:"%s లో",past:"%s క్రితం",s:"కొన్ని క్షణాలు",ss:"%d సెకన్లు",m:"ఒక నిమిషం",mm:"%d నిమిషాలు",h:"ఒక గంట",hh:"%d గంటలు",d:"ఒక రోజు",dd:"%d రోజులు",M:"ఒక నెల",MM:"%d నెలలు",y:"ఒక సంవత్సరం",yy:"%d సంవత్సరాలు"},dayOfMonthOrdinalParse:/\d{1,2}\u0c35/,ordinal:"%dవ",meridiemParse:/\u0c30\u0c3e\u0c24\u0c4d\u0c30\u0c3f|\u0c09\u0c26\u0c2f\u0c02|\u0c2e\u0c27\u0c4d\u0c2f\u0c3e\u0c39\u0c4d\u0c28\u0c02|\u0c38\u0c3e\u0c2f\u0c02\u0c24\u0c4d\u0c30\u0c02/,meridiemHour:function(e,t){return 12===e&&(e=0),"రాత్రి"===t?e<4?e:e+12:"ఉదయం"===t?e:"మధ్యాహ్నం"===t?10<=e?e:e+12:"సాయంత్రం"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"రాత్రి":e<10?"ఉదయం":e<17?"మధ్యాహ్నం":e<20?"సాయంత్రం":"రాత్రి"},week:{dow:0,doy:6}}),t.defineLocale("tet",{months:"Janeiru_Fevereiru_Marsu_Abril_Maiu_Juñu_Jullu_Agustu_Setembru_Outubru_Novembru_Dezembru".split("_"),monthsShort:"Jan_Fev_Mar_Abr_Mai_Jun_Jul_Ago_Set_Out_Nov_Dez".split("_"),weekdays:"Domingu_Segunda_Tersa_Kuarta_Kinta_Sesta_Sabadu".split("_"),weekdaysShort:"Dom_Seg_Ters_Kua_Kint_Sest_Sab".split("_"),weekdaysMin:"Do_Seg_Te_Ku_Ki_Ses_Sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Ohin iha] LT",nextDay:"[Aban iha] LT",nextWeek:"dddd [iha] LT",lastDay:"[Horiseik iha] LT",lastWeek:"dddd [semana kotuk] [iha] LT",sameElse:"L"},relativeTime:{future:"iha %s",past:"%s liuba",s:"segundu balun",ss:"segundu %d",m:"minutu ida",mm:"minutu %d",h:"oras ida",hh:"oras %d",d:"loron ida",dd:"loron %d",M:"fulan ida",MM:"fulan %d",y:"tinan ida",yy:"tinan %d"},dayOfMonthOrdinalParse:/\d{1,2}(st|nd|rd|th)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:1,doy:4}}),{0:"-ум",1:"-ум",2:"-юм",3:"-юм",4:"-ум",5:"-ум",6:"-ум",7:"-ум",8:"-ум",9:"-ум",10:"-ум",12:"-ум",13:"-ум",20:"-ум",30:"-юм",40:"-ум",50:"-ум",60:"-ум",70:"-ум",80:"-ум",90:"-ум",100:"-ум"}),Ar=(t.defineLocale("tg",{months:{format:"январи_феврали_марти_апрели_майи_июни_июли_августи_сентябри_октябри_ноябри_декабри".split("_"),standalone:"январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр".split("_")},monthsShort:"янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек".split("_"),weekdays:"якшанбе_душанбе_сешанбе_чоршанбе_панҷшанбе_ҷумъа_шанбе".split("_"),weekdaysShort:"яшб_дшб_сшб_чшб_пшб_ҷум_шнб".split("_"),weekdaysMin:"яш_дш_сш_чш_пш_ҷм_шб".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Имрӯз соати] LT",nextDay:"[Фардо соати] LT",lastDay:"[Дирӯз соати] LT",nextWeek:"dddd[и] [ҳафтаи оянда соати] LT",lastWeek:"dddd[и] [ҳафтаи гузашта соати] LT",sameElse:"L"},relativeTime:{future:"баъди %s",past:"%s пеш",s:"якчанд сония",m:"як дақиқа",mm:"%d дақиқа",h:"як соат",hh:"%d соат",d:"як рӯз",dd:"%d рӯз",M:"як моҳ",MM:"%d моҳ",y:"як сол",yy:"%d сол"},meridiemParse:/\u0448\u0430\u0431|\u0441\u0443\u0431\u04b3|\u0440\u04ef\u0437|\u0431\u0435\u0433\u043e\u04b3/,meridiemHour:function(e,t){return 12===e&&(e=0),"шаб"===t?e<4?e:e+12:"субҳ"===t?e:"рӯз"===t?11<=e?e:e+12:"бегоҳ"===t?e+12:void 0},meridiem:function(e,t,i){return e<4?"шаб":e<11?"субҳ":e<16?"рӯз":e<19?"бегоҳ":"шаб"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0443\u043c|\u044e\u043c)/,ordinal:function(e){return e+(Sr[e]||Sr[e%10]||Sr[100<=e?100:null])},week:{dow:1,doy:7}}),t.defineLocale("th",{months:"มกราคม_กุมภาพันธ์_มีนาคม_เมษายน_พฤษภาคม_มิถุนายน_กรกฎาคม_สิงหาคม_กันยายน_ตุลาคม_พฤศจิกายน_ธันวาคม".split("_"),monthsShort:"ม.ค._ก.พ._มี.ค._เม.ย._พ.ค._มิ.ย._ก.ค._ส.ค._ก.ย._ต.ค._พ.ย._ธ.ค.".split("_"),monthsParseExact:!0,weekdays:"อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัสบดี_ศุกร์_เสาร์".split("_"),weekdaysShort:"อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัส_ศุกร์_เสาร์".split("_"),weekdaysMin:"อา._จ._อ._พ._พฤ._ศ._ส.".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY เวลา H:mm",LLLL:"วันddddที่ D MMMM YYYY เวลา H:mm"},meridiemParse:/\u0e01\u0e48\u0e2d\u0e19\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07|\u0e2b\u0e25\u0e31\u0e07\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07/,isPM:function(e){return"หลังเที่ยง"===e},meridiem:function(e,t,i){return e<12?"ก่อนเที่ยง":"หลังเที่ยง"},calendar:{sameDay:"[วันนี้ เวลา] LT",nextDay:"[พรุ่งนี้ เวลา] LT",nextWeek:"dddd[หน้า เวลา] LT",lastDay:"[เมื่อวานนี้ เวลา] LT",lastWeek:"[วัน]dddd[ที่แล้ว เวลา] LT",sameElse:"L"},relativeTime:{future:"อีก %s",past:"%sที่แล้ว",s:"ไม่กี่วินาที",ss:"%d วินาที",m:"1 นาที",mm:"%d นาที",h:"1 ชั่วโมง",hh:"%d ชั่วโมง",d:"1 วัน",dd:"%d วัน",w:"1 สัปดาห์",ww:"%d สัปดาห์",M:"1 เดือน",MM:"%d เดือน",y:"1 ปี",yy:"%d ปี"}}),{1:"'inji",5:"'inji",8:"'inji",70:"'inji",80:"'inji",2:"'nji",7:"'nji",20:"'nji",50:"'nji",3:"'ünji",4:"'ünji",100:"'ünji",6:"'njy",9:"'unjy",10:"'unjy",30:"'unjy",60:"'ynjy",90:"'ynjy"}),Lr=(t.defineLocale("tk",{months:"Ýanwar_Fewral_Mart_Aprel_Maý_Iýun_Iýul_Awgust_Sentýabr_Oktýabr_Noýabr_Dekabr".split("_"),monthsShort:"Ýan_Few_Mar_Apr_Maý_Iýn_Iýl_Awg_Sen_Okt_Noý_Dek".split("_"),weekdays:"Ýekşenbe_Duşenbe_Sişenbe_Çarşenbe_Penşenbe_Anna_Şenbe".split("_"),weekdaysShort:"Ýek_Duş_Siş_Çar_Pen_Ann_Şen".split("_"),weekdaysMin:"Ýk_Dş_Sş_Çr_Pn_An_Şn".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[bugün sagat] LT",nextDay:"[ertir sagat] LT",nextWeek:"[indiki] dddd [sagat] LT",lastDay:"[düýn] LT",lastWeek:"[geçen] dddd [sagat] LT",sameElse:"L"},relativeTime:{future:"%s soň",past:"%s öň",s:"birnäçe sekunt",m:"bir minut",mm:"%d minut",h:"bir sagat",hh:"%d sagat",d:"bir gün",dd:"%d gün",M:"bir aý",MM:"%d aý",y:"bir ýyl",yy:"%d ýyl"},ordinal:function(e,t){switch(t){case"d":case"D":case"Do":case"DD":return e;default:var i;return 0===e?e+"'unjy":e+(Ar[i=e%10]||Ar[e%100-i]||Ar[100<=e?100:null])}},week:{dow:1,doy:7}}),t.defineLocale("tl-ph",{months:"Enero_Pebrero_Marso_Abril_Mayo_Hunyo_Hulyo_Agosto_Setyembre_Oktubre_Nobyembre_Disyembre".split("_"),monthsShort:"Ene_Peb_Mar_Abr_May_Hun_Hul_Ago_Set_Okt_Nob_Dis".split("_"),weekdays:"Linggo_Lunes_Martes_Miyerkules_Huwebes_Biyernes_Sabado".split("_"),weekdaysShort:"Lin_Lun_Mar_Miy_Huw_Biy_Sab".split("_"),weekdaysMin:"Li_Lu_Ma_Mi_Hu_Bi_Sab".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"MM/D/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY HH:mm",LLLL:"dddd, MMMM DD, YYYY HH:mm"},calendar:{sameDay:"LT [ngayong araw]",nextDay:"[Bukas ng] LT",nextWeek:"LT [sa susunod na] dddd",lastDay:"LT [kahapon]",lastWeek:"LT [noong nakaraang] dddd",sameElse:"L"},relativeTime:{future:"sa loob ng %s",past:"%s ang nakalipas",s:"ilang segundo",ss:"%d segundo",m:"isang minuto",mm:"%d minuto",h:"isang oras",hh:"%d oras",d:"isang araw",dd:"%d araw",M:"isang buwan",MM:"%d buwan",y:"isang taon",yy:"%d taon"},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:function(e){return e},week:{dow:1,doy:4}}),"pagh_wa’_cha’_wej_loS_vagh_jav_Soch_chorgh_Hut".split("_"));function Tr(e,t,i,n){var r=function(e){var t=Math.floor(e%1e3/100),i=Math.floor(e%100/10),n=(e=e%10,"");return 0<t&&(n+=Lr[t]+"vatlh"),0<i&&(n+=(""!==n?" ":"")+Lr[i]+"maH"),0<e&&(n+=(""!==n?" ":"")+Lr[e]),""===n?"pagh":n}(e);switch(i){case"ss":return r+" lup";case"mm":return r+" tup";case"hh":return r+" rep";case"dd":return r+" jaj";case"MM":return r+" jar";case"yy":return r+" DIS"}}t.defineLocale("tlh",{months:"tera’ jar wa’_tera’ jar cha’_tera’ jar wej_tera’ jar loS_tera’ jar vagh_tera’ jar jav_tera’ jar Soch_tera’ jar chorgh_tera’ jar Hut_tera’ jar wa’maH_tera’ jar wa’maH wa’_tera’ jar wa’maH cha’".split("_"),monthsShort:"jar wa’_jar cha’_jar wej_jar loS_jar vagh_jar jav_jar Soch_jar chorgh_jar Hut_jar wa’maH_jar wa’maH wa’_jar wa’maH cha’".split("_"),monthsParseExact:!0,weekdays:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),weekdaysShort:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),weekdaysMin:"lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[DaHjaj] LT",nextDay:"[wa’leS] LT",nextWeek:"LLL",lastDay:"[wa’Hu’] LT",lastWeek:"LLL",sameElse:"L"},relativeTime:{future:function(e){var t=e;return-1!==e.indexOf("jaj")?t.slice(0,-3)+"leS":-1!==e.indexOf("jar")?t.slice(0,-3)+"waQ":-1!==e.indexOf("DIS")?t.slice(0,-3)+"nem":t+" pIq"},past:function(e){var t=e;return-1!==e.indexOf("jaj")?t.slice(0,-3)+"Hu’":-1!==e.indexOf("jar")?t.slice(0,-3)+"wen":-1!==e.indexOf("DIS")?t.slice(0,-3)+"ben":t+" ret"},s:"puS lup",ss:Tr,m:"wa’ tup",mm:Tr,h:"wa’ rep",hh:Tr,d:"wa’ jaj",dd:Tr,M:"wa’ jar",MM:Tr,y:"wa’ DIS",yy:Tr},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}});var Cr={1:"'inci",5:"'inci",8:"'inci",70:"'inci",80:"'inci",2:"'nci",7:"'nci",20:"'nci",50:"'nci",3:"'üncü",4:"'üncü",100:"'üncü",6:"'ncı",9:"'uncu",10:"'uncu",30:"'uncu",60:"'ıncı",90:"'ıncı"};function Dr(e,t,i,n){return e={s:["viensas secunds","'iensas secunds"],ss:[e+" secunds",e+" secunds"],m:["'n míut","'iens míut"],mm:[e+" míuts",e+" míuts"],h:["'n þora","'iensa þora"],hh:[e+" þoras",e+" þoras"],d:["'n ziua","'iensa ziua"],dd:[e+" ziuas",e+" ziuas"],M:["'n mes","'iens mes"],MM:[e+" mesen",e+" mesen"],y:["'n ar","'iens ar"],yy:[e+" ars",e+" ars"]},n||t?e[i][0]:e[i][1]}function Er(e,t,i){return"m"===i?t?"хвилина":"хвилину":"h"===i?t?"година":"годину":e+" "+(e=+e,t=(t={ss:t?"секунда_секунди_секунд":"секунду_секунди_секунд",mm:t?"хвилина_хвилини_хвилин":"хвилину_хвилини_хвилин",hh:t?"година_години_годин":"годину_години_годин",dd:"день_дні_днів",MM:"місяць_місяці_місяців",yy:"рік_роки_років"}[i]).split("_"),e%10==1&&e%100!=11?t[0]:2<=e%10&&e%10<=4&&(e%100<10||20<=e%100)?t[1]:t[2])}function Or(e){return function(){return e+"о"+(11===this.hours()?"б":"")+"] LT"}}return t.defineLocale("tr",{months:"Ocak_Şubat_Mart_Nisan_Mayıs_Haziran_Temmuz_Ağustos_Eylül_Ekim_Kasım_Aralık".split("_"),monthsShort:"Oca_Şub_Mar_Nis_May_Haz_Tem_Ağu_Eyl_Eki_Kas_Ara".split("_"),weekdays:"Pazar_Pazartesi_Salı_Çarşamba_Perşembe_Cuma_Cumartesi".split("_"),weekdaysShort:"Paz_Pzt_Sal_Çar_Per_Cum_Cmt".split("_"),weekdaysMin:"Pz_Pt_Sa_Ça_Pe_Cu_Ct".split("_"),meridiem:function(e,t,i){return e<12?i?"öö":"ÖÖ":i?"ös":"ÖS"},meridiemParse:/\xf6\xf6|\xd6\xd6|\xf6s|\xd6S/,isPM:function(e){return"ös"===e||"ÖS"===e},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[bugün saat] LT",nextDay:"[yarın saat] LT",nextWeek:"[gelecek] dddd [saat] LT",lastDay:"[dün] LT",lastWeek:"[geçen] dddd [saat] LT",sameElse:"L"},relativeTime:{future:"%s sonra",past:"%s önce",s:"birkaç saniye",ss:"%d saniye",m:"bir dakika",mm:"%d dakika",h:"bir saat",hh:"%d saat",d:"bir gün",dd:"%d gün",w:"bir hafta",ww:"%d hafta",M:"bir ay",MM:"%d ay",y:"bir yıl",yy:"%d yıl"},ordinal:function(e,t){switch(t){case"d":case"D":case"Do":case"DD":return e;default:var i;return 0===e?e+"'ıncı":e+(Cr[i=e%10]||Cr[e%100-i]||Cr[100<=e?100:null])}},week:{dow:1,doy:7}}),t.defineLocale("tzl",{months:"Januar_Fevraglh_Març_Avrïu_Mai_Gün_Julia_Guscht_Setemvar_Listopäts_Noemvar_Zecemvar".split("_"),monthsShort:"Jan_Fev_Mar_Avr_Mai_Gün_Jul_Gus_Set_Lis_Noe_Zec".split("_"),weekdays:"Súladi_Lúneçi_Maitzi_Márcuri_Xhúadi_Viénerçi_Sáturi".split("_"),weekdaysShort:"Súl_Lún_Mai_Már_Xhú_Vié_Sát".split("_"),weekdaysMin:"Sú_Lú_Ma_Má_Xh_Vi_Sá".split("_"),longDateFormat:{LT:"HH.mm",LTS:"HH.mm.ss",L:"DD.MM.YYYY",LL:"D. MMMM [dallas] YYYY",LLL:"D. MMMM [dallas] YYYY HH.mm",LLLL:"dddd, [li] D. MMMM [dallas] YYYY HH.mm"},meridiemParse:/d\'o|d\'a/i,isPM:function(e){return"d'o"===e.toLowerCase()},meridiem:function(e,t,i){return 11<e?i?"d'o":"D'O":i?"d'a":"D'A"},calendar:{sameDay:"[oxhi à] LT",nextDay:"[demà à] LT",nextWeek:"dddd [à] LT",lastDay:"[ieiri à] LT",lastWeek:"[sür el] dddd [lasteu à] LT",sameElse:"L"},relativeTime:{future:"osprei %s",past:"ja%s",s:Dr,ss:Dr,m:Dr,mm:Dr,h:Dr,hh:Dr,d:Dr,dd:Dr,M:Dr,MM:Dr,y:Dr,yy:Dr},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}}),t.defineLocale("tzm-latn",{months:"innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir".split("_"),monthsShort:"innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir".split("_"),weekdays:"asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas".split("_"),weekdaysShort:"asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas".split("_"),weekdaysMin:"asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[asdkh g] LT",nextDay:"[aska g] LT",nextWeek:"dddd [g] LT",lastDay:"[assant g] LT",lastWeek:"dddd [g] LT",sameElse:"L"},relativeTime:{future:"dadkh s yan %s",past:"yan %s",s:"imik",ss:"%d imik",m:"minuḍ",mm:"%d minuḍ",h:"saɛa",hh:"%d tassaɛin",d:"ass",dd:"%d ossan",M:"ayowr",MM:"%d iyyirn",y:"asgas",yy:"%d isgasn"},week:{dow:6,doy:12}}),t.defineLocale("tzm",{months:"ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ".split("_"),monthsShort:"ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ".split("_"),weekdays:"ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ".split("_"),weekdaysShort:"ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ".split("_"),weekdaysMin:"ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[ⴰⵙⴷⵅ ⴴ] LT",nextDay:"[ⴰⵙⴽⴰ ⴴ] LT",nextWeek:"dddd [ⴴ] LT",lastDay:"[ⴰⵚⴰⵏⵜ ⴴ] LT",lastWeek:"dddd [ⴴ] LT",sameElse:"L"},relativeTime:{future:"ⴷⴰⴷⵅ ⵙ ⵢⴰⵏ %s",past:"ⵢⴰⵏ %s",s:"ⵉⵎⵉⴽ",ss:"%d ⵉⵎⵉⴽ",m:"ⵎⵉⵏⵓⴺ",mm:"%d ⵎⵉⵏⵓⴺ",h:"ⵙⴰⵄⴰ",hh:"%d ⵜⴰⵙⵙⴰⵄⵉⵏ",d:"ⴰⵙⵙ",dd:"%d oⵙⵙⴰⵏ",M:"ⴰⵢoⵓⵔ",MM:"%d ⵉⵢⵢⵉⵔⵏ",y:"ⴰⵙⴳⴰⵙ",yy:"%d ⵉⵙⴳⴰⵙⵏ"},week:{dow:6,doy:12}}),t.defineLocale("ug-cn",{months:"يانۋار_فېۋرال_مارت_ئاپرېل_ماي_ئىيۇن_ئىيۇل_ئاۋغۇست_سېنتەبىر_ئۆكتەبىر_نويابىر_دېكابىر".split("_"),monthsShort:"يانۋار_فېۋرال_مارت_ئاپرېل_ماي_ئىيۇن_ئىيۇل_ئاۋغۇست_سېنتەبىر_ئۆكتەبىر_نويابىر_دېكابىر".split("_"),weekdays:"يەكشەنبە_دۈشەنبە_سەيشەنبە_چارشەنبە_پەيشەنبە_جۈمە_شەنبە".split("_"),weekdaysShort:"يە_دۈ_سە_چا_پە_جۈ_شە".split("_"),weekdaysMin:"يە_دۈ_سە_چا_پە_جۈ_شە".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY-يىلىM-ئاينىڭD-كۈنى",LLL:"YYYY-يىلىM-ئاينىڭD-كۈنى، HH:mm",LLLL:"dddd، YYYY-يىلىM-ئاينىڭD-كۈنى، HH:mm"},meridiemParse:/\u064a\u06d0\u0631\u0649\u0645 \u0643\u06d0\u0686\u06d5|\u0633\u06d5\u06be\u06d5\u0631|\u0686\u06c8\u0634\u062a\u0649\u0646 \u0628\u06c7\u0631\u06c7\u0646|\u0686\u06c8\u0634|\u0686\u06c8\u0634\u062a\u0649\u0646 \u0643\u06d0\u064a\u0649\u0646|\u0643\u06d5\u0686/,meridiemHour:function(e,t){return 12===e&&(e=0),"يېرىم كېچە"===t||"سەھەر"===t||"چۈشتىن بۇرۇن"===t||"چۈشتىن كېيىن"!==t&&"كەچ"!==t&&11<=e?e:e+12},meridiem:function(e,t,i){return(e=100*e+t)<600?"يېرىم كېچە":e<900?"سەھەر":e<1130?"چۈشتىن بۇرۇن":e<1230?"چۈش":e<1800?"چۈشتىن كېيىن":"كەچ"},calendar:{sameDay:"[بۈگۈن سائەت] LT",nextDay:"[ئەتە سائەت] LT",nextWeek:"[كېلەركى] dddd [سائەت] LT",lastDay:"[تۆنۈگۈن] LT",lastWeek:"[ئالدىنقى] dddd [سائەت] LT",sameElse:"L"},relativeTime:{future:"%s كېيىن",past:"%s بۇرۇن",s:"نەچچە سېكونت",ss:"%d سېكونت",m:"بىر مىنۇت",mm:"%d مىنۇت",h:"بىر سائەت",hh:"%d سائەت",d:"بىر كۈن",dd:"%d كۈن",M:"بىر ئاي",MM:"%d ئاي",y:"بىر يىل",yy:"%d يىل"},dayOfMonthOrdinalParse:/\d{1,2}(-\u0643\u06c8\u0646\u0649|-\u0626\u0627\u064a|-\u06be\u06d5\u067e\u062a\u06d5)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"-كۈنى";case"w":case"W":return e+"-ھەپتە";default:return e}},preparse:function(e){return e.replace(/\u060c/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:1,doy:7}}),t.defineLocale("uk",{months:{format:"січня_лютого_березня_квітня_травня_червня_липня_серпня_вересня_жовтня_листопада_грудня".split("_"),standalone:"січень_лютий_березень_квітень_травень_червень_липень_серпень_вересень_жовтень_листопад_грудень".split("_")},monthsShort:"січ_лют_бер_квіт_трав_черв_лип_серп_вер_жовт_лист_груд".split("_"),weekdays:function(e,t){var i={nominative:"неділя_понеділок_вівторок_середа_четвер_п’ятниця_субота".split("_"),accusative:"неділю_понеділок_вівторок_середу_четвер_п’ятницю_суботу".split("_"),genitive:"неділі_понеділка_вівторка_середи_четверга_п’ятниці_суботи".split("_")};return!0===e?i.nominative.slice(1,7).concat(i.nominative.slice(0,1)):e?i[/(\[[\u0412\u0432\u0423\u0443]\]) ?dddd/.test(t)?"accusative":/\[?(?:\u043c\u0438\u043d\u0443\u043b\u043e\u0457|\u043d\u0430\u0441\u0442\u0443\u043f\u043d\u043e\u0457)? ?\] ?dddd/.test(t)?"genitive":"nominative"][e.day()]:i.nominative},weekdaysShort:"нд_пн_вт_ср_чт_пт_сб".split("_"),weekdaysMin:"нд_пн_вт_ср_чт_пт_сб".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY р.",LLL:"D MMMM YYYY р., HH:mm",LLLL:"dddd, D MMMM YYYY р., HH:mm"},calendar:{sameDay:Or("[Сьогодні "),nextDay:Or("[Завтра "),lastDay:Or("[Вчора "),nextWeek:Or("[У] dddd ["),lastWeek:function(){switch(this.day()){case 0:case 3:case 5:case 6:return Or("[Минулої] dddd [").call(this);case 1:case 2:case 4:return Or("[Минулого] dddd [").call(this)}},sameElse:"L"},relativeTime:{future:"за %s",past:"%s тому",s:"декілька секунд",ss:Er,m:Er,mm:Er,h:"годину",hh:Er,d:"день",dd:Er,M:"місяць",MM:Er,y:"рік",yy:Er},meridiemParse:/\u043d\u043e\u0447\u0456|\u0440\u0430\u043d\u043a\u0443|\u0434\u043d\u044f|\u0432\u0435\u0447\u043e\u0440\u0430/,isPM:function(e){return/^(\u0434\u043d\u044f|\u0432\u0435\u0447\u043e\u0440\u0430)$/.test(e)},meridiem:function(e,t,i){return e<4?"ночі":e<12?"ранку":e<17?"дня":"вечора"},dayOfMonthOrdinalParse:/\d{1,2}-(\u0439|\u0433\u043e)/,ordinal:function(e,t){switch(t){case"M":case"d":case"DDD":case"w":case"W":return e+"-й";case"D":return e+"-го";default:return e}},week:{dow:1,doy:7}}),Z=["جنوری","فروری","مارچ","اپریل","مئی","جون","جولائی","اگست","ستمبر","اکتوبر","نومبر","دسمبر"],vi=["اتوار","پیر","منگل","بدھ","جمعرات","جمعہ","ہفتہ"],t.defineLocale("ur",{months:Z,monthsShort:Z,weekdays:vi,weekdaysShort:vi,weekdaysMin:vi,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd، D MMMM YYYY HH:mm"},meridiemParse:/\u0635\u0628\u062d|\u0634\u0627\u0645/,isPM:function(e){return"شام"===e},meridiem:function(e,t,i){return e<12?"صبح":"شام"},calendar:{sameDay:"[آج بوقت] LT",nextDay:"[کل بوقت] LT",nextWeek:"dddd [بوقت] LT",lastDay:"[گذشتہ روز بوقت] LT",lastWeek:"[گذشتہ] dddd [بوقت] LT",sameElse:"L"},relativeTime:{future:"%s بعد",past:"%s قبل",s:"چند سیکنڈ",ss:"%d سیکنڈ",m:"ایک منٹ",mm:"%d منٹ",h:"ایک گھنٹہ",hh:"%d گھنٹے",d:"ایک دن",dd:"%d دن",M:"ایک ماہ",MM:"%d ماہ",y:"ایک سال",yy:"%d سال"},preparse:function(e){return e.replace(/\u060c/g,",")},postformat:function(e){return e.replace(/,/g,"،")},week:{dow:1,doy:4}}),t.defineLocale("uz-latn",{months:"Yanvar_Fevral_Mart_Aprel_May_Iyun_Iyul_Avgust_Sentabr_Oktabr_Noyabr_Dekabr".split("_"),monthsShort:"Yan_Fev_Mar_Apr_May_Iyun_Iyul_Avg_Sen_Okt_Noy_Dek".split("_"),weekdays:"Yakshanba_Dushanba_Seshanba_Chorshanba_Payshanba_Juma_Shanba".split("_"),weekdaysShort:"Yak_Dush_Sesh_Chor_Pay_Jum_Shan".split("_"),weekdaysMin:"Ya_Du_Se_Cho_Pa_Ju_Sha".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"D MMMM YYYY, dddd HH:mm"},calendar:{sameDay:"[Bugun soat] LT [da]",nextDay:"[Ertaga] LT [da]",nextWeek:"dddd [kuni soat] LT [da]",lastDay:"[Kecha soat] LT [da]",lastWeek:"[O'tgan] dddd [kuni soat] LT [da]",sameElse:"L"},relativeTime:{future:"Yaqin %s ichida",past:"Bir necha %s oldin",s:"soniya",ss:"%d soniya",m:"bir daqiqa",mm:"%d daqiqa",h:"bir soat",hh:"%d soat",d:"bir kun",dd:"%d kun",M:"bir oy",MM:"%d oy",y:"bir yil",yy:"%d yil"},week:{dow:1,doy:7}}),t.defineLocale("uz",{months:"январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр".split("_"),monthsShort:"янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек".split("_"),weekdays:"Якшанба_Душанба_Сешанба_Чоршанба_Пайшанба_Жума_Шанба".split("_"),weekdaysShort:"Якш_Душ_Сеш_Чор_Пай_Жум_Шан".split("_"),weekdaysMin:"Як_Ду_Се_Чо_Па_Жу_Ша".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"D MMMM YYYY, dddd HH:mm"},calendar:{sameDay:"[Бугун соат] LT [да]",nextDay:"[Эртага] LT [да]",nextWeek:"dddd [куни соат] LT [да]",lastDay:"[Кеча соат] LT [да]",lastWeek:"[Утган] dddd [куни соат] LT [да]",sameElse:"L"},relativeTime:{future:"Якин %s ичида",past:"Бир неча %s олдин",s:"фурсат",ss:"%d фурсат",m:"бир дакика",mm:"%d дакика",h:"бир соат",hh:"%d соат",d:"бир кун",dd:"%d кун",M:"бир ой",MM:"%d ой",y:"бир йил",yy:"%d йил"},week:{dow:1,doy:7}}),t.defineLocale("vi",{months:"tháng 1_tháng 2_tháng 3_tháng 4_tháng 5_tháng 6_tháng 7_tháng 8_tháng 9_tháng 10_tháng 11_tháng 12".split("_"),monthsShort:"Thg 01_Thg 02_Thg 03_Thg 04_Thg 05_Thg 06_Thg 07_Thg 08_Thg 09_Thg 10_Thg 11_Thg 12".split("_"),monthsParseExact:!0,weekdays:"chủ nhật_thứ hai_thứ ba_thứ tư_thứ năm_thứ sáu_thứ bảy".split("_"),weekdaysShort:"CN_T2_T3_T4_T5_T6_T7".split("_"),weekdaysMin:"CN_T2_T3_T4_T5_T6_T7".split("_"),weekdaysParseExact:!0,meridiemParse:/sa|ch/i,isPM:function(e){return/^ch$/i.test(e)},meridiem:function(e,t,i){return e<12?i?"sa":"SA":i?"ch":"CH"},longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM [năm] YYYY",LLL:"D MMMM [năm] YYYY HH:mm",LLLL:"dddd, D MMMM [năm] YYYY HH:mm",l:"DD/M/YYYY",ll:"D MMM YYYY",lll:"D MMM YYYY HH:mm",llll:"ddd, D MMM YYYY HH:mm"},calendar:{sameDay:"[Hôm nay lúc] LT",nextDay:"[Ngày mai lúc] LT",nextWeek:"dddd [tuần tới lúc] LT",lastDay:"[Hôm qua lúc] LT",lastWeek:"dddd [tuần trước lúc] LT",sameElse:"L"},relativeTime:{future:"%s tới",past:"%s trước",s:"vài giây",ss:"%d giây",m:"một phút",mm:"%d phút",h:"một giờ",hh:"%d giờ",d:"một ngày",dd:"%d ngày",w:"một tuần",ww:"%d tuần",M:"một tháng",MM:"%d tháng",y:"một năm",yy:"%d năm"},dayOfMonthOrdinalParse:/\d{1,2}/,ordinal:function(e){return e},week:{dow:1,doy:4}}),t.defineLocale("x-pseudo",{months:"J~áñúá~rý_F~ébrú~árý_~Márc~h_Áp~ríl_~Máý_~Júñé~_Júl~ý_Áú~gúst~_Sép~témb~ér_Ó~ctób~ér_Ñ~óvém~bér_~Décé~mbér".split("_"),monthsShort:"J~áñ_~Féb_~Már_~Ápr_~Máý_~Júñ_~Júl_~Áúg_~Sép_~Óct_~Ñóv_~Déc".split("_"),monthsParseExact:!0,weekdays:"S~úñdá~ý_Mó~ñdáý~_Túé~sdáý~_Wéd~ñésd~áý_T~húrs~dáý_~Fríd~áý_S~átúr~dáý".split("_"),weekdaysShort:"S~úñ_~Móñ_~Túé_~Wéd_~Thú_~Frí_~Sát".split("_"),weekdaysMin:"S~ú_Mó~_Tú_~Wé_T~h_Fr~_Sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[T~ódá~ý át] LT",nextDay:"[T~ómó~rró~w át] LT",nextWeek:"dddd [át] LT",lastDay:"[Ý~ést~érdá~ý át] LT",lastWeek:"[L~ást] dddd [át] LT",sameElse:"L"},relativeTime:{future:"í~ñ %s",past:"%s á~gó",s:"á ~féw ~sécó~ñds",ss:"%d s~écóñ~ds",m:"á ~míñ~úté",mm:"%d m~íñú~tés",h:"á~ñ hó~úr",hh:"%d h~óúrs",d:"á ~dáý",dd:"%d d~áýs",M:"á ~móñ~th",MM:"%d m~óñt~hs",y:"á ~ýéár",yy:"%d ý~éárs"},dayOfMonthOrdinalParse:/\d{1,2}(th|st|nd|rd)/,ordinal:function(e){var t=e%10;return e+(1==~~(e%100/10)?"th":1==t?"st":2==t?"nd":3==t?"rd":"th")},week:{dow:1,doy:4}}),t.defineLocale("yo",{months:"Sẹ́rẹ́_Èrèlè_Ẹrẹ̀nà_Ìgbé_Èbibi_Òkùdu_Agẹmo_Ògún_Owewe_Ọ̀wàrà_Bélú_Ọ̀pẹ̀̀".split("_"),monthsShort:"Sẹ́r_Èrl_Ẹrn_Ìgb_Èbi_Òkù_Agẹ_Ògú_Owe_Ọ̀wà_Bél_Ọ̀pẹ̀̀".split("_"),weekdays:"Àìkú_Ajé_Ìsẹ́gun_Ọjọ́rú_Ọjọ́bọ_Ẹtì_Àbámẹ́ta".split("_"),weekdaysShort:"Àìk_Ajé_Ìsẹ́_Ọjr_Ọjb_Ẹtì_Àbá".split("_"),weekdaysMin:"Àì_Aj_Ìs_Ọr_Ọb_Ẹt_Àb".split("_"),longDateFormat:{LT:"h:mm A",LTS:"h:mm:ss A",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY h:mm A",LLLL:"dddd, D MMMM YYYY h:mm A"},calendar:{sameDay:"[Ònì ni] LT",nextDay:"[Ọ̀la ni] LT",nextWeek:"dddd [Ọsẹ̀ tón'bọ] [ni] LT",lastDay:"[Àna ni] LT",lastWeek:"dddd [Ọsẹ̀ tólọ́] [ni] LT",sameElse:"L"},relativeTime:{future:"ní %s",past:"%s kọjá",s:"ìsẹjú aayá die",ss:"aayá %d",m:"ìsẹjú kan",mm:"ìsẹjú %d",h:"wákati kan",hh:"wákati %d",d:"ọjọ́ kan",dd:"ọjọ́ %d",M:"osù kan",MM:"osù %d",y:"ọdún kan",yy:"ọdún %d"},dayOfMonthOrdinalParse:/\u1ecdj\u1ecd\u0301\s\d{1,2}/,ordinal:"ọjọ́ %d",week:{dow:1,doy:4}}),t.defineLocale("zh-cn",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"周日_周一_周二_周三_周四_周五_周六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日Ah点mm分",LLLL:"YYYY年M月D日ddddAh点mm分",l:"YYYY/M/D",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/\u51cc\u6668|\u65e9\u4e0a|\u4e0a\u5348|\u4e2d\u5348|\u4e0b\u5348|\u665a\u4e0a/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t||"下午"!==t&&"晚上"!==t&&11<=e?e:e+12},meridiem:function(e,t,i){return(e=100*e+t)<600?"凌晨":e<900?"早上":e<1130?"上午":e<1230?"中午":e<1800?"下午":"晚上"},calendar:{sameDay:"[今天]LT",nextDay:"[明天]LT",nextWeek:function(e){return e.week()!==this.week()?"[下]dddLT":"[本]dddLT"},lastDay:"[昨天]LT",lastWeek:function(e){return this.week()!==e.week()?"[上]dddLT":"[本]dddLT"},sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(\u65e5|\u6708|\u5468)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"周";default:return e}},relativeTime:{future:"%s后",past:"%s前",s:"几秒",ss:"%d 秒",m:"1 分钟",mm:"%d 分钟",h:"1 小时",hh:"%d 小时",d:"1 天",dd:"%d 天",w:"1 周",ww:"%d 周",M:"1 个月",MM:"%d 个月",y:"1 年",yy:"%d 年"},week:{dow:1,doy:4}}),t.defineLocale("zh-hk",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"週日_週一_週二_週三_週四_週五_週六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日dddd HH:mm",l:"YYYY/M/D",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/\u51cc\u6668|\u65e9\u4e0a|\u4e0a\u5348|\u4e2d\u5348|\u4e0b\u5348|\u665a\u4e0a/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t?e:"中午"===t?11<=e?e:e+12:"下午"===t||"晚上"===t?e+12:void 0},meridiem:function(e,t,i){return(e=100*e+t)<600?"凌晨":e<900?"早上":e<1200?"上午":1200===e?"中午":e<1800?"下午":"晚上"},calendar:{sameDay:"[今天]LT",nextDay:"[明天]LT",nextWeek:"[下]ddddLT",lastDay:"[昨天]LT",lastWeek:"[上]ddddLT",sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(\u65e5|\u6708|\u9031)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"週";default:return e}},relativeTime:{future:"%s後",past:"%s前",s:"幾秒",ss:"%d 秒",m:"1 分鐘",mm:"%d 分鐘",h:"1 小時",hh:"%d 小時",d:"1 天",dd:"%d 天",M:"1 個月",MM:"%d 個月",y:"1 年",yy:"%d 年"}}),t.defineLocale("zh-mo",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"週日_週一_週二_週三_週四_週五_週六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日dddd HH:mm",l:"D/M/YYYY",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/\u51cc\u6668|\u65e9\u4e0a|\u4e0a\u5348|\u4e2d\u5348|\u4e0b\u5348|\u665a\u4e0a/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t?e:"中午"===t?11<=e?e:e+12:"下午"===t||"晚上"===t?e+12:void 0},meridiem:function(e,t,i){return(e=100*e+t)<600?"凌晨":e<900?"早上":e<1130?"上午":e<1230?"中午":e<1800?"下午":"晚上"},calendar:{sameDay:"[今天] LT",nextDay:"[明天] LT",nextWeek:"[下]dddd LT",lastDay:"[昨天] LT",lastWeek:"[上]dddd LT",sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(\u65e5|\u6708|\u9031)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"週";default:return e}},relativeTime:{future:"%s內",past:"%s前",s:"幾秒",ss:"%d 秒",m:"1 分鐘",mm:"%d 分鐘",h:"1 小時",hh:"%d 小時",d:"1 天",dd:"%d 天",M:"1 個月",MM:"%d 個月",y:"1 年",yy:"%d 年"}}),t.defineLocale("zh-tw",{months:"一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"),weekdaysShort:"週日_週一_週二_週三_週四_週五_週六".split("_"),weekdaysMin:"日_一_二_三_四_五_六".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日dddd HH:mm",l:"YYYY/M/D",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日dddd HH:mm"},meridiemParse:/\u51cc\u6668|\u65e9\u4e0a|\u4e0a\u5348|\u4e2d\u5348|\u4e0b\u5348|\u665a\u4e0a/,meridiemHour:function(e,t){return 12===e&&(e=0),"凌晨"===t||"早上"===t||"上午"===t?e:"中午"===t?11<=e?e:e+12:"下午"===t||"晚上"===t?e+12:void 0},meridiem:function(e,t,i){return(e=100*e+t)<600?"凌晨":e<900?"早上":e<1130?"上午":e<1230?"中午":e<1800?"下午":"晚上"},calendar:{sameDay:"[今天] LT",nextDay:"[明天] LT",nextWeek:"[下]dddd LT",lastDay:"[昨天] LT",lastWeek:"[上]dddd LT",sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}(\u65e5|\u6708|\u9031)/,ordinal:function(e,t){switch(t){case"d":case"D":case"DDD":return e+"日";case"M":return e+"月";case"w":case"W":return e+"週";default:return e}},relativeTime:{future:"%s後",past:"%s前",s:"幾秒",ss:"%d 秒",m:"1 分鐘",mm:"%d 分鐘",h:"1 小時",hh:"%d 小時",d:"1 天",dd:"%d 天",M:"1 個月",MM:"%d 個月",y:"1 年",yy:"%d 年"}}),t.locale("en"),t})),function(e){"function"==typeof define&&define.amd?define([],e):"object"==typeof exports?module.exports=e():window.wNumb=e()}((function(){"use strict";var e=["decimals","thousand","mark","prefix","suffix","encoder","decoder","negativeBefore","negative","edit","undo"];function t(e){return e.split("").reverse().join("")}function i(e,t){return e.substring(0,t.length)===t}function n(e,t,i){if((e[t]||e[i])&&e[t]===e[i])throw new Error(t)}function r(e){return"number"==typeof e&&isFinite(e)}function a(e,i,n,a,s,o,l,c,u,d,h,f){var p,m,g,v,y,b=f,x="",_="";return o&&(f=o(f)),!!r(f)&&(!1!==e&&0===parseFloat(f.toFixed(e))&&(f=0),f<0&&(p=!0,f=Math.abs(f)),!1!==e&&(y=e,v=(v=f).toString().split("e"),f=(+((v=(v=Math.round(+(v[0]+"e"+(v[1]?+v[1]+y:y)))).toString().split("e"))[0]+"e"+(v[1]?+v[1]-y:-y))).toFixed(y)),-1!==(f=f.toString()).indexOf(".")?(g=(m=f.split("."))[0],n&&(x=n+m[1])):g=f,i&&(g=t(g).match(/.{1,3}/g),g=t(g.join(t(i)))),p&&c&&(_+=c),a&&(_+=a),p&&u&&(_+=u),_+=g,_+=x,s&&(_+=s),d&&(_=d(_,b)),_)}function s(e,t,n,a,s,o,l,c,u,d,h,f){var p,m="";return h&&(f=h(f)),!(!f||"string"!=typeof f)&&(c&&i(f,c)&&(f=f.replace(c,""),p=!0),a&&i(f,a)&&(f=f.replace(a,"")),u&&i(f,u)&&(f=f.replace(u,""),p=!0),s&&function(e,t){return e.slice(-1*t.length)===t}(f,s)&&(f=f.slice(0,-1*s.length)),t&&(f=f.split(t).join("")),n&&(f=f.replace(n,".")),p&&(m+="-"),""!==(m=(m+=f).replace(/[^0-9\.\-.]/g,""))&&(m=Number(m),l&&(m=l(m)),!!r(m)&&m))}function o(t,i,n){var r,a=[];for(r=0;r<e.length;r+=1)a.push(t[e[r]]);return a.push(n),i.apply("",a)}return function t(i){if(!(this instanceof t))return new t(i);"object"==typeof i&&(i=function(t){var i,r,a,s={};for(void 0===t.suffix&&(t.suffix=t.postfix),i=0;i<e.length;i+=1)if(void 0===(a=t[r=e[i]]))"negative"!==r||s.negativeBefore?"mark"===r&&"."!==s.thousand?s[r]=".":s[r]=!1:s[r]="-";else if("decimals"===r){if(!(a>=0&&a<8))throw new Error(r);s[r]=a}else if("encoder"===r||"decoder"===r||"edit"===r||"undo"===r){if("function"!=typeof a)throw new Error(r);s[r]=a}else{if("string"!=typeof a)throw new Error(r);s[r]=a}return n(s,"mark","thousand"),n(s,"prefix","negative"),n(s,"prefix","negativeBefore"),s}(i),this.to=function(e){return o(i,a,e)},this.from=function(e){return o(i,s,e)})}})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(e="undefined"!=typeof globalThis?globalThis:e||self).axios=t()}(this,(function(){"use strict";function e(e){var i,n;function r(i,n){try{var s=e[i](n),o=s.value,l=o instanceof t;Promise.resolve(l?o.v:o).then((function(t){if(l){var n="return"===i?"return":"next";if(!o.k||t.done)return r(n,t);t=e[n](t).value}a(s.done?"return":"normal",t)}),(function(e){r("throw",e)}))}catch(e){a("throw",e)}}function a(e,t){switch(e){case"return":i.resolve({value:t,done:!0});break;case"throw":i.reject(t);break;default:i.resolve({value:t,done:!1})}(i=i.next)?r(i.key,i.arg):n=null}this._invoke=function(e,t){return new Promise((function(a,s){var o={key:e,arg:t,resolve:a,reject:s,next:null};n?n=n.next=o:(i=n=o,r(e,t))}))},"function"!=typeof e.return&&(this.return=void 0)}function t(e,t){this.v=e,this.k=t}function i(e){var i={},n=!1;function r(i,r){return n=!0,r=new Promise((function(t){t(e[i](r))})),{done:!1,value:new t(r,1)}}return i["undefined"!=typeof Symbol&&Symbol.iterator||"@@iterator"]=function(){return this},i.next=function(e){return n?(n=!1,e):r("next",e)},"function"==typeof e.throw&&(i.throw=function(e){if(n)throw n=!1,e;return r("throw",e)}),"function"==typeof e.return&&(i.return=function(e){return n?(n=!1,e):r("return",e)}),i}function n(e){var t,i,n,a=2;for("undefined"!=typeof Symbol&&(i=Symbol.asyncIterator,n=Symbol.iterator);a--;){if(i&&null!=(t=e[i]))return t.call(e);if(n&&null!=(t=e[n]))return new r(t.call(e));i="@@asyncIterator",n="@@iterator"}throw new TypeError("Object is not async iterable")}function r(e){function t(e){if(Object(e)!==e)return Promise.reject(new TypeError(e+" is not an object."));var t=e.done;return Promise.resolve(e.value).then((function(e){return{value:e,done:t}}))}return r=function(e){this.s=e,this.n=e.next},r.prototype={s:null,n:null,next:function(){return t(this.n.apply(this.s,arguments))},return:function(e){var i=this.s.return;return void 0===i?Promise.resolve({value:e,done:!0}):t(i.apply(this.s,arguments))},throw:function(e){var i=this.s.return;return void 0===i?Promise.reject(e):t(i.apply(this.s,arguments))}},new r(e)}function a(e){return new t(e,0)}function s(e,t){var i=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),i.push.apply(i,n)}return i}function o(e){for(var t=1;t<arguments.length;t++){var i=null!=arguments[t]?arguments[t]:{};t%2?s(Object(i),!0).forEach((function(t){g(e,t,i[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(i)):s(Object(i)).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(i,t))}))}return e}function l(){l=function(){return t};var e,t={},i=Object.prototype,n=i.hasOwnProperty,r=Object.defineProperty||function(e,t,i){e[t]=i.value},a="function"==typeof Symbol?Symbol:{},s=a.iterator||"@@iterator",o=a.asyncIterator||"@@asyncIterator",c=a.toStringTag||"@@toStringTag";function u(e,t,i){return Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}),e[t]}try{u({},"")}catch(e){u=function(e,t,i){return e[t]=i}}function d(e,t,i,n){var a=t&&t.prototype instanceof v?t:v,s=Object.create(a.prototype),o=new D(n||[]);return r(s,"_invoke",{value:A(e,i,o)}),s}function h(e,t,i){try{return{type:"normal",arg:e.call(t,i)}}catch(e){return{type:"throw",arg:e}}}t.wrap=d;var f="suspendedStart",p="executing",m="completed",g={};function v(){}function y(){}function b(){}var x={};u(x,s,(function(){return this}));var _=Object.getPrototypeOf,w=_&&_(_(E([])));w&&w!==i&&n.call(w,s)&&(x=w);var k=b.prototype=v.prototype=Object.create(x);function M(e){["next","throw","return"].forEach((function(t){u(e,t,(function(e){return this._invoke(t,e)}))}))}function S(e,t){function i(r,a,s,o){var l=h(e[r],e,a);if("throw"!==l.type){var c=l.arg,u=c.value;return u&&"object"==typeof u&&n.call(u,"__await")?t.resolve(u.__await).then((function(e){i("next",e,s,o)}),(function(e){i("throw",e,s,o)})):t.resolve(u).then((function(e){c.value=e,s(c)}),(function(e){return i("throw",e,s,o)}))}o(l.arg)}var a;r(this,"_invoke",{value:function(e,n){function r(){return new t((function(t,r){i(e,n,t,r)}))}return a=a?a.then(r,r):r()}})}function A(t,i,n){var r=f;return function(a,s){if(r===p)throw new Error("Generator is already running");if(r===m){if("throw"===a)throw s;return{value:e,done:!0}}for(n.method=a,n.arg=s;;){var o=n.delegate;if(o){var l=L(o,n);if(l){if(l===g)continue;return l}}if("next"===n.method)n.sent=n._sent=n.arg;else if("throw"===n.method){if(r===f)throw r=m,n.arg;n.dispatchException(n.arg)}else"return"===n.method&&n.abrupt("return",n.arg);r=p;var c=h(t,i,n);if("normal"===c.type){if(r=n.done?m:"suspendedYield",c.arg===g)continue;return{value:c.arg,done:n.done}}"throw"===c.type&&(r=m,n.method="throw",n.arg=c.arg)}}}function L(t,i){var n=i.method,r=t.iterator[n];if(r===e)return i.delegate=null,"throw"===n&&t.iterator.return&&(i.method="return",i.arg=e,L(t,i),"throw"===i.method)||"return"!==n&&(i.method="throw",i.arg=new TypeError("The iterator does not provide a '"+n+"' method")),g;var a=h(r,t.iterator,i.arg);if("throw"===a.type)return i.method="throw",i.arg=a.arg,i.delegate=null,g;var s=a.arg;return s?s.done?(i[t.resultName]=s.value,i.next=t.nextLoc,"return"!==i.method&&(i.method="next",i.arg=e),i.delegate=null,g):s:(i.method="throw",i.arg=new TypeError("iterator result is not an object"),i.delegate=null,g)}function T(e){var t={tryLoc:e[0]};1 in e&&(t.catchLoc=e[1]),2 in e&&(t.finallyLoc=e[2],t.afterLoc=e[3]),this.tryEntries.push(t)}function C(e){var t=e.completion||{};t.type="normal",delete t.arg,e.completion=t}function D(e){this.tryEntries=[{tryLoc:"root"}],e.forEach(T,this),this.reset(!0)}function E(t){if(t||""===t){var i=t[s];if(i)return i.call(t);if("function"==typeof t.next)return t;if(!isNaN(t.length)){var r=-1,a=function i(){for(;++r<t.length;)if(n.call(t,r))return i.value=t[r],i.done=!1,i;return i.value=e,i.done=!0,i};return a.next=a}}throw new TypeError(typeof t+" is not iterable")}return y.prototype=b,r(k,"constructor",{value:b,configurable:!0}),r(b,"constructor",{value:y,configurable:!0}),y.displayName=u(b,c,"GeneratorFunction"),t.isGeneratorFunction=function(e){var t="function"==typeof e&&e.constructor;return!!t&&(t===y||"GeneratorFunction"===(t.displayName||t.name))},t.mark=function(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,b):(e.__proto__=b,u(e,c,"GeneratorFunction")),e.prototype=Object.create(k),e},t.awrap=function(e){return{__await:e}},M(S.prototype),u(S.prototype,o,(function(){return this})),t.AsyncIterator=S,t.async=function(e,i,n,r,a){void 0===a&&(a=Promise);var s=new S(d(e,i,n,r),a);return t.isGeneratorFunction(i)?s:s.next().then((function(e){return e.done?e.value:s.next()}))},M(k),u(k,c,"Generator"),u(k,s,(function(){return this})),u(k,"toString",(function(){return"[object Generator]"})),t.keys=function(e){var t=Object(e),i=[];for(var n in t)i.push(n);return i.reverse(),function e(){for(;i.length;){var n=i.pop();if(n in t)return e.value=n,e.done=!1,e}return e.done=!0,e}},t.values=E,D.prototype={constructor:D,reset:function(t){if(this.prev=0,this.next=0,this.sent=this._sent=e,this.done=!1,this.delegate=null,this.method="next",this.arg=e,this.tryEntries.forEach(C),!t)for(var i in this)"t"===i.charAt(0)&&n.call(this,i)&&!isNaN(+i.slice(1))&&(this[i]=e)},stop:function(){this.done=!0;var e=this.tryEntries[0].completion;if("throw"===e.type)throw e.arg;return this.rval},dispatchException:function(t){if(this.done)throw t;var i=this;function r(n,r){return o.type="throw",o.arg=t,i.next=n,r&&(i.method="next",i.arg=e),!!r}for(var a=this.tryEntries.length-1;a>=0;--a){var s=this.tryEntries[a],o=s.completion;if("root"===s.tryLoc)return r("end");if(s.tryLoc<=this.prev){var l=n.call(s,"catchLoc"),c=n.call(s,"finallyLoc");if(l&&c){if(this.prev<s.catchLoc)return r(s.catchLoc,!0);if(this.prev<s.finallyLoc)return r(s.finallyLoc)}else if(l){if(this.prev<s.catchLoc)return r(s.catchLoc,!0)}else{if(!c)throw new Error("try statement without catch or finally");if(this.prev<s.finallyLoc)return r(s.finallyLoc)}}}},abrupt:function(e,t){for(var i=this.tryEntries.length-1;i>=0;--i){var r=this.tryEntries[i];if(r.tryLoc<=this.prev&&n.call(r,"finallyLoc")&&this.prev<r.finallyLoc){var a=r;break}}a&&("break"===e||"continue"===e)&&a.tryLoc<=t&&t<=a.finallyLoc&&(a=null);var s=a?a.completion:{};return s.type=e,s.arg=t,a?(this.method="next",this.next=a.finallyLoc,g):this.complete(s)},complete:function(e,t){if("throw"===e.type)throw e.arg;return"break"===e.type||"continue"===e.type?this.next=e.arg:"return"===e.type?(this.rval=this.arg=e.arg,this.method="return",this.next="end"):"normal"===e.type&&t&&(this.next=t),g},finish:function(e){for(var t=this.tryEntries.length-1;t>=0;--t){var i=this.tryEntries[t];if(i.finallyLoc===e)return this.complete(i.completion,i.afterLoc),C(i),g}},catch:function(e){for(var t=this.tryEntries.length-1;t>=0;--t){var i=this.tryEntries[t];if(i.tryLoc===e){var n=i.completion;if("throw"===n.type){var r=n.arg;C(i)}return r}}throw new Error("illegal catch attempt")},delegateYield:function(t,i,n){return this.delegate={iterator:E(t),resultName:i,nextLoc:n},"next"===this.method&&(this.arg=e),g}},t}function c(e){var t=function(e,t){if("object"!=typeof e||!e)return e;var i=e[Symbol.toPrimitive];if(void 0!==i){var n=i.call(e,"string");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==typeof t?t:String(t)}function u(e){return u="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},u(e)}function d(e,t,i,n,r,a,s){try{var o=e[a](s),l=o.value}catch(e){return void i(e)}o.done?t(l):Promise.resolve(l).then(n,r)}function h(e){return function(){var t=this,i=arguments;return new Promise((function(n,r){var a=e.apply(t,i);function s(e){d(a,n,r,s,o,"next",e)}function o(e){d(a,n,r,s,o,"throw",e)}s(void 0)}))}}function f(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function p(e,t){for(var i=0;i<t.length;i++){var n=t[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,c(n.key),n)}}function m(e,t,i){return t&&p(e.prototype,t),i&&p(e,i),Object.defineProperty(e,"prototype",{writable:!1}),e}function g(e,t,i){return(t=c(t))in e?Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}):e[t]=i,e}function v(e,t){return y(e)||function(e,t){var i=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=i){var n,r,a,s,o=[],l=!0,c=!1;try{if(a=(i=i.call(e)).next,0===t){if(Object(i)!==i)return;l=!1}else for(;!(l=(n=a.call(i)).done)&&(o.push(n.value),o.length!==t);l=!0);}catch(e){c=!0,r=e}finally{try{if(!l&&null!=i.return&&(s=i.return(),Object(s)!==s))return}finally{if(c)throw r}}return o}}(e,t)||x(e,t)||w()}function y(e){if(Array.isArray(e))return e}function b(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}function x(e,t){if(e){if("string"==typeof e)return _(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?_(e,t):void 0}}function _(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function w(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function k(e,t){return function(){return e.apply(t,arguments)}}e.prototype["function"==typeof Symbol&&Symbol.asyncIterator||"@@asyncIterator"]=function(){return this},e.prototype.next=function(e){return this._invoke("next",e)},e.prototype.throw=function(e){return this._invoke("throw",e)},e.prototype.return=function(e){return this._invoke("return",e)};var M,S=Object.prototype.toString,A=Object.getPrototypeOf,L=(M=Object.create(null),function(e){var t=S.call(e);return M[t]||(M[t]=t.slice(8,-1).toLowerCase())}),T=function(e){return e=e.toLowerCase(),function(t){return L(t)===e}},C=function(e){return function(t){return u(t)===e}},D=Array.isArray,E=C("undefined"),O=T("ArrayBuffer"),P=C("string"),Y=C("function"),I=C("number"),N=function(e){return null!==e&&"object"===u(e)},j=function(e){if("object"!==L(e))return!1;var t=A(e);return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||Symbol.toStringTag in e||Symbol.iterator in e)},H=T("Date"),F=T("File"),R=T("Blob"),z=T("FileList"),B=T("URLSearchParams"),V=v(["ReadableStream","Request","Response","Headers"].map(T),4),W=V[0],U=V[1],q=V[2],$=V[3];function X(e,t){var i,n,r=(arguments.length>2&&void 0!==arguments[2]?arguments[2]:{}).allOwnKeys,a=void 0!==r&&r;if(null!=e)if("object"!==u(e)&&(e=[e]),D(e))for(i=0,n=e.length;i<n;i++)t.call(null,e[i],i,e);else{var s,o=a?Object.getOwnPropertyNames(e):Object.keys(e),l=o.length;for(i=0;i<l;i++)s=o[i],t.call(null,e[s],s,e)}}function G(e,t){t=t.toLowerCase();for(var i,n=Object.keys(e),r=n.length;r-- >0;)if(t===(i=n[r]).toLowerCase())return i;return null}var Z,K="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:"undefined"!=typeof window?window:global,J=function(e){return!E(e)&&e!==K},Q=(Z="undefined"!=typeof Uint8Array&&A(Uint8Array),function(e){return Z&&e instanceof Z}),ee=T("HTMLFormElement"),te=function(e){var t=Object.prototype.hasOwnProperty;return function(e,i){return t.call(e,i)}}(),ie=T("RegExp"),ne=function(e,t){var i=Object.getOwnPropertyDescriptors(e),n={};X(i,(function(i,r){var a;!1!==(a=t(i,r,e))&&(n[r]=a||i)})),Object.defineProperties(e,n)},re="abcdefghijklmnopqrstuvwxyz",ae="0123456789",se={DIGIT:ae,ALPHA:re,ALPHA_DIGIT:re+re.toUpperCase()+ae},oe=T("AsyncFunction"),le={isArray:D,isArrayBuffer:O,isBuffer:function(e){return null!==e&&!E(e)&&null!==e.constructor&&!E(e.constructor)&&Y(e.constructor.isBuffer)&&e.constructor.isBuffer(e)},isFormData:function(e){var t;return e&&("function"==typeof FormData&&e instanceof FormData||Y(e.append)&&("formdata"===(t=L(e))||"object"===t&&Y(e.toString)&&"[object FormData]"===e.toString()))},isArrayBufferView:function(e){return"undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(e):e&&e.buffer&&O(e.buffer)},isString:P,isNumber:I,isBoolean:function(e){return!0===e||!1===e},isObject:N,isPlainObject:j,isReadableStream:W,isRequest:U,isResponse:q,isHeaders:$,isUndefined:E,isDate:H,isFile:F,isBlob:R,isRegExp:ie,isFunction:Y,isStream:function(e){return N(e)&&Y(e.pipe)},isURLSearchParams:B,isTypedArray:Q,isFileList:z,forEach:X,merge:function e(){for(var t=(J(this)&&this||{}).caseless,i={},n=function(n,r){var a=t&&G(i,r)||r;j(i[a])&&j(n)?i[a]=e(i[a],n):j(n)?i[a]=e({},n):D(n)?i[a]=n.slice():i[a]=n},r=0,a=arguments.length;r<a;r++)arguments[r]&&X(arguments[r],n);return i},extend:function(e,t,i){return X(t,(function(t,n){i&&Y(t)?e[n]=k(t,i):e[n]=t}),{allOwnKeys:(arguments.length>3&&void 0!==arguments[3]?arguments[3]:{}).allOwnKeys}),e},trim:function(e){return e.trim?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")},stripBOM:function(e){return 65279===e.charCodeAt(0)&&(e=e.slice(1)),e},inherits:function(e,t,i,n){e.prototype=Object.create(t.prototype,n),e.prototype.constructor=e,Object.defineProperty(e,"super",{value:t.prototype}),i&&Object.assign(e.prototype,i)},toFlatObject:function(e,t,i,n){var r,a,s,o={};if(t=t||{},null==e)return t;do{for(a=(r=Object.getOwnPropertyNames(e)).length;a-- >0;)s=r[a],n&&!n(s,e,t)||o[s]||(t[s]=e[s],o[s]=!0);e=!1!==i&&A(e)}while(e&&(!i||i(e,t))&&e!==Object.prototype);return t},kindOf:L,kindOfTest:T,endsWith:function(e,t,i){e=String(e),(void 0===i||i>e.length)&&(i=e.length),i-=t.length;var n=e.indexOf(t,i);return-1!==n&&n===i},toArray:function(e){if(!e)return null;if(D(e))return e;var t=e.length;if(!I(t))return null;for(var i=new Array(t);t-- >0;)i[t]=e[t];return i},forEachEntry:function(e,t){for(var i,n=(e&&e[Symbol.iterator]).call(e);(i=n.next())&&!i.done;){var r=i.value;t.call(e,r[0],r[1])}},matchAll:function(e,t){for(var i,n=[];null!==(i=e.exec(t));)n.push(i);return n},isHTMLForm:ee,hasOwnProperty:te,hasOwnProp:te,reduceDescriptors:ne,freezeMethods:function(e){ne(e,(function(t,i){if(Y(e)&&-1!==["arguments","caller","callee"].indexOf(i))return!1;var n=e[i];Y(n)&&(t.enumerable=!1,"writable"in t?t.writable=!1:t.set||(t.set=function(){throw Error("Can not rewrite read-only method '"+i+"'")}))}))},toObjectSet:function(e,t){var i={},n=function(e){e.forEach((function(e){i[e]=!0}))};return D(e)?n(e):n(String(e).split(t)),i},toCamelCase:function(e){return e.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,(function(e,t,i){return t.toUpperCase()+i}))},noop:function(){},toFiniteNumber:function(e,t){return null!=e&&Number.isFinite(e=+e)?e:t},findKey:G,global:K,isContextDefined:J,ALPHABET:se,generateString:function(){for(var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:16,t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:se.ALPHA_DIGIT,i="",n=t.length;e--;)i+=t[Math.random()*n|0];return i},isSpecCompliantForm:function(e){return!!(e&&Y(e.append)&&"FormData"===e[Symbol.toStringTag]&&e[Symbol.iterator])},toJSONObject:function(e){var t=new Array(10);return function e(i,n){if(N(i)){if(t.indexOf(i)>=0)return;if(!("toJSON"in i)){t[n]=i;var r=D(i)?[]:{};return X(i,(function(t,i){var a=e(t,n+1);!E(a)&&(r[i]=a)})),t[n]=void 0,r}}return i}(e,0)},isAsyncFn:oe,isThenable:function(e){return e&&(N(e)||Y(e))&&Y(e.then)&&Y(e.catch)}};function ce(e,t,i,n,r){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=(new Error).stack,this.message=e,this.name="AxiosError",t&&(this.code=t),i&&(this.config=i),n&&(this.request=n),r&&(this.response=r)}le.inherits(ce,Error,{toJSON:function(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:le.toJSONObject(this.config),code:this.code,status:this.response&&this.response.status?this.response.status:null}}});var ue=ce.prototype,de={};function he(e){return le.isPlainObject(e)||le.isArray(e)}function fe(e){return le.endsWith(e,"[]")?e.slice(0,-2):e}function pe(e,t,i){return e?e.concat(t).map((function(e,t){return e=fe(e),!i&&t?"["+e+"]":e})).join(i?".":""):t}["ERR_BAD_OPTION_VALUE","ERR_BAD_OPTION","ECONNABORTED","ETIMEDOUT","ERR_NETWORK","ERR_FR_TOO_MANY_REDIRECTS","ERR_DEPRECATED","ERR_BAD_RESPONSE","ERR_BAD_REQUEST","ERR_CANCELED","ERR_NOT_SUPPORT","ERR_INVALID_URL"].forEach((function(e){de[e]={value:e}})),Object.defineProperties(ce,de),Object.defineProperty(ue,"isAxiosError",{value:!0}),ce.from=function(e,t,i,n,r,a){var s=Object.create(ue);return le.toFlatObject(e,s,(function(e){return e!==Error.prototype}),(function(e){return"isAxiosError"!==e})),ce.call(s,e.message,t,i,n,r),s.cause=e,s.name=e.name,a&&Object.assign(s,a),s};var me=le.toFlatObject(le,{},null,(function(e){return/^is[A-Z]/.test(e)}));function ge(e,t,i){if(!le.isObject(e))throw new TypeError("target must be an object");t=t||new FormData;var n=(i=le.toFlatObject(i,{metaTokens:!0,dots:!1,indexes:!1},!1,(function(e,t){return!le.isUndefined(t[e])}))).metaTokens,r=i.visitor||c,a=i.dots,s=i.indexes,o=(i.Blob||"undefined"!=typeof Blob&&Blob)&&le.isSpecCompliantForm(t);if(!le.isFunction(r))throw new TypeError("visitor must be a function");function l(e){if(null===e)return"";if(le.isDate(e))return e.toISOString();if(!o&&le.isBlob(e))throw new ce("Blob is not supported. Use a Buffer instead.");return le.isArrayBuffer(e)||le.isTypedArray(e)?o&&"function"==typeof Blob?new Blob([e]):Buffer.from(e):e}function c(e,i,r){var o=e;if(e&&!r&&"object"===u(e))if(le.endsWith(i,"{}"))i=n?i:i.slice(0,-2),e=JSON.stringify(e);else if(le.isArray(e)&&function(e){return le.isArray(e)&&!e.some(he)}(e)||(le.isFileList(e)||le.endsWith(i,"[]"))&&(o=le.toArray(e)))return i=fe(i),o.forEach((function(e,n){!le.isUndefined(e)&&null!==e&&t.append(!0===s?pe([i],n,a):null===s?i:i+"[]",l(e))})),!1;return!!he(e)||(t.append(pe(r,i,a),l(e)),!1)}var d=[],h=Object.assign(me,{defaultVisitor:c,convertValue:l,isVisitable:he});if(!le.isObject(e))throw new TypeError("data must be an object");return function e(i,n){if(!le.isUndefined(i)){if(-1!==d.indexOf(i))throw Error("Circular reference detected in "+n.join("."));d.push(i),le.forEach(i,(function(i,a){!0===(!(le.isUndefined(i)||null===i)&&r.call(t,i,le.isString(a)?a.trim():a,n,h))&&e(i,n?n.concat(a):[a])})),d.pop()}}(e),t}function ve(e){var t={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(e).replace(/[!'()~]|%20|%00/g,(function(e){return t[e]}))}function ye(e,t){this._pairs=[],e&&ge(e,this,t)}var be=ye.prototype;function xe(e){return encodeURIComponent(e).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}function _e(e,t,i){if(!t)return e;var n,r=i&&i.encode||xe,a=i&&i.serialize;if(n=a?a(t,i):le.isURLSearchParams(t)?t.toString():new ye(t,i).toString(r)){var s=e.indexOf("#");-1!==s&&(e=e.slice(0,s)),e+=(-1===e.indexOf("?")?"?":"&")+n}return e}be.append=function(e,t){this._pairs.push([e,t])},be.toString=function(e){var t=e?function(t){return e.call(this,t,ve)}:ve;return this._pairs.map((function(e){return t(e[0])+"="+t(e[1])}),"").join("&")};var we,ke=function(){function e(){f(this,e),this.handlers=[]}return m(e,[{key:"use",value:function(e,t,i){return this.handlers.push({fulfilled:e,rejected:t,synchronous:!!i&&i.synchronous,runWhen:i?i.runWhen:null}),this.handlers.length-1}},{key:"eject",value:function(e){this.handlers[e]&&(this.handlers[e]=null)}},{key:"clear",value:function(){this.handlers&&(this.handlers=[])}},{key:"forEach",value:function(e){le.forEach(this.handlers,(function(t){null!==t&&e(t)}))}}]),e}(),Me={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1},Se={isBrowser:!0,classes:{URLSearchParams:"undefined"!=typeof URLSearchParams?URLSearchParams:ye,FormData:"undefined"!=typeof FormData?FormData:null,Blob:"undefined"!=typeof Blob?Blob:null},protocols:["http","https","file","blob","url","data"]},Ae="undefined"!=typeof window&&"undefined"!=typeof document,Le=(we="undefined"!=typeof navigator&&navigator.product,Ae&&["ReactNative","NativeScript","NS"].indexOf(we)<0),Te="undefined"!=typeof WorkerGlobalScope&&self instanceof WorkerGlobalScope&&"function"==typeof self.importScripts,Ce=Ae&&window.location.href||"http://localhost",De=o(o({},Object.freeze({__proto__:null,hasBrowserEnv:Ae,hasStandardBrowserWebWorkerEnv:Te,hasStandardBrowserEnv:Le,origin:Ce})),Se);function Ee(e){function t(e,i,n,r){var a=e[r++];if("__proto__"===a)return!0;var s=Number.isFinite(+a),o=r>=e.length;return a=!a&&le.isArray(n)?n.length:a,o?(le.hasOwnProp(n,a)?n[a]=[n[a],i]:n[a]=i,!s):(n[a]&&le.isObject(n[a])||(n[a]=[]),t(e,i,n[a],r)&&le.isArray(n[a])&&(n[a]=function(e){var t,i,n={},r=Object.keys(e),a=r.length;for(t=0;t<a;t++)n[i=r[t]]=e[i];return n}(n[a])),!s)}if(le.isFormData(e)&&le.isFunction(e.entries)){var i={};return le.forEachEntry(e,(function(e,n){t(function(e){return le.matchAll(/\w+|\[(\w*)]/g,e).map((function(e){return"[]"===e[0]?"":e[1]||e[0]}))}(e),n,i,0)})),i}return null}var Oe={transitional:Me,adapter:["xhr","http","fetch"],transformRequest:[function(e,t){var i,n=t.getContentType()||"",r=n.indexOf("application/json")>-1,a=le.isObject(e);if(a&&le.isHTMLForm(e)&&(e=new FormData(e)),le.isFormData(e))return r?JSON.stringify(Ee(e)):e;if(le.isArrayBuffer(e)||le.isBuffer(e)||le.isStream(e)||le.isFile(e)||le.isBlob(e)||le.isReadableStream(e))return e;if(le.isArrayBufferView(e))return e.buffer;if(le.isURLSearchParams(e))return t.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),e.toString();if(a){if(n.indexOf("application/x-www-form-urlencoded")>-1)return function(e,t){return ge(e,new De.classes.URLSearchParams,Object.assign({visitor:function(e,t,i,n){return De.isNode&&le.isBuffer(e)?(this.append(t,e.toString("base64")),!1):n.defaultVisitor.apply(this,arguments)}},t))}(e,this.formSerializer).toString();if((i=le.isFileList(e))||n.indexOf("multipart/form-data")>-1){var s=this.env&&this.env.FormData;return ge(i?{"files[]":e}:e,s&&new s,this.formSerializer)}}return a||r?(t.setContentType("application/json",!1),function(e,t,i){if(le.isString(e))try{return(0,JSON.parse)(e),le.trim(e)}catch(e){if("SyntaxError"!==e.name)throw e}return(0,JSON.stringify)(e)}(e)):e}],transformResponse:[function(e){var t=this.transitional||Oe.transitional,i=t&&t.forcedJSONParsing,n="json"===this.responseType;if(le.isResponse(e)||le.isReadableStream(e))return e;if(e&&le.isString(e)&&(i&&!this.responseType||n)){var r=!(t&&t.silentJSONParsing)&&n;try{return JSON.parse(e)}catch(e){if(r){if("SyntaxError"===e.name)throw ce.from(e,ce.ERR_BAD_RESPONSE,this,null,this.response);throw e}}}return e}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:De.classes.FormData,Blob:De.classes.Blob},validateStatus:function(e){return e>=200&&e<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};le.forEach(["delete","get","head","post","put","patch"],(function(e){Oe.headers[e]={}}));var Pe=Oe,Ye=le.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),Ie=Symbol("internals");function Ne(e){return e&&String(e).trim().toLowerCase()}function je(e){return!1===e||null==e?e:le.isArray(e)?e.map(je):String(e)}function He(e,t,i,n,r){return le.isFunction(n)?n.call(this,t,i):(r&&(t=i),le.isString(t)?le.isString(n)?-1!==t.indexOf(n):le.isRegExp(n)?n.test(t):void 0:void 0)}var Fe=function(e,t){function i(e){f(this,i),e&&this.set(e)}return m(i,[{key:"set",value:function(e,t,i){var n=this;function r(e,t,i){var r=Ne(t);if(!r)throw new Error("header name must be a non-empty string");var a=le.findKey(n,r);(!a||void 0===n[a]||!0===i||void 0===i&&!1!==n[a])&&(n[a||t]=je(e))}var a=function(e,t){return le.forEach(e,(function(e,i){return r(e,i,t)}))};if(le.isPlainObject(e)||e instanceof this.constructor)a(e,t);else if(le.isString(e)&&(e=e.trim())&&!/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim()))a(function(e){var t,i,n,r={};return e&&e.split("\n").forEach((function(e){n=e.indexOf(":"),t=e.substring(0,n).trim().toLowerCase(),i=e.substring(n+1).trim(),!t||r[t]&&Ye[t]||("set-cookie"===t?r[t]?r[t].push(i):r[t]=[i]:r[t]=r[t]?r[t]+", "+i:i)})),r}(e),t);else if(le.isHeaders(e)){var s,o=function(e,t){var i="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!i){if(Array.isArray(e)||(i=x(e))){i&&(e=i);var n=0,r=function(){};return{s:r,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,s=!0,o=!1;return{s:function(){i=i.call(e)},n:function(){var e=i.next();return s=e.done,e},e:function(e){o=!0,a=e},f:function(){try{s||null==i.return||i.return()}finally{if(o)throw a}}}}(e.entries());try{for(o.s();!(s=o.n()).done;){var l=v(s.value,2),c=l[0];r(l[1],c,i)}}catch(e){o.e(e)}finally{o.f()}}else null!=e&&r(t,e,i);return this}},{key:"get",value:function(e,t){if(e=Ne(e)){var i=le.findKey(this,e);if(i){var n=this[i];if(!t)return n;if(!0===t)return function(e){for(var t,i=Object.create(null),n=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;t=n.exec(e);)i[t[1]]=t[2];return i}(n);if(le.isFunction(t))return t.call(this,n,i);if(le.isRegExp(t))return t.exec(n);throw new TypeError("parser must be boolean|regexp|function")}}}},{key:"has",value:function(e,t){if(e=Ne(e)){var i=le.findKey(this,e);return!(!i||void 0===this[i]||t&&!He(0,this[i],i,t))}return!1}},{key:"delete",value:function(e,t){var i=this,n=!1;function r(e){if(e=Ne(e)){var r=le.findKey(i,e);!r||t&&!He(0,i[r],r,t)||(delete i[r],n=!0)}}return le.isArray(e)?e.forEach(r):r(e),n}},{key:"clear",value:function(e){for(var t=Object.keys(this),i=t.length,n=!1;i--;){var r=t[i];e&&!He(0,this[r],r,e,!0)||(delete this[r],n=!0)}return n}},{key:"normalize",value:function(e){var t=this,i={};return le.forEach(this,(function(n,r){var a=le.findKey(i,r);if(a)return t[a]=je(n),void delete t[r];var s=e?function(e){return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(function(e,t,i){return t.toUpperCase()+i}))}(r):String(r).trim();s!==r&&delete t[r],t[s]=je(n),i[s]=!0})),this}},{key:"concat",value:function(){for(var e,t=arguments.length,i=new Array(t),n=0;n<t;n++)i[n]=arguments[n];return(e=this.constructor).concat.apply(e,[this].concat(i))}},{key:"toJSON",value:function(e){var t=Object.create(null);return le.forEach(this,(function(i,n){null!=i&&!1!==i&&(t[n]=e&&le.isArray(i)?i.join(", "):i)})),t}},{key:Symbol.iterator,value:function(){return Object.entries(this.toJSON())[Symbol.iterator]()}},{key:"toString",value:function(){return Object.entries(this.toJSON()).map((function(e){var t=v(e,2);return t[0]+": "+t[1]})).join("\n")}},{key:Symbol.toStringTag,get:function(){return"AxiosHeaders"}}],[{key:"from",value:function(e){return e instanceof this?e:new this(e)}},{key:"concat",value:function(e){for(var t=new this(e),i=arguments.length,n=new Array(i>1?i-1:0),r=1;r<i;r++)n[r-1]=arguments[r];return n.forEach((function(e){return t.set(e)})),t}},{key:"accessor",value:function(e){var t=(this[Ie]=this[Ie]={accessors:{}}).accessors,i=this.prototype;function n(e){var n=Ne(e);t[n]||(function(e,t){var i=le.toCamelCase(" "+t);["get","set","has"].forEach((function(n){Object.defineProperty(e,n+i,{value:function(e,i,r){return this[n].call(this,t,e,i,r)},configurable:!0})}))}(i,e),t[n]=!0)}return le.isArray(e)?e.forEach(n):n(e),this}}]),i}();Fe.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]),le.reduceDescriptors(Fe.prototype,(function(e,t){var i=e.value,n=t[0].toUpperCase()+t.slice(1);return{get:function(){return i},set:function(e){this[n]=e}}})),le.freezeMethods(Fe);var Re=Fe;function ze(e,t){var i=this||Pe,n=t||i,r=Re.from(n.headers),a=n.data;return le.forEach(e,(function(e){a=e.call(i,a,r.normalize(),t?t.status:void 0)})),r.normalize(),a}function Be(e){return!(!e||!e.__CANCEL__)}function Ve(e,t,i){ce.call(this,null==e?"canceled":e,ce.ERR_CANCELED,t,i),this.name="CanceledError"}function We(e,t,i){var n=i.config.validateStatus;i.status&&n&&!n(i.status)?t(new ce("Request failed with status code "+i.status,[ce.ERR_BAD_REQUEST,ce.ERR_BAD_RESPONSE][Math.floor(i.status/100)-4],i.config,i.request,i)):e(i)}le.inherits(Ve,ce,{__CANCEL__:!0});var Ue=function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:3,n=0,r=function(e,t){e=e||10;var i,n=new Array(e),r=new Array(e),a=0,s=0;return t=void 0!==t?t:1e3,function(o){var l=Date.now(),c=r[s];i||(i=l),n[a]=o,r[a]=l;for(var u=s,d=0;u!==a;)d+=n[u++],u%=e;if((a=(a+1)%e)===s&&(s=(s+1)%e),!(l-i<t)){var h=c&&l-c;return h?Math.round(1e3*d/h):void 0}}}(50,250);return function(e,t){var i=0,n=1e3/t,r=null;return function(){var t=arguments,a=!0===this,s=Date.now();if(a||s-i>n)return r&&(clearTimeout(r),r=null),i=s,e.apply(null,arguments);r||(r=setTimeout((function(){return r=null,i=Date.now(),e.apply(null,t)}),n-(s-i)))}}((function(i){var a=i.loaded,s=i.lengthComputable?i.total:void 0,o=a-n,l=r(o);n=a;var c={loaded:a,total:s,progress:s?a/s:void 0,bytes:o,rate:l||void 0,estimated:l&&s&&a<=s?(s-a)/l:void 0,event:i,lengthComputable:null!=s};c[t?"download":"upload"]=!0,e(c)}),i)},qe=De.hasStandardBrowserEnv?function(){var e,t=/(msie|trident)/i.test(navigator.userAgent),i=document.createElement("a");function n(e){var n=e;return t&&(i.setAttribute("href",n),n=i.href),i.setAttribute("href",n),{href:i.href,protocol:i.protocol?i.protocol.replace(/:$/,""):"",host:i.host,search:i.search?i.search.replace(/^\?/,""):"",hash:i.hash?i.hash.replace(/^#/,""):"",hostname:i.hostname,port:i.port,pathname:"/"===i.pathname.charAt(0)?i.pathname:"/"+i.pathname}}return e=n(window.location.href),function(t){var i=le.isString(t)?n(t):t;return i.protocol===e.protocol&&i.host===e.host}}():function(){return!0},$e=De.hasStandardBrowserEnv?{write:function(e,t,i,n,r,a){var s=[e+"="+encodeURIComponent(t)];le.isNumber(i)&&s.push("expires="+new Date(i).toGMTString()),le.isString(n)&&s.push("path="+n),le.isString(r)&&s.push("domain="+r),!0===a&&s.push("secure"),document.cookie=s.join("; ")},read:function(e){var t=document.cookie.match(new RegExp("(^|;\\s*)("+e+")=([^;]*)"));return t?decodeURIComponent(t[3]):null},remove:function(e){this.write(e,"",Date.now()-864e5)}}:{write:function(){},read:function(){return null},remove:function(){}};function Xe(e,t){return e&&!/^([a-z][a-z\d+\-.]*:)?\/\//i.test(t)?function(e,t){return t?e.replace(/\/?\/$/,"")+"/"+t.replace(/^\/+/,""):e}(e,t):t}var Ge=function(e){return e instanceof Re?o({},e):e};function Ze(e,t){t=t||{};var i={};function n(e,t,i){return le.isPlainObject(e)&&le.isPlainObject(t)?le.merge.call({caseless:i},e,t):le.isPlainObject(t)?le.merge({},t):le.isArray(t)?t.slice():t}function r(e,t,i){return le.isUndefined(t)?le.isUndefined(e)?void 0:n(void 0,e,i):n(e,t,i)}function a(e,t){if(!le.isUndefined(t))return n(void 0,t)}function s(e,t){return le.isUndefined(t)?le.isUndefined(e)?void 0:n(void 0,e):n(void 0,t)}function o(i,r,a){return a in t?n(i,r):a in e?n(void 0,i):void 0}var l={url:a,method:a,data:a,baseURL:s,transformRequest:s,transformResponse:s,paramsSerializer:s,timeout:s,timeoutMessage:s,withCredentials:s,withXSRFToken:s,adapter:s,responseType:s,xsrfCookieName:s,xsrfHeaderName:s,onUploadProgress:s,onDownloadProgress:s,decompress:s,maxContentLength:s,maxBodyLength:s,beforeRedirect:s,transport:s,httpAgent:s,httpsAgent:s,cancelToken:s,socketPath:s,responseEncoding:s,validateStatus:o,headers:function(e,t){return r(Ge(e),Ge(t),!0)}};return le.forEach(Object.keys(Object.assign({},e,t)),(function(n){var a=l[n]||r,s=a(e[n],t[n],n);le.isUndefined(s)&&a!==o||(i[n]=s)})),i}var Ke,Je,Qe,et,tt=function(e){var t,i,n=Ze({},e),r=n.data,a=n.withXSRFToken,s=n.xsrfHeaderName,o=n.xsrfCookieName,l=n.headers,c=n.auth;if(n.headers=l=Re.from(l),n.url=_e(Xe(n.baseURL,n.url),e.params,e.paramsSerializer),c&&l.set("Authorization","Basic "+btoa((c.username||"")+":"+(c.password?unescape(encodeURIComponent(c.password)):""))),le.isFormData(r))if(De.hasStandardBrowserEnv||De.hasStandardBrowserWebWorkerEnv)l.setContentType(void 0);else if(!1!==(t=l.getContentType())){var u=t?t.split(";").map((function(e){return e.trim()})).filter(Boolean):[],d=y(i=u)||b(i)||x(i)||w(),h=d[0],f=d.slice(1);l.setContentType([h||"multipart/form-data"].concat(function(e){return function(e){if(Array.isArray(e))return _(e)}(e)||b(e)||x(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(f)).join("; "))}if(De.hasStandardBrowserEnv&&(a&&le.isFunction(a)&&(a=a(n)),a||!1!==a&&qe(n.url))){var p=s&&o&&$e.read(o);p&&l.set(s,p)}return n},it="undefined"!=typeof XMLHttpRequest&&function(e){return new Promise((function(t,i){var n,r=tt(e),a=r.data,s=Re.from(r.headers).normalize(),o=r.responseType;function l(){r.cancelToken&&r.cancelToken.unsubscribe(n),r.signal&&r.signal.removeEventListener("abort",n)}var c=new XMLHttpRequest;function u(){if(c){var n=Re.from("getAllResponseHeaders"in c&&c.getAllResponseHeaders());We((function(e){t(e),l()}),(function(e){i(e),l()}),{data:o&&"text"!==o&&"json"!==o?c.response:c.responseText,status:c.status,statusText:c.statusText,headers:n,config:e,request:c}),c=null}}c.open(r.method.toUpperCase(),r.url,!0),c.timeout=r.timeout,"onloadend"in c?c.onloadend=u:c.onreadystatechange=function(){c&&4===c.readyState&&(0!==c.status||c.responseURL&&0===c.responseURL.indexOf("file:"))&&setTimeout(u)},c.onabort=function(){c&&(i(new ce("Request aborted",ce.ECONNABORTED,r,c)),c=null)},c.onerror=function(){i(new ce("Network Error",ce.ERR_NETWORK,r,c)),c=null},c.ontimeout=function(){var e=r.timeout?"timeout of "+r.timeout+"ms exceeded":"timeout exceeded",t=r.transitional||Me;r.timeoutErrorMessage&&(e=r.timeoutErrorMessage),i(new ce(e,t.clarifyTimeoutError?ce.ETIMEDOUT:ce.ECONNABORTED,r,c)),c=null},void 0===a&&s.setContentType(null),"setRequestHeader"in c&&le.forEach(s.toJSON(),(function(e,t){c.setRequestHeader(t,e)})),le.isUndefined(r.withCredentials)||(c.withCredentials=!!r.withCredentials),o&&"json"!==o&&(c.responseType=r.responseType),"function"==typeof r.onDownloadProgress&&c.addEventListener("progress",Ue(r.onDownloadProgress,!0)),"function"==typeof r.onUploadProgress&&c.upload&&c.upload.addEventListener("progress",Ue(r.onUploadProgress)),(r.cancelToken||r.signal)&&(n=function(t){c&&(i(!t||t.type?new Ve(null,e,c):t),c.abort(),c=null)},r.cancelToken&&r.cancelToken.subscribe(n),r.signal&&(r.signal.aborted?n():r.signal.addEventListener("abort",n)));var d,h,f=(d=r.url,(h=/^([-+\w]{1,25})(:?\/\/|:)/.exec(d))&&h[1]||"");f&&-1===De.protocols.indexOf(f)?i(new ce("Unsupported protocol "+f+":",ce.ERR_BAD_REQUEST,e)):c.send(a||null)}))},nt=function(e,t){var i,n=new AbortController,r=function(e){if(!i){i=!0,s();var t=e instanceof Error?e:this.reason;n.abort(t instanceof ce?t:new Ve(t instanceof Error?t.message:t))}},a=t&&setTimeout((function(){r(new ce("timeout ".concat(t," of ms exceeded"),ce.ETIMEDOUT))}),t),s=function(){e&&(a&&clearTimeout(a),a=null,e.forEach((function(e){e&&(e.removeEventListener?e.removeEventListener("abort",r):e.unsubscribe(r))})),e=null)};e.forEach((function(e){return e&&e.addEventListener&&e.addEventListener("abort",r)}));var o=n.signal;return o.unsubscribe=s,[o,function(){a&&clearTimeout(a),a=null}]},rt=l().mark((function e(t,i){var n,r,a;return l().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:if(n=t.byteLength,i&&!(n<i)){e.next=5;break}return e.next=4,t;case 4:return e.abrupt("return");case 5:r=0;case 6:if(!(r<n)){e.next=13;break}return a=r+i,e.next=10,t.slice(r,a);case 10:r=a,e.next=6;break;case 13:case"end":return e.stop()}}),e)})),at=function(){var t,r=(t=l().mark((function e(t,r,s){var o,c,u,d,h,f;return l().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:o=!1,c=!1,e.prev=2,d=n(t);case 4:return e.next=6,a(d.next());case 6:if(!(o=!(h=e.sent).done)){e.next=27;break}if(f=h.value,e.t0=i,e.t1=n,e.t2=rt,!ArrayBuffer.isView(f)){e.next=15;break}e.t3=f,e.next=18;break;case 15:return e.next=17,a(s(String(f)));case 17:e.t3=e.sent;case 18:return e.t4=e.t3,e.t5=r,e.t6=(0,e.t2)(e.t4,e.t5),e.t7=(0,e.t1)(e.t6),e.t8=a,e.delegateYield((0,e.t0)(e.t7,e.t8),"t9",24);case 24:o=!1,e.next=4;break;case 27:e.next=33;break;case 29:e.prev=29,e.t10=e.catch(2),c=!0,u=e.t10;case 33:if(e.prev=33,e.prev=34,!o||null==d.return){e.next=38;break}return e.next=38,a(d.return());case 38:if(e.prev=38,!c){e.next=41;break}throw u;case 41:return e.finish(38);case 42:return e.finish(33);case 43:case"end":return e.stop()}}),e,null,[[2,29,33,43],[34,,38,42]])})),function(){return new e(t.apply(this,arguments))});return function(e,t,i){return r.apply(this,arguments)}}(),st=function(e,t,i,n,r){var a=at(e,t,r),s=0;return new ReadableStream({type:"bytes",pull:function(e){return h(l().mark((function t(){var r,o,c,u;return l().wrap((function(t){for(;;)switch(t.prev=t.next){case 0:return t.next=2,a.next();case 2:if(r=t.sent,o=r.done,c=r.value,!o){t.next=9;break}return e.close(),n(),t.abrupt("return");case 9:u=c.byteLength,i&&i(s+=u),e.enqueue(new Uint8Array(c));case 12:case"end":return t.stop()}}),t)})))()},cancel:function(e){return n(e),a.return()}},{highWaterMark:2})},ot=function(e,t){var i=null!=e;return function(n){return setTimeout((function(){return t({lengthComputable:i,total:e,loaded:n})}))}},lt="function"==typeof fetch&&"function"==typeof Request&&"function"==typeof Response,ct=lt&&"function"==typeof ReadableStream,ut=lt&&("function"==typeof TextEncoder?(Ke=new TextEncoder,function(e){return Ke.encode(e)}):function(){var e=h(l().mark((function e(t){return l().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:return e.t0=Uint8Array,e.next=3,new Response(t).arrayBuffer();case 3:return e.t1=e.sent,e.abrupt("return",new e.t0(e.t1));case 5:case"end":return e.stop()}}),e)})));return function(t){return e.apply(this,arguments)}}()),dt=ct&&(Je=!1,Qe=new Request(De.origin,{body:new ReadableStream,method:"POST",get duplex(){return Je=!0,"half"}}).headers.has("Content-Type"),Je&&!Qe),ht=ct&&!!function(){try{return le.isReadableStream(new Response("").body)}catch(e){}}(),ft={stream:ht&&function(e){return e.body}};lt&&(et=new Response,["text","arrayBuffer","blob","formData","stream"].forEach((function(e){!ft[e]&&(ft[e]=le.isFunction(et[e])?function(t){return t[e]()}:function(t,i){throw new ce("Response type '".concat(e,"' is not supported"),ce.ERR_NOT_SUPPORT,i)})})));var pt=function(){var e=h(l().mark((function e(t){return l().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:if(null!=t){e.next=2;break}return e.abrupt("return",0);case 2:if(!le.isBlob(t)){e.next=4;break}return e.abrupt("return",t.size);case 4:if(!le.isSpecCompliantForm(t)){e.next=8;break}return e.next=7,new Request(t).arrayBuffer();case 7:case 14:return e.abrupt("return",e.sent.byteLength);case 8:if(!le.isArrayBufferView(t)){e.next=10;break}return e.abrupt("return",t.byteLength);case 10:if(le.isURLSearchParams(t)&&(t+=""),!le.isString(t)){e.next=15;break}return e.next=14,ut(t);case 15:case"end":return e.stop()}}),e)})));return function(t){return e.apply(this,arguments)}}(),mt=function(){var e=h(l().mark((function e(t,i){var n;return l().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:return n=le.toFiniteNumber(t.getContentLength()),e.abrupt("return",null==n?pt(i):n);case 2:case"end":return e.stop()}}),e)})));return function(t,i){return e.apply(this,arguments)}}(),gt=lt&&function(){var e=h(l().mark((function e(t){var i,n,r,a,s,c,u,d,h,f,p,m,g,y,b,x,_,w,k,M,S,A,L,T,C,D,E,O,P;return l().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:if(i=tt(t),n=i.url,r=i.method,a=i.data,s=i.signal,c=i.cancelToken,u=i.timeout,d=i.onDownloadProgress,h=i.onUploadProgress,f=i.responseType,p=i.headers,m=i.withCredentials,g=void 0===m?"same-origin":m,y=i.fetchOptions,f=f?(f+"").toLowerCase():"text",b=s||c||u?nt([s,c],u):[],x=v(b,2),_=x[0],w=x[1],S=function(){!k&&setTimeout((function(){_&&_.unsubscribe()})),k=!0},e.prev=4,e.t0=h&&dt&&"get"!==r&&"head"!==r,!e.t0){e.next=11;break}return e.next=9,mt(p,a);case 9:e.t1=A=e.sent,e.t0=0!==e.t1;case 11:if(!e.t0){e.next=15;break}L=new Request(n,{method:"POST",body:a,duplex:"half"}),le.isFormData(a)&&(T=L.headers.get("content-type"))&&p.setContentType(T),L.body&&(a=st(L.body,65536,ot(A,Ue(h)),null,ut));case 15:return le.isString(g)||(g=g?"cors":"omit"),M=new Request(n,o(o({},y),{},{signal:_,method:r.toUpperCase(),headers:p.normalize().toJSON(),body:a,duplex:"half",withCredentials:g})),e.next=19,fetch(M);case 19:return C=e.sent,D=ht&&("stream"===f||"response"===f),ht&&(d||D)&&(E={},["status","statusText","headers"].forEach((function(e){E[e]=C[e]})),O=le.toFiniteNumber(C.headers.get("content-length")),C=new Response(st(C.body,65536,d&&ot(O,Ue(d,!0)),D&&S,ut),E)),f=f||"text",e.next=25,ft[le.findKey(ft,f)||"text"](C,t);case 25:return P=e.sent,!D&&S(),w&&w(),e.next=30,new Promise((function(e,i){We(e,i,{data:P,headers:Re.from(C.headers),status:C.status,statusText:C.statusText,config:t,request:M})}));case 30:return e.abrupt("return",e.sent);case 33:if(e.prev=33,e.t2=e.catch(4),S(),!e.t2||"TypeError"!==e.t2.name||!/fetch/i.test(e.t2.message)){e.next=38;break}throw Object.assign(new ce("Network Error",ce.ERR_NETWORK,t,M),{cause:e.t2.cause||e.t2});case 38:throw ce.from(e.t2,e.t2&&e.t2.code,t,M);case 39:case"end":return e.stop()}}),e,null,[[4,33]])})));return function(t){return e.apply(this,arguments)}}(),vt={http:null,xhr:it,fetch:gt};le.forEach(vt,(function(e,t){if(e){try{Object.defineProperty(e,"name",{value:t})}catch(e){}Object.defineProperty(e,"adapterName",{value:t})}}));var yt=function(e){return"- ".concat(e)},bt=function(e){return le.isFunction(e)||null===e||!1===e},xt=function(e){for(var t,i,n=(e=le.isArray(e)?e:[e]).length,r={},a=0;a<n;a++){var s=void 0;if(i=t=e[a],!bt(t)&&void 0===(i=vt[(s=String(t)).toLowerCase()]))throw new ce("Unknown adapter '".concat(s,"'"));if(i)break;r[s||"#"+a]=i}if(!i){var o=Object.entries(r).map((function(e){var t=v(e,2),i=t[0],n=t[1];return"adapter ".concat(i," ")+(!1===n?"is not supported by the environment":"is not available in the build")}));throw new ce("There is no suitable adapter to dispatch the request "+(n?o.length>1?"since :\n"+o.map(yt).join("\n"):" "+yt(o[0]):"as no adapter specified"),"ERR_NOT_SUPPORT")}return i};function _t(e){if(e.cancelToken&&e.cancelToken.throwIfRequested(),e.signal&&e.signal.aborted)throw new Ve(null,e)}function wt(e){return _t(e),e.headers=Re.from(e.headers),e.data=ze.call(e,e.transformRequest),-1!==["post","put","patch"].indexOf(e.method)&&e.headers.setContentType("application/x-www-form-urlencoded",!1),xt(e.adapter||Pe.adapter)(e).then((function(t){return _t(e),t.data=ze.call(e,e.transformResponse,t),t.headers=Re.from(t.headers),t}),(function(t){return Be(t)||(_t(e),t&&t.response&&(t.response.data=ze.call(e,e.transformResponse,t.response),t.response.headers=Re.from(t.response.headers))),Promise.reject(t)}))}var kt={};["object","boolean","number","function","string","symbol"].forEach((function(e,t){kt[e]=function(i){return u(i)===e||"a"+(t<1?"n ":" ")+e}}));var Mt={};kt.transitional=function(e,t,i){function n(e,t){return"[Axios v1.7.2] Transitional option '"+e+"'"+t+(i?". "+i:"")}return function(i,r,a){if(!1===e)throw new ce(n(r," has been removed"+(t?" in "+t:"")),ce.ERR_DEPRECATED);return t&&!Mt[r]&&(Mt[r]=!0,console.warn(n(r," has been deprecated since v"+t+" and will be removed in the near future"))),!e||e(i,r,a)}};var St={assertOptions:function(e,t,i){if("object"!==u(e))throw new ce("options must be an object",ce.ERR_BAD_OPTION_VALUE);for(var n=Object.keys(e),r=n.length;r-- >0;){var a=n[r],s=t[a];if(s){var o=e[a],l=void 0===o||s(o,a,e);if(!0!==l)throw new ce("option "+a+" must be "+l,ce.ERR_BAD_OPTION_VALUE)}else if(!0!==i)throw new ce("Unknown option "+a,ce.ERR_BAD_OPTION)}},validators:kt},At=St.validators,Lt=function(){function e(t){f(this,e),this.defaults=t,this.interceptors={request:new ke,response:new ke}}var t;return m(e,[{key:"request",value:(t=h(l().mark((function e(t,i){var n,r;return l().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:return e.prev=0,e.next=3,this._request(t,i);case 3:return e.abrupt("return",e.sent);case 6:if(e.prev=6,e.t0=e.catch(0),e.t0 instanceof Error){Error.captureStackTrace?Error.captureStackTrace(n={}):n=new Error,r=n.stack?n.stack.replace(/^.+\n/,""):"";try{e.t0.stack?r&&!String(e.t0.stack).endsWith(r.replace(/^.+\n.+\n/,""))&&(e.t0.stack+="\n"+r):e.t0.stack=r}catch(e){}}throw e.t0;case 10:case"end":return e.stop()}}),e,this,[[0,6]])}))),function(e,i){return t.apply(this,arguments)})},{key:"_request",value:function(e,t){"string"==typeof e?(t=t||{}).url=e:t=e||{};var i=t=Ze(this.defaults,t),n=i.transitional,r=i.paramsSerializer,a=i.headers;void 0!==n&&St.assertOptions(n,{silentJSONParsing:At.transitional(At.boolean),forcedJSONParsing:At.transitional(At.boolean),clarifyTimeoutError:At.transitional(At.boolean)},!1),null!=r&&(le.isFunction(r)?t.paramsSerializer={serialize:r}:St.assertOptions(r,{encode:At.function,serialize:At.function},!0)),t.method=(t.method||this.defaults.method||"get").toLowerCase();var s=a&&le.merge(a.common,a[t.method]);a&&le.forEach(["delete","get","head","post","put","patch","common"],(function(e){delete a[e]})),t.headers=Re.concat(s,a);var o=[],l=!0;this.interceptors.request.forEach((function(e){"function"==typeof e.runWhen&&!1===e.runWhen(t)||(l=l&&e.synchronous,o.unshift(e.fulfilled,e.rejected))}));var c,u=[];this.interceptors.response.forEach((function(e){u.push(e.fulfilled,e.rejected)}));var d,h=0;if(!l){var f=[wt.bind(this),void 0];for(f.unshift.apply(f,o),f.push.apply(f,u),d=f.length,c=Promise.resolve(t);h<d;)c=c.then(f[h++],f[h++]);return c}d=o.length;var p=t;for(h=0;h<d;){var m=o[h++],g=o[h++];try{p=m(p)}catch(e){g.call(this,e);break}}try{c=wt.call(this,p)}catch(e){return Promise.reject(e)}for(h=0,d=u.length;h<d;)c=c.then(u[h++],u[h++]);return c}},{key:"getUri",value:function(e){return _e(Xe((e=Ze(this.defaults,e)).baseURL,e.url),e.params,e.paramsSerializer)}}]),e}();le.forEach(["delete","get","head","options"],(function(e){Lt.prototype[e]=function(t,i){return this.request(Ze(i||{},{method:e,url:t,data:(i||{}).data}))}})),le.forEach(["post","put","patch"],(function(e){function t(t){return function(i,n,r){return this.request(Ze(r||{},{method:e,headers:t?{"Content-Type":"multipart/form-data"}:{},url:i,data:n}))}}Lt.prototype[e]=t(),Lt.prototype[e+"Form"]=t(!0)}));var Tt=Lt,Ct=function(){function e(t){if(f(this,e),"function"!=typeof t)throw new TypeError("executor must be a function.");var i;this.promise=new Promise((function(e){i=e}));var n=this;this.promise.then((function(e){if(n._listeners){for(var t=n._listeners.length;t-- >0;)n._listeners[t](e);n._listeners=null}})),this.promise.then=function(e){var t,i=new Promise((function(e){n.subscribe(e),t=e})).then(e);return i.cancel=function(){n.unsubscribe(t)},i},t((function(e,t,r){n.reason||(n.reason=new Ve(e,t,r),i(n.reason))}))}return m(e,[{key:"throwIfRequested",value:function(){if(this.reason)throw this.reason}},{key:"subscribe",value:function(e){this.reason?e(this.reason):this._listeners?this._listeners.push(e):this._listeners=[e]}},{key:"unsubscribe",value:function(e){if(this._listeners){var t=this._listeners.indexOf(e);-1!==t&&this._listeners.splice(t,1)}}}],[{key:"source",value:function(){var t;return{token:new e((function(e){t=e})),cancel:t}}}]),e}(),Dt={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511};Object.entries(Dt).forEach((function(e){var t=v(e,2),i=t[0],n=t[1];Dt[n]=i}));var Et=Dt,Ot=function e(t){var i=new Tt(t),n=k(Tt.prototype.request,i);return le.extend(n,Tt.prototype,i,{allOwnKeys:!0}),le.extend(n,i,null,{allOwnKeys:!0}),n.create=function(i){return e(Ze(t,i))},n}(Pe);return Ot.Axios=Tt,Ot.CanceledError=Ve,Ot.CancelToken=Ct,Ot.isCancel=Be,Ot.VERSION="1.7.2",Ot.toFormData=ge,Ot.AxiosError=ce,Ot.Cancel=Ot.CanceledError,Ot.all=function(e){return Promise.all(e)},Ot.spread=function(e){return function(t){return e.apply(null,t)}},Ot.isAxiosError=function(e){return le.isObject(e)&&!0===e.isAxiosError},Ot.mergeConfig=Ze,Ot.AxiosHeaders=Re,Ot.formToJSON=function(e){return Ee(le.isHTMLForm(e)?new FormData(e):e)},Ot.getAdapter=xt,Ot.HttpStatusCode=Et,Ot.default=Ot,Ot})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):e.lozad=t()}(this,(function(){"use strict";var e="undefined"!=typeof document&&document.documentMode,t={rootMargin:"0px",threshold:0,load:function(t){if("picture"===t.nodeName.toLowerCase()){var i=t.querySelector("img"),n=!1;null===i&&(i=document.createElement("img"),n=!0),e&&t.getAttribute("data-iesrc")&&(i.src=t.getAttribute("data-iesrc")),t.getAttribute("data-alt")&&(i.alt=t.getAttribute("data-alt")),n&&t.append(i)}if("video"===t.nodeName.toLowerCase()&&!t.getAttribute("data-src")&&t.children){for(var r=t.children,a=void 0,s=0;s<=r.length-1;s++)(a=r[s].getAttribute("data-src"))&&(r[s].src=a);t.load()}t.getAttribute("data-poster")&&(t.poster=t.getAttribute("data-poster")),t.getAttribute("data-src")&&(t.src=t.getAttribute("data-src")),t.getAttribute("data-srcset")&&t.setAttribute("srcset",t.getAttribute("data-srcset"));var o=",";if(t.getAttribute("data-background-delimiter")&&(o=t.getAttribute("data-background-delimiter")),t.getAttribute("data-background-image"))t.style.backgroundImage="url('"+t.getAttribute("data-background-image").split(o).join("'),url('")+"')";else if(t.getAttribute("data-background-image-set")){var l=t.getAttribute("data-background-image-set").split(o),c=l[0].substr(0,l[0].indexOf(" "))||l[0];c=-1===c.indexOf("url(")?"url("+c+")":c,1===l.length?t.style.backgroundImage=c:t.setAttribute("style",(t.getAttribute("style")||"")+"background-image: "+c+"; background-image: -webkit-image-set("+l+"); background-image: image-set("+l+")")}t.getAttribute("data-toggle-class")&&t.classList.toggle(t.getAttribute("data-toggle-class"))},loaded:function(){}};function i(e){e.setAttribute("data-loaded",!0)}var n=function(e){return"true"===e.getAttribute("data-loaded")},r=function(e){var t=1<arguments.length&&void 0!==arguments[1]?arguments[1]:document;return e instanceof Element?[e]:e instanceof NodeList?e:t.querySelectorAll(e)};return function(){var e,a,s=0<arguments.length&&void 0!==arguments[0]?arguments[0]:".lozad",o=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{},l=Object.assign({},t,o),c=l.root,u=l.rootMargin,d=l.threshold,h=l.load,f=l.loaded,p=void 0;"undefined"!=typeof window&&window.IntersectionObserver&&(p=new IntersectionObserver((e=h,a=f,function(t,r){t.forEach((function(t){(0<t.intersectionRatio||t.isIntersecting)&&(r.unobserve(t.target),n(t.target)||(e(t.target),i(t.target),a(t.target)))}))}),{root:c,rootMargin:u,threshold:d}));for(var m,g=r(s,c),v=0;v<g.length;v++)(m=g[v]).getAttribute("data-placeholder-background")&&(m.style.background=m.getAttribute("data-placeholder-background"));return{observe:function(){for(var e=r(s,c),t=0;t<e.length;t++)n(e[t])||(p?p.observe(e[t]):(h(e[t]),i(e[t]),f(e[t])))},triggerLoad:function(e){n(e)||(h(e),i(e),f(e))},observer:p}}})),function(e){"function"==typeof define&&define.amd?define(["jquery"],e):"object"==typeof module&&module.exports?module.exports=function(t,i){return void 0===i&&(i="undefined"!=typeof window?require("jquery"):require("jquery")(t)),e(i),i}:e(jQuery)}((function(e){var t=function(){if(e&&e.fn&&e.fn.select2&&e.fn.select2.amd)var t=e.fn.select2.amd;var i;return function(){
/**
 * @license almond 0.3.3 Copyright jQuery Foundation and other contributors.
 * Released under MIT license, http://github.com/requirejs/almond/LICENSE
 */
var e,i,n;t&&t.requirejs||(t?i=t:t={},function(t){var r,a,s,o,l={},c={},u={},d={},h=Object.prototype.hasOwnProperty,f=[].slice,p=/\.js$/;function m(e,t){return h.call(e,t)}function g(e,t){var i,n,r,a,s,o,l,c,d,h,f,m=t&&t.split("/"),g=u.map,v=g&&g["*"]||{};if(e){for(s=(e=e.split("/")).length-1,u.nodeIdCompat&&p.test(e[s])&&(e[s]=e[s].replace(p,"")),"."===e[0].charAt(0)&&m&&(e=m.slice(0,m.length-1).concat(e)),d=0;d<e.length;d++)if("."===(f=e[d]))e.splice(d,1),d-=1;else if(".."===f){if(0===d||1===d&&".."===e[2]||".."===e[d-1])continue;d>0&&(e.splice(d-1,2),d-=2)}e=e.join("/")}if((m||v)&&g){for(d=(i=e.split("/")).length;d>0;d-=1){if(n=i.slice(0,d).join("/"),m)for(h=m.length;h>0;h-=1)if((r=g[m.slice(0,h).join("/")])&&(r=r[n])){a=r,o=d;break}if(a)break;!l&&v&&v[n]&&(l=v[n],c=d)}!a&&l&&(a=l,o=c),a&&(i.splice(0,o,a),e=i.join("/"))}return e}function v(e,i){return function(){var n=f.call(arguments,0);return"string"!=typeof n[0]&&1===n.length&&n.push(null),a.apply(t,n.concat([e,i]))}}function y(e){return function(t){l[e]=t}}function b(e){if(m(c,e)){var i=c[e];delete c[e],d[e]=!0,r.apply(t,i)}if(!m(l,e)&&!m(d,e))throw new Error("No "+e);return l[e]}function x(e){var t,i=e?e.indexOf("!"):-1;return i>-1&&(t=e.substring(0,i),e=e.substring(i+1,e.length)),[t,e]}function _(e){return e?x(e):[]}function w(e){return function(){return u&&u.config&&u.config[e]||{}}}s=function(e,t){var i,n,r=x(e),a=r[0],s=t[1];return e=r[1],a&&(i=b(a=g(a,s))),a?e=i&&i.normalize?i.normalize(e,(n=s,function(e){return g(e,n)})):g(e,s):(a=(r=x(e=g(e,s)))[0],e=r[1],a&&(i=b(a))),{f:a?a+"!"+e:e,n:e,pr:a,p:i}},o={require:function(e){return v(e)},exports:function(e){var t=l[e];return void 0!==t?t:l[e]={}},module:function(e){return{id:e,uri:"",exports:l[e],config:w(e)}}},r=function(e,i,n,r){var a,u,h,f,p,g,x,w=[],k=typeof n;if(g=_(r=r||e),"undefined"===k||"function"===k){for(i=!i.length&&n.length?["require","exports","module"]:i,p=0;p<i.length;p+=1)if("require"===(u=(f=s(i[p],g)).f))w[p]=o.require(e);else if("exports"===u)w[p]=o.exports(e),x=!0;else if("module"===u)a=w[p]=o.module(e);else if(m(l,u)||m(c,u)||m(d,u))w[p]=b(u);else{if(!f.p)throw new Error(e+" missing "+u);f.p.load(f.n,v(r,!0),y(u),{}),w[p]=l[u]}h=n?n.apply(l[e],w):void 0,e&&(a&&a.exports!==t&&a.exports!==l[e]?l[e]=a.exports:h===t&&x||(l[e]=h))}else e&&(l[e]=n)},e=i=a=function(e,i,n,l,c){if("string"==typeof e)return o[e]?o[e](i):b(s(e,_(i)).f);if(!e.splice){if((u=e).deps&&a(u.deps,u.callback),!i)return;i.splice?(e=i,i=n,n=null):e=t}return i=i||function(){},"function"==typeof n&&(n=l,l=c),l?r(t,e,i,n):setTimeout((function(){r(t,e,i,n)}),4),a},a.config=function(e){return a(e)},e._defined=l,(n=function(e,t,i){if("string"!=typeof e)throw new Error("See almond README: incorrect module build, no module name");t.splice||(i=t,t=[]),m(l,e)||m(c,e)||(c[e]=[e,t,i])}).amd={jQuery:!0}}(),t.requirejs=e,t.require=i,t.define=n)}(),t.define("almond",(function(){})),t.define("jquery",[],(function(){var t=e||$;return null==t&&console&&console.error&&console.error("Select2: An instance of jQuery or a jQuery-compatible library was not found. Make sure that you are including jQuery before Select2 on your web page."),t})),t.define("select2/utils",["jquery"],(function(e){var t={};function i(e){var t=e.prototype,i=[];for(var n in t){"function"==typeof t[n]&&("constructor"!==n&&i.push(n))}return i}t.Extend=function(e,t){var i={}.hasOwnProperty;function n(){this.constructor=e}for(var r in t)i.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},t.Decorate=function(e,t){var n=i(t),r=i(e);function a(){var i=Array.prototype.unshift,n=t.prototype.constructor.length,r=e.prototype.constructor;n>0&&(i.call(arguments,e.prototype.constructor),r=t.prototype.constructor),r.apply(this,arguments)}t.displayName=e.displayName,a.prototype=new function(){this.constructor=a};for(var s=0;s<r.length;s++){var o=r[s];a.prototype[o]=e.prototype[o]}for(var l=function(e){var i=function(){};e in a.prototype&&(i=a.prototype[e]);var n=t.prototype[e];return function(){return Array.prototype.unshift.call(arguments,i),n.apply(this,arguments)}},c=0;c<n.length;c++){var u=n[c];a.prototype[u]=l(u)}return a};var n=function(){this.listeners={}};n.prototype.on=function(e,t){this.listeners=this.listeners||{},e in this.listeners?this.listeners[e].push(t):this.listeners[e]=[t]},n.prototype.trigger=function(e){var t=Array.prototype.slice,i=t.call(arguments,1);this.listeners=this.listeners||{},null==i&&(i=[]),0===i.length&&i.push({}),i[0]._type=e,e in this.listeners&&this.invoke(this.listeners[e],t.call(arguments,1)),"*"in this.listeners&&this.invoke(this.listeners["*"],arguments)},n.prototype.invoke=function(e,t){for(var i=0,n=e.length;i<n;i++)e[i].apply(this,t)},t.Observable=n,t.generateChars=function(e){for(var t="",i=0;i<e;i++){t+=Math.floor(36*Math.random()).toString(36)}return t},t.bind=function(e,t){return function(){e.apply(t,arguments)}},t._convertData=function(e){for(var t in e){var i=t.split("-"),n=e;if(1!==i.length){for(var r=0;r<i.length;r++){var a=i[r];(a=a.substring(0,1).toLowerCase()+a.substring(1))in n||(n[a]={}),r==i.length-1&&(n[a]=e[t]),n=n[a]}delete e[t]}}return e},t.hasScroll=function(t,i){var n=e(i),r=i.style.overflowX,a=i.style.overflowY;return(r!==a||"hidden"!==a&&"visible"!==a)&&("scroll"===r||"scroll"===a||(n.innerHeight()<i.scrollHeight||n.innerWidth()<i.scrollWidth))},t.escapeMarkup=function(e){var t={"\\":"&#92;","&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","/":"&#47;"};return"string"!=typeof e?e:String(e).replace(/[&<>"'\/\\]/g,(function(e){return t[e]}))},t.__cache={};var r=0;return t.GetUniqueElementId=function(e){var i=e.getAttribute("data-select2-id");return null!=i||(i=e.id?"select2-data-"+e.id:"select2-data-"+(++r).toString()+"-"+t.generateChars(4),e.setAttribute("data-select2-id",i)),i},t.StoreData=function(e,i,n){var r=t.GetUniqueElementId(e);t.__cache[r]||(t.__cache[r]={}),t.__cache[r][i]=n},t.GetData=function(i,n){var r=t.GetUniqueElementId(i);return n?t.__cache[r]&&null!=t.__cache[r][n]?t.__cache[r][n]:e(i).data(n):t.__cache[r]},t.RemoveData=function(e){var i=t.GetUniqueElementId(e);null!=t.__cache[i]&&delete t.__cache[i],e.removeAttribute("data-select2-id")},t.copyNonInternalCssClasses=function(e,t){var i=e.getAttribute("class").trim().split(/\s+/);i=i.filter((function(e){return 0===e.indexOf("select2-")}));var n=t.getAttribute("class").trim().split(/\s+/);n=n.filter((function(e){return 0!==e.indexOf("select2-")}));var r=i.concat(n);e.setAttribute("class",r.join(" "))},t})),t.define("select2/results",["jquery","./utils"],(function(e,t){function i(e,t,n){this.$element=e,this.data=n,this.options=t,i.__super__.constructor.call(this)}return t.Extend(i,t.Observable),i.prototype.render=function(){var t=e('<ul class="select2-results__options" role="listbox"></ul>');return this.options.get("multiple")&&t.attr("aria-multiselectable","true"),this.$results=t,t},i.prototype.clear=function(){this.$results.empty()},i.prototype.displayMessage=function(t){var i=this.options.get("escapeMarkup");this.clear(),this.hideLoading();var n=e('<li role="alert" aria-live="assertive" class="select2-results__option"></li>'),r=this.options.get("translations").get(t.message);n.append(i(r(t.args))),n[0].className+=" select2-results__message",this.$results.append(n)},i.prototype.hideMessages=function(){this.$results.find(".select2-results__message").remove()},i.prototype.append=function(e){this.hideLoading();var t=[];if(null!=e.results&&0!==e.results.length){e.results=this.sort(e.results);for(var i=0;i<e.results.length;i++){var n=e.results[i],r=this.option(n);t.push(r)}this.$results.append(t)}else 0===this.$results.children().length&&this.trigger("results:message",{message:"noResults"})},i.prototype.position=function(e,t){t.find(".select2-results").append(e)},i.prototype.sort=function(e){return this.options.get("sorter")(e)},i.prototype.highlightFirstItem=function(){var e=this.$results.find(".select2-results__option--selectable"),t=e.filter(".select2-results__option--selected");t.length>0?t.first().trigger("mouseenter"):e.first().trigger("mouseenter"),this.ensureHighlightVisible()},i.prototype.setClasses=function(){var i=this;this.data.current((function(n){var r=n.map((function(e){return e.id.toString()}));i.$results.find(".select2-results__option--selectable").each((function(){var i=e(this),n=t.GetData(this,"data"),a=""+n.id;null!=n.element&&n.element.selected||null==n.element&&r.indexOf(a)>-1?(this.classList.add("select2-results__option--selected"),i.attr("aria-selected","true")):(this.classList.remove("select2-results__option--selected"),i.attr("aria-selected","false"))}))}))},i.prototype.showLoading=function(e){this.hideLoading();var t={disabled:!0,loading:!0,text:this.options.get("translations").get("searching")(e)},i=this.option(t);i.className+=" loading-results",this.$results.prepend(i)},i.prototype.hideLoading=function(){this.$results.find(".loading-results").remove()},i.prototype.option=function(i){var n=document.createElement("li");n.classList.add("select2-results__option"),n.classList.add("select2-results__option--selectable");var r={role:"option"},a=window.Element.prototype.matches||window.Element.prototype.msMatchesSelector||window.Element.prototype.webkitMatchesSelector;for(var s in(null!=i.element&&a.call(i.element,":disabled")||null==i.element&&i.disabled)&&(r["aria-disabled"]="true",n.classList.remove("select2-results__option--selectable"),n.classList.add("select2-results__option--disabled")),null==i.id&&n.classList.remove("select2-results__option--selectable"),null!=i._resultId&&(n.id=i._resultId),i.title&&(n.title=i.title),i.children&&(r.role="group",r["aria-label"]=i.text,n.classList.remove("select2-results__option--selectable"),n.classList.add("select2-results__option--group")),r){var o=r[s];n.setAttribute(s,o)}if(i.children){var l=e(n),c=document.createElement("strong");c.className="select2-results__group",this.template(i,c);for(var u=[],d=0;d<i.children.length;d++){var h=i.children[d],f=this.option(h);u.push(f)}var p=e("<ul></ul>",{class:"select2-results__options select2-results__options--nested",role:"none"});p.append(u),l.append(c),l.append(p)}else this.template(i,n);return t.StoreData(n,"data",i),n},i.prototype.bind=function(i,n){var r=this,a=i.id+"-results";this.$results.attr("id",a),i.on("results:all",(function(e){r.clear(),r.append(e.data),i.isOpen()&&(r.setClasses(),r.highlightFirstItem())})),i.on("results:append",(function(e){r.append(e.data),i.isOpen()&&r.setClasses()})),i.on("query",(function(e){r.hideMessages(),r.showLoading(e)})),i.on("select",(function(){i.isOpen()&&(r.setClasses(),r.options.get("scrollAfterSelect")&&r.highlightFirstItem())})),i.on("unselect",(function(){i.isOpen()&&(r.setClasses(),r.options.get("scrollAfterSelect")&&r.highlightFirstItem())})),i.on("open",(function(){r.$results.attr("aria-expanded","true"),r.$results.attr("aria-hidden","false"),r.setClasses(),r.ensureHighlightVisible()})),i.on("close",(function(){r.$results.attr("aria-expanded","false"),r.$results.attr("aria-hidden","true"),r.$results.removeAttr("aria-activedescendant")})),i.on("results:toggle",(function(){var e=r.getHighlightedResults();0!==e.length&&e.trigger("mouseup")})),i.on("results:select",(function(){var e=r.getHighlightedResults();if(0!==e.length){var i=t.GetData(e[0],"data");e.hasClass("select2-results__option--selected")?r.trigger("close",{}):r.trigger("select",{data:i})}})),i.on("results:previous",(function(){var e=r.getHighlightedResults(),t=r.$results.find(".select2-results__option--selectable"),i=t.index(e);if(!(i<=0)){var n=i-1;0===e.length&&(n=0);var a=t.eq(n);a.trigger("mouseenter");var s=r.$results.offset().top,o=a.offset().top,l=r.$results.scrollTop()+(o-s);0===n?r.$results.scrollTop(0):o-s<0&&r.$results.scrollTop(l)}})),i.on("results:next",(function(){var e=r.getHighlightedResults(),t=r.$results.find(".select2-results__option--selectable"),i=t.index(e)+1;if(!(i>=t.length)){var n=t.eq(i);n.trigger("mouseenter");var a=r.$results.offset().top+r.$results.outerHeight(!1),s=n.offset().top+n.outerHeight(!1),o=r.$results.scrollTop()+s-a;0===i?r.$results.scrollTop(0):s>a&&r.$results.scrollTop(o)}})),i.on("results:focus",(function(e){e.element[0].classList.add("select2-results__option--highlighted"),e.element[0].setAttribute("aria-selected","true")})),i.on("results:message",(function(e){r.displayMessage(e)})),e.fn.mousewheel&&this.$results.on("mousewheel",(function(e){var t=r.$results.scrollTop(),i=r.$results.get(0).scrollHeight-t+e.deltaY,n=e.deltaY>0&&t-e.deltaY<=0,a=e.deltaY<0&&i<=r.$results.height();n?(r.$results.scrollTop(0),e.preventDefault(),e.stopPropagation()):a&&(r.$results.scrollTop(r.$results.get(0).scrollHeight-r.$results.height()),e.preventDefault(),e.stopPropagation())})),this.$results.on("mouseup",".select2-results__option--selectable",(function(i){var n=e(this),a=t.GetData(this,"data");n.hasClass("select2-results__option--selected")?r.options.get("multiple")?r.trigger("unselect",{originalEvent:i,data:a}):r.trigger("close",{}):r.trigger("select",{originalEvent:i,data:a})})),this.$results.on("mouseenter",".select2-results__option--selectable",(function(i){var n=t.GetData(this,"data");r.getHighlightedResults().removeClass("select2-results__option--highlighted").attr("aria-selected","false"),r.trigger("results:focus",{data:n,element:e(this)})}))},i.prototype.getHighlightedResults=function(){return this.$results.find(".select2-results__option--highlighted")},i.prototype.destroy=function(){this.$results.remove()},i.prototype.ensureHighlightVisible=function(){var e=this.getHighlightedResults();if(0!==e.length){var t=this.$results.find(".select2-results__option--selectable").index(e),i=this.$results.offset().top,n=e.offset().top,r=this.$results.scrollTop()+(n-i),a=n-i;r-=2*e.outerHeight(!1),t<=2?this.$results.scrollTop(0):(a>this.$results.outerHeight()||a<0)&&this.$results.scrollTop(r)}},i.prototype.template=function(t,i){var n=this.options.get("templateResult"),r=this.options.get("escapeMarkup"),a=n(t,i);null==a?i.style.display="none":"string"==typeof a?i.innerHTML=r(a):e(i).append(a)},i})),t.define("select2/keys",[],(function(){return{BACKSPACE:8,TAB:9,ENTER:13,SHIFT:16,CTRL:17,ALT:18,ESC:27,SPACE:32,PAGE_UP:33,PAGE_DOWN:34,END:35,HOME:36,LEFT:37,UP:38,RIGHT:39,DOWN:40,DELETE:46}})),t.define("select2/selection/base",["jquery","../utils","../keys"],(function(e,t,i){function n(e,t){this.$element=e,this.options=t,n.__super__.constructor.call(this)}return t.Extend(n,t.Observable),n.prototype.render=function(){var i=e('<span class="select2-selection" role="combobox"  aria-haspopup="true" aria-expanded="false"></span>');return this._tabindex=0,null!=t.GetData(this.$element[0],"old-tabindex")?this._tabindex=t.GetData(this.$element[0],"old-tabindex"):null!=this.$element.attr("tabindex")&&(this._tabindex=this.$element.attr("tabindex")),i.attr("title",this.$element.attr("title")),i.attr("tabindex",this._tabindex),i.attr("aria-disabled","false"),this.$selection=i,i},n.prototype.bind=function(e,t){var n=this,r=e.id+"-results";this.container=e,this.$selection.on("focus",(function(e){n.trigger("focus",e)})),this.$selection.on("blur",(function(e){n._handleBlur(e)})),this.$selection.on("keydown",(function(e){n.trigger("keypress",e),e.which===i.SPACE&&e.preventDefault()})),e.on("results:focus",(function(e){n.$selection.attr("aria-activedescendant",e.data._resultId)})),e.on("selection:update",(function(e){n.update(e.data)})),e.on("open",(function(){n.$selection.attr("aria-expanded","true"),n.$selection.attr("aria-owns",r),n._attachCloseHandler(e)})),e.on("close",(function(){n.$selection.attr("aria-expanded","false"),n.$selection.removeAttr("aria-activedescendant"),n.$selection.removeAttr("aria-owns"),n.$selection.trigger("focus"),n._detachCloseHandler(e)})),e.on("enable",(function(){n.$selection.attr("tabindex",n._tabindex),n.$selection.attr("aria-disabled","false")})),e.on("disable",(function(){n.$selection.attr("tabindex","-1"),n.$selection.attr("aria-disabled","true")}))},n.prototype._handleBlur=function(t){var i=this;window.setTimeout((function(){document.activeElement==i.$selection[0]||e.contains(i.$selection[0],document.activeElement)||i.trigger("blur",t)}),1)},n.prototype._attachCloseHandler=function(i){e(document.body).on("mousedown.select2."+i.id,(function(i){var n=e(i.target).closest(".select2");e(".select2.select2-container--open").each((function(){this!=n[0]&&t.GetData(this,"element").select2("close")}))}))},n.prototype._detachCloseHandler=function(t){e(document.body).off("mousedown.select2."+t.id)},n.prototype.position=function(e,t){t.find(".selection").append(e)},n.prototype.destroy=function(){this._detachCloseHandler(this.container)},n.prototype.update=function(e){throw new Error("The `update` method must be defined in child classes.")},n.prototype.isEnabled=function(){return!this.isDisabled()},n.prototype.isDisabled=function(){return this.options.get("disabled")},n})),t.define("select2/selection/single",["jquery","./base","../utils","../keys"],(function(e,t,i,n){function r(){r.__super__.constructor.apply(this,arguments)}return i.Extend(r,t),r.prototype.render=function(){var e=r.__super__.render.call(this);return e[0].classList.add("select2-selection--single"),e.html('<span class="select2-selection__rendered"></span><span class="select2-selection__arrow" role="presentation"><b role="presentation"></b></span>'),e},r.prototype.bind=function(e,t){var i=this;r.__super__.bind.apply(this,arguments);var n=e.id+"-container";this.$selection.find(".select2-selection__rendered").attr("id",n).attr("role","textbox").attr("aria-readonly","true"),this.$selection.attr("aria-labelledby",n),this.$selection.attr("aria-controls",n),this.$selection.on("mousedown",(function(e){1===e.which&&i.trigger("toggle",{originalEvent:e})})),this.$selection.on("focus",(function(e){})),this.$selection.on("blur",(function(e){})),e.on("focus",(function(t){e.isOpen()||i.$selection.trigger("focus")}))},r.prototype.clear=function(){var e=this.$selection.find(".select2-selection__rendered");e.empty(),e.removeAttr("title")},r.prototype.display=function(e,t){var i=this.options.get("templateSelection");return this.options.get("escapeMarkup")(i(e,t))},r.prototype.selectionContainer=function(){return e("<span></span>")},r.prototype.update=function(e){if(0!==e.length){var t=e[0],i=this.$selection.find(".select2-selection__rendered"),n=this.display(t,i);i.empty().append(n);var r=t.title||t.text;r?i.attr("title",r):i.removeAttr("title")}else this.clear()},r})),t.define("select2/selection/multiple",["jquery","./base","../utils"],(function(e,t,i){function n(e,t){n.__super__.constructor.apply(this,arguments)}return i.Extend(n,t),n.prototype.render=function(){var e=n.__super__.render.call(this);return e[0].classList.add("select2-selection--multiple"),e.html('<ul class="select2-selection__rendered"></ul>'),e},n.prototype.bind=function(t,r){var a=this;n.__super__.bind.apply(this,arguments);var s=t.id+"-container";this.$selection.find(".select2-selection__rendered").attr("id",s),this.$selection.on("click",(function(e){a.trigger("toggle",{originalEvent:e})})),this.$selection.on("click",".select2-selection__choice__remove",(function(t){if(!a.isDisabled()){var n=e(this).parent(),r=i.GetData(n[0],"data");a.trigger("unselect",{originalEvent:t,data:r})}})),this.$selection.on("keydown",".select2-selection__choice__remove",(function(e){a.isDisabled()||e.stopPropagation()}))},n.prototype.clear=function(){var e=this.$selection.find(".select2-selection__rendered");e.empty(),e.removeAttr("title")},n.prototype.display=function(e,t){var i=this.options.get("templateSelection");return this.options.get("escapeMarkup")(i(e,t))},n.prototype.selectionContainer=function(){return e('<li class="select2-selection__choice"><button type="button" class="select2-selection__choice__remove" tabindex="-1"><span aria-hidden="true">&times;</span></button><span class="select2-selection__choice__display"></span></li>')},n.prototype.update=function(e){if(this.clear(),0!==e.length){for(var t=[],n=this.$selection.find(".select2-selection__rendered").attr("id")+"-choice-",r=0;r<e.length;r++){var a=e[r],s=this.selectionContainer(),o=this.display(a,s),l=n+i.generateChars(4)+"-";a.id?l+=a.id:l+=i.generateChars(4),s.find(".select2-selection__choice__display").append(o).attr("id",l);var c=a.title||a.text;c&&s.attr("title",c);var u=this.options.get("translations").get("removeItem"),d=s.find(".select2-selection__choice__remove");d.attr("title",u()),d.attr("aria-label",u()),d.attr("aria-describedby",l),i.StoreData(s[0],"data",a),t.push(s)}this.$selection.find(".select2-selection__rendered").append(t)}},n})),t.define("select2/selection/placeholder",[],(function(){function e(e,t,i){this.placeholder=this.normalizePlaceholder(i.get("placeholder")),e.call(this,t,i)}return e.prototype.normalizePlaceholder=function(e,t){return"string"==typeof t&&(t={id:"",text:t}),t},e.prototype.createPlaceholder=function(e,t){var i=this.selectionContainer();i.html(this.display(t)),i[0].classList.add("select2-selection__placeholder"),i[0].classList.remove("select2-selection__choice");var n=t.title||t.text||i.text();return this.$selection.find(".select2-selection__rendered").attr("title",n),i},e.prototype.update=function(e,t){var i=1==t.length&&t[0].id!=this.placeholder.id;if(t.length>1||i)return e.call(this,t);this.clear();var n=this.createPlaceholder(this.placeholder);this.$selection.find(".select2-selection__rendered").append(n)},e})),t.define("select2/selection/allowClear",["jquery","../keys","../utils"],(function(e,t,i){function n(){}return n.prototype.bind=function(e,t,i){var n=this;e.call(this,t,i),null==this.placeholder&&this.options.get("debug")&&window.console&&console.error&&console.error("Select2: The `allowClear` option should be used in combination with the `placeholder` option."),this.$selection.on("mousedown",".select2-selection__clear",(function(e){n._handleClear(e)})),t.on("keypress",(function(e){n._handleKeyboardClear(e,t)}))},n.prototype._handleClear=function(e,t){if(!this.isDisabled()){var n=this.$selection.find(".select2-selection__clear");if(0!==n.length){t.stopPropagation();var r=i.GetData(n[0],"data"),a=this.$element.val();this.$element.val(this.placeholder.id);var s={data:r};if(this.trigger("clear",s),s.prevented)this.$element.val(a);else{for(var o=0;o<r.length;o++)if(s={data:r[o]},this.trigger("unselect",s),s.prevented)return void this.$element.val(a);this.$element.trigger("input").trigger("change"),this.trigger("toggle",{})}}}},n.prototype._handleKeyboardClear=function(e,i,n){n.isOpen()||i.which!=t.DELETE&&i.which!=t.BACKSPACE||this._handleClear(i)},n.prototype.update=function(t,n){if(t.call(this,n),this.$selection.find(".select2-selection__clear").remove(),this.$selection[0].classList.remove("select2-selection--clearable"),!(this.$selection.find(".select2-selection__placeholder").length>0||0===n.length)){var r=this.$selection.find(".select2-selection__rendered").attr("id"),a=this.options.get("translations").get("removeAllItems"),s=e('<button type="button" class="select2-selection__clear" tabindex="-1"><span aria-hidden="true">&times;</span></button>');s.attr("title",a()),s.attr("aria-label",a()),s.attr("aria-describedby",r),i.StoreData(s[0],"data",n),this.$selection.prepend(s),this.$selection[0].classList.add("select2-selection--clearable")}},n})),t.define("select2/selection/search",["jquery","../utils","../keys"],(function(e,t,i){function n(e,t,i){e.call(this,t,i)}return n.prototype.render=function(t){var i=this.options.get("translations").get("search"),n=e('<span class="select2-search select2-search--inline"><textarea class="select2-search__field" type="search" tabindex="-1" autocorrect="off" autocapitalize="none" spellcheck="false" role="searchbox" aria-autocomplete="list" ></textarea></span>');this.$searchContainer=n,this.$search=n.find("textarea"),this.$search.prop("autocomplete",this.options.get("autocomplete")),this.$search.attr("aria-label",i());var r=t.call(this);return this._transferTabIndex(),r.append(this.$searchContainer),r},n.prototype.bind=function(e,n,r){var a=this,s=n.id+"-results",o=n.id+"-container";e.call(this,n,r),a.$search.attr("aria-describedby",o),n.on("open",(function(){a.$search.attr("aria-controls",s),a.$search.trigger("focus")})),n.on("close",(function(){a.$search.val(""),a.resizeSearch(),a.$search.removeAttr("aria-controls"),a.$search.removeAttr("aria-activedescendant"),a.$search.trigger("focus")})),n.on("enable",(function(){a.$search.prop("disabled",!1),a._transferTabIndex()})),n.on("disable",(function(){a.$search.prop("disabled",!0)})),n.on("focus",(function(e){a.$search.trigger("focus")})),n.on("results:focus",(function(e){e.data._resultId?a.$search.attr("aria-activedescendant",e.data._resultId):a.$search.removeAttr("aria-activedescendant")})),this.$selection.on("focusin",".select2-search--inline",(function(e){a.trigger("focus",e)})),this.$selection.on("focusout",".select2-search--inline",(function(e){a._handleBlur(e)})),this.$selection.on("keydown",".select2-search--inline",(function(e){if(e.stopPropagation(),a.trigger("keypress",e),a._keyUpPrevented=e.isDefaultPrevented(),e.which===i.BACKSPACE&&""===a.$search.val()){var n=a.$selection.find(".select2-selection__choice").last();if(n.length>0){var r=t.GetData(n[0],"data");a.searchRemoveChoice(r),e.preventDefault()}}})),this.$selection.on("click",".select2-search--inline",(function(e){a.$search.val()&&e.stopPropagation()}));var l=document.documentMode,c=l&&l<=11;this.$selection.on("input.searchcheck",".select2-search--inline",(function(e){c?a.$selection.off("input.search input.searchcheck"):a.$selection.off("keyup.search")})),this.$selection.on("keyup.search input.search",".select2-search--inline",(function(e){if(c&&"input"===e.type)a.$selection.off("input.search input.searchcheck");else{var t=e.which;t!=i.SHIFT&&t!=i.CTRL&&t!=i.ALT&&t!=i.TAB&&a.handleSearch(e)}}))},n.prototype._transferTabIndex=function(e){this.$search.attr("tabindex",this.$selection.attr("tabindex")),this.$selection.attr("tabindex","-1")},n.prototype.createPlaceholder=function(e,t){this.$search.attr("placeholder",t.text)},n.prototype.update=function(e,t){var i=this.$search[0]==document.activeElement;this.$search.attr("placeholder",""),e.call(this,t),this.resizeSearch(),i&&this.$search.trigger("focus")},n.prototype.handleSearch=function(){if(this.resizeSearch(),!this._keyUpPrevented){var e=this.$search.val();this.trigger("query",{term:e})}this._keyUpPrevented=!1},n.prototype.searchRemoveChoice=function(e,t){this.trigger("unselect",{data:t}),this.$search.val(t.text),this.handleSearch()},n.prototype.resizeSearch=function(){this.$search.css("width","25px");var e="100%";""===this.$search.attr("placeholder")&&(e=.75*(this.$search.val().length+1)+"em");this.$search.css("width",e)},n})),t.define("select2/selection/selectionCss",["../utils"],(function(e){function t(){}return t.prototype.render=function(t){var i=t.call(this),n=this.options.get("selectionCssClass")||"";return-1!==n.indexOf(":all:")&&(n=n.replace(":all:",""),e.copyNonInternalCssClasses(i[0],this.$element[0])),i.addClass(n),i},t})),t.define("select2/selection/eventRelay",["jquery"],(function(e){function t(){}return t.prototype.bind=function(t,i,n){var r=this,a=["open","opening","close","closing","select","selecting","unselect","unselecting","clear","clearing"],s=["opening","closing","selecting","unselecting","clearing"];t.call(this,i,n),i.on("*",(function(t,i){if(-1!==a.indexOf(t)){i=i||{};var n=e.Event("select2:"+t,{params:i});r.$element.trigger(n),-1!==s.indexOf(t)&&(i.prevented=n.isDefaultPrevented())}}))},t})),t.define("select2/translation",["jquery","require"],(function(e,t){function i(e){this.dict=e||{}}return i.prototype.all=function(){return this.dict},i.prototype.get=function(e){return this.dict[e]},i.prototype.extend=function(t){this.dict=e.extend({},t.all(),this.dict)},i._cache={},i.loadPath=function(e){if(!(e in i._cache)){var n=t(e);i._cache[e]=n}return new i(i._cache[e])},i})),t.define("select2/diacritics",[],(function(){return{"Ⓐ":"A","Ａ":"A","À":"A","Á":"A","Â":"A","Ầ":"A","Ấ":"A","Ẫ":"A","Ẩ":"A","Ã":"A","Ā":"A","Ă":"A","Ằ":"A","Ắ":"A","Ẵ":"A","Ẳ":"A","Ȧ":"A","Ǡ":"A","Ä":"A","Ǟ":"A","Ả":"A","Å":"A","Ǻ":"A","Ǎ":"A","Ȁ":"A","Ȃ":"A","Ạ":"A","Ậ":"A","Ặ":"A","Ḁ":"A","Ą":"A","Ⱥ":"A","Ɐ":"A","Ꜳ":"AA","Æ":"AE","Ǽ":"AE","Ǣ":"AE","Ꜵ":"AO","Ꜷ":"AU","Ꜹ":"AV","Ꜻ":"AV","Ꜽ":"AY","Ⓑ":"B","Ｂ":"B","Ḃ":"B","Ḅ":"B","Ḇ":"B","Ƀ":"B","Ƃ":"B","Ɓ":"B","Ⓒ":"C","Ｃ":"C","Ć":"C","Ĉ":"C","Ċ":"C","Č":"C","Ç":"C","Ḉ":"C","Ƈ":"C","Ȼ":"C","Ꜿ":"C","Ⓓ":"D","Ｄ":"D","Ḋ":"D","Ď":"D","Ḍ":"D","Ḑ":"D","Ḓ":"D","Ḏ":"D","Đ":"D","Ƌ":"D","Ɗ":"D","Ɖ":"D","Ꝺ":"D","Ǳ":"DZ","Ǆ":"DZ","ǲ":"Dz","ǅ":"Dz","Ⓔ":"E","Ｅ":"E","È":"E","É":"E","Ê":"E","Ề":"E","Ế":"E","Ễ":"E","Ể":"E","Ẽ":"E","Ē":"E","Ḕ":"E","Ḗ":"E","Ĕ":"E","Ė":"E","Ë":"E","Ẻ":"E","Ě":"E","Ȅ":"E","Ȇ":"E","Ẹ":"E","Ệ":"E","Ȩ":"E","Ḝ":"E","Ę":"E","Ḙ":"E","Ḛ":"E","Ɛ":"E","Ǝ":"E","Ⓕ":"F","Ｆ":"F","Ḟ":"F","Ƒ":"F","Ꝼ":"F","Ⓖ":"G","Ｇ":"G","Ǵ":"G","Ĝ":"G","Ḡ":"G","Ğ":"G","Ġ":"G","Ǧ":"G","Ģ":"G","Ǥ":"G","Ɠ":"G","Ꞡ":"G","Ᵹ":"G","Ꝿ":"G","Ⓗ":"H","Ｈ":"H","Ĥ":"H","Ḣ":"H","Ḧ":"H","Ȟ":"H","Ḥ":"H","Ḩ":"H","Ḫ":"H","Ħ":"H","Ⱨ":"H","Ⱶ":"H","Ɥ":"H","Ⓘ":"I","Ｉ":"I","Ì":"I","Í":"I","Î":"I","Ĩ":"I","Ī":"I","Ĭ":"I","İ":"I","Ï":"I","Ḯ":"I","Ỉ":"I","Ǐ":"I","Ȉ":"I","Ȋ":"I","Ị":"I","Į":"I","Ḭ":"I","Ɨ":"I","Ⓙ":"J","Ｊ":"J","Ĵ":"J","Ɉ":"J","Ⓚ":"K","Ｋ":"K","Ḱ":"K","Ǩ":"K","Ḳ":"K","Ķ":"K","Ḵ":"K","Ƙ":"K","Ⱪ":"K","Ꝁ":"K","Ꝃ":"K","Ꝅ":"K","Ꞣ":"K","Ⓛ":"L","Ｌ":"L","Ŀ":"L","Ĺ":"L","Ľ":"L","Ḷ":"L","Ḹ":"L","Ļ":"L","Ḽ":"L","Ḻ":"L","Ł":"L","Ƚ":"L","Ɫ":"L","Ⱡ":"L","Ꝉ":"L","Ꝇ":"L","Ꞁ":"L","Ǉ":"LJ","ǈ":"Lj","Ⓜ":"M","Ｍ":"M","Ḿ":"M","Ṁ":"M","Ṃ":"M","Ɱ":"M","Ɯ":"M","Ⓝ":"N","Ｎ":"N","Ǹ":"N","Ń":"N","Ñ":"N","Ṅ":"N","Ň":"N","Ṇ":"N","Ņ":"N","Ṋ":"N","Ṉ":"N","Ƞ":"N","Ɲ":"N","Ꞑ":"N","Ꞥ":"N","Ǌ":"NJ","ǋ":"Nj","Ⓞ":"O","Ｏ":"O","Ò":"O","Ó":"O","Ô":"O","Ồ":"O","Ố":"O","Ỗ":"O","Ổ":"O","Õ":"O","Ṍ":"O","Ȭ":"O","Ṏ":"O","Ō":"O","Ṑ":"O","Ṓ":"O","Ŏ":"O","Ȯ":"O","Ȱ":"O","Ö":"O","Ȫ":"O","Ỏ":"O","Ő":"O","Ǒ":"O","Ȍ":"O","Ȏ":"O","Ơ":"O","Ờ":"O","Ớ":"O","Ỡ":"O","Ở":"O","Ợ":"O","Ọ":"O","Ộ":"O","Ǫ":"O","Ǭ":"O","Ø":"O","Ǿ":"O","Ɔ":"O","Ɵ":"O","Ꝋ":"O","Ꝍ":"O","Œ":"OE","Ƣ":"OI","Ꝏ":"OO","Ȣ":"OU","Ⓟ":"P","Ｐ":"P","Ṕ":"P","Ṗ":"P","Ƥ":"P","Ᵽ":"P","Ꝑ":"P","Ꝓ":"P","Ꝕ":"P","Ⓠ":"Q","Ｑ":"Q","Ꝗ":"Q","Ꝙ":"Q","Ɋ":"Q","Ⓡ":"R","Ｒ":"R","Ŕ":"R","Ṙ":"R","Ř":"R","Ȑ":"R","Ȓ":"R","Ṛ":"R","Ṝ":"R","Ŗ":"R","Ṟ":"R","Ɍ":"R","Ɽ":"R","Ꝛ":"R","Ꞧ":"R","Ꞃ":"R","Ⓢ":"S","Ｓ":"S","ẞ":"S","Ś":"S","Ṥ":"S","Ŝ":"S","Ṡ":"S","Š":"S","Ṧ":"S","Ṣ":"S","Ṩ":"S","Ș":"S","Ş":"S","Ȿ":"S","Ꞩ":"S","Ꞅ":"S","Ⓣ":"T","Ｔ":"T","Ṫ":"T","Ť":"T","Ṭ":"T","Ț":"T","Ţ":"T","Ṱ":"T","Ṯ":"T","Ŧ":"T","Ƭ":"T","Ʈ":"T","Ⱦ":"T","Ꞇ":"T","Ꜩ":"TZ","Ⓤ":"U","Ｕ":"U","Ù":"U","Ú":"U","Û":"U","Ũ":"U","Ṹ":"U","Ū":"U","Ṻ":"U","Ŭ":"U","Ü":"U","Ǜ":"U","Ǘ":"U","Ǖ":"U","Ǚ":"U","Ủ":"U","Ů":"U","Ű":"U","Ǔ":"U","Ȕ":"U","Ȗ":"U","Ư":"U","Ừ":"U","Ứ":"U","Ữ":"U","Ử":"U","Ự":"U","Ụ":"U","Ṳ":"U","Ų":"U","Ṷ":"U","Ṵ":"U","Ʉ":"U","Ⓥ":"V","Ｖ":"V","Ṽ":"V","Ṿ":"V","Ʋ":"V","Ꝟ":"V","Ʌ":"V","Ꝡ":"VY","Ⓦ":"W","Ｗ":"W","Ẁ":"W","Ẃ":"W","Ŵ":"W","Ẇ":"W","Ẅ":"W","Ẉ":"W","Ⱳ":"W","Ⓧ":"X","Ｘ":"X","Ẋ":"X","Ẍ":"X","Ⓨ":"Y","Ｙ":"Y","Ỳ":"Y","Ý":"Y","Ŷ":"Y","Ỹ":"Y","Ȳ":"Y","Ẏ":"Y","Ÿ":"Y","Ỷ":"Y","Ỵ":"Y","Ƴ":"Y","Ɏ":"Y","Ỿ":"Y","Ⓩ":"Z","Ｚ":"Z","Ź":"Z","Ẑ":"Z","Ż":"Z","Ž":"Z","Ẓ":"Z","Ẕ":"Z","Ƶ":"Z","Ȥ":"Z","Ɀ":"Z","Ⱬ":"Z","Ꝣ":"Z","ⓐ":"a","ａ":"a","ẚ":"a","à":"a","á":"a","â":"a","ầ":"a","ấ":"a","ẫ":"a","ẩ":"a","ã":"a","ā":"a","ă":"a","ằ":"a","ắ":"a","ẵ":"a","ẳ":"a","ȧ":"a","ǡ":"a","ä":"a","ǟ":"a","ả":"a","å":"a","ǻ":"a","ǎ":"a","ȁ":"a","ȃ":"a","ạ":"a","ậ":"a","ặ":"a","ḁ":"a","ą":"a","ⱥ":"a","ɐ":"a","ꜳ":"aa","æ":"ae","ǽ":"ae","ǣ":"ae","ꜵ":"ao","ꜷ":"au","ꜹ":"av","ꜻ":"av","ꜽ":"ay","ⓑ":"b","ｂ":"b","ḃ":"b","ḅ":"b","ḇ":"b","ƀ":"b","ƃ":"b","ɓ":"b","ⓒ":"c","ｃ":"c","ć":"c","ĉ":"c","ċ":"c","č":"c","ç":"c","ḉ":"c","ƈ":"c","ȼ":"c","ꜿ":"c","ↄ":"c","ⓓ":"d","ｄ":"d","ḋ":"d","ď":"d","ḍ":"d","ḑ":"d","ḓ":"d","ḏ":"d","đ":"d","ƌ":"d","ɖ":"d","ɗ":"d","ꝺ":"d","ǳ":"dz","ǆ":"dz","ⓔ":"e","ｅ":"e","è":"e","é":"e","ê":"e","ề":"e","ế":"e","ễ":"e","ể":"e","ẽ":"e","ē":"e","ḕ":"e","ḗ":"e","ĕ":"e","ė":"e","ë":"e","ẻ":"e","ě":"e","ȅ":"e","ȇ":"e","ẹ":"e","ệ":"e","ȩ":"e","ḝ":"e","ę":"e","ḙ":"e","ḛ":"e","ɇ":"e","ɛ":"e","ǝ":"e","ⓕ":"f","ｆ":"f","ḟ":"f","ƒ":"f","ꝼ":"f","ⓖ":"g","ｇ":"g","ǵ":"g","ĝ":"g","ḡ":"g","ğ":"g","ġ":"g","ǧ":"g","ģ":"g","ǥ":"g","ɠ":"g","ꞡ":"g","ᵹ":"g","ꝿ":"g","ⓗ":"h","ｈ":"h","ĥ":"h","ḣ":"h","ḧ":"h","ȟ":"h","ḥ":"h","ḩ":"h","ḫ":"h","ẖ":"h","ħ":"h","ⱨ":"h","ⱶ":"h","ɥ":"h","ƕ":"hv","ⓘ":"i","ｉ":"i","ì":"i","í":"i","î":"i","ĩ":"i","ī":"i","ĭ":"i","ï":"i","ḯ":"i","ỉ":"i","ǐ":"i","ȉ":"i","ȋ":"i","ị":"i","į":"i","ḭ":"i","ɨ":"i","ı":"i","ⓙ":"j","ｊ":"j","ĵ":"j","ǰ":"j","ɉ":"j","ⓚ":"k","ｋ":"k","ḱ":"k","ǩ":"k","ḳ":"k","ķ":"k","ḵ":"k","ƙ":"k","ⱪ":"k","ꝁ":"k","ꝃ":"k","ꝅ":"k","ꞣ":"k","ⓛ":"l","ｌ":"l","ŀ":"l","ĺ":"l","ľ":"l","ḷ":"l","ḹ":"l","ļ":"l","ḽ":"l","ḻ":"l","ſ":"l","ł":"l","ƚ":"l","ɫ":"l","ⱡ":"l","ꝉ":"l","ꞁ":"l","ꝇ":"l","ǉ":"lj","ⓜ":"m","ｍ":"m","ḿ":"m","ṁ":"m","ṃ":"m","ɱ":"m","ɯ":"m","ⓝ":"n","ｎ":"n","ǹ":"n","ń":"n","ñ":"n","ṅ":"n","ň":"n","ṇ":"n","ņ":"n","ṋ":"n","ṉ":"n","ƞ":"n","ɲ":"n","ŉ":"n","ꞑ":"n","ꞥ":"n","ǌ":"nj","ⓞ":"o","ｏ":"o","ò":"o","ó":"o","ô":"o","ồ":"o","ố":"o","ỗ":"o","ổ":"o","õ":"o","ṍ":"o","ȭ":"o","ṏ":"o","ō":"o","ṑ":"o","ṓ":"o","ŏ":"o","ȯ":"o","ȱ":"o","ö":"o","ȫ":"o","ỏ":"o","ő":"o","ǒ":"o","ȍ":"o","ȏ":"o","ơ":"o","ờ":"o","ớ":"o","ỡ":"o","ở":"o","ợ":"o","ọ":"o","ộ":"o","ǫ":"o","ǭ":"o","ø":"o","ǿ":"o","ɔ":"o","ꝋ":"o","ꝍ":"o","ɵ":"o","œ":"oe","ƣ":"oi","ȣ":"ou","ꝏ":"oo","ⓟ":"p","ｐ":"p","ṕ":"p","ṗ":"p","ƥ":"p","ᵽ":"p","ꝑ":"p","ꝓ":"p","ꝕ":"p","ⓠ":"q","ｑ":"q","ɋ":"q","ꝗ":"q","ꝙ":"q","ⓡ":"r","ｒ":"r","ŕ":"r","ṙ":"r","ř":"r","ȑ":"r","ȓ":"r","ṛ":"r","ṝ":"r","ŗ":"r","ṟ":"r","ɍ":"r","ɽ":"r","ꝛ":"r","ꞧ":"r","ꞃ":"r","ⓢ":"s","ｓ":"s","ß":"s","ś":"s","ṥ":"s","ŝ":"s","ṡ":"s","š":"s","ṧ":"s","ṣ":"s","ṩ":"s","ș":"s","ş":"s","ȿ":"s","ꞩ":"s","ꞅ":"s","ẛ":"s","ⓣ":"t","ｔ":"t","ṫ":"t","ẗ":"t","ť":"t","ṭ":"t","ț":"t","ţ":"t","ṱ":"t","ṯ":"t","ŧ":"t","ƭ":"t","ʈ":"t","ⱦ":"t","ꞇ":"t","ꜩ":"tz","ⓤ":"u","ｕ":"u","ù":"u","ú":"u","û":"u","ũ":"u","ṹ":"u","ū":"u","ṻ":"u","ŭ":"u","ü":"u","ǜ":"u","ǘ":"u","ǖ":"u","ǚ":"u","ủ":"u","ů":"u","ű":"u","ǔ":"u","ȕ":"u","ȗ":"u","ư":"u","ừ":"u","ứ":"u","ữ":"u","ử":"u","ự":"u","ụ":"u","ṳ":"u","ų":"u","ṷ":"u","ṵ":"u","ʉ":"u","ⓥ":"v","ｖ":"v","ṽ":"v","ṿ":"v","ʋ":"v","ꝟ":"v","ʌ":"v","ꝡ":"vy","ⓦ":"w","ｗ":"w","ẁ":"w","ẃ":"w","ŵ":"w","ẇ":"w","ẅ":"w","ẘ":"w","ẉ":"w","ⱳ":"w","ⓧ":"x","ｘ":"x","ẋ":"x","ẍ":"x","ⓨ":"y","ｙ":"y","ỳ":"y","ý":"y","ŷ":"y","ỹ":"y","ȳ":"y","ẏ":"y","ÿ":"y","ỷ":"y","ẙ":"y","ỵ":"y","ƴ":"y","ɏ":"y","ỿ":"y","ⓩ":"z","ｚ":"z","ź":"z","ẑ":"z","ż":"z","ž":"z","ẓ":"z","ẕ":"z","ƶ":"z","ȥ":"z","ɀ":"z","ⱬ":"z","ꝣ":"z","Ά":"Α","Έ":"Ε","Ή":"Η","Ί":"Ι","Ϊ":"Ι","Ό":"Ο","Ύ":"Υ","Ϋ":"Υ","Ώ":"Ω","ά":"α","έ":"ε","ή":"η","ί":"ι","ϊ":"ι","ΐ":"ι","ό":"ο","ύ":"υ","ϋ":"υ","ΰ":"υ","ώ":"ω","ς":"σ","’":"'"}})),t.define("select2/data/base",["../utils"],(function(e){function t(e,i){t.__super__.constructor.call(this)}return e.Extend(t,e.Observable),t.prototype.current=function(e){throw new Error("The `current` method must be defined in child classes.")},t.prototype.query=function(e,t){throw new Error("The `query` method must be defined in child classes.")},t.prototype.bind=function(e,t){},t.prototype.destroy=function(){},t.prototype.generateResultId=function(t,i){var n=t.id+"-result-";return n+=e.generateChars(4),null!=i.id?n+="-"+i.id.toString():n+="-"+e.generateChars(4),n},t})),t.define("select2/data/select",["./base","../utils","jquery"],(function(e,t,i){function n(e,t){this.$element=e,this.options=t,n.__super__.constructor.call(this)}return t.Extend(n,e),n.prototype.current=function(e){var t=this;e(Array.prototype.map.call(this.$element[0].querySelectorAll(":checked"),(function(e){return t.item(i(e))})))},n.prototype.select=function(e){var t=this;if(e.selected=!0,null!=e.element&&"option"===e.element.tagName.toLowerCase())return e.element.selected=!0,void this.$element.trigger("input").trigger("change");if(this.$element.prop("multiple"))this.current((function(i){var n=[];(e=[e]).push.apply(e,i);for(var r=0;r<e.length;r++){var a=e[r].id;-1===n.indexOf(a)&&n.push(a)}t.$element.val(n),t.$element.trigger("input").trigger("change")}));else{var i=e.id;this.$element.val(i),this.$element.trigger("input").trigger("change")}},n.prototype.unselect=function(e){var t=this;if(this.$element.prop("multiple")){if(e.selected=!1,null!=e.element&&"option"===e.element.tagName.toLowerCase())return e.element.selected=!1,void this.$element.trigger("input").trigger("change");this.current((function(i){for(var n=[],r=0;r<i.length;r++){var a=i[r].id;a!==e.id&&-1===n.indexOf(a)&&n.push(a)}t.$element.val(n),t.$element.trigger("input").trigger("change")}))}},n.prototype.bind=function(e,t){var i=this;this.container=e,e.on("select",(function(e){i.select(e.data)})),e.on("unselect",(function(e){i.unselect(e.data)}))},n.prototype.destroy=function(){this.$element.find("*").each((function(){t.RemoveData(this)}))},n.prototype.query=function(e,t){var n=[],r=this;this.$element.children().each((function(){if("option"===this.tagName.toLowerCase()||"optgroup"===this.tagName.toLowerCase()){var t=i(this),a=r.item(t),s=r.matches(e,a);null!==s&&n.push(s)}})),t({results:n})},n.prototype.addOptions=function(e){this.$element.append(e)},n.prototype.option=function(e){var n;e.children?(n=document.createElement("optgroup")).label=e.text:void 0!==(n=document.createElement("option")).textContent?n.textContent=e.text:n.innerText=e.text,void 0!==e.id&&(n.value=e.id),e.disabled&&(n.disabled=!0),e.selected&&(n.selected=!0),e.title&&(n.title=e.title);var r=this._normalizeItem(e);return r.element=n,t.StoreData(n,"data",r),i(n)},n.prototype.item=function(e){var n={};if(null!=(n=t.GetData(e[0],"data")))return n;var r=e[0];if("option"===r.tagName.toLowerCase())n={id:e.val(),text:e.text(),disabled:e.prop("disabled"),selected:e.prop("selected"),title:e.prop("title")};else if("optgroup"===r.tagName.toLowerCase()){n={text:e.prop("label"),children:[],title:e.prop("title")};for(var a=e.children("option"),s=[],o=0;o<a.length;o++){var l=i(a[o]),c=this.item(l);s.push(c)}n.children=s}return(n=this._normalizeItem(n)).element=e[0],t.StoreData(e[0],"data",n),n},n.prototype._normalizeItem=function(e){e!==Object(e)&&(e={id:e,text:e});return null!=(e=i.extend({},{text:""},e)).id&&(e.id=e.id.toString()),null!=e.text&&(e.text=e.text.toString()),null==e._resultId&&e.id&&null!=this.container&&(e._resultId=this.generateResultId(this.container,e)),i.extend({},{selected:!1,disabled:!1},e)},n.prototype.matches=function(e,t){return this.options.get("matcher")(e,t)},n})),t.define("select2/data/array",["./select","../utils","jquery"],(function(e,t,i){function n(e,t){this._dataToConvert=t.get("data")||[],n.__super__.constructor.call(this,e,t)}return t.Extend(n,e),n.prototype.bind=function(e,t){n.__super__.bind.call(this,e,t),this.addOptions(this.convertToOptions(this._dataToConvert))},n.prototype.select=function(e){var t=this.$element.find("option").filter((function(t,i){return i.value==e.id.toString()}));0===t.length&&(t=this.option(e),this.addOptions(t)),n.__super__.select.call(this,e)},n.prototype.convertToOptions=function(e){var t=this,n=this.$element.find("option"),r=n.map((function(){return t.item(i(this)).id})).get(),a=[];function s(e){return function(){return i(this).val()==e.id}}for(var o=0;o<e.length;o++){var l=this._normalizeItem(e[o]);if(r.indexOf(l.id)>=0){var c=n.filter(s(l)),u=this.item(c),d=i.extend(!0,{},l,u),h=this.option(d);c.replaceWith(h)}else{var f=this.option(l);if(l.children){var p=this.convertToOptions(l.children);f.append(p)}a.push(f)}}return a},n})),t.define("select2/data/ajax",["./array","../utils","jquery"],(function(e,t,i){function n(e,t){this.ajaxOptions=this._applyDefaults(t.get("ajax")),null!=this.ajaxOptions.processResults&&(this.processResults=this.ajaxOptions.processResults),n.__super__.constructor.call(this,e,t)}return t.Extend(n,e),n.prototype._applyDefaults=function(e){var t={data:function(e){return i.extend({},e,{q:e.term})},transport:function(e,t,n){var r=i.ajax(e);return r.then(t),r.fail(n),r}};return i.extend({},t,e,!0)},n.prototype.processResults=function(e){return e},n.prototype.query=function(e,t){var n=this;null!=this._request&&("function"==typeof this._request.abort&&this._request.abort(),this._request=null);var r=i.extend({type:"GET"},this.ajaxOptions);function a(){var i=r.transport(r,(function(i){var r=n.processResults(i,e);n.options.get("debug")&&window.console&&console.error&&(r&&r.results&&Array.isArray(r.results)||console.error("Select2: The AJAX results did not return an array in the `results` key of the response.")),t(r)}),(function(){(!("status"in i)||0!==i.status&&"0"!==i.status)&&n.trigger("results:message",{message:"errorLoading"})}));n._request=i}"function"==typeof r.url&&(r.url=r.url.call(this.$element,e)),"function"==typeof r.data&&(r.data=r.data.call(this.$element,e)),this.ajaxOptions.delay&&null!=e.term?(this._queryTimeout&&window.clearTimeout(this._queryTimeout),this._queryTimeout=window.setTimeout(a,this.ajaxOptions.delay)):a()},n})),t.define("select2/data/tags",["jquery"],(function(e){function t(e,t,i){var n=i.get("tags"),r=i.get("createTag");void 0!==r&&(this.createTag=r);var a=i.get("insertTag");if(void 0!==a&&(this.insertTag=a),e.call(this,t,i),Array.isArray(n))for(var s=0;s<n.length;s++){var o=n[s],l=this._normalizeItem(o),c=this.option(l);this.$element.append(c)}}return t.prototype.query=function(e,t,i){var n=this;this._removeOldTags(),null!=t.term&&null==t.page?e.call(this,t,(function e(r,a){for(var s=r.results,o=0;o<s.length;o++){var l=s[o],c=null!=l.children&&!e({results:l.children},!0);if((l.text||"").toUpperCase()===(t.term||"").toUpperCase()||c)return!a&&(r.data=s,void i(r))}if(a)return!0;var u=n.createTag(t);if(null!=u){var d=n.option(u);d.attr("data-select2-tag","true"),n.addOptions([d]),n.insertTag(s,u)}r.results=s,i(r)})):e.call(this,t,i)},t.prototype.createTag=function(e,t){if(null==t.term)return null;var i=t.term.trim();return""===i?null:{id:i,text:i}},t.prototype.insertTag=function(e,t,i){t.unshift(i)},t.prototype._removeOldTags=function(t){this.$element.find("option[data-select2-tag]").each((function(){this.selected||e(this).remove()}))},t})),t.define("select2/data/tokenizer",["jquery"],(function(e){function t(e,t,i){var n=i.get("tokenizer");void 0!==n&&(this.tokenizer=n),e.call(this,t,i)}return t.prototype.bind=function(e,t,i){e.call(this,t,i),this.$search=t.dropdown.$search||t.selection.$search||i.find(".select2-search__field")},t.prototype.query=function(t,i,n){var r=this;i.term=i.term||"";var a=this.tokenizer(i,this.options,(function(t){var i=r._normalizeItem(t);if(!r.$element.find("option").filter((function(){return e(this).val()===i.id})).length){var n=r.option(i);n.attr("data-select2-tag",!0),r._removeOldTags(),r.addOptions([n])}!function(e){r.trigger("select",{data:e})}(i)}));a.term!==i.term&&(this.$search.length&&(this.$search.val(a.term),this.$search.trigger("focus")),i.term=a.term),t.call(this,i,n)},t.prototype.tokenizer=function(t,i,n,r){for(var a=n.get("tokenSeparators")||[],s=i.term,o=0,l=this.createTag||function(e){return{id:e.term,text:e.term}};o<s.length;){var c=s[o];if(-1!==a.indexOf(c)){var u=s.substr(0,o),d=l(e.extend({},i,{term:u}));null!=d?(r(d),s=s.substr(o+1)||"",o=0):o++}else o++}return{term:s}},t})),t.define("select2/data/minimumInputLength",[],(function(){function e(e,t,i){this.minimumInputLength=i.get("minimumInputLength"),e.call(this,t,i)}return e.prototype.query=function(e,t,i){t.term=t.term||"",t.term.length<this.minimumInputLength?this.trigger("results:message",{message:"inputTooShort",args:{minimum:this.minimumInputLength,input:t.term,params:t}}):e.call(this,t,i)},e})),t.define("select2/data/maximumInputLength",[],(function(){function e(e,t,i){this.maximumInputLength=i.get("maximumInputLength"),e.call(this,t,i)}return e.prototype.query=function(e,t,i){t.term=t.term||"",this.maximumInputLength>0&&t.term.length>this.maximumInputLength?this.trigger("results:message",{message:"inputTooLong",args:{maximum:this.maximumInputLength,input:t.term,params:t}}):e.call(this,t,i)},e})),t.define("select2/data/maximumSelectionLength",[],(function(){function e(e,t,i){this.maximumSelectionLength=i.get("maximumSelectionLength"),e.call(this,t,i)}return e.prototype.bind=function(e,t,i){var n=this;e.call(this,t,i),t.on("select",(function(){n._checkIfMaximumSelected()}))},e.prototype.query=function(e,t,i){var n=this;this._checkIfMaximumSelected((function(){e.call(n,t,i)}))},e.prototype._checkIfMaximumSelected=function(e,t){var i=this;this.current((function(e){var n=null!=e?e.length:0;i.maximumSelectionLength>0&&n>=i.maximumSelectionLength?i.trigger("results:message",{message:"maximumSelected",args:{maximum:i.maximumSelectionLength}}):t&&t()}))},e})),t.define("select2/dropdown",["jquery","./utils"],(function(e,t){function i(e,t){this.$element=e,this.options=t,i.__super__.constructor.call(this)}return t.Extend(i,t.Observable),i.prototype.render=function(){var t=e('<span class="select2-dropdown"><span class="select2-results"></span></span>');return t.attr("dir",this.options.get("dir")),this.$dropdown=t,t},i.prototype.bind=function(){},i.prototype.position=function(e,t){},i.prototype.destroy=function(){this.$dropdown.remove()},i})),t.define("select2/dropdown/search",["jquery"],(function(e){function t(){}return t.prototype.render=function(t){var i=t.call(this),n=this.options.get("translations").get("search"),r=e('<span class="select2-search select2-search--dropdown"><input class="select2-search__field" type="search" tabindex="-1" autocorrect="off" autocapitalize="none" spellcheck="false" role="searchbox" aria-autocomplete="list" /></span>');return this.$searchContainer=r,this.$search=r.find("input"),this.$search.prop("autocomplete",this.options.get("autocomplete")),this.$search.attr("aria-label",n()),i.prepend(r),i},t.prototype.bind=function(t,i,n){var r=this,a=i.id+"-results";t.call(this,i,n),this.$search.on("keydown",(function(e){r.trigger("keypress",e),r._keyUpPrevented=e.isDefaultPrevented()})),this.$search.on("input",(function(t){e(this).off("keyup")})),this.$search.on("keyup input",(function(e){r.handleSearch(e)})),i.on("open",(function(){r.$search.attr("tabindex",0),r.$search.attr("aria-controls",a),r.$search.trigger("focus"),window.setTimeout((function(){r.$search.trigger("focus")}),0)})),i.on("close",(function(){r.$search.attr("tabindex",-1),r.$search.removeAttr("aria-controls"),r.$search.removeAttr("aria-activedescendant"),r.$search.val(""),r.$search.trigger("blur")})),i.on("focus",(function(){i.isOpen()||r.$search.trigger("focus")})),i.on("results:all",(function(e){null!=e.query.term&&""!==e.query.term||(r.showSearch(e)?r.$searchContainer[0].classList.remove("select2-search--hide"):r.$searchContainer[0].classList.add("select2-search--hide"))})),i.on("results:focus",(function(e){e.data._resultId?r.$search.attr("aria-activedescendant",e.data._resultId):r.$search.removeAttr("aria-activedescendant")}))},t.prototype.handleSearch=function(e){if(!this._keyUpPrevented){var t=this.$search.val();this.trigger("query",{term:t})}this._keyUpPrevented=!1},t.prototype.showSearch=function(e,t){return!0},t})),t.define("select2/dropdown/hidePlaceholder",[],(function(){function e(e,t,i,n){this.placeholder=this.normalizePlaceholder(i.get("placeholder")),e.call(this,t,i,n)}return e.prototype.append=function(e,t){t.results=this.removePlaceholder(t.results),e.call(this,t)},e.prototype.normalizePlaceholder=function(e,t){return"string"==typeof t&&(t={id:"",text:t}),t},e.prototype.removePlaceholder=function(e,t){for(var i=t.slice(0),n=t.length-1;n>=0;n--){var r=t[n];this.placeholder.id===r.id&&i.splice(n,1)}return i},e})),t.define("select2/dropdown/infiniteScroll",["jquery"],(function(e){function t(e,t,i,n){this.lastParams={},e.call(this,t,i,n),this.$loadingMore=this.createLoadingMore(),this.loading=!1}return t.prototype.append=function(e,t){this.$loadingMore.remove(),this.loading=!1,e.call(this,t),this.showLoadingMore(t)&&(this.$results.append(this.$loadingMore),this.loadMoreIfNeeded())},t.prototype.bind=function(e,t,i){var n=this;e.call(this,t,i),t.on("query",(function(e){n.lastParams=e,n.loading=!0})),t.on("query:append",(function(e){n.lastParams=e,n.loading=!0})),this.$results.on("scroll",this.loadMoreIfNeeded.bind(this))},t.prototype.loadMoreIfNeeded=function(){var t=e.contains(document.documentElement,this.$loadingMore[0]);!this.loading&&t&&(this.$results.offset().top+this.$results.outerHeight(!1)+50>=this.$loadingMore.offset().top+this.$loadingMore.outerHeight(!1)&&this.loadMore())},t.prototype.loadMore=function(){this.loading=!0;var t=e.extend({},{page:1},this.lastParams);t.page++,this.trigger("query:append",t)},t.prototype.showLoadingMore=function(e,t){return t.pagination&&t.pagination.more},t.prototype.createLoadingMore=function(){var t=e('<li class="select2-results__option select2-results__option--load-more"role="option" aria-disabled="true"></li>'),i=this.options.get("translations").get("loadingMore");return t.html(i(this.lastParams)),t},t})),t.define("select2/dropdown/attachBody",["jquery","../utils"],(function(e,t){function i(t,i,n){this.$dropdownParent=e(n.get("dropdownParent")||document.body),t.call(this,i,n)}return i.prototype.bind=function(e,t,i){var n=this;e.call(this,t,i),t.on("open",(function(){n._showDropdown(),n._attachPositioningHandler(t),n._bindContainerResultHandlers(t)})),t.on("close",(function(){n._hideDropdown(),n._detachPositioningHandler(t)})),this.$dropdownContainer.on("mousedown",(function(e){e.stopPropagation()}))},i.prototype.destroy=function(e){e.call(this),this.$dropdownContainer.remove()},i.prototype.position=function(e,t,i){t.attr("class",i.attr("class")),t[0].classList.remove("select2"),t[0].classList.add("select2-container--open"),t.css({position:"absolute",top:-999999}),this.$container=i},i.prototype.render=function(t){var i=e("<span></span>"),n=t.call(this);return i.append(n),this.$dropdownContainer=i,i},i.prototype._hideDropdown=function(e){this.$dropdownContainer.detach()},i.prototype._bindContainerResultHandlers=function(e,t){if(!this._containerResultsHandlersBound){var i=this;t.on("results:all",(function(){i._positionDropdown(),i._resizeDropdown()})),t.on("results:append",(function(){i._positionDropdown(),i._resizeDropdown()})),t.on("results:message",(function(){i._positionDropdown(),i._resizeDropdown()})),t.on("select",(function(){i._positionDropdown(),i._resizeDropdown()})),t.on("unselect",(function(){i._positionDropdown(),i._resizeDropdown()})),this._containerResultsHandlersBound=!0}},i.prototype._attachPositioningHandler=function(i,n){var r=this,a="scroll.select2."+n.id,s="resize.select2."+n.id,o="orientationchange.select2."+n.id,l=this.$container.parents().filter(t.hasScroll);l.each((function(){t.StoreData(this,"select2-scroll-position",{x:e(this).scrollLeft(),y:e(this).scrollTop()})})),l.on(a,(function(i){var n=t.GetData(this,"select2-scroll-position");e(this).scrollTop(n.y)})),e(window).on(a+" "+s+" "+o,(function(e){r._positionDropdown(),r._resizeDropdown()}))},i.prototype._detachPositioningHandler=function(i,n){var r="scroll.select2."+n.id,a="resize.select2."+n.id,s="orientationchange.select2."+n.id;this.$container.parents().filter(t.hasScroll).off(r),e(window).off(r+" "+a+" "+s)},i.prototype._positionDropdown=function(){var t=e(window),i=this.$dropdown[0].classList.contains("select2-dropdown--above"),n=this.$dropdown[0].classList.contains("select2-dropdown--below"),r=null,a=this.$container.offset();a.bottom=a.top+this.$container.outerHeight(!1);var s={height:this.$container.outerHeight(!1)};s.top=a.top,s.bottom=a.top+s.height;var o=this.$dropdown.outerHeight(!1),l=t.scrollTop(),c=t.scrollTop()+t.height(),u=l<a.top-o,d=c>a.bottom+o,h={left:a.left,top:s.bottom},f=this.$dropdownParent;"static"===f.css("position")&&(f=f.offsetParent());var p={top:0,left:0};(e.contains(document.body,f[0])||f[0].isConnected)&&(p=f.offset()),h.top-=p.top,h.left-=p.left,i||n||(r="below"),d||!u||i?!u&&d&&i&&(r="below"):r="above",("above"==r||i&&"below"!==r)&&(h.top=s.top-p.top-o),null!=r&&(this.$dropdown[0].classList.remove("select2-dropdown--below"),this.$dropdown[0].classList.remove("select2-dropdown--above"),this.$dropdown[0].classList.add("select2-dropdown--"+r),this.$container[0].classList.remove("select2-container--below"),this.$container[0].classList.remove("select2-container--above"),this.$container[0].classList.add("select2-container--"+r)),this.$dropdownContainer.css(h)},i.prototype._resizeDropdown=function(){var e={width:this.$container.outerWidth(!1)+"px"};this.options.get("dropdownAutoWidth")&&(e.minWidth=e.width,e.position="relative",e.width="auto"),this.$dropdown.css(e)},i.prototype._showDropdown=function(e){this.$dropdownContainer.appendTo(this.$dropdownParent),this._positionDropdown(),this._resizeDropdown()},i})),t.define("select2/dropdown/minimumResultsForSearch",[],(function(){function e(t){for(var i=0,n=0;n<t.length;n++){var r=t[n];r.children?i+=e(r.children):i++}return i}function t(e,t,i,n){this.minimumResultsForSearch=i.get("minimumResultsForSearch"),this.minimumResultsForSearch<0&&(this.minimumResultsForSearch=1/0),e.call(this,t,i,n)}return t.prototype.showSearch=function(t,i){return!(e(i.data.results)<this.minimumResultsForSearch)&&t.call(this,i)},t})),t.define("select2/dropdown/selectOnClose",["../utils"],(function(e){function t(){}return t.prototype.bind=function(e,t,i){var n=this;e.call(this,t,i),t.on("close",(function(e){n._handleSelectOnClose(e)}))},t.prototype._handleSelectOnClose=function(t,i){if(i&&null!=i.originalSelect2Event){var n=i.originalSelect2Event;if("select"===n._type||"unselect"===n._type)return}var r=this.getHighlightedResults();if(!(r.length<1)){var a=e.GetData(r[0],"data");null!=a.element&&a.element.selected||null==a.element&&a.selected||this.trigger("select",{data:a})}},t})),t.define("select2/dropdown/closeOnSelect",[],(function(){function e(){}return e.prototype.bind=function(e,t,i){var n=this;e.call(this,t,i),t.on("select",(function(e){n._selectTriggered(e)})),t.on("unselect",(function(e){n._selectTriggered(e)}))},e.prototype._selectTriggered=function(e,t){var i=t.originalEvent;i&&(i.ctrlKey||i.metaKey)||this.trigger("close",{originalEvent:i,originalSelect2Event:t})},e})),t.define("select2/dropdown/dropdownCss",["../utils"],(function(e){function t(){}return t.prototype.render=function(t){var i=t.call(this),n=this.options.get("dropdownCssClass")||"";return-1!==n.indexOf(":all:")&&(n=n.replace(":all:",""),e.copyNonInternalCssClasses(i[0],this.$element[0])),i.addClass(n),i},t})),t.define("select2/dropdown/tagsSearchHighlight",["../utils"],(function(e){function t(){}return t.prototype.highlightFirstItem=function(t){var i=this.$results.find(".select2-results__option--selectable:not(.select2-results__option--selected)");if(i.length>0){var n=i.first(),r=e.GetData(n[0],"data").element;if(r&&r.getAttribute&&"true"===r.getAttribute("data-select2-tag"))return void n.trigger("mouseenter")}t.call(this)},t})),t.define("select2/i18n/en",[],(function(){return{errorLoading:function(){return"The results could not be loaded."},inputTooLong:function(e){var t=e.input.length-e.maximum,i="Please delete "+t+" character";return 1!=t&&(i+="s"),i},inputTooShort:function(e){return"Please enter "+(e.minimum-e.input.length)+" or more characters"},loadingMore:function(){return"Loading more results…"},maximumSelected:function(e){var t="You can only select "+e.maximum+" item";return 1!=e.maximum&&(t+="s"),t},noResults:function(){return"No results found"},searching:function(){return"Searching…"},removeAllItems:function(){return"Remove all items"},removeItem:function(){return"Remove item"},search:function(){return"Search"}}})),t.define("select2/defaults",["jquery","./results","./selection/single","./selection/multiple","./selection/placeholder","./selection/allowClear","./selection/search","./selection/selectionCss","./selection/eventRelay","./utils","./translation","./diacritics","./data/select","./data/array","./data/ajax","./data/tags","./data/tokenizer","./data/minimumInputLength","./data/maximumInputLength","./data/maximumSelectionLength","./dropdown","./dropdown/search","./dropdown/hidePlaceholder","./dropdown/infiniteScroll","./dropdown/attachBody","./dropdown/minimumResultsForSearch","./dropdown/selectOnClose","./dropdown/closeOnSelect","./dropdown/dropdownCss","./dropdown/tagsSearchHighlight","./i18n/en"],(function(e,t,i,n,r,a,s,o,l,c,u,d,h,f,p,m,g,v,y,b,x,_,w,k,M,S,A,L,T,C,D){function E(){this.reset()}return E.prototype.apply=function(u){if(null==(u=e.extend(!0,{},this.defaults,u)).dataAdapter&&(null!=u.ajax?u.dataAdapter=p:null!=u.data?u.dataAdapter=f:u.dataAdapter=h,u.minimumInputLength>0&&(u.dataAdapter=c.Decorate(u.dataAdapter,v)),u.maximumInputLength>0&&(u.dataAdapter=c.Decorate(u.dataAdapter,y)),u.maximumSelectionLength>0&&(u.dataAdapter=c.Decorate(u.dataAdapter,b)),u.tags&&(u.dataAdapter=c.Decorate(u.dataAdapter,m)),null==u.tokenSeparators&&null==u.tokenizer||(u.dataAdapter=c.Decorate(u.dataAdapter,g))),null==u.resultsAdapter&&(u.resultsAdapter=t,null!=u.ajax&&(u.resultsAdapter=c.Decorate(u.resultsAdapter,k)),null!=u.placeholder&&(u.resultsAdapter=c.Decorate(u.resultsAdapter,w)),u.selectOnClose&&(u.resultsAdapter=c.Decorate(u.resultsAdapter,A)),u.tags&&(u.resultsAdapter=c.Decorate(u.resultsAdapter,C))),null==u.dropdownAdapter){if(u.multiple)u.dropdownAdapter=x;else{var d=c.Decorate(x,_);u.dropdownAdapter=d}0!==u.minimumResultsForSearch&&(u.dropdownAdapter=c.Decorate(u.dropdownAdapter,S)),u.closeOnSelect&&(u.dropdownAdapter=c.Decorate(u.dropdownAdapter,L)),null!=u.dropdownCssClass&&(u.dropdownAdapter=c.Decorate(u.dropdownAdapter,T)),u.dropdownAdapter=c.Decorate(u.dropdownAdapter,M)}null==u.selectionAdapter&&(u.multiple?u.selectionAdapter=n:u.selectionAdapter=i,null!=u.placeholder&&(u.selectionAdapter=c.Decorate(u.selectionAdapter,r)),u.allowClear&&(u.selectionAdapter=c.Decorate(u.selectionAdapter,a)),u.multiple&&(u.selectionAdapter=c.Decorate(u.selectionAdapter,s)),null!=u.selectionCssClass&&(u.selectionAdapter=c.Decorate(u.selectionAdapter,o)),u.selectionAdapter=c.Decorate(u.selectionAdapter,l)),u.language=this._resolveLanguage(u.language),u.language.push("en");for(var D=[],E=0;E<u.language.length;E++){var O=u.language[E];-1===D.indexOf(O)&&D.push(O)}return u.language=D,u.translations=this._processTranslations(u.language,u.debug),u},E.prototype.reset=function(){function t(e){return e.replace(/[^\u0000-\u007E]/g,(function(e){return d[e]||e}))}this.defaults={amdLanguageBase:"./i18n/",autocomplete:"off",closeOnSelect:!0,debug:!1,dropdownAutoWidth:!1,escapeMarkup:c.escapeMarkup,language:{},matcher:function i(n,r){if(null==n.term||""===n.term.trim())return r;if(r.children&&r.children.length>0){for(var a=e.extend(!0,{},r),s=r.children.length-1;s>=0;s--){null==i(n,r.children[s])&&a.children.splice(s,1)}return a.children.length>0?a:i(n,a)}var o=t(r.text).toUpperCase(),l=t(n.term).toUpperCase();return o.indexOf(l)>-1?r:null},minimumInputLength:0,maximumInputLength:0,maximumSelectionLength:0,minimumResultsForSearch:0,selectOnClose:!1,scrollAfterSelect:!1,sorter:function(e){return e},templateResult:function(e){return e.text},templateSelection:function(e){return e.text},theme:"default",width:"resolve"}},E.prototype.applyFromElement=function(e,t){var i=e.language,n=this.defaults.language,r=t.prop("lang"),a=t.closest("[lang]").prop("lang"),s=Array.prototype.concat.call(this._resolveLanguage(r),this._resolveLanguage(i),this._resolveLanguage(n),this._resolveLanguage(a));return e.language=s,e},E.prototype._resolveLanguage=function(t){if(!t)return[];if(e.isEmptyObject(t))return[];if(e.isPlainObject(t))return[t];var i;i=Array.isArray(t)?t:[t];for(var n=[],r=0;r<i.length;r++)if(n.push(i[r]),"string"==typeof i[r]&&i[r].indexOf("-")>0){var a=i[r].split("-")[0];n.push(a)}return n},E.prototype._processTranslations=function(t,i){for(var n=new u,r=0;r<t.length;r++){var a=new u,s=t[r];if("string"==typeof s)try{a=u.loadPath(s)}catch(e){try{s=this.defaults.amdLanguageBase+s,a=u.loadPath(s)}catch(e){i&&window.console&&console.warn&&console.warn('Select2: The language file for "'+s+'" could not be automatically loaded. A fallback will be used instead.')}}else a=e.isPlainObject(s)?new u(s):s;n.extend(a)}return n},E.prototype.set=function(t,i){var n={};n[e.camelCase(t)]=i;var r=c._convertData(n);e.extend(!0,this.defaults,r)},new E})),t.define("select2/options",["jquery","./defaults","./utils"],(function(e,t,i){function n(e,i){this.options=e,null!=i&&this.fromElement(i),null!=i&&(this.options=t.applyFromElement(this.options,i)),this.options=t.apply(this.options)}return n.prototype.fromElement=function(t){var n=["select2"];null==this.options.multiple&&(this.options.multiple=t.prop("multiple")),null==this.options.disabled&&(this.options.disabled=t.prop("disabled")),null==this.options.autocomplete&&t.prop("autocomplete")&&(this.options.autocomplete=t.prop("autocomplete")),null==this.options.dir&&(t.prop("dir")?this.options.dir=t.prop("dir"):t.closest("[dir]").prop("dir")?this.options.dir=t.closest("[dir]").prop("dir"):this.options.dir="ltr"),t.prop("disabled",this.options.disabled),t.prop("multiple",this.options.multiple),i.GetData(t[0],"select2Tags")&&(this.options.debug&&window.console&&console.warn&&console.warn('Select2: The `data-select2-tags` attribute has been changed to use the `data-data` and `data-tags="true"` attributes and will be removed in future versions of Select2.'),i.StoreData(t[0],"data",i.GetData(t[0],"select2Tags")),i.StoreData(t[0],"tags",!0)),i.GetData(t[0],"ajaxUrl")&&(this.options.debug&&window.console&&console.warn&&console.warn("Select2: The `data-ajax-url` attribute has been changed to `data-ajax--url` and support for the old attribute will be removed in future versions of Select2."),t.attr("ajax--url",i.GetData(t[0],"ajaxUrl")),i.StoreData(t[0],"ajax-Url",i.GetData(t[0],"ajaxUrl")));var r={};function a(e,t){return t.toUpperCase()}for(var s=0;s<t[0].attributes.length;s++){var o=t[0].attributes[s].name,l="data-";if(o.substr(0,5)==l){var c=o.substring(5),u=i.GetData(t[0],c);r[c.replace(/-([a-z])/g,a)]=u}}e.fn.jquery&&"1."==e.fn.jquery.substr(0,2)&&t[0].dataset&&(r=e.extend(!0,{},t[0].dataset,r));var d=e.extend(!0,{},i.GetData(t[0]),r);for(var h in d=i._convertData(d))n.indexOf(h)>-1||(e.isPlainObject(this.options[h])?e.extend(this.options[h],d[h]):this.options[h]=d[h]);return this},n.prototype.get=function(e){return this.options[e]},n.prototype.set=function(e,t){this.options[e]=t},n})),t.define("select2/core",["jquery","./options","./utils","./keys"],(function(e,t,i,n){var r=function(e,n){null!=i.GetData(e[0],"select2")&&i.GetData(e[0],"select2").destroy(),this.$element=e,this.id=this._generateId(e),n=n||{},this.options=new t(n,e),r.__super__.constructor.call(this);var a=e.attr("tabindex")||0;i.StoreData(e[0],"old-tabindex",a),e.attr("tabindex","-1");var s=this.options.get("dataAdapter");this.dataAdapter=new s(e,this.options);var o=this.render();this._placeContainer(o);var l=this.options.get("selectionAdapter");this.selection=new l(e,this.options),this.$selection=this.selection.render(),this.selection.position(this.$selection,o);var c=this.options.get("dropdownAdapter");this.dropdown=new c(e,this.options),this.$dropdown=this.dropdown.render(),this.dropdown.position(this.$dropdown,o);var u=this.options.get("resultsAdapter");this.results=new u(e,this.options,this.dataAdapter),this.$results=this.results.render(),this.results.position(this.$results,this.$dropdown);var d=this;this._bindAdapters(),this._registerDomEvents(),this._registerDataEvents(),this._registerSelectionEvents(),this._registerDropdownEvents(),this._registerResultsEvents(),this._registerEvents(),this.dataAdapter.current((function(e){d.trigger("selection:update",{data:e})})),e[0].classList.add("select2-hidden-accessible"),e.attr("aria-hidden","true"),this._syncAttributes(),i.StoreData(e[0],"select2",this),e.data("select2",this)};return i.Extend(r,i.Observable),r.prototype._generateId=function(e){return"select2-"+(null!=e.attr("id")?e.attr("id"):null!=e.attr("name")?e.attr("name")+"-"+i.generateChars(2):i.generateChars(4)).replace(/(:|\.|\[|\]|,)/g,"")},r.prototype._placeContainer=function(e){e.insertAfter(this.$element);var t=this._resolveWidth(this.$element,this.options.get("width"));null!=t&&e.css("width",t)},r.prototype._resolveWidth=function(e,t){var i=/^width:(([-+]?([0-9]*\.)?[0-9]+)(px|em|ex|%|in|cm|mm|pt|pc))/i;if("resolve"==t){var n=this._resolveWidth(e,"style");return null!=n?n:this._resolveWidth(e,"element")}if("element"==t){var r=e.outerWidth(!1);return r<=0?"auto":r+"px"}if("style"==t){var a=e.attr("style");if("string"!=typeof a)return null;for(var s=a.split(";"),o=0,l=s.length;o<l;o+=1){var c=s[o].replace(/\s/g,"").match(i);if(null!==c&&c.length>=1)return c[1]}return null}return"computedstyle"==t?window.getComputedStyle(e[0]).width:t},r.prototype._bindAdapters=function(){this.dataAdapter.bind(this,this.$container),this.selection.bind(this,this.$container),this.dropdown.bind(this,this.$container),this.results.bind(this,this.$container)},r.prototype._registerDomEvents=function(){var e=this;this.$element.on("change.select2",(function(){e.dataAdapter.current((function(t){e.trigger("selection:update",{data:t})}))})),this.$element.on("focus.select2",(function(t){e.trigger("focus",t)})),this._syncA=i.bind(this._syncAttributes,this),this._syncS=i.bind(this._syncSubtree,this),this._observer=new window.MutationObserver((function(t){e._syncA(),e._syncS(t)})),this._observer.observe(this.$element[0],{attributes:!0,childList:!0,subtree:!1})},r.prototype._registerDataEvents=function(){var e=this;this.dataAdapter.on("*",(function(t,i){e.trigger(t,i)}))},r.prototype._registerSelectionEvents=function(){var e=this,t=["toggle","focus"];this.selection.on("toggle",(function(){e.toggleDropdown()})),this.selection.on("focus",(function(t){e.focus(t)})),this.selection.on("*",(function(i,n){-1===t.indexOf(i)&&e.trigger(i,n)}))},r.prototype._registerDropdownEvents=function(){var e=this;this.dropdown.on("*",(function(t,i){e.trigger(t,i)}))},r.prototype._registerResultsEvents=function(){var e=this;this.results.on("*",(function(t,i){e.trigger(t,i)}))},r.prototype._registerEvents=function(){var e=this;this.on("open",(function(){e.$container[0].classList.add("select2-container--open")})),this.on("close",(function(){e.$container[0].classList.remove("select2-container--open")})),this.on("enable",(function(){e.$container[0].classList.remove("select2-container--disabled")})),this.on("disable",(function(){e.$container[0].classList.add("select2-container--disabled")})),this.on("blur",(function(){e.$container[0].classList.remove("select2-container--focus")})),this.on("query",(function(t){e.isOpen()||e.trigger("open",{}),this.dataAdapter.query(t,(function(i){e.trigger("results:all",{data:i,query:t})}))})),this.on("query:append",(function(t){this.dataAdapter.query(t,(function(i){e.trigger("results:append",{data:i,query:t})}))})),this.on("keypress",(function(t){var i=t.which;e.isOpen()?i===n.ESC||i===n.UP&&t.altKey?(e.close(t),t.preventDefault()):i===n.ENTER||i===n.TAB?(e.trigger("results:select",{}),t.preventDefault()):i===n.SPACE&&t.ctrlKey?(e.trigger("results:toggle",{}),t.preventDefault()):i===n.UP?(e.trigger("results:previous",{}),t.preventDefault()):i===n.DOWN&&(e.trigger("results:next",{}),t.preventDefault()):(i===n.ENTER||i===n.SPACE||i===n.DOWN&&t.altKey)&&(e.open(),t.preventDefault())}))},r.prototype._syncAttributes=function(){this.options.set("disabled",this.$element.prop("disabled")),this.isDisabled()?(this.isOpen()&&this.close(),this.trigger("disable",{})):this.trigger("enable",{})},r.prototype._isChangeMutation=function(e){var t=this;if(e.addedNodes&&e.addedNodes.length>0)for(var i=0;i<e.addedNodes.length;i++){if(e.addedNodes[i].selected)return!0}else{if(e.removedNodes&&e.removedNodes.length>0)return!0;if(Array.isArray(e))return e.some((function(e){return t._isChangeMutation(e)}))}return!1},r.prototype._syncSubtree=function(e){var t=this._isChangeMutation(e),i=this;t&&this.dataAdapter.current((function(e){i.trigger("selection:update",{data:e})}))},r.prototype.trigger=function(e,t){var i=r.__super__.trigger,n={open:"opening",close:"closing",select:"selecting",unselect:"unselecting",clear:"clearing"};if(void 0===t&&(t={}),e in n){var a=n[e],s={prevented:!1,name:e,args:t};if(i.call(this,a,s),s.prevented)return void(t.prevented=!0)}i.call(this,e,t)},r.prototype.toggleDropdown=function(){this.isDisabled()||(this.isOpen()?this.close():this.open())},r.prototype.open=function(){this.isOpen()||this.isDisabled()||this.trigger("query",{})},r.prototype.close=function(e){this.isOpen()&&this.trigger("close",{originalEvent:e})},r.prototype.isEnabled=function(){return!this.isDisabled()},r.prototype.isDisabled=function(){return this.options.get("disabled")},r.prototype.isOpen=function(){return this.$container[0].classList.contains("select2-container--open")},r.prototype.hasFocus=function(){return this.$container[0].classList.contains("select2-container--focus")},r.prototype.focus=function(e){this.hasFocus()||(this.$container[0].classList.add("select2-container--focus"),this.trigger("focus",{}))},r.prototype.enable=function(e){this.options.get("debug")&&window.console&&console.warn&&console.warn('Select2: The `select2("enable")` method has been deprecated and will be removed in later Select2 versions. Use $element.prop("disabled") instead.'),null!=e&&0!==e.length||(e=[!0]);var t=!e[0];this.$element.prop("disabled",t)},r.prototype.data=function(){this.options.get("debug")&&arguments.length>0&&window.console&&console.warn&&console.warn('Select2: Data can no longer be set using `select2("data")`. You should consider setting the value instead using `$element.val()`.');var e=[];return this.dataAdapter.current((function(t){e=t})),e},r.prototype.val=function(e){if(this.options.get("debug")&&window.console&&console.warn&&console.warn('Select2: The `select2("val")` method has been deprecated and will be removed in later Select2 versions. Use $element.val() instead.'),null==e||0===e.length)return this.$element.val();var t=e[0];Array.isArray(t)&&(t=t.map((function(e){return e.toString()}))),this.$element.val(t).trigger("input").trigger("change")},r.prototype.destroy=function(){i.RemoveData(this.$container[0]),this.$container.remove(),this._observer.disconnect(),this._observer=null,this._syncA=null,this._syncS=null,this.$element.off(".select2"),this.$element.attr("tabindex",i.GetData(this.$element[0],"old-tabindex")),this.$element[0].classList.remove("select2-hidden-accessible"),this.$element.attr("aria-hidden","false"),i.RemoveData(this.$element[0]),this.$element.removeData("select2"),this.dataAdapter.destroy(),this.selection.destroy(),this.dropdown.destroy(),this.results.destroy(),this.dataAdapter=null,this.selection=null,this.dropdown=null,this.results=null},r.prototype.render=function(){var t=e('<span class="select2 select2-container"><span class="selection"></span><span class="dropdown-wrapper" aria-hidden="true"></span></span>');return t.attr("dir",this.options.get("dir")),this.$container=t,this.$container[0].classList.add("select2-container--"+this.options.get("theme")),i.StoreData(t[0],"element",this.$element),t},r})),t.define("select2/dropdown/attachContainer",[],(function(){function e(e,t,i){e.call(this,t,i)}return e.prototype.position=function(e,t,i){i.find(".dropdown-wrapper").append(t),t[0].classList.add("select2-dropdown--below"),i[0].classList.add("select2-container--below")},e})),t.define("select2/dropdown/stopPropagation",[],(function(){function e(){}return e.prototype.bind=function(e,t,i){e.call(this,t,i);this.$dropdown.on(["blur","change","click","dblclick","focus","focusin","focusout","input","keydown","keyup","keypress","mousedown","mouseenter","mouseleave","mousemove","mouseover","mouseup","search","touchend","touchstart"].join(" "),(function(e){e.stopPropagation()}))},e})),t.define("select2/selection/stopPropagation",[],(function(){function e(){}return e.prototype.bind=function(e,t,i){e.call(this,t,i);this.$selection.on(["blur","change","click","dblclick","focus","focusin","focusout","input","keydown","keyup","keypress","mousedown","mouseenter","mouseleave","mousemove","mouseover","mouseup","search","touchend","touchstart"].join(" "),(function(e){e.stopPropagation()}))},e})),
/*!
 * jQuery Mousewheel 3.1.13
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 */
i=function(e){var t,i,n=["wheel","mousewheel","DOMMouseScroll","MozMousePixelScroll"],r="onwheel"in document||document.documentMode>=9?["wheel"]:["mousewheel","DomMouseScroll","MozMousePixelScroll"],a=Array.prototype.slice;if(e.event.fixHooks)for(var s=n.length;s;)e.event.fixHooks[n[--s]]=e.event.mouseHooks;var o=e.event.special.mousewheel={version:"3.1.12",setup:function(){if(this.addEventListener)for(var t=r.length;t;)this.addEventListener(r[--t],l,!1);else this.onmousewheel=l;e.data(this,"mousewheel-line-height",o.getLineHeight(this)),e.data(this,"mousewheel-page-height",o.getPageHeight(this))},teardown:function(){if(this.removeEventListener)for(var t=r.length;t;)this.removeEventListener(r[--t],l,!1);else this.onmousewheel=null;e.removeData(this,"mousewheel-line-height"),e.removeData(this,"mousewheel-page-height")},getLineHeight:function(t){var i=e(t),n=i["offsetParent"in e.fn?"offsetParent":"parent"]();return n.length||(n=e("body")),parseInt(n.css("fontSize"),10)||parseInt(i.css("fontSize"),10)||16},getPageHeight:function(t){return e(t).height()},settings:{adjustOldDeltas:!0,normalizeOffset:!0}};function l(n){var r,s=n||window.event,l=a.call(arguments,1),d=0,h=0,f=0,p=0,m=0;if((n=e.event.fix(s)).type="mousewheel","detail"in s&&(f=-1*s.detail),"wheelDelta"in s&&(f=s.wheelDelta),"wheelDeltaY"in s&&(f=s.wheelDeltaY),"wheelDeltaX"in s&&(h=-1*s.wheelDeltaX),"axis"in s&&s.axis===s.HORIZONTAL_AXIS&&(h=-1*f,f=0),d=0===f?h:f,"deltaY"in s&&(d=f=-1*s.deltaY),"deltaX"in s&&(h=s.deltaX,0===f&&(d=-1*h)),0!==f||0!==h){if(1===s.deltaMode){var g=e.data(this,"mousewheel-line-height");d*=g,f*=g,h*=g}else if(2===s.deltaMode){var v=e.data(this,"mousewheel-page-height");d*=v,f*=v,h*=v}if(r=Math.max(Math.abs(f),Math.abs(h)),(!i||r<i)&&(i=r,u(s,r)&&(i/=40)),u(s,r)&&(d/=40,h/=40,f/=40),d=Math[d>=1?"floor":"ceil"](d/i),h=Math[h>=1?"floor":"ceil"](h/i),f=Math[f>=1?"floor":"ceil"](f/i),o.settings.normalizeOffset&&this.getBoundingClientRect){var y=this.getBoundingClientRect();p=n.clientX-y.left,m=n.clientY-y.top}return n.deltaX=h,n.deltaY=f,n.deltaFactor=i,n.offsetX=p,n.offsetY=m,n.deltaMode=0,l.unshift(n,d,h,f),t&&clearTimeout(t),t=setTimeout(c,200),(e.event.dispatch||e.event.handle).apply(this,l)}}function c(){i=null}function u(e,t){return o.settings.adjustOldDeltas&&"mousewheel"===e.type&&t%120==0}e.fn.extend({mousewheel:function(e){return e?this.bind("mousewheel",e):this.trigger("mousewheel")},unmousewheel:function(e){return this.unbind("mousewheel",e)}})},"function"==typeof t.define&&t.define.amd?t.define("jquery-mousewheel",["jquery"],i):"object"==typeof exports?module.exports=i:i(e),t.define("jquery.select2",["jquery","jquery-mousewheel","./select2/core","./select2/defaults","./select2/utils"],(function(e,t,i,n,r){if(null==e.fn.select2){var a=["open","close","destroy"];e.fn.select2=function(t){if("object"==typeof(t=t||{}))return this.each((function(){var n=e.extend(!0,{},t);new i(e(this),n)})),this;if("string"==typeof t){var n,s=Array.prototype.slice.call(arguments,1);return this.each((function(){var e=r.GetData(this,"select2");null==e&&window.console&&console.error&&console.error("The select2('"+t+"') method was called on an element that is not using Select2."),n=e[t].apply(e,s)})),a.indexOf(t)>-1?this:n}throw new Error("Invalid arguments for Select2: "+t)}}return null==e.fn.select2.defaults&&(e.fn.select2.defaults=n),i})),{define:t.define,require:t.require}}(),i=t.require("jquery.select2");return e.fn.select2.amd=t,i})),$.fn.select2.defaults.set("theme","bootstrap5"),$.fn.select2.defaults.set("width","100%"),$.fn.select2.defaults.set("selectionCssClass",":all:"),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).tempusDominus={})}(this,(function(e){"use strict";class t extends Error{}const i="tempus-dominus";class n{}n.NAME=i,n.dataKey="td",n.events=new class{constructor(){this.key=".td",this.change=`change${this.key}`,this.update=`update${this.key}`,this.error=`error${this.key}`,this.show=`show${this.key}`,this.hide=`hide${this.key}`,this.blur=`blur${this.key}`,this.focus=`focus${this.key}`,this.keyup=`keyup${this.key}`,this.keydown=`keydown${this.key}`}},n.css=new class{constructor(){this.widget=`${i}-widget`,this.calendarHeader="calendar-header",this.switch="picker-switch",this.toolbar="toolbar",this.noHighlight="no-highlight",this.sideBySide="timepicker-sbs",this.previous="previous",this.next="next",this.disabled="disabled",this.old="old",this.new="new",this.active="active",this.dateContainer="date-container",this.decadesContainer=`${this.dateContainer}-decades`,this.decade="decade",this.yearsContainer=`${this.dateContainer}-years`,this.year="year",this.monthsContainer=`${this.dateContainer}-months`,this.month="month",this.daysContainer=`${this.dateContainer}-days`,this.day="day",this.calendarWeeks="cw",this.dayOfTheWeek="dow",this.today="today",this.weekend="weekend",this.rangeIn="range-in",this.rangeStart="range-start",this.rangeEnd="range-end",this.timeContainer="time-container",this.separator="separator",this.clockContainer=`${this.timeContainer}-clock`,this.hourContainer=`${this.timeContainer}-hour`,this.minuteContainer=`${this.timeContainer}-minute`,this.secondContainer=`${this.timeContainer}-second`,this.hour="hour",this.minute="minute",this.second="second",this.toggleMeridiem="toggleMeridiem",this.show="show",this.collapsing="td-collapsing",this.collapse="td-collapse",this.inline="inline",this.lightTheme="light",this.darkTheme="dark",this.isDarkPreferredQuery="(prefers-color-scheme: dark)"}},n.errorMessages=new class{constructor(){this.base="TD:",this.failedToSetInvalidDate="Failed to set invalid date",this.failedToParseInput="Failed parse input field"}unexpectedOption(e){const i=new t(`${this.base} Unexpected option: ${e} does not match a known option.`);throw i.code=1,i}unexpectedOptions(e){const i=new t(`${this.base}: ${e.join(", ")}`);throw i.code=1,i}unexpectedOptionValue(e,i,n){const r=new t(`${this.base} Unexpected option value: ${e} does not accept a value of "${i}". Valid values are: ${n.join(", ")}`);throw r.code=2,r}typeMismatch(e,i,n){const r=new t(`${this.base} Mismatch types: ${e} has a type of ${i} instead of the required ${n}`);throw r.code=3,r}numbersOutOfRange(e,i,n){const r=new t(`${this.base} ${e} expected an array of number between ${i} and ${n}.`);throw r.code=4,r}failedToParseDate(e,i,n=!1){const r=new t(`${this.base} Could not correctly parse "${i}" to a date for ${e}.`);if(r.code=5,!n)throw r;console.warn(r)}mustProvideElement(){const e=new t(`${this.base} No element was provided.`);throw e.code=6,e}subscribeMismatch(){const e=new t(`${this.base} The subscribed events does not match the number of callbacks`);throw e.code=7,e}conflictingConfiguration(e){const i=new t(`${this.base} A configuration value conflicts with another rule. ${e}`);throw i.code=8,i}customDateFormatError(e){const i=new t(`${this.base} Custom Date Format: ${e}`);throw i.code=9,i}dateString(){console.warn(`${this.base} Using a string for date options is not recommended unless you specify an ISO string or use the customDateFormat plugin.`)}deprecatedWarning(e,t){console.warn(`${this.base} Warning ${e} is deprecated and will be removed in a future version. ${t}`)}throwError(e){const i=new t(`${this.base} ${e}`);throw i.code=9,i}};var r,a={dateFormats:{LTS:"h:mm:ss T",LT:"h:mm T",L:"MM/dd/yyyy",LL:"MMMM d, yyyy",LLL:"MMMM d, yyyy h:mm T",LLLL:"dddd, MMMM d, yyyy h:mm T"},format:"L LT",locale:"default",hourCycle:void 0,ordinal:e=>{const t=["th","st","nd","rd"],i=e%100;return`[${e}${t[(i-20)%10]||t[i]||t[0]}]`}};e.Unit=void 0,(r=e.Unit||(e.Unit={})).seconds="seconds",r.minutes="minutes",r.hours="hours",r.date="date",r.month="month",r.year="year";const s={month:"2-digit",day:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit"},o=e=>{switch(e){case"date":return{dateStyle:"short"};case"month":return{month:"numeric",year:"numeric"};case"year":return{year:"numeric"}}},l=e=>{if(!e)return"h12";const t={hour:"2-digit",minute:"2-digit",numberingSystem:"latn"},i=(new c).setLocalization({locale:e});i.hours=0;const n=i.parts(void 0,t).hour;if("12"===n)return"h12";if("24"===n)return"h24";i.hours=23;const r=i.parts(void 0,t).hour;return"00"===n&&"11"===r?"h11":"00"===n&&"23"===r?"h23":void console.warn(`couldn't determine hour cycle for ${e}. start: ${n}. end: ${r}`)};class c extends Date{constructor(){super(...arguments),this.localization=a,this.nonLeapLadder=[0,31,59,90,120,151,181,212,243,273,304,334],this.leapLadder=[0,31,60,91,121,152,182,213,244,274,305,335],this.dateTimeRegex=/(\[[^[\]]*])|y{1,4}|M{1,4}|d{1,4}|H{1,2}|h{1,2}|t|T|m{1,2}|s{1,2}|f{3}/g,this.formattingTokens=/(\[[^[\]]*])|([-_:/.,()\s]+)|(T|t|yyyy|yy?|MM?M?M?|Do|dd?d?d?|hh?|HH?|mm?|ss?)/g,this.match2=/\d\d/,this.match3=/\d{3}/,this.match4=/\d{4}/,this.match1to2=/\d\d?/,this.matchSigned=/[+-]?\d+/,this.matchOffset=/[+-]\d\d:?(\d\d)?|Z/,this.matchWord=/[^\d_:/,\-()\s]+/,this.zoneExpressions=[this.matchOffset,(e,t)=>{e.offset=this.offsetFromString(t)}],this.expressions={t:{pattern:void 0,parser:(e,t)=>{e.afternoon=this.meridiemMatch(t)}},T:{pattern:void 0,parser:(e,t)=>{e.afternoon=this.meridiemMatch(t)}},fff:{pattern:this.match3,parser:(e,t)=>{e.milliseconds=+t}},s:{pattern:this.match1to2,parser:this.addInput("seconds")},ss:{pattern:this.match1to2,parser:this.addInput("seconds")},m:{pattern:this.match1to2,parser:this.addInput("minutes")},mm:{pattern:this.match1to2,parser:this.addInput("minutes")},H:{pattern:this.match1to2,parser:this.addInput("hours")},h:{pattern:this.match1to2,parser:this.addInput("hours")},HH:{pattern:this.match1to2,parser:this.addInput("hours")},hh:{pattern:this.match1to2,parser:this.addInput("hours")},d:{pattern:this.match1to2,parser:this.addInput("day")},dd:{pattern:this.match2,parser:this.addInput("day")},Do:{pattern:this.matchWord,parser:(e,t)=>{if(e.day=+(t.match(/\d+/)[0]||1),this.localization.ordinal)for(let i=1;i<=31;i+=1)this.localization.ordinal(i).replace(/[[\]]/g,"")===t&&(e.day=i)}},M:{pattern:this.match1to2,parser:this.addInput("month")},MM:{pattern:this.match2,parser:this.addInput("month")},MMM:{pattern:this.matchWord,parser:(e,t)=>{const i=this.getAllMonths(),n=(this.getAllMonths("short")||i.map((e=>e.slice(0,3)))).indexOf(t)+1;if(n<1)throw new Error;e.month=n%12||n}},MMMM:{pattern:this.matchWord,parser:(e,t)=>{const i=this.getAllMonths().indexOf(t)+1;if(i<1)throw new Error;e.month=i%12||i}},y:{pattern:this.matchSigned,parser:this.addInput("year")},yy:{pattern:this.match2,parser:(e,t)=>{e.year=this.parseTwoDigitYear(+t)}},yyyy:{pattern:this.match4,parser:this.addInput("year")}}}setLocale(e){return this.localization||(this.localization=a,this.localization.locale=e),this}setLocalization(e){return this.localization=e,this}static convert(e,t="default",i=void 0){if(!e)throw new Error("A date is required");return i||((i=a).locale=t),new c(e.getFullYear(),e.getMonth(),e.getDate(),e.getHours(),e.getMinutes(),e.getSeconds(),e.getMilliseconds()).setLocalization(i)}get clone(){return new c(this.year,this.month,this.date,this.hours,this.minutes,this.seconds,this.getMilliseconds()).setLocalization(this.localization)}static isValid(e){return void 0!==e&&"null"!==JSON.stringify(e)&&e.constructor.name===c.name}startOf(t,i=0){if(void 0===this[t])throw new Error(`Unit '${t}' is not valid`);switch(t){case"seconds":this.setMilliseconds(0);break;case"minutes":this.setSeconds(0,0);break;case"hours":this.setMinutes(0,0,0);break;case"date":this.setHours(0,0,0,0);break;case"weekDay":{if(this.startOf(e.Unit.date),this.weekDay===i)break;const t=(this.weekDay-i+7)%7;this.manipulate(-1*t,e.Unit.date);break}case"month":this.startOf(e.Unit.date),this.setDate(1);break;case"year":this.startOf(e.Unit.date),this.setMonth(0,1)}return this}endOf(t,i=0){if(void 0===this[t])throw new Error(`Unit '${t}' is not valid`);switch(t){case"seconds":this.setMilliseconds(999);break;case"minutes":this.setSeconds(59,999);break;case"hours":this.setMinutes(59,59,999);break;case"date":this.setHours(23,59,59,999);break;case"weekDay":{this.endOf(e.Unit.date);const t=6+i;if(this.weekDay===t)break;this.manipulate(t-this.weekDay,e.Unit.date);break}case"month":this.endOf(e.Unit.date),this.manipulate(1,e.Unit.month),this.setDate(0);break;case"year":this.endOf(e.Unit.date),this.setMonth(11,31)}return this}manipulate(e,t){if(void 0===this[t])throw new Error(`Unit '${t}' is not valid`);return this[t]+=e,this}isBefore(e,t){if(!c.isValid(e))return!1;if(!t)return this.valueOf()<e.valueOf();if(void 0===this[t])throw new Error(`Unit '${t}' is not valid`);return this.clone.startOf(t).valueOf()<e.clone.startOf(t).valueOf()}isAfter(e,t){if(!c.isValid(e))return!1;if(!t)return this.valueOf()>e.valueOf();if(void 0===this[t])throw new Error(`Unit '${t}' is not valid`);return this.clone.startOf(t).valueOf()>e.clone.startOf(t).valueOf()}isSame(e,t){if(!c.isValid(e))return!1;if(!t)return this.valueOf()===e.valueOf();if(void 0===this[t])throw new Error(`Unit '${t}' is not valid`);return e=c.convert(e),this.clone.startOf(t).valueOf()===e.startOf(t).valueOf()}isBetween(e,t,i,n="()"){if(!c.isValid(e)||!c.isValid(t))return!1;if(i&&void 0===this[i])throw new Error(`Unit '${i}' is not valid`);const r="("===n[0],a=")"===n[1],s=r?this.isAfter(e,i):!this.isBefore(e,i),o=a?this.isBefore(t,i):!this.isAfter(t,i);return s&&o}parts(e=this.localization.locale,t={dateStyle:"full",timeStyle:"long"}){const i={};return new Intl.DateTimeFormat(e,t).formatToParts(this).filter((e=>"literal"!==e.type)).forEach((e=>i[e.type]=e.value)),i}get seconds(){return this.getSeconds()}set seconds(e){this.setSeconds(e)}get secondsFormatted(){return this.parts(void 0,s).second}get minutes(){return this.getMinutes()}set minutes(e){this.setMinutes(e)}get minutesFormatted(){return this.parts(void 0,s).minute}get hours(){return this.getHours()}set hours(e){this.setHours(e)}getHoursFormatted(e="h12"){return this.parts(void 0,{...s,hourCycle:e}).hour}meridiem(e=this.localization.locale){return new Intl.DateTimeFormat(e,{hour:"numeric",hour12:!0}).formatToParts(this).find((e=>"dayPeriod"===e.type))?.value}get date(){return this.getDate()}set date(e){this.setDate(e)}get dateFormatted(){return this.parts(void 0,s).day}get weekDay(){return this.getDay()}get month(){return this.getMonth()}set month(e){const t=new Date(this.year,e+1);t.setDate(0);const i=t.getDate();this.date>i&&(this.date=i),this.setMonth(e)}get monthFormatted(){return this.parts(void 0,s).month}get year(){return this.getFullYear()}set year(e){this.setFullYear(e)}get week(){const e=this.computeOrdinal(),t=this.getUTCDay();let i=Math.floor((e-t+10)/7);return i<1?i=this.weeksInWeekYear():i>this.weeksInWeekYear()&&(i=1),i}weeksInWeekYear(){const e=(this.year+Math.floor(this.year/4)-Math.floor(this.year/100)+Math.floor(this.year/400))%7,t=this.year-1,i=(t+Math.floor(t/4)-Math.floor(t/100)+Math.floor(t/400))%7;return 4===e||3===i?53:52}get isLeapYear(){return this.year%4==0&&(this.year%100!=0||this.year%400==0)}computeOrdinal(){return this.date+(this.isLeapYear?this.leapLadder:this.nonLeapLadder)[this.month]}getAllMonths(e="long"){const t=new Intl.DateTimeFormat(this.localization.locale,{month:e}).format;return[...Array(12).keys()].map((e=>t(new Date(2021,e))))}replaceTokens(e,t){return e.replace(/(\[[^[\]]*])|(LTS?|l{1,4}|L{1,4})/g,((e,i,n)=>{const r=n&&n.toUpperCase();return i||t[r]||a.dateFormats[r]}))}parseTwoDigitYear(e){return e+(e>68?1900:2e3)}offsetFromString(e){if(!e)return 0;if("Z"===e)return 0;const[t,i,n]=e.match(/([+-]|\d\d)/g),r=60*+i+(+n||0);return 0===r?0:"+"===t?-r:r}zoneInformation(e,t){let i=e.parts(this.localization.locale,{timeZoneName:"longOffset"}).timeZoneName.replace("GMT","").replace(":","");const n=i.includes("-");return i=i.replace("-",""),"z"===t?i=i.substring(1,2):"zz"===t&&(i=i.substring(0,2)),`${n?"-":""}${i}`}addInput(e){return(t,i)=>{t[e]=+i}}getLocaleAfternoon(){return new Intl.DateTimeFormat(this.localization.locale,{hour:"numeric",hour12:!0}).formatToParts(new Date(2022,3,4,13)).find((e=>"dayPeriod"===e.type))?.value?.replace(/\s+/g," ")}meridiemMatch(e){return e.toLowerCase()===this.getLocaleAfternoon().toLowerCase()}correctHours(e){const{afternoon:t}=e;if(void 0!==t){const{hours:i}=e;t?i<12&&(e.hours+=12):12===i&&(e.hours=0),delete e.afternoon}}makeParser(e){const t=(e=this.replaceTokens(e,this.localization.dateFormats)).match(this.formattingTokens),{length:i}=t,n=[];for(let e=0;e<i;e+=1){const i=t[e],r=this.expressions[i];n[e]=r?.parser?r:i.replace(/^\[[^[\]]*]$/g,"")}return e=>{const t={hours:0,minutes:0,seconds:0,milliseconds:0};for(let r=0,a=0;r<i;r+=1){const i=n[r];if("string"==typeof i)a+=i.length;else{const n=e.slice(a);let r=n;i.pattern&&(r=i.pattern.exec(n)[0]),i.parser.call(this,t,r),e=e.replace(r,"")}}return this.correctHours(t),t}}static fromString(e,t){t?.format||n.errorMessages.customDateFormatError("No format was provided");try{const i=new c;if(i.setLocalization(t),["x","X"].indexOf(t.format)>-1)return new c(("X"===t.format?1e3:1)*+e);e=e.replace(/\s+/g," ");const n=i.makeParser(t.format),{year:r,month:a,day:s,hours:o,minutes:l,seconds:u,milliseconds:d,zone:h}=n(e),f=s||(r||a?1:i.getDate()),p=r||i.getFullYear();let m=0;return r&&!a||(m=a>0?a-1:i.getMonth()),h?new c(Date.UTC(p,m,f,o,l,u,d+60*h.offset*1e3)):new c(p,m,f,o,l,u,d)}catch(i){n.errorMessages.customDateFormatError(`Unable to parse provided input: ${e}, format: ${t.format}`)}}format(e,t=this.localization.locale){if(e&&"object"==typeof e)return new Intl.DateTimeFormat(t,e).format(this);const i=this.replaceTokens(e||this.localization.format||`${a.dateFormats.L}, ${a.dateFormats.LT}`,this.localization.dateFormats),n=e=>new Intl.DateTimeFormat(this.localization.locale,e).format(this);this.localization.hourCycle||(this.localization.hourCycle=l(this.localization.locale));const r=this.localization.hourCycle.startsWith("h1")?"h24":this.localization.hourCycle,s=this.localization.hourCycle.startsWith("h2")?"h12":this.localization.hourCycle,o={y:this.year,yy:n({year:"2-digit"}),yyyy:this.year,M:n({month:"numeric"}),MM:this.monthFormatted,MMM:this.getAllMonths("short")[this.getMonth()],MMMM:this.getAllMonths()[this.getMonth()],d:this.date,dd:this.dateFormatted,ddd:n({weekday:"short"}),dddd:n({weekday:"long"}),H:this.getHours(),HH:this.getHoursFormatted(r),h:this.hours>12?this.hours-12:this.hours,hh:this.getHoursFormatted(s),t:this.meridiem(),T:this.meridiem().toUpperCase(),m:this.minutes,mm:this.minutesFormatted,s:this.seconds,ss:this.secondsFormatted,fff:this.getMilliseconds()};return i.replace(this.dateTimeRegex,((e,t)=>t||o[e])).replace(/\[/g,"").replace(/]/g,"")}}class u{constructor(){this.cache=new Map}locate(e){const t=this.cache.get(e);if(t)return t;const i=new e;return this.cache.set(e,i),i}}let d;const h=[{name:"calendar",className:n.css.daysContainer,unit:e.Unit.month,step:1},{name:"months",className:n.css.monthsContainer,unit:e.Unit.year,step:1},{name:"years",className:n.css.yearsContainer,unit:e.Unit.year,step:10},{name:"decades",className:n.css.decadesContainer,unit:e.Unit.year,step:100}];class f{constructor(){this._currentCalendarViewMode=0,this._viewDate=new c,this.minimumCalendarViewMode=0,this.currentView="calendar"}get currentCalendarViewMode(){return this._currentCalendarViewMode}set currentCalendarViewMode(e){this._currentCalendarViewMode=e,this.currentView=h[e].name}get viewDate(){return this._viewDate}set viewDate(e){this._viewDate=e,this.options&&(this.options.viewDate=e)}refreshCurrentView(){this.currentView=h[this.currentCalendarViewMode].name}get isTwelveHour(){return["h12","h11"].includes(this.options.localization.hourCycle)}}class p{constructor(){this.optionsStore=d.locate(f)}isValid(t,i){if(!this._enabledDisabledDatesIsValid(i,t))return!1;if(i!==e.Unit.month&&i!==e.Unit.year&&this.optionsStore.options.restrictions.daysOfWeekDisabled?.length>0&&-1!==this.optionsStore.options.restrictions.daysOfWeekDisabled.indexOf(t.weekDay))return!1;if(!this._minMaxIsValid(i,t))return!1;if(i===e.Unit.hours||i===e.Unit.minutes||i===e.Unit.seconds){if(!this._enabledDisabledHoursIsValid(t))return!1;if(0!==this.optionsStore.options.restrictions.disabledTimeIntervals?.filter((e=>t.isBetween(e.from,e.to))).length)return!1}return!0}_enabledDisabledDatesIsValid(t,i){return!(t===e.Unit.date&&(this.optionsStore.options.restrictions.disabledDates.length>0&&this._isInDisabledDates(i)||this.optionsStore.options.restrictions.enabledDates.length>0&&!this._isInEnabledDates(i)))}_isInDisabledDates(t){return!(!this.optionsStore.options.restrictions.disabledDates||0===this.optionsStore.options.restrictions.disabledDates.length||!this.optionsStore.options.restrictions.disabledDates.find((i=>i.isSame(t,e.Unit.date))))}_isInEnabledDates(t){return!this.optionsStore.options.restrictions.enabledDates||0===this.optionsStore.options.restrictions.enabledDates.length||!!this.optionsStore.options.restrictions.enabledDates.find((i=>i.isSame(t,e.Unit.date)))}_minMaxIsValid(e,t){return!(this.optionsStore.options.restrictions.minDate&&t.isBefore(this.optionsStore.options.restrictions.minDate,e)||this.optionsStore.options.restrictions.maxDate&&t.isAfter(this.optionsStore.options.restrictions.maxDate,e))}_enabledDisabledHoursIsValid(e){return!(this.optionsStore.options.restrictions.disabledHours.length>0&&this._isInDisabledHours(e)||this.optionsStore.options.restrictions.enabledHours.length>0&&!this._isInEnabledHours(e))}_isInDisabledHours(e){if(!this.optionsStore.options.restrictions.disabledHours||0===this.optionsStore.options.restrictions.disabledHours.length)return!1;const t=e.hours;return this.optionsStore.options.restrictions.disabledHours.includes(t)}_isInEnabledHours(e){if(!this.optionsStore.options.restrictions.enabledHours||0===this.optionsStore.options.restrictions.enabledHours.length)return!0;const t=e.hours;return this.optionsStore.options.restrictions.enabledHours.includes(t)}dateRangeIsValid(t,i,n){if(!this.optionsStore.options.dateRange)return!0;if(2!==t.length&&1!==i)return!0;const r=t[0].clone;if(r.isSame(n,e.Unit.date))return!0;for(r.manipulate(1,e.Unit.date);!r.isSame(n,e.Unit.date);){if(!this.isValid(r,e.Unit.date))return!1;r.manipulate(1,e.Unit.date)}return!0}}class m{constructor(){this.subscribers=[]}subscribe(e){return this.subscribers.push(e),this.unsubscribe.bind(this,this.subscribers.length-1)}unsubscribe(e){this.subscribers.splice(e,1)}emit(e){this.subscribers.forEach((t=>{t(e)}))}destroy(){this.subscribers=null,this.subscribers=[]}}class g{constructor(){this.triggerEvent=new m,this.viewUpdate=new m,this.updateDisplay=new m,this.action=new m,this.updateViewDate=new m}destroy(){this.triggerEvent.destroy(),this.viewUpdate.destroy(),this.updateDisplay.destroy(),this.action.destroy(),this.updateViewDate.destroy()}}const v={clear:"Clear selection",close:"Close the picker",dateFormats:a.dateFormats,dayViewHeaderFormat:{month:"long",year:"2-digit"},decrementHour:"Decrement Hour",decrementMinute:"Decrement Minute",decrementSecond:"Decrement Second",format:a.format,hourCycle:a.hourCycle,incrementHour:"Increment Hour",incrementMinute:"Increment Minute",incrementSecond:"Increment Second",locale:a.locale,maxWeekdayLength:0,nextCentury:"Next Century",nextDecade:"Next Decade",nextMonth:"Next Month",nextYear:"Next Year",ordinal:a.ordinal,pickHour:"Pick Hour",pickMinute:"Pick Minute",pickSecond:"Pick Second",previousCentury:"Previous Century",previousDecade:"Previous Decade",previousMonth:"Previous Month",previousYear:"Previous Year",selectDate:"Select Date",selectDecade:"Select Decade",selectMonth:"Select Month",selectTime:"Select Time",selectYear:"Select Year",startOfTheWeek:0,today:"Go to today",toggleMeridiem:"Toggle Meridiem"},y={allowInputToggle:!1,container:void 0,dateRange:!1,debug:!1,defaultDate:void 0,display:{icons:{type:"icons",time:"fa-solid fa-clock",date:"fa-solid fa-calendar",up:"fa-solid fa-arrow-up",down:"fa-solid fa-arrow-down",previous:"fa-solid fa-chevron-left",next:"fa-solid fa-chevron-right",today:"fa-solid fa-calendar-check",clear:"fa-solid fa-trash",close:"fa-solid fa-xmark"},sideBySide:!1,calendarWeeks:!1,viewMode:"calendar",toolbarPlacement:"bottom",keepOpen:!1,buttons:{today:!1,clear:!1,close:!1},components:{calendar:!0,date:!0,month:!0,year:!0,decades:!0,clock:!0,hours:!0,minutes:!0,seconds:!1,useTwentyfourHour:void 0},inline:!1,theme:"auto",placement:"bottom"},keepInvalid:!1,localization:v,meta:{},multipleDates:!1,multipleDatesSeparator:"; ",promptTimeOnDateChange:!1,promptTimeOnDateChangeTransitionDelay:200,restrictions:{minDate:void 0,maxDate:void 0,disabledDates:[],enabledDates:[],daysOfWeekDisabled:[],disabledTimeIntervals:[],disabledHours:[],enabledHours:[]},stepping:1,useCurrent:!0,viewDate:new c},b={...v};function x(e,t){if(!e)return null;if(e.constructor.name===c.name)return e;if(e.constructor.name===Date.name)return c.convert(e);if("string"==typeof e){const i=c.fromString(e,t);return"null"===JSON.stringify(i)?null:i}return null}function _(e,t,i){"string"==typeof e&&"input"!==t&&n.errorMessages.dateString();const r=x(e,i);return r||n.errorMessages.failedToParseDate(t,e,"input"===t),r}function w(e,t,i,r=a){Array.isArray(t)||n.errorMessages.typeMismatch(e,i,"array of DateTime or Date");for(let i=0;i<t.length;i++){const n=_(t[i],e,r);n.setLocalization(r),t[i]=n}}function k(e,t,i){Array.isArray(t)&&!t.some((e=>"number"!=typeof e))||n.errorMessages.typeMismatch(e,i,"array of numbers")}function M(e){return({value:t,providedType:i,localization:n})=>{const r=_(t,e,n);if(void 0!==r)return r.setLocalization(n),r}}function S(e){const t=M(e);return e=>void 0===e.value?e.value:t(e)}function A(e,t,i){return({value:r,providedType:a})=>void 0===r?[]:(k(e,r,a),r.some((e=>e<t||e>i))&&n.errorMessages.numbersOutOfRange(e,t,i),r)}function L(e){return A(e,0,23)}function T(e){return({value:t,providedType:i,localization:n})=>void 0===t?[]:(w(e,t,i,n),t)}function C(e){return({value:t,path:i})=>(e.includes(t)||n.errorMessages.unexpectedOptionValue(i.substring(1),t,e),t)}const D=Object.freeze({defaultDate:M("defaultDate"),viewDate:M("viewDate"),minDate:S("restrictions.minDate"),maxDate:S("restrictions.maxDate"),disabledHours:L("restrictions.disabledHours"),enabledHours:L("restrictions.enabledHours"),disabledDates:T("restrictions.disabledDates"),enabledDates:T("restrictions.enabledDates"),daysOfWeekDisabled:A("restrictions.daysOfWeekDisabled",0,6),disabledTimeIntervals:({key:e,value:t,providedType:i,localization:r})=>{if(void 0===t)return[];Array.isArray(t)||n.errorMessages.typeMismatch(e,i,"array of { from: DateTime|Date, to: DateTime|Date }");const a=t;for(let t=0;t<a.length;t++)Object.keys(a[t]).forEach((i=>{const n=`${e}[${t}].${i}`,s=_(a[t][i],n,r);s.setLocalization(r),a[t][i]=s}));return a},toolbarPlacement:C(["top","bottom","default"]),type:C(["icons","sprites"]),viewMode:C(["clock","calendar","months","years","decades"]),theme:C(["light","dark","auto"]),placement:C(["top","bottom"]),meta:({value:e})=>e,dayViewHeaderFormat:({value:e})=>e,container:({value:e,path:t})=>(e&&!(e instanceof HTMLElement||e instanceof Element||e?.appendChild)&&n.errorMessages.typeMismatch(t.substring(1),typeof e,"HTMLElement"),e),useTwentyfourHour:({value:e,path:t,providedType:i,defaultType:r})=>{if(n.errorMessages.deprecatedWarning("useTwentyfourHour",'Please use "options.localization.hourCycle" instead'),void 0===e||"boolean"===i)return e;n.errorMessages.typeMismatch(t,i,r)},hourCycle:C(["h11","h12","h23","h24"])}),E=({value:e,defaultType:t,providedType:i,path:r})=>{switch(t){case"boolean":return"true"===e||!0===e;case"number":return+e;case"string":return e.toString();case"object":return{};case"function":return e;default:n.errorMessages.typeMismatch(r,i,t)}};class O{static deepCopy(e){const t={};return Object.keys(e).forEach((i=>{const n=e[i];n instanceof c?t[i]=n.clone:n instanceof Date?t[i]=new Date(n.valueOf()):(t[i]=n,"object"!=typeof n||n instanceof HTMLElement||n instanceof Element||Array.isArray(n)||(t[i]=O.deepCopy(n)))})),t}static objectPath(e,t){return"."===e.charAt(0)&&(e=e.slice(1)),e?e.split(".").reduce(((e,t)=>O.isValue(e)||O.isValue(e[t])?e[t]:void 0),t):t}static spread(e,t,i,r=""){const a=O.objectPath(r,y),s=Object.keys(e).filter((e=>!Object.keys(a).includes(e)));if(s.length>0){const e=O.getFlattenDefaultOptions(),t=s.map((t=>{let i=`"${r}.${t}" in not a known option.`;const n=e.find((e=>e.includes(t)));return n&&(i+=` Did you mean "${n}"?`),i}));n.errorMessages.unexpectedOptions(t)}Object.keys(e).filter((e=>"__proto__"!==e&&"constructor"!==e)).forEach((n=>{"."===(r+=`.${n}`).charAt(0)&&(r=r.slice(1));const s=a[n],o=typeof e[n],l=typeof s,c=e[n];if(null==c)return t[n]=c,void(r=r.substring(0,r.lastIndexOf(`.${n}`)));"object"!=typeof s||Array.isArray(e[n])||s instanceof Date||O.ignoreProperties.includes(n)?t[n]=O.processKey(n,c,o,l,r,i):O.spread(e[n],t[n],i,r),r=r.substring(0,r.lastIndexOf(`.${n}`))}))}static processKey(e,t,i,n,r,a){return(D[(s={key:e,value:t,providedType:i,defaultType:n,path:r,localization:a}).key]||E)(s);var s}static _mergeOptions(e,t){const i=O.deepCopy(t),n="default"!==t.localization?.locale?t.localization:e?.localization||y.localization;return O.spread(e,i,n,""),i}static _dataToOptions(e,t){const i=JSON.parse(JSON.stringify(e.dataset));if(i?.tdTargetInput&&delete i.tdTargetInput,i?.tdTargetToggle&&delete i.tdTargetToggle,!i||0===Object.keys(i).length)return t;const r={},a=e=>{const t={};return Object.keys(e).forEach((e=>{t[e.toLowerCase()]=e})),t},s=this.normalizeObject(a),o=a(t);return Object.keys(i).filter((e=>e.startsWith(n.dataKey))).map((e=>e.substring(2))).forEach((e=>{let n=o[e.toLowerCase()];if(e.includes("_")){const a=e.split("_");n=o[a[0].toLowerCase()],void 0!==n&&t[n].constructor===Object&&(r[n]=s(a,1,t[n],i[`td${e}`]))}else void 0!==n&&(r[n]=i[`td${e}`])})),this._mergeOptions(r,t)}static normalizeObject(e){const t=(i,n,r,a)=>{const s=e(r)[i[n].toLowerCase()],o={};return void 0===s||(r[s]?.constructor===Object?(n++,o[s]=t(i,n,r[s],a)):o[s]=a),o};return t}static _dateTypeCheck(e,t){return x(e,t)}static _typeCheckDateArray(e,t,i,n){return w(e,t,i,n)}static _typeCheckNumberArray(e,t,i){return k(e,t,i)}static dateConversion(e,t,i){return _(e,t,i)}static getFlattenDefaultOptions(){if(this._flattenDefaults)return this._flattenDefaults;const e=(t,i=[])=>Array.isArray(t)?[]:Object(t)===t?Object.entries(t).flatMap((([t,n])=>e(n,[...i,t]))):i.join(".");return this._flattenDefaults=e(y),this._flattenDefaults}static _validateConflicts(e){!e.display.sideBySide||e.display.components.clock&&(e.display.components.hours||e.display.components.minutes||e.display.components.seconds)||n.errorMessages.conflictingConfiguration("Cannot use side by side mode without the clock components"),e.restrictions.minDate&&e.restrictions.maxDate&&(e.restrictions.minDate.isAfter(e.restrictions.maxDate)&&n.errorMessages.conflictingConfiguration("minDate is after maxDate"),e.restrictions.maxDate.isBefore(e.restrictions.minDate)&&n.errorMessages.conflictingConfiguration("maxDate is before minDate")),e.multipleDates&&e.dateRange&&n.errorMessages.conflictingConfiguration('Cannot uss option "multipleDates" with "dateRange"')}}O.ignoreProperties=["meta","dayViewHeaderFormat","container","dateForms","ordinal"],O.isValue=e=>null!=e;class P{constructor(){this._dates=[],this.optionsStore=d.locate(f),this.validation=d.locate(p),this._eventEmitters=d.locate(g)}get picked(){return[...this._dates]}get lastPicked(){return this._dates[this.lastPickedIndex]?.clone}get lastPickedIndex(){return 0===this._dates.length?0:this._dates.length-1}formatInput(e){return e?(e.localization=this.optionsStore.options.localization,e.format()):""}parseInput(e){try{return O.dateConversion(e,"input",this.optionsStore.options.localization)}catch(t){return void this._eventEmitters.triggerEvent.emit({type:n.events.error,reason:n.errorMessages.failedToParseInput,format:this.optionsStore.options.localization.format,value:e})}}setFromInput(e,t){if(!e)return void this.setValue(void 0,t);const i=this.parseInput(e);i&&(i.setLocalization(this.optionsStore.options.localization),this.setValue(i,t))}add(e){this._dates.push(e)}isPicked(e,t){if(!c.isValid(e))return!1;if(!t)return void 0!==this._dates.find((t=>t.isSame(e)));const i=o(t),n=e.format(i);return void 0!==this._dates.map((e=>e.format(i))).find((e=>e===n))}pickedIndex(e,t){if(!c.isValid(e))return-1;if(!t)return this._dates.map((e=>e.valueOf())).indexOf(e.valueOf());const i=o(t),n=e.format(i);return this._dates.map((e=>e.format(i))).indexOf(n)}clear(){this.optionsStore.unset=!0,this._eventEmitters.triggerEvent.emit({type:n.events.change,date:void 0,oldDate:this.lastPicked,isClear:!0,isValid:!0}),this._dates=[],this.optionsStore.input&&(this.optionsStore.input.value=""),this._eventEmitters.updateDisplay.emit("all")}static getStartEndYear(e,t){const i=e/10,n=Math.floor(t/e)*e;return[n,n+9*i,Math.floor(t/i)*i]}updateInput(e){if(!this.optionsStore.input)return;let t=this.formatInput(e);(this.optionsStore.options.multipleDates||this.optionsStore.options.dateRange)&&(t=this._dates.map((e=>this.formatInput(e))).join(this.optionsStore.options.multipleDatesSeparator)),this.optionsStore.input.value!=t&&(this.optionsStore.input.value=t)}setValue(t,i){const r=void 0===i,a=!t&&r;let s=this.optionsStore.unset?null:this._dates[i]?.clone;if(!s&&!this.optionsStore.unset&&r&&a&&(s=this.lastPicked),t&&s?.isSame(t))return void this.updateInput(t);if(!t)return void this._setValueNull(a,i,s);i=i||0,t=t.clone,1!==this.optionsStore.options.stepping&&(t.minutes=Math.round(t.minutes/this.optionsStore.options.stepping)*this.optionsStore.options.stepping,t.startOf(e.Unit.minutes));const o=e=>{this._dates[i]=t,this._eventEmitters.updateViewDate.emit(t.clone),this.updateInput(t),this.optionsStore.unset=!1,this._eventEmitters.updateDisplay.emit("all"),this._eventEmitters.triggerEvent.emit({type:n.events.change,date:t,oldDate:s,isClear:a,isValid:e})};this.validation.isValid(t)&&this.validation.dateRangeIsValid(this.picked,i,t)?o(!0):(this.optionsStore.options.keepInvalid&&o(!1),this._eventEmitters.triggerEvent.emit({type:n.events.error,reason:n.errorMessages.failedToSetInvalidDate,date:t,oldDate:s}))}_setValueNull(e,t,i){!this.optionsStore.options.multipleDates||1===this._dates.length||e?(this.optionsStore.unset=!0,this._dates=[]):this._dates.splice(t,1),this.updateInput(),this._eventEmitters.triggerEvent.emit({type:n.events.change,date:void 0,oldDate:i,isClear:e,isValid:!0}),this._eventEmitters.updateDisplay.emit("all")}}var Y;!function(e){e.next="next",e.previous="previous",e.changeCalendarView="changeCalendarView",e.selectMonth="selectMonth",e.selectYear="selectYear",e.selectDecade="selectDecade",e.selectDay="selectDay",e.selectHour="selectHour",e.selectMinute="selectMinute",e.selectSecond="selectSecond",e.incrementHours="incrementHours",e.incrementMinutes="incrementMinutes",e.incrementSeconds="incrementSeconds",e.decrementHours="decrementHours",e.decrementMinutes="decrementMinutes",e.decrementSeconds="decrementSeconds",e.toggleMeridiem="toggleMeridiem",e.togglePicker="togglePicker",e.showClock="showClock",e.showHours="showHours",e.showMinutes="showMinutes",e.showSeconds="showSeconds",e.clear="clear",e.close="close",e.today="today"}(Y||(Y={}));var I=Y;class N{constructor(){this.optionsStore=d.locate(f),this.dates=d.locate(P),this.validation=d.locate(p)}getPicker(){const e=document.createElement("div");if(e.classList.add(n.css.daysContainer),e.append(...this._daysOfTheWeek()),this.optionsStore.options.display.calendarWeeks){const t=document.createElement("div");t.classList.add(n.css.calendarWeeks,n.css.noHighlight),e.appendChild(t)}const{rangeHoverEvent:t,rangeHoverOutEvent:i}=this.handleMouseEvents(e);for(let r=0;r<42;r++){if(0!==r&&r%7==0&&this.optionsStore.options.display.calendarWeeks){const t=document.createElement("div");t.classList.add(n.css.calendarWeeks,n.css.noHighlight),e.appendChild(t)}const a=document.createElement("div");a.setAttribute("data-action",I.selectDay),e.appendChild(a),matchMedia("(hover: hover)").matches&&this.optionsStore.options.dateRange&&(a.addEventListener("mouseover",t),a.addEventListener("mouseout",i))}return e}_update(t,i){const r=t.getElementsByClassName(n.css.daysContainer)[0];this._updateCalendarView(r);const a=this.optionsStore.viewDate.clone.startOf(e.Unit.month).startOf("weekDay",this.optionsStore.options.localization.startOfTheWeek).manipulate(12,e.Unit.hours);this._handleCalendarWeeks(r,a.clone),r.querySelectorAll(`[data-action="${I.selectDay}"]`).forEach((t=>{const r=[];r.push(n.css.day),a.isBefore(this.optionsStore.viewDate,e.Unit.month)&&r.push(n.css.old),a.isAfter(this.optionsStore.viewDate,e.Unit.month)&&r.push(n.css.new),this.optionsStore.unset||this.optionsStore.options.dateRange||!this.dates.isPicked(a,e.Unit.date)||r.push(n.css.active),this.validation.isValid(a,e.Unit.date)||r.push(n.css.disabled),a.isSame(new c,e.Unit.date)&&r.push(n.css.today),0!==a.weekDay&&6!==a.weekDay||r.push(n.css.weekend),this._handleDateRange(a,r),i(e.Unit.date,a,r,t),t.classList.remove(...t.classList),t.classList.add(...r),t.setAttribute("data-value",this._dateToDataValue(a)),t.setAttribute("data-day",`${a.date}`),t.innerText=a.parts(void 0,{day:"numeric"}).day,a.manipulate(1,e.Unit.date)}))}_dateToDataValue(e){return c.isValid(e)?`${e.year}-${e.month.toString().padStart(2,"0")}-${e.date.toString().padStart(2,"0")}`:""}_handleDateRange(t,i){const r=this.dates.picked[0],a=this.dates.picked[1];this.optionsStore.options.dateRange&&(t.isBetween(r,a,e.Unit.date)&&i.push(n.css.rangeIn),t.isSame(r,e.Unit.date)&&i.push(n.css.rangeStart),t.isSame(a,e.Unit.date)&&i.push(n.css.rangeEnd))}handleMouseEvents(t){return{rangeHoverEvent:i=>{const r=i?.currentTarget;if(1!==this.dates.picked.length||r.classList.contains(n.css.disabled))return;const a=[...t.querySelectorAll(".day")],s=r.getAttribute("data-value"),o=c.fromString(s,{format:"yyyy-MM-dd"}),l=a.findIndex((e=>e.getAttribute("data-value")===s)),u=this.dates.picked[0],d=this.dates.picked[1],h=this._dateToDataValue(u),f=a.findIndex((e=>e.getAttribute("data-value")===h)),p=a[f];let m;o.isSame(u,e.Unit.date)||r.classList.remove(n.css.rangeStart),o.isSame(d,e.Unit.date)||r.classList.remove(n.css.rangeEnd),o.isBefore(u)?(r.classList.add(n.css.rangeStart),p?.classList.remove(n.css.rangeStart),p?.classList.add(n.css.rangeEnd),m=(e,t)=>t>l&&t<f):(r.classList.add(n.css.rangeEnd),p?.classList.remove(n.css.rangeEnd),p?.classList.add(n.css.rangeStart),m=(e,t)=>t<l&&t>f),a.filter(m).forEach((e=>{e.classList.add(n.css.rangeIn)}))},rangeHoverOutEvent:i=>{const r=[...t.querySelectorAll(".day")];if(1===this.dates.picked.length&&r.forEach((e=>e.classList.remove(n.css.rangeIn))),1!==this.dates.picked.length)return;const a=i?.currentTarget,s=new c(a.getAttribute("data-value"));s.isSame(this.dates.picked[0],e.Unit.date)||a.classList.remove(n.css.rangeStart),s.isSame(this.dates.picked[1],e.Unit.date)||a.classList.remove(n.css.rangeEnd)}}}_updateCalendarView(t){if("calendar"!==this.optionsStore.currentView)return;const[i,r,a]=t.parentElement.getElementsByClassName(n.css.calendarHeader)[0].getElementsByTagName("div");r.setAttribute(n.css.daysContainer,this.optionsStore.viewDate.format(this.optionsStore.options.localization.dayViewHeaderFormat)),this.optionsStore.options.display.components.month?r.classList.remove(n.css.disabled):r.classList.add(n.css.disabled),this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(-1,e.Unit.month),e.Unit.month)?i.classList.remove(n.css.disabled):i.classList.add(n.css.disabled),this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(1,e.Unit.month),e.Unit.month)?a.classList.remove(n.css.disabled):a.classList.add(n.css.disabled)}_daysOfTheWeek(){const t=this.optionsStore.viewDate.clone.startOf("weekDay",this.optionsStore.options.localization.startOfTheWeek).startOf(e.Unit.date),i=[];if(document.createElement("div"),this.optionsStore.options.display.calendarWeeks){const e=document.createElement("div");e.classList.add(n.css.calendarWeeks,n.css.noHighlight),e.innerText="#",i.push(e)}for(let r=0;r<7;r++){const r=document.createElement("div");r.classList.add(n.css.dayOfTheWeek,n.css.noHighlight);let a=t.format({weekday:"short"});this.optionsStore.options.localization.maxWeekdayLength>0&&(a=a.substring(0,this.optionsStore.options.localization.maxWeekdayLength)),r.innerText=a,t.manipulate(1,e.Unit.date),i.push(r)}return i}_handleCalendarWeeks(t,i){[...t.querySelectorAll(`.${n.css.calendarWeeks}`)].filter((e=>"#"!==e.innerText)).forEach((t=>{t.innerText=`${i.week}`,i.manipulate(7,e.Unit.date)}))}}class j{constructor(){this.optionsStore=d.locate(f),this.dates=d.locate(P),this.validation=d.locate(p)}getPicker(){const e=document.createElement("div");e.classList.add(n.css.monthsContainer);for(let t=0;t<12;t++){const t=document.createElement("div");t.setAttribute("data-action",I.selectMonth),e.appendChild(t)}return e}_update(t,i){const r=t.getElementsByClassName(n.css.monthsContainer)[0];if("months"===this.optionsStore.currentView){const[t,i,a]=r.parentElement.getElementsByClassName(n.css.calendarHeader)[0].getElementsByTagName("div");i.setAttribute(n.css.monthsContainer,this.optionsStore.viewDate.format({year:"numeric"})),this.optionsStore.options.display.components.year?i.classList.remove(n.css.disabled):i.classList.add(n.css.disabled),this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(-1,e.Unit.year),e.Unit.year)?t.classList.remove(n.css.disabled):t.classList.add(n.css.disabled),this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(1,e.Unit.year),e.Unit.year)?a.classList.remove(n.css.disabled):a.classList.add(n.css.disabled)}const a=this.optionsStore.viewDate.clone.startOf(e.Unit.year);r.querySelectorAll(`[data-action="${I.selectMonth}"]`).forEach(((t,r)=>{const s=[];s.push(n.css.month),!this.optionsStore.unset&&this.dates.isPicked(a,e.Unit.month)&&s.push(n.css.active),this.validation.isValid(a,e.Unit.month)||s.push(n.css.disabled),i(e.Unit.month,a,s,t),t.classList.remove(...t.classList),t.classList.add(...s),t.setAttribute("data-value",`${r}`),t.innerText=`${a.format({month:"short"})}`,a.manipulate(1,e.Unit.month)}))}}class H{constructor(){this.optionsStore=d.locate(f),this.dates=d.locate(P),this.validation=d.locate(p)}getPicker(){const e=document.createElement("div");e.classList.add(n.css.yearsContainer);for(let t=0;t<12;t++){const t=document.createElement("div");t.setAttribute("data-action",I.selectYear),e.appendChild(t)}return e}_update(t,i){this._startYear=this.optionsStore.viewDate.clone.manipulate(-1,e.Unit.year),this._endYear=this.optionsStore.viewDate.clone.manipulate(10,e.Unit.year);const r=t.getElementsByClassName(n.css.yearsContainer)[0];if("years"===this.optionsStore.currentView){const[t,i,a]=r.parentElement.getElementsByClassName(n.css.calendarHeader)[0].getElementsByTagName("div");i.setAttribute(n.css.yearsContainer,`${this._startYear.format({year:"numeric"})}-${this._endYear.format({year:"numeric"})}`),this.optionsStore.options.display.components.decades?i.classList.remove(n.css.disabled):i.classList.add(n.css.disabled),this.validation.isValid(this._startYear,e.Unit.year)?t.classList.remove(n.css.disabled):t.classList.add(n.css.disabled),this.validation.isValid(this._endYear,e.Unit.year)?a.classList.remove(n.css.disabled):a.classList.add(n.css.disabled)}const a=this.optionsStore.viewDate.clone.startOf(e.Unit.year).manipulate(-1,e.Unit.year);r.querySelectorAll(`[data-action="${I.selectYear}"]`).forEach((t=>{const r=[];r.push(n.css.year),!this.optionsStore.unset&&this.dates.isPicked(a,e.Unit.year)&&r.push(n.css.active),this.validation.isValid(a,e.Unit.year)||r.push(n.css.disabled),i(e.Unit.year,a,r,t),t.classList.remove(...t.classList),t.classList.add(...r),t.setAttribute("data-value",`${a.year}`),t.innerText=a.format({year:"numeric"}),a.manipulate(1,e.Unit.year)}))}}class F{constructor(){this.optionsStore=d.locate(f),this.dates=d.locate(P),this.validation=d.locate(p)}getPicker(){const e=document.createElement("div");e.classList.add(n.css.decadesContainer);for(let t=0;t<12;t++){const t=document.createElement("div");t.setAttribute("data-action",I.selectDecade),e.appendChild(t)}return e}_update(t,i){const[r,a]=P.getStartEndYear(100,this.optionsStore.viewDate.year);this._startDecade=this.optionsStore.viewDate.clone.startOf(e.Unit.year),this._startDecade.year=r,this._endDecade=this.optionsStore.viewDate.clone.startOf(e.Unit.year),this._endDecade.year=a;const s=t.getElementsByClassName(n.css.decadesContainer)[0],[o,l,c]=s.parentElement.getElementsByClassName(n.css.calendarHeader)[0].getElementsByTagName("div");"decades"===this.optionsStore.currentView&&(l.setAttribute(n.css.decadesContainer,`${this._startDecade.format({year:"numeric"})}-${this._endDecade.format({year:"numeric"})}`),this.validation.isValid(this._startDecade,e.Unit.year)?o.classList.remove(n.css.disabled):o.classList.add(n.css.disabled),this.validation.isValid(this._endDecade,e.Unit.year)?c.classList.remove(n.css.disabled):c.classList.add(n.css.disabled));const u=this.dates.picked.map((e=>e.year));s.querySelectorAll(`[data-action="${I.selectDecade}"]`).forEach(((t,r)=>{if(0===r)return t.classList.add(n.css.old),this._startDecade.year-10<0?(t.textContent=" ",o.classList.add(n.css.disabled),t.classList.add(n.css.disabled),void t.setAttribute("data-value","")):(t.innerText=this._startDecade.clone.manipulate(-10,e.Unit.year).format({year:"numeric"}),void t.setAttribute("data-value",`${this._startDecade.year}`));const a=[];a.push(n.css.decade);const s=this._startDecade.year,l=this._startDecade.year+9;!this.optionsStore.unset&&u.filter((e=>e>=s&&e<=l)).length>0&&a.push(n.css.active),this.validation.isValid(this._startDecade,e.Unit.year)||this.validation.isValid(this._startDecade.clone.manipulate(10,e.Unit.year),e.Unit.year)||a.push(n.css.disabled),i("decade",this._startDecade,a,t),t.classList.remove(...t.classList),t.classList.add(...a),t.setAttribute("data-value",`${this._startDecade.year}`),t.innerText=`${this._startDecade.format({year:"numeric"})}`,this._startDecade.manipulate(10,e.Unit.year)}))}}class R{constructor(){this._gridColumns="",this.optionsStore=d.locate(f),this.dates=d.locate(P),this.validation=d.locate(p)}getPicker(e){const t=document.createElement("div");return t.classList.add(n.css.clockContainer),t.append(...this._grid(e)),t}_update(t){const i=t.getElementsByClassName(n.css.clockContainer)[0];let r=this.dates.lastPicked?.clone;if(!r&&this.optionsStore.options.useCurrent&&(r=this.optionsStore.viewDate.clone),i.querySelectorAll(".disabled").forEach((e=>e.classList.remove(n.css.disabled))),this.optionsStore.options.display.components.hours&&(this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(1,e.Unit.hours),e.Unit.hours)||i.querySelector(`[data-action=${I.incrementHours}]`).classList.add(n.css.disabled),this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(-1,e.Unit.hours),e.Unit.hours)||i.querySelector(`[data-action=${I.decrementHours}]`).classList.add(n.css.disabled),i.querySelector(`[data-time-component=${e.Unit.hours}]`).innerText=r?r.getHoursFormatted(this.optionsStore.options.localization.hourCycle):"--"),this.optionsStore.options.display.components.minutes&&(this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(1,e.Unit.minutes),e.Unit.minutes)||i.querySelector(`[data-action=${I.incrementMinutes}]`).classList.add(n.css.disabled),this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(-1,e.Unit.minutes),e.Unit.minutes)||i.querySelector(`[data-action=${I.decrementMinutes}]`).classList.add(n.css.disabled),i.querySelector(`[data-time-component=${e.Unit.minutes}]`).innerText=r?r.minutesFormatted:"--"),this.optionsStore.options.display.components.seconds&&(this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(1,e.Unit.seconds),e.Unit.seconds)||i.querySelector(`[data-action=${I.incrementSeconds}]`).classList.add(n.css.disabled),this.validation.isValid(this.optionsStore.viewDate.clone.manipulate(-1,e.Unit.seconds),e.Unit.seconds)||i.querySelector(`[data-action=${I.decrementSeconds}]`).classList.add(n.css.disabled),i.querySelector(`[data-time-component=${e.Unit.seconds}]`).innerText=r?r.secondsFormatted:"--"),this.optionsStore.isTwelveHour){const t=i.querySelector(`[data-action=${I.toggleMeridiem}]`),a=(r||this.optionsStore.viewDate).clone;t.innerText=a.meridiem(),this.validation.isValid(a.manipulate(a.hours>=12?-12:12,e.Unit.hours))?t.classList.remove(n.css.disabled):t.classList.add(n.css.disabled)}i.style.gridTemplateAreas=`"${this._gridColumns}"`}_grid(t){this._gridColumns="";const i=[],r=[],a=[],s=document.createElement("div"),o=t(this.optionsStore.options.display.icons.up),l=t(this.optionsStore.options.display.icons.down);s.classList.add(n.css.separator,n.css.noHighlight);const c=s.cloneNode(!0);c.innerHTML=":";const u=(e=!1)=>e?c.cloneNode(!0):s.cloneNode(!0);if(this.optionsStore.options.display.components.hours){let t=document.createElement("div");t.setAttribute("title",this.optionsStore.options.localization.incrementHour),t.setAttribute("data-action",I.incrementHours),t.appendChild(o.cloneNode(!0)),i.push(t),t=document.createElement("div"),t.setAttribute("title",this.optionsStore.options.localization.pickHour),t.setAttribute("data-action",I.showHours),t.setAttribute("data-time-component",e.Unit.hours),r.push(t),t=document.createElement("div"),t.setAttribute("title",this.optionsStore.options.localization.decrementHour),t.setAttribute("data-action",I.decrementHours),t.appendChild(l.cloneNode(!0)),a.push(t),this._gridColumns+="a"}if(this.optionsStore.options.display.components.minutes){this._gridColumns+=" a",this.optionsStore.options.display.components.hours&&(i.push(u()),r.push(u(!0)),a.push(u()),this._gridColumns+=" a");let t=document.createElement("div");t.setAttribute("title",this.optionsStore.options.localization.incrementMinute),t.setAttribute("data-action",I.incrementMinutes),t.appendChild(o.cloneNode(!0)),i.push(t),t=document.createElement("div"),t.setAttribute("title",this.optionsStore.options.localization.pickMinute),t.setAttribute("data-action",I.showMinutes),t.setAttribute("data-time-component",e.Unit.minutes),r.push(t),t=document.createElement("div"),t.setAttribute("title",this.optionsStore.options.localization.decrementMinute),t.setAttribute("data-action",I.decrementMinutes),t.appendChild(l.cloneNode(!0)),a.push(t)}if(this.optionsStore.options.display.components.seconds){this._gridColumns+=" a",this.optionsStore.options.display.components.minutes&&(i.push(u()),r.push(u(!0)),a.push(u()),this._gridColumns+=" a");let t=document.createElement("div");t.setAttribute("title",this.optionsStore.options.localization.incrementSecond),t.setAttribute("data-action",I.incrementSeconds),t.appendChild(o.cloneNode(!0)),i.push(t),t=document.createElement("div"),t.setAttribute("title",this.optionsStore.options.localization.pickSecond),t.setAttribute("data-action",I.showSeconds),t.setAttribute("data-time-component",e.Unit.seconds),r.push(t),t=document.createElement("div"),t.setAttribute("title",this.optionsStore.options.localization.decrementSecond),t.setAttribute("data-action",I.decrementSeconds),t.appendChild(l.cloneNode(!0)),a.push(t)}if(this.optionsStore.isTwelveHour){this._gridColumns+=" a";let e=u();i.push(e);const t=document.createElement("button");t.setAttribute("type","button"),t.setAttribute("title",this.optionsStore.options.localization.toggleMeridiem),t.setAttribute("data-action",I.toggleMeridiem),t.setAttribute("tabindex","-1"),n.css.toggleMeridiem.includes(",")?t.classList.add(...n.css.toggleMeridiem.split(",")):t.classList.add(n.css.toggleMeridiem),e=document.createElement("div"),e.classList.add(n.css.noHighlight),e.appendChild(t),r.push(e),e=u(),a.push(e)}return this._gridColumns=this._gridColumns.trim(),[...i,...r,...a]}}class z{constructor(){this.optionsStore=d.locate(f),this.validation=d.locate(p)}getPicker(){const e=document.createElement("div");e.classList.add(n.css.hourContainer);for(let t=0;t<(this.optionsStore.isTwelveHour?12:24);t++){const t=document.createElement("div");t.setAttribute("data-action",I.selectHour),e.appendChild(t)}return e}_update(t,i){const r=t.getElementsByClassName(n.css.hourContainer)[0],a=this.optionsStore.viewDate.clone.startOf(e.Unit.date);r.querySelectorAll(`[data-action="${I.selectHour}"]`).forEach((t=>{const r=[];r.push(n.css.hour),this.validation.isValid(a,e.Unit.hours)||r.push(n.css.disabled),i(e.Unit.hours,a,r,t),t.classList.remove(...t.classList),t.classList.add(...r),t.setAttribute("data-value",`${a.hours}`),t.innerText=a.getHoursFormatted(this.optionsStore.options.localization.hourCycle),a.manipulate(1,e.Unit.hours)}))}}class B{constructor(){this.optionsStore=d.locate(f),this.validation=d.locate(p)}getPicker(){const e=document.createElement("div");e.classList.add(n.css.minuteContainer);const t=1===this.optionsStore.options.stepping?5:this.optionsStore.options.stepping;for(let i=0;i<60/t;i++){const t=document.createElement("div");t.setAttribute("data-action",I.selectMinute),e.appendChild(t)}return e}_update(t,i){const r=t.getElementsByClassName(n.css.minuteContainer)[0],a=this.optionsStore.viewDate.clone.startOf(e.Unit.hours),s=1===this.optionsStore.options.stepping?5:this.optionsStore.options.stepping;r.querySelectorAll(`[data-action="${I.selectMinute}"]`).forEach((t=>{const r=[];r.push(n.css.minute),this.validation.isValid(a,e.Unit.minutes)||r.push(n.css.disabled),i(e.Unit.minutes,a,r,t),t.classList.remove(...t.classList),t.classList.add(...r),t.setAttribute("data-value",`${a.minutes}`),t.innerText=a.minutesFormatted,a.manipulate(s,e.Unit.minutes)}))}}class V{constructor(){this.optionsStore=d.locate(f),this.validation=d.locate(p)}getPicker(){const e=document.createElement("div");e.classList.add(n.css.secondContainer);for(let t=0;t<12;t++){const t=document.createElement("div");t.setAttribute("data-action",I.selectSecond),e.appendChild(t)}return e}_update(t,i){const r=t.getElementsByClassName(n.css.secondContainer)[0],a=this.optionsStore.viewDate.clone.startOf(e.Unit.minutes);r.querySelectorAll(`[data-action="${I.selectSecond}"]`).forEach((t=>{const r=[];r.push(n.css.second),this.validation.isValid(a,e.Unit.seconds)||r.push(n.css.disabled),i(e.Unit.seconds,a,r,t),t.classList.remove(...t.classList),t.classList.add(...r),t.setAttribute("data-value",`${a.seconds}`),t.innerText=a.secondsFormatted,a.manipulate(5,e.Unit.seconds)}))}}class W{static toggle(e){e.classList.contains(n.css.show)?this.hide(e):this.show(e)}static showImmediately(e){e.classList.remove(n.css.collapsing),e.classList.add(n.css.collapse,n.css.show),e.style.height=""}static show(e){e.classList.contains(n.css.collapsing)||e.classList.contains(n.css.show)||(e.style.height="0",e.classList.remove(n.css.collapse),e.classList.add(n.css.collapsing),setTimeout((()=>{W.showImmediately(e)}),this.getTransitionDurationFromElement(e)),e.style.height=`${e.scrollHeight}px`)}static hideImmediately(e){e&&(e.classList.remove(n.css.collapsing,n.css.show),e.classList.add(n.css.collapse))}static hide(e){!e.classList.contains(n.css.collapsing)&&e.classList.contains(n.css.show)&&(e.style.height=`${e.getBoundingClientRect().height}px`,e.offsetHeight,e.classList.remove(n.css.collapse,n.css.show),e.classList.add(n.css.collapsing),e.style.height="",setTimeout((()=>{W.hideImmediately(e)}),this.getTransitionDurationFromElement(e)))}}W.getTransitionDurationFromElement=e=>{if(!e)return 0;let{transitionDuration:t,transitionDelay:i}=window.getComputedStyle(e);const n=Number.parseFloat(t),r=Number.parseFloat(i);return n||r?(t=t.split(",")[0],i=i.split(",")[0],1e3*(Number.parseFloat(t)+Number.parseFloat(i))):0};class U{constructor(){this._isVisible=!1,this._documentClickEvent=e=>{this.optionsStore.options.debug||window.debug||!this._isVisible||e.composedPath().includes(this.widget)||e.composedPath()?.includes(this.optionsStore.element)||this.hide()},this._actionsClickEvent=e=>{this._eventEmitters.action.emit({e:e})},this.optionsStore=d.locate(f),this.validation=d.locate(p),this.dates=d.locate(P),this.dateDisplay=d.locate(N),this.monthDisplay=d.locate(j),this.yearDisplay=d.locate(H),this.decadeDisplay=d.locate(F),this.timeDisplay=d.locate(R),this.hourDisplay=d.locate(z),this.minuteDisplay=d.locate(B),this.secondDisplay=d.locate(V),this._eventEmitters=d.locate(g),this._widget=void 0,this._eventEmitters.updateDisplay.subscribe((e=>{this._update(e)}))}get widget(){return this._widget}get dateContainer(){return this.widget?.querySelector(`div.${n.css.dateContainer}`)}get timeContainer(){return this.widget?.querySelector(`div.${n.css.timeContainer}`)}get isVisible(){return this._isVisible}_update(t){if(this.widget)switch(t){case e.Unit.seconds:this.secondDisplay._update(this.widget,this.paint);break;case e.Unit.minutes:this.minuteDisplay._update(this.widget,this.paint);break;case e.Unit.hours:this.hourDisplay._update(this.widget,this.paint);break;case e.Unit.date:this.dateDisplay._update(this.widget,this.paint);break;case e.Unit.month:this.monthDisplay._update(this.widget,this.paint);break;case e.Unit.year:this.yearDisplay._update(this.widget,this.paint);break;case"decade":this.decadeDisplay._update(this.widget,this.paint);break;case"clock":if(!this._hasTime)break;this.timeDisplay._update(this.widget),this._update(e.Unit.hours),this._update(e.Unit.minutes),this._update(e.Unit.seconds);break;case"calendar":this._update(e.Unit.date),this._update(e.Unit.year),this._update(e.Unit.month),this.decadeDisplay._update(this.widget,this.paint),this._updateCalendarHeader();break;case"all":this._hasTime&&this._update("clock"),this._hasDate&&this._update("calendar")}}paint(e,t,i,n){}show(){if(null==this.widget){if(this._showSetDefaultIfNeeded(),this._buildWidget(),this._updateTheme(),this._showSetupViewMode(),this.optionsStore.options.display.inline)this.optionsStore.element.appendChild(this.widget);else{const e=this.optionsStore.options?.container||document.body,t=this.optionsStore.options?.display?.placement||"bottom";e.appendChild(this.widget),this.createPopup(this.optionsStore.element,this.widget,{modifiers:[{name:"eventListeners",enabled:!0}],placement:"rtl"===document.documentElement.dir?`${t}-end`:`${t}-start`}).then()}"clock"==this.optionsStore.options.display.viewMode&&this._eventEmitters.action.emit({e:null,action:I.showClock}),this.widget.querySelectorAll("[data-action]").forEach((e=>e.addEventListener("click",this._actionsClickEvent))),this._hasTime&&this.optionsStore.options.display.sideBySide&&(this.timeDisplay._update(this.widget),this.widget.getElementsByClassName(n.css.clockContainer)[0].style.display="grid")}this.widget.classList.add(n.css.show),this.optionsStore.options.display.inline||(this.updatePopup(),document.addEventListener("click",this._documentClickEvent)),this._eventEmitters.triggerEvent.emit({type:n.events.show}),this._isVisible=!0}_showSetupViewMode(){const e=this._hasTime&&!this._hasDate;e?(this.optionsStore.currentView="clock",this._eventEmitters.action.emit({e:null,action:I.showClock})):this.optionsStore.currentCalendarViewMode||(this.optionsStore.currentCalendarViewMode=this.optionsStore.minimumCalendarViewMode),e||"clock"===this.optionsStore.options.display.viewMode||(this._hasTime&&(this.optionsStore.options.display.sideBySide?W.show(this.timeContainer):W.hideImmediately(this.timeContainer)),W.show(this.dateContainer)),this._hasDate&&this._showMode()}_showSetDefaultIfNeeded(){if(0==this.dates.picked.length){if(this.optionsStore.options.useCurrent&&!this.optionsStore.options.defaultDate){const t=(new c).setLocalization(this.optionsStore.options.localization);if(!this.optionsStore.options.keepInvalid){let i=0,n=1;for(this.optionsStore.options.restrictions.maxDate?.isBefore(t)&&(n=-1);!this.validation.isValid(t)&&i>31;)t.manipulate(n,e.Unit.date),i++}this.dates.setValue(t)}this.optionsStore.options.defaultDate&&this.dates.setValue(this.optionsStore.options.defaultDate)}}async createPopup(e,t,i){let n;if(window?.Popper)n=window?.Popper?.createPopper;else{const{createPopper:e}=await import("@popperjs/core");n=e}n&&(this._popperInstance=n(e,t,i))}updatePopup(){this._popperInstance?.update()}_showMode(e){if(!this.widget)return;if(e){const t=Math.max(this.optionsStore.minimumCalendarViewMode,Math.min(3,this.optionsStore.currentCalendarViewMode+e));if(this.optionsStore.currentCalendarViewMode==t)return;this.optionsStore.currentCalendarViewMode=t}this.widget.querySelectorAll(`.${n.css.dateContainer} > div:not(.${n.css.calendarHeader}), .${n.css.timeContainer} > div:not(.${n.css.clockContainer})`).forEach((e=>e.style.display="none"));const t=h[this.optionsStore.currentCalendarViewMode],i=this.widget.querySelector(`.${t.className}`);switch(t.className){case n.css.decadesContainer:this.decadeDisplay._update(this.widget,this.paint);break;case n.css.yearsContainer:this.yearDisplay._update(this.widget,this.paint);break;case n.css.monthsContainer:this.monthDisplay._update(this.widget,this.paint);break;case n.css.daysContainer:this.dateDisplay._update(this.widget,this.paint)}i.style.display="grid",this.optionsStore.options.display.sideBySide&&(this.widget.querySelectorAll(`.${n.css.clockContainer}`)[0].style.display="grid"),this._updateCalendarHeader(),this._eventEmitters.viewUpdate.emit()}_updateTheme(e){if(this.widget){if(e){if(this.optionsStore.options.display.theme===e)return;this.optionsStore.options.display.theme=e}this.widget.classList.remove("light","dark"),this.widget.classList.add(this._getThemeClass()),"auto"===this.optionsStore.options.display.theme?window.matchMedia(n.css.isDarkPreferredQuery).addEventListener("change",(()=>this._updateTheme())):window.matchMedia(n.css.isDarkPreferredQuery).removeEventListener("change",(()=>this._updateTheme()))}}_getThemeClass(){const e=this.optionsStore.options.display.theme||"auto",t=window.matchMedia&&window.matchMedia(n.css.isDarkPreferredQuery).matches;switch(e){case"light":return n.css.lightTheme;case"dark":return n.css.darkTheme;case"auto":return t?n.css.darkTheme:n.css.lightTheme}}_updateCalendarHeader(){if(!this._hasDate)return;const e=[...this.widget.querySelector(`.${n.css.dateContainer} div[style*="display: grid"]`).classList].find((e=>e.startsWith(n.css.dateContainer))),[t,i,r]=this.widget.getElementsByClassName(n.css.calendarHeader)[0].getElementsByTagName("div");switch(e){case n.css.decadesContainer:t.setAttribute("title",this.optionsStore.options.localization.previousCentury),i.setAttribute("title",""),r.setAttribute("title",this.optionsStore.options.localization.nextCentury);break;case n.css.yearsContainer:t.setAttribute("title",this.optionsStore.options.localization.previousDecade),i.setAttribute("title",this.optionsStore.options.localization.selectDecade),r.setAttribute("title",this.optionsStore.options.localization.nextDecade);break;case n.css.monthsContainer:t.setAttribute("title",this.optionsStore.options.localization.previousYear),i.setAttribute("title",this.optionsStore.options.localization.selectYear),r.setAttribute("title",this.optionsStore.options.localization.nextYear);break;case n.css.daysContainer:t.setAttribute("title",this.optionsStore.options.localization.previousMonth),i.setAttribute("title",this.optionsStore.options.localization.selectMonth),r.setAttribute("title",this.optionsStore.options.localization.nextMonth),i.setAttribute(e,this.optionsStore.viewDate.format(this.optionsStore.options.localization.dayViewHeaderFormat))}i.innerText=i.getAttribute(e)}hide(){this.widget&&this._isVisible&&(this.widget.classList.remove(n.css.show),this._isVisible&&(this._eventEmitters.triggerEvent.emit({type:n.events.hide,date:this.optionsStore.unset?null:this.dates.lastPicked?.clone}),this._isVisible=!1),document.removeEventListener("click",this._documentClickEvent))}toggle(){return this._isVisible?this.hide():this.show()}_dispose(){document.removeEventListener("click",this._documentClickEvent),this.widget&&(this.widget.querySelectorAll("[data-action]").forEach((e=>e.removeEventListener("click",this._actionsClickEvent))),this.widget.parentNode.removeChild(this.widget),this._widget=void 0)}_buildWidget(){const e=document.createElement("div");e.classList.add(n.css.widget);const t=document.createElement("div");t.classList.add(n.css.dateContainer),t.append(this.getHeadTemplate(),this.decadeDisplay.getPicker(),this.yearDisplay.getPicker(),this.monthDisplay.getPicker(),this.dateDisplay.getPicker());const i=document.createElement("div");i.classList.add(n.css.timeContainer),i.appendChild(this.timeDisplay.getPicker(this._iconTag.bind(this))),i.appendChild(this.hourDisplay.getPicker()),i.appendChild(this.minuteDisplay.getPicker()),i.appendChild(this.secondDisplay.getPicker());const r=document.createElement("div");if(r.classList.add(n.css.toolbar),r.append(...this.getToolbarElements()),this.optionsStore.options.display.inline&&e.classList.add(n.css.inline),this.optionsStore.options.display.calendarWeeks&&e.classList.add("calendarWeeks"),this.optionsStore.options.display.sideBySide&&this._hasDateAndTime)return void this._buildWidgetSideBySide(e,t,i,r);"top"===this.optionsStore.options.display.toolbarPlacement&&e.appendChild(r);const a=(t,i,r,a)=>{t&&(i&&(r.classList.add(n.css.collapse),a&&r.classList.add(n.css.show)),e.appendChild(r))};a(this._hasDate,this._hasTime,t,"clock"!==this.optionsStore.options.display.viewMode),a(this._hasTime,this._hasDate,i,"clock"===this.optionsStore.options.display.viewMode),"bottom"===this.optionsStore.options.display.toolbarPlacement&&e.appendChild(r);const s=document.createElement("div");s.classList.add("arrow"),s.setAttribute("data-popper-arrow",""),e.appendChild(s),this._widget=e}_buildWidgetSideBySide(e,t,i,r){e.classList.add(n.css.sideBySide),"top"===this.optionsStore.options.display.toolbarPlacement&&e.appendChild(r);const a=document.createElement("div");a.classList.add("td-row"),t.classList.add("td-half"),i.classList.add("td-half"),a.appendChild(t),a.appendChild(i),e.appendChild(a),"bottom"===this.optionsStore.options.display.toolbarPlacement&&e.appendChild(r),this._widget=e}get _hasTime(){return this.optionsStore.options.display.components.clock&&(this.optionsStore.options.display.components.hours||this.optionsStore.options.display.components.minutes||this.optionsStore.options.display.components.seconds)}get _hasDate(){return this.optionsStore.options.display.components.calendar&&(this.optionsStore.options.display.components.year||this.optionsStore.options.display.components.month||this.optionsStore.options.display.components.date)}get _hasDateAndTime(){return this._hasDate&&this._hasTime}getToolbarElements(){const e=[];if(this.optionsStore.options.display.buttons.today){const t=document.createElement("div");t.setAttribute("data-action",I.today),t.setAttribute("title",this.optionsStore.options.localization.today),t.appendChild(this._iconTag(this.optionsStore.options.display.icons.today)),e.push(t)}if(!this.optionsStore.options.display.sideBySide&&this._hasDate&&this._hasTime){let t,i;"clock"===this.optionsStore.options.display.viewMode?(t=this.optionsStore.options.localization.selectDate,i=this.optionsStore.options.display.icons.date):(t=this.optionsStore.options.localization.selectTime,i=this.optionsStore.options.display.icons.time);const n=document.createElement("div");n.setAttribute("data-action",I.togglePicker),n.setAttribute("title",t),n.appendChild(this._iconTag(i)),e.push(n)}if(this.optionsStore.options.display.buttons.clear){const t=document.createElement("div");t.setAttribute("data-action",I.clear),t.setAttribute("title",this.optionsStore.options.localization.clear),t.appendChild(this._iconTag(this.optionsStore.options.display.icons.clear)),e.push(t)}if(this.optionsStore.options.display.buttons.close){const t=document.createElement("div");t.setAttribute("data-action",I.close),t.setAttribute("title",this.optionsStore.options.localization.close),t.appendChild(this._iconTag(this.optionsStore.options.display.icons.close)),e.push(t)}return e}getHeadTemplate(){const e=document.createElement("div");e.classList.add(n.css.calendarHeader);const t=document.createElement("div");t.classList.add(n.css.previous),t.setAttribute("data-action",I.previous),t.appendChild(this._iconTag(this.optionsStore.options.display.icons.previous));const i=document.createElement("div");i.classList.add(n.css.switch),i.setAttribute("data-action",I.changeCalendarView);const r=document.createElement("div");return r.classList.add(n.css.next),r.setAttribute("data-action",I.next),r.appendChild(this._iconTag(this.optionsStore.options.display.icons.next)),e.append(t,i,r),e}_iconTag(e){if("sprites"===this.optionsStore.options.display.icons.type){const t=document.createElementNS("http://www.w3.org/2000/svg","svg"),i=document.createElementNS("http://www.w3.org/2000/svg","use");return i.setAttribute("xlink:href",e),i.setAttribute("href",e),t.appendChild(i),t}const t=document.createElement("i");return t.classList.add(...e.split(" ")),t}_rebuild(){const e=this._isVisible;this._dispose(),e&&this.show()}refreshCurrentView(){switch(this._isVisible||this._dispose(),this.optionsStore.currentView){case"clock":this._update("clock");break;case"calendar":this._update(e.Unit.date);break;case"months":this._update(e.Unit.month);break;case"years":this._update(e.Unit.year);break;case"decades":this._update("decade")}}}class q{constructor(){this.optionsStore=d.locate(f),this.dates=d.locate(P),this.validation=d.locate(p),this.display=d.locate(U),this._eventEmitters=d.locate(g),this._eventEmitters.action.subscribe((e=>{this.do(e.e,e.action)}))}do(t,i){const r=t?.currentTarget;if(r?.classList?.contains(n.css.disabled))return;i=i||r?.dataset?.action;const a=(this.dates.lastPicked||this.optionsStore.viewDate).clone;switch(i){case I.next:case I.previous:this.handleNextPrevious(i);break;case I.changeCalendarView:this.display._showMode(1),this.display._updateCalendarHeader();break;case I.selectMonth:case I.selectYear:case I.selectDecade:this.handleSelectCalendarMode(i,r);break;case I.selectDay:this.handleSelectDay(r);break;case I.selectHour:{let e=+r.dataset.value;a.hours>=12&&this.optionsStore.isTwelveHour&&(e+=12),a.hours=e,this.dates.setValue(a,this.dates.lastPickedIndex),this.hideOrClock(t);break}case I.selectMinute:a.minutes=+r.dataset.value,this.dates.setValue(a,this.dates.lastPickedIndex),this.hideOrClock(t);break;case I.selectSecond:a.seconds=+r.dataset.value,this.dates.setValue(a,this.dates.lastPickedIndex),this.hideOrClock(t);break;case I.incrementHours:this.manipulateAndSet(a,e.Unit.hours);break;case I.incrementMinutes:this.manipulateAndSet(a,e.Unit.minutes,this.optionsStore.options.stepping);break;case I.incrementSeconds:this.manipulateAndSet(a,e.Unit.seconds);break;case I.decrementHours:this.manipulateAndSet(a,e.Unit.hours,-1);break;case I.decrementMinutes:this.manipulateAndSet(a,e.Unit.minutes,-1*this.optionsStore.options.stepping);break;case I.decrementSeconds:this.manipulateAndSet(a,e.Unit.seconds,-1);break;case I.toggleMeridiem:this.manipulateAndSet(a,e.Unit.hours,this.dates.lastPicked.hours>=12?-12:12);break;case I.togglePicker:this.handleToggle(r);break;case I.showClock:case I.showHours:case I.showMinutes:case I.showSeconds:this.optionsStore.options.display.sideBySide||"clock"===this.optionsStore.currentView||(W.hideImmediately(this.display.dateContainer),W.showImmediately(this.display.timeContainer)),this.handleShowClockContainers(i);break;case I.clear:this.dates.setValue(null),this.display._updateCalendarHeader();break;case I.close:this.display.hide();break;case I.today:{const t=(new c).setLocalization(this.optionsStore.options.localization);this._eventEmitters.updateViewDate.emit(t),this.validation.isValid(t,e.Unit.date)&&this.dates.setValue(t,this.dates.lastPickedIndex);break}}}handleShowClockContainers(t){if(!this.display._hasTime)return void n.errorMessages.throwError("Cannot show clock containers when time is disabled.");this.optionsStore.currentView="clock",this.display.widget.querySelectorAll(`.${n.css.timeContainer} > div`).forEach((e=>e.style.display="none"));let i="";switch(t){case I.showClock:i=n.css.clockContainer,this.display._update("clock");break;case I.showHours:i=n.css.hourContainer,this.display._update(e.Unit.hours);break;case I.showMinutes:i=n.css.minuteContainer,this.display._update(e.Unit.minutes);break;case I.showSeconds:i=n.css.secondContainer,this.display._update(e.Unit.seconds)}this.display.widget.getElementsByClassName(i)[0].style.display="grid"}handleNextPrevious(e){const{unit:t,step:i}=h[this.optionsStore.currentCalendarViewMode];e===I.next?this.optionsStore.viewDate.manipulate(i,t):this.optionsStore.viewDate.manipulate(-1*i,t),this._eventEmitters.viewUpdate.emit(),this.display._showMode()}hideOrClock(e){this.optionsStore.isTwelveHour||this.optionsStore.options.display.components.minutes||this.optionsStore.options.display.keepOpen||this.optionsStore.options.display.inline?this.do(e,I.showClock):this.display.hide()}manipulateAndSet(e,t,i=1){const n=e.manipulate(i,t);this.validation.isValid(n,t)&&this.dates.setValue(n,this.dates.lastPickedIndex)}handleSelectCalendarMode(e,t){const i=+t.dataset.value;switch(e){case I.selectMonth:this.optionsStore.viewDate.month=i;break;case I.selectYear:case I.selectDecade:this.optionsStore.viewDate.year=i}this.optionsStore.currentCalendarViewMode===this.optionsStore.minimumCalendarViewMode?(this.dates.setValue(this.optionsStore.viewDate,this.dates.lastPickedIndex),this.optionsStore.options.display.inline||this.display.hide()):this.display._showMode(-1)}handleToggle(e){e.getAttribute("title")===this.optionsStore.options.localization.selectDate?(e.setAttribute("title",this.optionsStore.options.localization.selectTime),e.innerHTML=this.display._iconTag(this.optionsStore.options.display.icons.time).outerHTML,this.display._updateCalendarHeader(),this.optionsStore.refreshCurrentView()):(e.setAttribute("title",this.optionsStore.options.localization.selectDate),e.innerHTML=this.display._iconTag(this.optionsStore.options.display.icons.date).outerHTML,this.display._hasTime&&(this.handleShowClockContainers(I.showClock),this.display._update("clock"))),this.display.widget.querySelectorAll(`.${n.css.dateContainer}, .${n.css.timeContainer}`).forEach((e=>W.toggle(e))),this._eventEmitters.viewUpdate.emit()}handleSelectDay(t){const i=this.optionsStore.viewDate.clone;t.classList.contains(n.css.old)&&i.manipulate(-1,e.Unit.month),t.classList.contains(n.css.new)&&i.manipulate(1,e.Unit.month),i.date=+t.dataset.day,this.optionsStore.options.dateRange?this.handleDateRange(i):this.optionsStore.options.multipleDates?this.handleMultiDate(i):this.dates.setValue(i,this.dates.lastPickedIndex),this.display._hasTime||this.optionsStore.options.display.keepOpen||this.optionsStore.options.display.inline||this.optionsStore.options.multipleDates||this.optionsStore.options.dateRange||this.display.hide()}handleMultiDate(t){let i=this.dates.pickedIndex(t,e.Unit.date);console.log(i),-1!==i?this.dates.setValue(null,i):(i=this.dates.lastPickedIndex+1,0===this.dates.picked.length&&(i=0),this.dates.setValue(t,i))}handleDateRange(e){switch(this.dates.picked.length){case 2:this.dates.clear();break;case 1:{const t=this.dates.picked[0];if(e.getTime()===t.getTime()){this.dates.clear();break}return e.isBefore(t)?(this.dates.setValue(e,0),void this.dates.setValue(t,1)):void this.dates.setValue(e,1)}}this.dates.setValue(e,0)}}class ${constructor(e,t={}){this._subscribers={},this._isDisabled=!1,this._inputChangeEvent=e=>{const t=e?.detail;if(t)return;const i=()=>{this.dates.lastPicked&&(this.optionsStore.viewDate=this.dates.lastPicked.clone)},n=this.optionsStore.input.value;if(this.optionsStore.options.multipleDates||this.optionsStore.options.dateRange)try{const e=n.split(this.optionsStore.options.multipleDatesSeparator);for(let t=0;t<e.length;t++)this.dates.setFromInput(e[t],t);i()}catch{console.warn("TD: Something went wrong trying to set the multipleDates values from the input field.")}else this.dates.setFromInput(n,0),i()},this._toggleClickEvent=()=>{this.optionsStore.element?.disabled||this.optionsStore.input?.disabled||"INPUT"===this._toggle.nodeName&&"text"===this._toggle?.type&&this.optionsStore.options.allowInputToggle||this.toggle()},this._openClickEvent=()=>{this.optionsStore.element?.disabled||this.optionsStore.input?.disabled||this.display.isVisible||this.show()},d=new u,this._eventEmitters=d.locate(g),this.optionsStore=d.locate(f),this.display=d.locate(U),this.dates=d.locate(P),this.actions=d.locate(q),e||n.errorMessages.mustProvideElement(),this.optionsStore.element=e,this._initializeOptions(t,y,!0),this.optionsStore.viewDate.setLocalization(this.optionsStore.options.localization),this.optionsStore.unset=!0,this._initializeInput(),this._initializeToggle(),this.optionsStore.options.display.inline&&this.display.show(),this._eventEmitters.triggerEvent.subscribe((e=>{this._triggerEvent(e)})),this._eventEmitters.viewUpdate.subscribe((()=>{this._viewUpdate()})),this._eventEmitters.updateViewDate.subscribe((e=>{this.viewDate=e}))}get viewDate(){return this.optionsStore.viewDate}set viewDate(e){this.optionsStore.viewDate=e,this.optionsStore.viewDate.setLocalization(this.optionsStore.options.localization),this.display._update("clock"===this.optionsStore.currentView?"clock":"calendar")}updateOptions(e,t=!1){t?this._initializeOptions(e,y):this._initializeOptions(e,this.optionsStore.options),this.optionsStore.viewDate.setLocalization(this.optionsStore.options.localization),this.display.refreshCurrentView()}toggle(){this._isDisabled||this.display.toggle()}show(){this._isDisabled||this.display.show()}hide(){this.display.hide()}disable(){this._isDisabled=!0,this.optionsStore.input?.setAttribute("disabled","disabled"),this.display.hide()}enable(){this._isDisabled=!1,this.optionsStore.input?.removeAttribute("disabled")}clear(){this.optionsStore.input.value="",this.dates.clear()}subscribe(e,t){let i;"string"==typeof e&&(e=[e]),i=Array.isArray(t)?t:[t],e.length!==i.length&&n.errorMessages.subscribeMismatch();const r=[];for(let t=0;t<e.length;t++){const n=e[t];if(Array.isArray(this._subscribers[n])||(this._subscribers[n]=[]),this._subscribers[n].push(i[t]),r.push({unsubscribe:this._unsubscribe.bind(this,n,this._subscribers[n].length-1)}),1===e.length)return r[0]}return r}dispose(){this.display.hide(),this.display._dispose(),this._eventEmitters.destroy(),this.optionsStore.input?.removeEventListener("change",this._inputChangeEvent),this.optionsStore.options.allowInputToggle&&(this.optionsStore.input?.removeEventListener("click",this._openClickEvent),this.optionsStore.input?.removeEventListener("focus",this._openClickEvent)),this._toggle?.removeEventListener("click",this._toggleClickEvent),this._subscribers={}}locale(e){const t=X[e];t&&this.updateOptions({localization:t})}_triggerEvent(e){e.viewMode=this.optionsStore.currentView;const t=e.type===n.events.change;if(t){const{date:t,oldDate:i,isClear:n}=e;if(t&&i&&t.isSame(i)||!n&&!t&&!i)return;this._handleAfterChangeEvent(e),this.optionsStore.input?.dispatchEvent(new CustomEvent("change",{detail:e}))}if(this.optionsStore.element.dispatchEvent(new CustomEvent(e.type,{detail:e})),window.jQuery){const i=window.jQuery;t&&this.optionsStore.input?i(this.optionsStore.input).trigger(e):i(this.optionsStore.element).trigger(e)}this._publish(e)}_publish(e){Array.isArray(this._subscribers[e.type])&&this._subscribers[e.type].forEach((t=>{t(e)}))}_viewUpdate(){this._triggerEvent({type:n.events.update,viewDate:this.optionsStore.viewDate.clone})}_unsubscribe(e,t){this._subscribers[e].splice(t,1)}_initializeOptions(e,t,i=!1){let n=O.deepCopy(e);n=O._mergeOptions(n,t),i&&(n=O._dataToOptions(this.optionsStore.element,n)),O._validateConflicts(n),n.viewDate=n.viewDate.setLocalization(n.localization),this.optionsStore.viewDate.isSame(n.viewDate)||(this.optionsStore.viewDate=n.viewDate),n.display.components.year&&(this.optionsStore.minimumCalendarViewMode=2),n.display.components.month&&(this.optionsStore.minimumCalendarViewMode=1),n.display.components.date&&(this.optionsStore.minimumCalendarViewMode=0),this.optionsStore.currentCalendarViewMode=Math.max(this.optionsStore.minimumCalendarViewMode,this.optionsStore.currentCalendarViewMode),h[this.optionsStore.currentCalendarViewMode].name!==n.display.viewMode&&(this.optionsStore.currentCalendarViewMode=Math.max(h.findIndex((e=>e.name===n.display.viewMode)),this.optionsStore.minimumCalendarViewMode)),this.display?.isVisible&&this.display._update("all"),n.display.components.useTwentyfourHour&&void 0===n.localization.hourCycle?n.localization.hourCycle="h24":void 0===n.localization.hourCycle&&(n.localization.hourCycle=l(n.localization.locale)),this.optionsStore.options=n,n.restrictions.maxDate&&this.viewDate.isAfter(n.restrictions.maxDate)&&(this.viewDate=n.restrictions.maxDate.clone),n.restrictions.minDate&&this.viewDate.isBefore(n.restrictions.minDate)&&(this.viewDate=n.restrictions.minDate.clone)}_initializeInput(){if("INPUT"==this.optionsStore.element.tagName)this.optionsStore.input=this.optionsStore.element;else{const e=this.optionsStore.element.dataset.tdTargetInput;this.optionsStore.input=null==e||"nearest"==e?this.optionsStore.element.querySelector("input"):this.optionsStore.element.querySelector(e)}this.optionsStore.input&&(!this.optionsStore.input.value&&this.optionsStore.options.defaultDate&&(this.optionsStore.input.value=this.dates.formatInput(this.optionsStore.options.defaultDate)),this.optionsStore.input.addEventListener("change",this._inputChangeEvent),this.optionsStore.options.allowInputToggle&&(this.optionsStore.input.addEventListener("click",this._openClickEvent),this.optionsStore.input.addEventListener("focus",this._openClickEvent)),this.optionsStore.input.value&&this._inputChangeEvent())}_initializeToggle(){if(this.optionsStore.options.display.inline)return;let e=this.optionsStore.element.dataset.tdTargetToggle;"nearest"==e&&(e='[data-td-toggle="datetimepicker"]'),this._toggle=null==e?this.optionsStore.element:this.optionsStore.element.querySelector(e),this._toggle.addEventListener("click",this._toggleClickEvent)}_handleAfterChangeEvent(e){!this.optionsStore.options.promptTimeOnDateChange||this.optionsStore.options.multipleDates||this.optionsStore.options.display.inline||this.optionsStore.options.display.sideBySide||!this.display._hasTime||this.display.widget?.getElementsByClassName(n.css.show)[0].classList.contains(n.css.timeContainer)||!e.oldDate&&this.optionsStore.options.useCurrent||e.oldDate&&e.date?.isSame(e.oldDate)||(clearTimeout(this._currentPromptTimeTimeout),this._currentPromptTimeTimeout=setTimeout((()=>{this.display.widget&&this._eventEmitters.action.emit({e:{currentTarget:this.display.widget.querySelector('[data-action="togglePicker"]')},action:I.togglePicker})}),this.optionsStore.options.promptTimeOnDateChangeTransitionDelay))}}const X={},G=e=>{X[e.name]||(X[e.name]=e.localization)},Z=e=>{const t=X[e];t&&(y.localization=t)},K=function(e,t=void 0){return e?(e.installed||(e(t,{TempusDominus:$,Dates:P,Display:U,DateTime:c,Namespace:n},Q),e.installed=!0),Q):Q},J="6.9.4",Q={TempusDominus:$,extend:K,loadLocale:G,locale:Z,Namespace:n,DefaultOptions:y,DateTime:c,Unit:e.Unit,version:J,DefaultEnLocalization:b};e.DateTime=c,e.DefaultEnLocalization=b,e.DefaultOptions=y,e.Namespace=n,e.TempusDominus=$,e.extend=K,e.loadLocale=G,e.locale=Z,e.version=J,Object.defineProperty(e,"__esModule",{value:!0})})),tempusDominus.DefaultOptions.display.icons={time:"ki-outline ki-time fs-3",date:"ki-outline ki-calendar fs-3",up:"ki-outline ki-up fs-3",down:"ki-outline ki-down fs-3",previous:"ki-outline ki-left fs-3",next:"ki-outline ki-right fs-3",today:"ki-outline ki-calendar-tick fs-3",clear:"ki-outline ki-trash fs-3",close:"ki-outline ki-cross fs-2"},
/*!
  * Tempus Dominus v6.9.4 (https://getdatepicker.com/)
  * Copyright 2013-2024 Jonathan Peterson
  * Licensed under MIT (https://github.com/Eonasdan/tempus-dominus/blob/master/LICENSE)
  */
function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t(((e="undefined"!=typeof globalThis?globalThis:e||self).tempusDominus=e.tempusDominus||{},e.tempusDominus.locales=e.tempusDominus.locales||{},e.tempusDominus.locales.de={}))}(this,(function(e){"use strict";e.localization={today:"Heute",clear:"Auswahl löschen",close:"Auswahlbox schließen",selectMonth:"Monat wählen",previousMonth:"Letzter Monat",nextMonth:"Nächster Monat",selectYear:"Jahr wählen",previousYear:"Letztes Jahr",nextYear:"Nächstes Jahr",selectDecade:"Jahrzehnt wählen",previousDecade:"Letztes Jahrzehnt",nextDecade:"Nächstes Jahrzehnt",previousCentury:"Letztes Jahrhundert",nextCentury:"Nächstes Jahrhundert",pickHour:"Stunde wählen",incrementHour:"Stunde erhöhen",decrementHour:"Stunde verringern",pickMinute:"Minute wählen",incrementMinute:"Minute erhöhen",decrementMinute:"Minute verringern",pickSecond:"Sekunde wählen",incrementSecond:"Sekunde erhöhen",decrementSecond:"Sekunde verringern",toggleMeridiem:"Tageszeit umschalten",selectTime:"Zeit wählen",selectDate:"Datum wählen",dayViewHeaderFormat:{month:"long",year:"2-digit"},locale:"de",startOfTheWeek:1,dateFormats:{LTS:"HH:mm:ss",LT:"HH:mm",L:"dd.MM.yyyy",LL:"d. MMMM yyyy",LLL:"d. MMMM yyyy HH:mm",LLLL:"dddd, d. MMMM yyyy HH:mm"},ordinal:e=>`${e}.`,format:"L LT"},e.name="de",Object.defineProperty(e,"__esModule",{value:!0})})),
/*!
  * Tempus Dominus v6.9.4 (https://getdatepicker.com/)
  * Copyright 2013-2024 Jonathan Peterson
  * Licensed under MIT (https://github.com/Eonasdan/tempus-dominus/blob/master/LICENSE)
  */
function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):((e="undefined"!=typeof globalThis?globalThis:e||self).tempusDominus=e.tempusDominus||{},e.tempusDominus.plugins=e.tempusDominus.plugins||{},e.tempusDominus.plugins.customDateFormat=t())}(this,(function(){"use strict";return()=>{console.warn("This plugin has been merged with the main picker and is now longer required")}})),
/* flatpickr v4.6.13, @license MIT */
function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(e="undefined"!=typeof globalThis?globalThis:e||self).flatpickr=t()}(this,(function(){"use strict";
/*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */var e=function(){return e=Object.assign||function(e){for(var t,i=1,n=arguments.length;i<n;i++)for(var r in t=arguments[i])Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r]);return e},e.apply(this,arguments)};function t(){for(var e=0,t=0,i=arguments.length;t<i;t++)e+=arguments[t].length;var n=Array(e),r=0;for(t=0;t<i;t++)for(var a=arguments[t],s=0,o=a.length;s<o;s++,r++)n[r]=a[s];return n}var i=["onChange","onClose","onDayCreate","onDestroy","onKeyDown","onMonthChange","onOpen","onParseConfig","onReady","onValueUpdate","onYearChange","onPreCalendarPosition"],n={_disable:[],allowInput:!1,allowInvalidPreload:!1,altFormat:"F j, Y",altInput:!1,altInputClass:"form-control input",animate:"object"==typeof window&&-1===window.navigator.userAgent.indexOf("MSIE"),ariaDateFormat:"F j, Y",autoFillDefaultTime:!0,clickOpens:!0,closeOnSelect:!0,conjunction:", ",dateFormat:"Y-m-d",defaultHour:12,defaultMinute:0,defaultSeconds:0,disable:[],disableMobile:!1,enableSeconds:!1,enableTime:!1,errorHandler:function(e){return"undefined"!=typeof console&&console.warn(e)},getWeek:function(e){var t=new Date(e.getTime());t.setHours(0,0,0,0),t.setDate(t.getDate()+3-(t.getDay()+6)%7);var i=new Date(t.getFullYear(),0,4);return 1+Math.round(((t.getTime()-i.getTime())/864e5-3+(i.getDay()+6)%7)/7)},hourIncrement:1,ignoredFocusElements:[],inline:!1,locale:"default",minuteIncrement:5,mode:"single",monthSelectorType:"dropdown",nextArrow:"<svg version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' viewBox='0 0 17 17'><g></g><path d='M13.207 8.472l-7.854 7.854-0.707-0.707 7.146-7.146-7.146-7.148 0.707-0.707 7.854 7.854z' /></svg>",noCalendar:!1,now:new Date,onChange:[],onClose:[],onDayCreate:[],onDestroy:[],onKeyDown:[],onMonthChange:[],onOpen:[],onParseConfig:[],onReady:[],onValueUpdate:[],onYearChange:[],onPreCalendarPosition:[],plugins:[],position:"auto",positionElement:void 0,prevArrow:"<svg version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' viewBox='0 0 17 17'><g></g><path d='M5.207 8.471l7.146 7.147-0.707 0.707-7.853-7.854 7.854-7.853 0.707 0.707-7.147 7.146z' /></svg>",shorthandCurrentMonth:!1,showMonths:1,static:!1,time_24hr:!1,weekNumbers:!1,wrap:!1},r={weekdays:{shorthand:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],longhand:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"]},months:{shorthand:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],longhand:["January","February","March","April","May","June","July","August","September","October","November","December"]},daysInMonth:[31,28,31,30,31,30,31,31,30,31,30,31],firstDayOfWeek:0,ordinal:function(e){var t=e%100;if(t>3&&t<21)return"th";switch(t%10){case 1:return"st";case 2:return"nd";case 3:return"rd";default:return"th"}},rangeSeparator:" to ",weekAbbreviation:"Wk",scrollTitle:"Scroll to increment",toggleTitle:"Click to toggle",amPM:["AM","PM"],yearAriaLabel:"Year",monthAriaLabel:"Month",hourAriaLabel:"Hour",minuteAriaLabel:"Minute",time_24hr:!1},a=function(e,t){return void 0===t&&(t=2),("000"+e).slice(-1*t)},s=function(e){return!0===e?1:0};function o(e,t){var i;return function(){var n=this,r=arguments;clearTimeout(i),i=setTimeout((function(){return e.apply(n,r)}),t)}}var l=function(e){return e instanceof Array?e:[e]};function c(e,t,i){if(!0===i)return e.classList.add(t);e.classList.remove(t)}function u(e,t,i){var n=window.document.createElement(e);return t=t||"",i=i||"",n.className=t,void 0!==i&&(n.textContent=i),n}function d(e){for(;e.firstChild;)e.removeChild(e.firstChild)}function h(e,t){return t(e)?e:e.parentNode?h(e.parentNode,t):void 0}function f(e,t){var i=u("div","numInputWrapper"),n=u("input","numInput "+e),r=u("span","arrowUp"),a=u("span","arrowDown");if(-1===navigator.userAgent.indexOf("MSIE 9.0")?n.type="number":(n.type="text",n.pattern="\\d*"),void 0!==t)for(var s in t)n.setAttribute(s,t[s]);return i.appendChild(n),i.appendChild(r),i.appendChild(a),i}function p(e){try{return"function"==typeof e.composedPath?e.composedPath()[0]:e.target}catch(t){return e.target}}var m=function(){},g=function(e,t,i){return i.months[t?"shorthand":"longhand"][e]},v={D:m,F:function(e,t,i){e.setMonth(i.months.longhand.indexOf(t))},G:function(e,t){e.setHours((e.getHours()>=12?12:0)+parseFloat(t))},H:function(e,t){e.setHours(parseFloat(t))},J:function(e,t){e.setDate(parseFloat(t))},K:function(e,t,i){e.setHours(e.getHours()%12+12*s(new RegExp(i.amPM[1],"i").test(t)))},M:function(e,t,i){e.setMonth(i.months.shorthand.indexOf(t))},S:function(e,t){e.setSeconds(parseFloat(t))},U:function(e,t){return new Date(1e3*parseFloat(t))},W:function(e,t,i){var n=parseInt(t),r=new Date(e.getFullYear(),0,2+7*(n-1),0,0,0,0);return r.setDate(r.getDate()-r.getDay()+i.firstDayOfWeek),r},Y:function(e,t){e.setFullYear(parseFloat(t))},Z:function(e,t){return new Date(t)},d:function(e,t){e.setDate(parseFloat(t))},h:function(e,t){e.setHours((e.getHours()>=12?12:0)+parseFloat(t))},i:function(e,t){e.setMinutes(parseFloat(t))},j:function(e,t){e.setDate(parseFloat(t))},l:m,m:function(e,t){e.setMonth(parseFloat(t)-1)},n:function(e,t){e.setMonth(parseFloat(t)-1)},s:function(e,t){e.setSeconds(parseFloat(t))},u:function(e,t){return new Date(parseFloat(t))},w:m,y:function(e,t){e.setFullYear(2e3+parseFloat(t))}},y={D:"",F:"",G:"(\\d\\d|\\d)",H:"(\\d\\d|\\d)",J:"(\\d\\d|\\d)\\w+",K:"",M:"",S:"(\\d\\d|\\d)",U:"(.+)",W:"(\\d\\d|\\d)",Y:"(\\d{4})",Z:"(.+)",d:"(\\d\\d|\\d)",h:"(\\d\\d|\\d)",i:"(\\d\\d|\\d)",j:"(\\d\\d|\\d)",l:"",m:"(\\d\\d|\\d)",n:"(\\d\\d|\\d)",s:"(\\d\\d|\\d)",u:"(.+)",w:"(\\d\\d|\\d)",y:"(\\d{2})"},b={Z:function(e){return e.toISOString()},D:function(e,t,i){return t.weekdays.shorthand[b.w(e,t,i)]},F:function(e,t,i){return g(b.n(e,t,i)-1,!1,t)},G:function(e,t,i){return a(b.h(e,t,i))},H:function(e){return a(e.getHours())},J:function(e,t){return void 0!==t.ordinal?e.getDate()+t.ordinal(e.getDate()):e.getDate()},K:function(e,t){return t.amPM[s(e.getHours()>11)]},M:function(e,t){return g(e.getMonth(),!0,t)},S:function(e){return a(e.getSeconds())},U:function(e){return e.getTime()/1e3},W:function(e,t,i){return i.getWeek(e)},Y:function(e){return a(e.getFullYear(),4)},d:function(e){return a(e.getDate())},h:function(e){return e.getHours()%12?e.getHours()%12:12},i:function(e){return a(e.getMinutes())},j:function(e){return e.getDate()},l:function(e,t){return t.weekdays.longhand[e.getDay()]},m:function(e){return a(e.getMonth()+1)},n:function(e){return e.getMonth()+1},s:function(e){return e.getSeconds()},u:function(e){return e.getTime()},w:function(e){return e.getDay()},y:function(e){return String(e.getFullYear()).substring(2)}},x=function(e){var t=e.config,i=void 0===t?n:t,a=e.l10n,s=void 0===a?r:a,o=e.isMobile,l=void 0!==o&&o;return function(e,t,n){var r=n||s;return void 0===i.formatDate||l?t.split("").map((function(t,n,a){return b[t]&&"\\"!==a[n-1]?b[t](e,r,i):"\\"!==t?t:""})).join(""):i.formatDate(e,t,r)}},_=function(e){var t=e.config,i=void 0===t?n:t,a=e.l10n,s=void 0===a?r:a;return function(e,t,r,a){if(0===e||e){var o,l=a||s,c=e;if(e instanceof Date)o=new Date(e.getTime());else if("string"!=typeof e&&void 0!==e.toFixed)o=new Date(e);else if("string"==typeof e){var u=t||(i||n).dateFormat,d=String(e).trim();if("today"===d)o=new Date,r=!0;else if(i&&i.parseDate)o=i.parseDate(e,u);else if(/Z$/.test(d)||/GMT$/.test(d))o=new Date(e);else{for(var h=void 0,f=[],p=0,m=0,g="";p<u.length;p++){var b=u[p],x="\\"===b,_="\\"===u[p-1]||x;if(y[b]&&!_){g+=y[b];var w=new RegExp(g).exec(e);w&&(h=!0)&&f["Y"!==b?"push":"unshift"]({fn:v[b],val:w[++m]})}else x||(g+=".")}o=i&&i.noCalendar?new Date((new Date).setHours(0,0,0,0)):new Date((new Date).getFullYear(),0,1,0,0,0,0),f.forEach((function(e){var t=e.fn,i=e.val;return o=t(o,i,l)||o})),o=h?o:void 0}}if(o instanceof Date&&!isNaN(o.getTime()))return!0===r&&o.setHours(0,0,0,0),o;i.errorHandler(new Error("Invalid date provided: "+c))}}};function w(e,t,i){return void 0===i&&(i=!0),!1!==i?new Date(e.getTime()).setHours(0,0,0,0)-new Date(t.getTime()).setHours(0,0,0,0):e.getTime()-t.getTime()}var k=function(e,t,i){return e>Math.min(t,i)&&e<Math.max(t,i)},M=function(e,t,i){return 3600*e+60*t+i},S=function(e){var t=Math.floor(e/3600),i=(e-3600*t)/60;return[t,i,e-3600*t-60*i]},A={DAY:864e5};function L(e){var t=e.defaultHour,i=e.defaultMinute,n=e.defaultSeconds;if(void 0!==e.minDate){var r=e.minDate.getHours(),a=e.minDate.getMinutes(),s=e.minDate.getSeconds();t<r&&(t=r),t===r&&i<a&&(i=a),t===r&&i===a&&n<s&&(n=e.minDate.getSeconds())}if(void 0!==e.maxDate){var o=e.maxDate.getHours(),l=e.maxDate.getMinutes();(t=Math.min(t,o))===o&&(i=Math.min(l,i)),t===o&&i===l&&(n=e.maxDate.getSeconds())}return{hours:t,minutes:i,seconds:n}}"function"!=typeof Object.assign&&(Object.assign=function(e){for(var t=[],i=1;i<arguments.length;i++)t[i-1]=arguments[i];if(!e)throw TypeError("Cannot convert undefined or null to object");for(var n=function(t){t&&Object.keys(t).forEach((function(i){return e[i]=t[i]}))},r=0,a=t;r<a.length;r++){n(a[r])}return e});var T=300;function C(m,v){var b={config:e(e({},n),E.defaultConfig),l10n:r};function C(){var e;return(null===(e=b.calendarContainer)||void 0===e?void 0:e.getRootNode()).activeElement||document.activeElement}function D(e){return e.bind(b)}function O(){var e=b.config;!1===e.weekNumbers&&1===e.showMonths||!0!==e.noCalendar&&window.requestAnimationFrame((function(){if(void 0!==b.calendarContainer&&(b.calendarContainer.style.visibility="hidden",b.calendarContainer.style.display="block"),void 0!==b.daysContainer){var t=(b.days.offsetWidth+1)*e.showMonths;b.daysContainer.style.width=t+"px",b.calendarContainer.style.width=t+(void 0!==b.weekWrapper?b.weekWrapper.offsetWidth:0)+"px",b.calendarContainer.style.removeProperty("visibility"),b.calendarContainer.style.removeProperty("display")}}))}function P(e){if(0===b.selectedDates.length){var t=void 0===b.config.minDate||w(new Date,b.config.minDate)>=0?new Date:new Date(b.config.minDate.getTime()),i=L(b.config);t.setHours(i.hours,i.minutes,i.seconds,t.getMilliseconds()),b.selectedDates=[t],b.latestSelectedDateObj=t}void 0!==e&&"blur"!==e.type&&function(e){e.preventDefault();var t="keydown"===e.type,i=p(e),n=i;void 0!==b.amPM&&i===b.amPM&&(b.amPM.textContent=b.l10n.amPM[s(b.amPM.textContent===b.l10n.amPM[0])]);var r=parseFloat(n.getAttribute("min")),o=parseFloat(n.getAttribute("max")),l=parseFloat(n.getAttribute("step")),c=parseInt(n.value,10),u=e.delta||(t?38===e.which?1:-1:0),d=c+l*u;if(void 0!==n.value&&2===n.value.length){var h=n===b.hourElement,f=n===b.minuteElement;d<r?(d=o+d+s(!h)+(s(h)&&s(!b.amPM)),f&&B(void 0,-1,b.hourElement)):d>o&&(d=n===b.hourElement?d-o-s(!b.amPM):r,f&&B(void 0,1,b.hourElement)),b.amPM&&h&&(1===l?d+c===23:Math.abs(d-c)>l)&&(b.amPM.textContent=b.l10n.amPM[s(b.amPM.textContent===b.l10n.amPM[0])]),n.value=a(d)}}(e);var n=b._input.value;Y(),Ae(),b._input.value!==n&&b._debouncedChange()}function Y(){if(void 0!==b.hourElement&&void 0!==b.minuteElement){var e,t,i=(parseInt(b.hourElement.value.slice(-2),10)||0)%24,n=(parseInt(b.minuteElement.value,10)||0)%60,r=void 0!==b.secondElement?(parseInt(b.secondElement.value,10)||0)%60:0;void 0!==b.amPM&&(e=i,t=b.amPM.textContent,i=e%12+12*s(t===b.l10n.amPM[1]));var a=void 0!==b.config.minTime||b.config.minDate&&b.minDateHasTime&&b.latestSelectedDateObj&&0===w(b.latestSelectedDateObj,b.config.minDate,!0),o=void 0!==b.config.maxTime||b.config.maxDate&&b.maxDateHasTime&&b.latestSelectedDateObj&&0===w(b.latestSelectedDateObj,b.config.maxDate,!0);if(void 0!==b.config.maxTime&&void 0!==b.config.minTime&&b.config.minTime>b.config.maxTime){var l=M(b.config.minTime.getHours(),b.config.minTime.getMinutes(),b.config.minTime.getSeconds()),c=M(b.config.maxTime.getHours(),b.config.maxTime.getMinutes(),b.config.maxTime.getSeconds()),u=M(i,n,r);if(u>c&&u<l){var d=S(l);i=d[0],n=d[1],r=d[2]}}else{if(o){var h=void 0!==b.config.maxTime?b.config.maxTime:b.config.maxDate;(i=Math.min(i,h.getHours()))===h.getHours()&&(n=Math.min(n,h.getMinutes())),n===h.getMinutes()&&(r=Math.min(r,h.getSeconds()))}if(a){var f=void 0!==b.config.minTime?b.config.minTime:b.config.minDate;(i=Math.max(i,f.getHours()))===f.getHours()&&n<f.getMinutes()&&(n=f.getMinutes()),n===f.getMinutes()&&(r=Math.max(r,f.getSeconds()))}}N(i,n,r)}}function I(e){var t=e||b.latestSelectedDateObj;t&&t instanceof Date&&N(t.getHours(),t.getMinutes(),t.getSeconds())}function N(e,t,i){void 0!==b.latestSelectedDateObj&&b.latestSelectedDateObj.setHours(e%24,t,i||0,0),b.hourElement&&b.minuteElement&&!b.isMobile&&(b.hourElement.value=a(b.config.time_24hr?e:(12+e)%12+12*s(e%12==0)),b.minuteElement.value=a(t),void 0!==b.amPM&&(b.amPM.textContent=b.l10n.amPM[s(e>=12)]),void 0!==b.secondElement&&(b.secondElement.value=a(i)))}function j(e){var t=p(e),i=parseInt(t.value)+(e.delta||0);(i/1e3>1||"Enter"===e.key&&!/[^\d]/.test(i.toString()))&&ne(i)}function H(e,t,i,n){return t instanceof Array?t.forEach((function(t){return H(e,t,i,n)})):e instanceof Array?e.forEach((function(e){return H(e,t,i,n)})):(e.addEventListener(t,i,n),void b._handlers.push({remove:function(){return e.removeEventListener(t,i,n)}}))}function F(){_e("onChange")}function R(e,t){var i=void 0!==e?b.parseDate(e):b.latestSelectedDateObj||(b.config.minDate&&b.config.minDate>b.now?b.config.minDate:b.config.maxDate&&b.config.maxDate<b.now?b.config.maxDate:b.now),n=b.currentYear,r=b.currentMonth;try{void 0!==i&&(b.currentYear=i.getFullYear(),b.currentMonth=i.getMonth())}catch(e){e.message="Invalid date supplied: "+i,b.config.errorHandler(e)}t&&b.currentYear!==n&&(_e("onYearChange"),G()),!t||b.currentYear===n&&b.currentMonth===r||_e("onMonthChange"),b.redraw()}function z(e){var t=p(e);~t.className.indexOf("arrow")&&B(e,t.classList.contains("arrowUp")?1:-1)}function B(e,t,i){var n=e&&p(e),r=i||n&&n.parentNode&&n.parentNode.firstChild,a=we("increment");a.delta=t,r&&r.dispatchEvent(a)}function V(e,t,i,n){var r=re(t,!0),a=u("span",e,t.getDate().toString());return a.dateObj=t,a.$i=n,a.setAttribute("aria-label",b.formatDate(t,b.config.ariaDateFormat)),-1===e.indexOf("hidden")&&0===w(t,b.now)&&(b.todayDateElem=a,a.classList.add("today"),a.setAttribute("aria-current","date")),r?(a.tabIndex=-1,ke(t)&&(a.classList.add("selected"),b.selectedDateElem=a,"range"===b.config.mode&&(c(a,"startRange",b.selectedDates[0]&&0===w(t,b.selectedDates[0],!0)),c(a,"endRange",b.selectedDates[1]&&0===w(t,b.selectedDates[1],!0)),"nextMonthDay"===e&&a.classList.add("inRange")))):a.classList.add("flatpickr-disabled"),"range"===b.config.mode&&function(e){return!("range"!==b.config.mode||b.selectedDates.length<2)&&(w(e,b.selectedDates[0])>=0&&w(e,b.selectedDates[1])<=0)}(t)&&!ke(t)&&a.classList.add("inRange"),b.weekNumbers&&1===b.config.showMonths&&"prevMonthDay"!==e&&n%7==6&&b.weekNumbers.insertAdjacentHTML("beforeend","<span class='flatpickr-day'>"+b.config.getWeek(t)+"</span>"),_e("onDayCreate",a),a}function W(e){e.focus(),"range"===b.config.mode&&le(e)}function U(e){for(var t=e>0?0:b.config.showMonths-1,i=e>0?b.config.showMonths:-1,n=t;n!=i;n+=e)for(var r=b.daysContainer.children[n],a=e>0?0:r.children.length-1,s=e>0?r.children.length:-1,o=a;o!=s;o+=e){var l=r.children[o];if(-1===l.className.indexOf("hidden")&&re(l.dateObj))return l}}function q(e,t){var i=C(),n=ae(i||document.body),r=void 0!==e?e:n?i:void 0!==b.selectedDateElem&&ae(b.selectedDateElem)?b.selectedDateElem:void 0!==b.todayDateElem&&ae(b.todayDateElem)?b.todayDateElem:U(t>0?1:-1);void 0===r?b._input.focus():n?function(e,t){for(var i=-1===e.className.indexOf("Month")?e.dateObj.getMonth():b.currentMonth,n=t>0?b.config.showMonths:-1,r=t>0?1:-1,a=i-b.currentMonth;a!=n;a+=r)for(var s=b.daysContainer.children[a],o=i-b.currentMonth===a?e.$i+t:t<0?s.children.length-1:0,l=s.children.length,c=o;c>=0&&c<l&&c!=(t>0?l:-1);c+=r){var u=s.children[c];if(-1===u.className.indexOf("hidden")&&re(u.dateObj)&&Math.abs(e.$i-c)>=Math.abs(t))return W(u)}b.changeMonth(r),q(U(r),0)}(r,t):W(r)}function $(e,t){for(var i=(new Date(e,t,1).getDay()-b.l10n.firstDayOfWeek+7)%7,n=b.utils.getDaysInMonth((t-1+12)%12,e),r=b.utils.getDaysInMonth(t,e),a=window.document.createDocumentFragment(),s=b.config.showMonths>1,o=s?"prevMonthDay hidden":"prevMonthDay",l=s?"nextMonthDay hidden":"nextMonthDay",c=n+1-i,d=0;c<=n;c++,d++)a.appendChild(V("flatpickr-day "+o,new Date(e,t-1,c),0,d));for(c=1;c<=r;c++,d++)a.appendChild(V("flatpickr-day",new Date(e,t,c),0,d));for(var h=r+1;h<=42-i&&(1===b.config.showMonths||d%7!=0);h++,d++)a.appendChild(V("flatpickr-day "+l,new Date(e,t+1,h%r),0,d));var f=u("div","dayContainer");return f.appendChild(a),f}function X(){if(void 0!==b.daysContainer){d(b.daysContainer),b.weekNumbers&&d(b.weekNumbers);for(var e=document.createDocumentFragment(),t=0;t<b.config.showMonths;t++){var i=new Date(b.currentYear,b.currentMonth,1);i.setMonth(b.currentMonth+t),e.appendChild($(i.getFullYear(),i.getMonth()))}b.daysContainer.appendChild(e),b.days=b.daysContainer.firstChild,"range"===b.config.mode&&1===b.selectedDates.length&&le()}}function G(){if(!(b.config.showMonths>1||"dropdown"!==b.config.monthSelectorType)){var e=function(e){return!(void 0!==b.config.minDate&&b.currentYear===b.config.minDate.getFullYear()&&e<b.config.minDate.getMonth())&&!(void 0!==b.config.maxDate&&b.currentYear===b.config.maxDate.getFullYear()&&e>b.config.maxDate.getMonth())};b.monthsDropdownContainer.tabIndex=-1,b.monthsDropdownContainer.innerHTML="";for(var t=0;t<12;t++)if(e(t)){var i=u("option","flatpickr-monthDropdown-month");i.value=new Date(b.currentYear,t).getMonth().toString(),i.textContent=g(t,b.config.shorthandCurrentMonth,b.l10n),i.tabIndex=-1,b.currentMonth===t&&(i.selected=!0),b.monthsDropdownContainer.appendChild(i)}}}function Z(){var e,t=u("div","flatpickr-month"),i=window.document.createDocumentFragment();b.config.showMonths>1||"static"===b.config.monthSelectorType?e=u("span","cur-month"):(b.monthsDropdownContainer=u("select","flatpickr-monthDropdown-months"),b.monthsDropdownContainer.setAttribute("aria-label",b.l10n.monthAriaLabel),H(b.monthsDropdownContainer,"change",(function(e){var t=p(e),i=parseInt(t.value,10);b.changeMonth(i-b.currentMonth),_e("onMonthChange")})),G(),e=b.monthsDropdownContainer);var n=f("cur-year",{tabindex:"-1"}),r=n.getElementsByTagName("input")[0];r.setAttribute("aria-label",b.l10n.yearAriaLabel),b.config.minDate&&r.setAttribute("min",b.config.minDate.getFullYear().toString()),b.config.maxDate&&(r.setAttribute("max",b.config.maxDate.getFullYear().toString()),r.disabled=!!b.config.minDate&&b.config.minDate.getFullYear()===b.config.maxDate.getFullYear());var a=u("div","flatpickr-current-month");return a.appendChild(e),a.appendChild(n),i.appendChild(a),t.appendChild(i),{container:t,yearElement:r,monthElement:e}}function K(){d(b.monthNav),b.monthNav.appendChild(b.prevMonthNav),b.config.showMonths&&(b.yearElements=[],b.monthElements=[]);for(var e=b.config.showMonths;e--;){var t=Z();b.yearElements.push(t.yearElement),b.monthElements.push(t.monthElement),b.monthNav.appendChild(t.container)}b.monthNav.appendChild(b.nextMonthNav)}function J(){b.weekdayContainer?d(b.weekdayContainer):b.weekdayContainer=u("div","flatpickr-weekdays");for(var e=b.config.showMonths;e--;){var t=u("div","flatpickr-weekdaycontainer");b.weekdayContainer.appendChild(t)}return Q(),b.weekdayContainer}function Q(){if(b.weekdayContainer){var e=b.l10n.firstDayOfWeek,i=t(b.l10n.weekdays.shorthand);e>0&&e<i.length&&(i=t(i.splice(e,i.length),i.splice(0,e)));for(var n=b.config.showMonths;n--;)b.weekdayContainer.children[n].innerHTML="\n      <span class='flatpickr-weekday'>\n        "+i.join("</span><span class='flatpickr-weekday'>")+"\n      </span>\n      "}}function ee(e,t){void 0===t&&(t=!0);var i=t?e:e-b.currentMonth;i<0&&!0===b._hidePrevMonthArrow||i>0&&!0===b._hideNextMonthArrow||(b.currentMonth+=i,(b.currentMonth<0||b.currentMonth>11)&&(b.currentYear+=b.currentMonth>11?1:-1,b.currentMonth=(b.currentMonth+12)%12,_e("onYearChange"),G()),X(),_e("onMonthChange"),Me())}function te(e){return b.calendarContainer.contains(e)}function ie(e){if(b.isOpen&&!b.config.inline){var t=p(e),i=te(t),n=!(t===b.input||t===b.altInput||b.element.contains(t)||e.path&&e.path.indexOf&&(~e.path.indexOf(b.input)||~e.path.indexOf(b.altInput)))&&!i&&!te(e.relatedTarget),r=!b.config.ignoredFocusElements.some((function(e){return e.contains(t)}));n&&r&&(b.config.allowInput&&b.setDate(b._input.value,!1,b.config.altInput?b.config.altFormat:b.config.dateFormat),void 0!==b.timeContainer&&void 0!==b.minuteElement&&void 0!==b.hourElement&&""!==b.input.value&&void 0!==b.input.value&&P(),b.close(),b.config&&"range"===b.config.mode&&1===b.selectedDates.length&&b.clear(!1))}}function ne(e){if(!(!e||b.config.minDate&&e<b.config.minDate.getFullYear()||b.config.maxDate&&e>b.config.maxDate.getFullYear())){var t=e,i=b.currentYear!==t;b.currentYear=t||b.currentYear,b.config.maxDate&&b.currentYear===b.config.maxDate.getFullYear()?b.currentMonth=Math.min(b.config.maxDate.getMonth(),b.currentMonth):b.config.minDate&&b.currentYear===b.config.minDate.getFullYear()&&(b.currentMonth=Math.max(b.config.minDate.getMonth(),b.currentMonth)),i&&(b.redraw(),_e("onYearChange"),G())}}function re(e,t){var i;void 0===t&&(t=!0);var n=b.parseDate(e,void 0,t);if(b.config.minDate&&n&&w(n,b.config.minDate,void 0!==t?t:!b.minDateHasTime)<0||b.config.maxDate&&n&&w(n,b.config.maxDate,void 0!==t?t:!b.maxDateHasTime)>0)return!1;if(!b.config.enable&&0===b.config.disable.length)return!0;if(void 0===n)return!1;for(var r=!!b.config.enable,a=null!==(i=b.config.enable)&&void 0!==i?i:b.config.disable,s=0,o=void 0;s<a.length;s++){if("function"==typeof(o=a[s])&&o(n))return r;if(o instanceof Date&&void 0!==n&&o.getTime()===n.getTime())return r;if("string"==typeof o){var l=b.parseDate(o,void 0,!0);return l&&l.getTime()===n.getTime()?r:!r}if("object"==typeof o&&void 0!==n&&o.from&&o.to&&n.getTime()>=o.from.getTime()&&n.getTime()<=o.to.getTime())return r}return!r}function ae(e){return void 0!==b.daysContainer&&(-1===e.className.indexOf("hidden")&&-1===e.className.indexOf("flatpickr-disabled")&&b.daysContainer.contains(e))}function se(e){var t=e.target===b._input,i=b._input.value.trimEnd()!==Se();!t||!i||e.relatedTarget&&te(e.relatedTarget)||b.setDate(b._input.value,!0,e.target===b.altInput?b.config.altFormat:b.config.dateFormat)}function oe(e){var t=p(e),i=b.config.wrap?m.contains(t):t===b._input,n=b.config.allowInput,r=b.isOpen&&(!n||!i),a=b.config.inline&&i&&!n;if(13===e.keyCode&&i){if(n)return b.setDate(b._input.value,!0,t===b.altInput?b.config.altFormat:b.config.dateFormat),b.close(),t.blur();b.open()}else if(te(t)||r||a){var s=!!b.timeContainer&&b.timeContainer.contains(t);switch(e.keyCode){case 13:s?(e.preventDefault(),P(),me()):ge(e);break;case 27:e.preventDefault(),me();break;case 8:case 46:i&&!b.config.allowInput&&(e.preventDefault(),b.clear());break;case 37:case 39:if(s||i)b.hourElement&&b.hourElement.focus();else{e.preventDefault();var o=C();if(void 0!==b.daysContainer&&(!1===n||o&&ae(o))){var l=39===e.keyCode?1:-1;e.ctrlKey?(e.stopPropagation(),ee(l),q(U(1),0)):q(void 0,l)}}break;case 38:case 40:e.preventDefault();var c=40===e.keyCode?1:-1;b.daysContainer&&void 0!==t.$i||t===b.input||t===b.altInput?e.ctrlKey?(e.stopPropagation(),ne(b.currentYear-c),q(U(1),0)):s||q(void 0,7*c):t===b.currentYearElement?ne(b.currentYear-c):b.config.enableTime&&(!s&&b.hourElement&&b.hourElement.focus(),P(e),b._debouncedChange());break;case 9:if(s){var u=[b.hourElement,b.minuteElement,b.secondElement,b.amPM].concat(b.pluginElements).filter((function(e){return e})),d=u.indexOf(t);if(-1!==d){var h=u[d+(e.shiftKey?-1:1)];e.preventDefault(),(h||b._input).focus()}}else!b.config.noCalendar&&b.daysContainer&&b.daysContainer.contains(t)&&e.shiftKey&&(e.preventDefault(),b._input.focus())}}if(void 0!==b.amPM&&t===b.amPM)switch(e.key){case b.l10n.amPM[0].charAt(0):case b.l10n.amPM[0].charAt(0).toLowerCase():b.amPM.textContent=b.l10n.amPM[0],Y(),Ae();break;case b.l10n.amPM[1].charAt(0):case b.l10n.amPM[1].charAt(0).toLowerCase():b.amPM.textContent=b.l10n.amPM[1],Y(),Ae()}(i||te(t))&&_e("onKeyDown",e)}function le(e,t){if(void 0===t&&(t="flatpickr-day"),1===b.selectedDates.length&&(!e||e.classList.contains(t)&&!e.classList.contains("flatpickr-disabled"))){for(var i=e?e.dateObj.getTime():b.days.firstElementChild.dateObj.getTime(),n=b.parseDate(b.selectedDates[0],void 0,!0).getTime(),r=Math.min(i,b.selectedDates[0].getTime()),a=Math.max(i,b.selectedDates[0].getTime()),s=!1,o=0,l=0,c=r;c<a;c+=A.DAY)re(new Date(c),!0)||(s=s||c>r&&c<a,c<n&&(!o||c>o)?o=c:c>n&&(!l||c<l)&&(l=c));Array.from(b.rContainer.querySelectorAll("*:nth-child(-n+"+b.config.showMonths+") > ."+t)).forEach((function(t){var r=t.dateObj.getTime(),a=o>0&&r<o||l>0&&r>l;if(a)return t.classList.add("notAllowed"),void["inRange","startRange","endRange"].forEach((function(e){t.classList.remove(e)}));s&&!a||(["startRange","inRange","endRange","notAllowed"].forEach((function(e){t.classList.remove(e)})),void 0!==e&&(e.classList.add(i<=b.selectedDates[0].getTime()?"startRange":"endRange"),n<i&&r===n?t.classList.add("startRange"):n>i&&r===n&&t.classList.add("endRange"),r>=o&&(0===l||r<=l)&&k(r,n,i)&&t.classList.add("inRange")))}))}}function ce(){!b.isOpen||b.config.static||b.config.inline||fe()}function ue(e){return function(t){var i=b.config["_"+e+"Date"]=b.parseDate(t,b.config.dateFormat),n=b.config["_"+("min"===e?"max":"min")+"Date"];void 0!==i&&(b["min"===e?"minDateHasTime":"maxDateHasTime"]=i.getHours()>0||i.getMinutes()>0||i.getSeconds()>0),b.selectedDates&&(b.selectedDates=b.selectedDates.filter((function(e){return re(e)})),b.selectedDates.length||"min"!==e||I(i),Ae()),b.daysContainer&&(pe(),void 0!==i?b.currentYearElement[e]=i.getFullYear().toString():b.currentYearElement.removeAttribute(e),b.currentYearElement.disabled=!!n&&void 0!==i&&n.getFullYear()===i.getFullYear())}}function de(){return b.config.wrap?m.querySelector("[data-input]"):m}function he(){"object"!=typeof b.config.locale&&void 0===E.l10ns[b.config.locale]&&b.config.errorHandler(new Error("flatpickr: invalid locale "+b.config.locale)),b.l10n=e(e({},E.l10ns.default),"object"==typeof b.config.locale?b.config.locale:"default"!==b.config.locale?E.l10ns[b.config.locale]:void 0),y.D="("+b.l10n.weekdays.shorthand.join("|")+")",y.l="("+b.l10n.weekdays.longhand.join("|")+")",y.M="("+b.l10n.months.shorthand.join("|")+")",y.F="("+b.l10n.months.longhand.join("|")+")",y.K="("+b.l10n.amPM[0]+"|"+b.l10n.amPM[1]+"|"+b.l10n.amPM[0].toLowerCase()+"|"+b.l10n.amPM[1].toLowerCase()+")",void 0===e(e({},v),JSON.parse(JSON.stringify(m.dataset||{}))).time_24hr&&void 0===E.defaultConfig.time_24hr&&(b.config.time_24hr=b.l10n.time_24hr),b.formatDate=x(b),b.parseDate=_({config:b.config,l10n:b.l10n})}function fe(e){if("function"!=typeof b.config.position){if(void 0!==b.calendarContainer){_e("onPreCalendarPosition");var t=e||b._positionElement,i=Array.prototype.reduce.call(b.calendarContainer.children,(function(e,t){return e+t.offsetHeight}),0),n=b.calendarContainer.offsetWidth,r=b.config.position.split(" "),a=r[0],s=r.length>1?r[1]:null,o=t.getBoundingClientRect(),l=window.innerHeight-o.bottom,u="above"===a||"below"!==a&&l<i&&o.top>i,d=window.pageYOffset+o.top+(u?-i-2:t.offsetHeight+2);if(c(b.calendarContainer,"arrowTop",!u),c(b.calendarContainer,"arrowBottom",u),!b.config.inline){var h=window.pageXOffset+o.left,f=!1,p=!1;"center"===s?(h-=(n-o.width)/2,f=!0):"right"===s&&(h-=n-o.width,p=!0),c(b.calendarContainer,"arrowLeft",!f&&!p),c(b.calendarContainer,"arrowCenter",f),c(b.calendarContainer,"arrowRight",p);var m=window.document.body.offsetWidth-(window.pageXOffset+o.right),g=h+n>window.document.body.offsetWidth,v=m+n>window.document.body.offsetWidth;if(c(b.calendarContainer,"rightMost",g),!b.config.static)if(b.calendarContainer.style.top=d+"px",g)if(v){var y=function(){for(var e=null,t=0;t<document.styleSheets.length;t++){var i=document.styleSheets[t];if(i.cssRules){try{i.cssRules}catch(e){continue}e=i;break}}return null!=e?e:(n=document.createElement("style"),document.head.appendChild(n),n.sheet);var n}();if(void 0===y)return;var x=window.document.body.offsetWidth,_=Math.max(0,x/2-n/2),w=y.cssRules.length,k="{left:"+o.left+"px;right:auto;}";c(b.calendarContainer,"rightMost",!1),c(b.calendarContainer,"centerMost",!0),y.insertRule(".flatpickr-calendar.centerMost:before,.flatpickr-calendar.centerMost:after"+k,w),b.calendarContainer.style.left=_+"px",b.calendarContainer.style.right="auto"}else b.calendarContainer.style.left="auto",b.calendarContainer.style.right=m+"px";else b.calendarContainer.style.left=h+"px",b.calendarContainer.style.right="auto"}}}else b.config.position(b,e)}function pe(){b.config.noCalendar||b.isMobile||(G(),Me(),X())}function me(){b._input.focus(),-1!==window.navigator.userAgent.indexOf("MSIE")||void 0!==navigator.msMaxTouchPoints?setTimeout(b.close,0):b.close()}function ge(e){e.preventDefault(),e.stopPropagation();var t=h(p(e),(function(e){return e.classList&&e.classList.contains("flatpickr-day")&&!e.classList.contains("flatpickr-disabled")&&!e.classList.contains("notAllowed")}));if(void 0!==t){var i=t,n=b.latestSelectedDateObj=new Date(i.dateObj.getTime()),r=(n.getMonth()<b.currentMonth||n.getMonth()>b.currentMonth+b.config.showMonths-1)&&"range"!==b.config.mode;if(b.selectedDateElem=i,"single"===b.config.mode)b.selectedDates=[n];else if("multiple"===b.config.mode){var a=ke(n);a?b.selectedDates.splice(parseInt(a),1):b.selectedDates.push(n)}else"range"===b.config.mode&&(2===b.selectedDates.length&&b.clear(!1,!1),b.latestSelectedDateObj=n,b.selectedDates.push(n),0!==w(n,b.selectedDates[0],!0)&&b.selectedDates.sort((function(e,t){return e.getTime()-t.getTime()})));if(Y(),r){var s=b.currentYear!==n.getFullYear();b.currentYear=n.getFullYear(),b.currentMonth=n.getMonth(),s&&(_e("onYearChange"),G()),_e("onMonthChange")}if(Me(),X(),Ae(),r||"range"===b.config.mode||1!==b.config.showMonths?void 0!==b.selectedDateElem&&void 0===b.hourElement&&b.selectedDateElem&&b.selectedDateElem.focus():W(i),void 0!==b.hourElement&&void 0!==b.hourElement&&b.hourElement.focus(),b.config.closeOnSelect){var o="single"===b.config.mode&&!b.config.enableTime,l="range"===b.config.mode&&2===b.selectedDates.length&&!b.config.enableTime;(o||l)&&me()}F()}}b.parseDate=_({config:b.config,l10n:b.l10n}),b._handlers=[],b.pluginElements=[],b.loadedPlugins=[],b._bind=H,b._setHoursFromDate=I,b._positionCalendar=fe,b.changeMonth=ee,b.changeYear=ne,b.clear=function(e,t){void 0===e&&(e=!0);void 0===t&&(t=!0);b.input.value="",void 0!==b.altInput&&(b.altInput.value="");void 0!==b.mobileInput&&(b.mobileInput.value="");b.selectedDates=[],b.latestSelectedDateObj=void 0,!0===t&&(b.currentYear=b._initialDate.getFullYear(),b.currentMonth=b._initialDate.getMonth());if(!0===b.config.enableTime){var i=L(b.config);N(i.hours,i.minutes,i.seconds)}b.redraw(),e&&_e("onChange")},b.close=function(){b.isOpen=!1,b.isMobile||(void 0!==b.calendarContainer&&b.calendarContainer.classList.remove("open"),void 0!==b._input&&b._input.classList.remove("active"));_e("onClose")},b.onMouseOver=le,b._createElement=u,b.createDay=V,b.destroy=function(){void 0!==b.config&&_e("onDestroy");for(var e=b._handlers.length;e--;)b._handlers[e].remove();if(b._handlers=[],b.mobileInput)b.mobileInput.parentNode&&b.mobileInput.parentNode.removeChild(b.mobileInput),b.mobileInput=void 0;else if(b.calendarContainer&&b.calendarContainer.parentNode)if(b.config.static&&b.calendarContainer.parentNode){var t=b.calendarContainer.parentNode;if(t.lastChild&&t.removeChild(t.lastChild),t.parentNode){for(;t.firstChild;)t.parentNode.insertBefore(t.firstChild,t);t.parentNode.removeChild(t)}}else b.calendarContainer.parentNode.removeChild(b.calendarContainer);b.altInput&&(b.input.type="text",b.altInput.parentNode&&b.altInput.parentNode.removeChild(b.altInput),delete b.altInput);b.input&&(b.input.type=b.input._type,b.input.classList.remove("flatpickr-input"),b.input.removeAttribute("readonly"));["_showTimeInput","latestSelectedDateObj","_hideNextMonthArrow","_hidePrevMonthArrow","__hideNextMonthArrow","__hidePrevMonthArrow","isMobile","isOpen","selectedDateElem","minDateHasTime","maxDateHasTime","days","daysContainer","_input","_positionElement","innerContainer","rContainer","monthNav","todayDateElem","calendarContainer","weekdayContainer","prevMonthNav","nextMonthNav","monthsDropdownContainer","currentMonthElement","currentYearElement","navigationCurrentMonth","selectedDateElem","config"].forEach((function(e){try{delete b[e]}catch(e){}}))},b.isEnabled=re,b.jumpToDate=R,b.updateValue=Ae,b.open=function(e,t){void 0===t&&(t=b._positionElement);if(!0===b.isMobile){if(e){e.preventDefault();var i=p(e);i&&i.blur()}return void 0!==b.mobileInput&&(b.mobileInput.focus(),b.mobileInput.click()),void _e("onOpen")}if(b._input.disabled||b.config.inline)return;var n=b.isOpen;b.isOpen=!0,n||(b.calendarContainer.classList.add("open"),b._input.classList.add("active"),_e("onOpen"),fe(t));!0===b.config.enableTime&&!0===b.config.noCalendar&&(!1!==b.config.allowInput||void 0!==e&&b.timeContainer.contains(e.relatedTarget)||setTimeout((function(){return b.hourElement.select()}),50))},b.redraw=pe,b.set=function(e,t){if(null!==e&&"object"==typeof e)for(var n in Object.assign(b.config,e),e)void 0!==ve[n]&&ve[n].forEach((function(e){return e()}));else b.config[e]=t,void 0!==ve[e]?ve[e].forEach((function(e){return e()})):i.indexOf(e)>-1&&(b.config[e]=l(t));b.redraw(),Ae(!0)},b.setDate=function(e,t,i){void 0===t&&(t=!1);void 0===i&&(i=b.config.dateFormat);if(0!==e&&!e||e instanceof Array&&0===e.length)return b.clear(t);ye(e,i),b.latestSelectedDateObj=b.selectedDates[b.selectedDates.length-1],b.redraw(),R(void 0,t),I(),0===b.selectedDates.length&&b.clear(!1);Ae(t),t&&_e("onChange")},b.toggle=function(e){if(!0===b.isOpen)return b.close();b.open(e)};var ve={locale:[he,Q],showMonths:[K,O,J],minDate:[R],maxDate:[R],positionElement:[xe],clickOpens:[function(){!0===b.config.clickOpens?(H(b._input,"focus",b.open),H(b._input,"click",b.open)):(b._input.removeEventListener("focus",b.open),b._input.removeEventListener("click",b.open))}]};function ye(e,t){var i=[];if(e instanceof Array)i=e.map((function(e){return b.parseDate(e,t)}));else if(e instanceof Date||"number"==typeof e)i=[b.parseDate(e,t)];else if("string"==typeof e)switch(b.config.mode){case"single":case"time":i=[b.parseDate(e,t)];break;case"multiple":i=e.split(b.config.conjunction).map((function(e){return b.parseDate(e,t)}));break;case"range":i=e.split(b.l10n.rangeSeparator).map((function(e){return b.parseDate(e,t)}))}else b.config.errorHandler(new Error("Invalid date supplied: "+JSON.stringify(e)));b.selectedDates=b.config.allowInvalidPreload?i:i.filter((function(e){return e instanceof Date&&re(e,!1)})),"range"===b.config.mode&&b.selectedDates.sort((function(e,t){return e.getTime()-t.getTime()}))}function be(e){return e.slice().map((function(e){return"string"==typeof e||"number"==typeof e||e instanceof Date?b.parseDate(e,void 0,!0):e&&"object"==typeof e&&e.from&&e.to?{from:b.parseDate(e.from,void 0),to:b.parseDate(e.to,void 0)}:e})).filter((function(e){return e}))}function xe(){b._positionElement=b.config.positionElement||b._input}function _e(e,t){if(void 0!==b.config){var i=b.config[e];if(void 0!==i&&i.length>0)for(var n=0;i[n]&&n<i.length;n++)i[n](b.selectedDates,b.input.value,b,t);"onChange"===e&&(b.input.dispatchEvent(we("change")),b.input.dispatchEvent(we("input")))}}function we(e){var t=document.createEvent("Event");return t.initEvent(e,!0,!0),t}function ke(e){for(var t=0;t<b.selectedDates.length;t++){var i=b.selectedDates[t];if(i instanceof Date&&0===w(i,e))return""+t}return!1}function Me(){b.config.noCalendar||b.isMobile||!b.monthNav||(b.yearElements.forEach((function(e,t){var i=new Date(b.currentYear,b.currentMonth,1);i.setMonth(b.currentMonth+t),b.config.showMonths>1||"static"===b.config.monthSelectorType?b.monthElements[t].textContent=g(i.getMonth(),b.config.shorthandCurrentMonth,b.l10n)+" ":b.monthsDropdownContainer.value=i.getMonth().toString(),e.value=i.getFullYear().toString()})),b._hidePrevMonthArrow=void 0!==b.config.minDate&&(b.currentYear===b.config.minDate.getFullYear()?b.currentMonth<=b.config.minDate.getMonth():b.currentYear<b.config.minDate.getFullYear()),b._hideNextMonthArrow=void 0!==b.config.maxDate&&(b.currentYear===b.config.maxDate.getFullYear()?b.currentMonth+1>b.config.maxDate.getMonth():b.currentYear>b.config.maxDate.getFullYear()))}function Se(e){var t=e||(b.config.altInput?b.config.altFormat:b.config.dateFormat);return b.selectedDates.map((function(e){return b.formatDate(e,t)})).filter((function(e,t,i){return"range"!==b.config.mode||b.config.enableTime||i.indexOf(e)===t})).join("range"!==b.config.mode?b.config.conjunction:b.l10n.rangeSeparator)}function Ae(e){void 0===e&&(e=!0),void 0!==b.mobileInput&&b.mobileFormatStr&&(b.mobileInput.value=void 0!==b.latestSelectedDateObj?b.formatDate(b.latestSelectedDateObj,b.mobileFormatStr):""),b.input.value=Se(b.config.dateFormat),void 0!==b.altInput&&(b.altInput.value=Se(b.config.altFormat)),!1!==e&&_e("onValueUpdate")}function Le(e){var t=p(e),i=b.prevMonthNav.contains(t),n=b.nextMonthNav.contains(t);i||n?ee(i?-1:1):b.yearElements.indexOf(t)>=0?t.select():t.classList.contains("arrowUp")?b.changeYear(b.currentYear+1):t.classList.contains("arrowDown")&&b.changeYear(b.currentYear-1)}return function(){b.element=b.input=m,b.isOpen=!1,function(){var t=["wrap","weekNumbers","allowInput","allowInvalidPreload","clickOpens","time_24hr","enableTime","noCalendar","altInput","shorthandCurrentMonth","inline","static","enableSeconds","disableMobile"],r=e(e({},JSON.parse(JSON.stringify(m.dataset||{}))),v),a={};b.config.parseDate=r.parseDate,b.config.formatDate=r.formatDate,Object.defineProperty(b.config,"enable",{get:function(){return b.config._enable},set:function(e){b.config._enable=be(e)}}),Object.defineProperty(b.config,"disable",{get:function(){return b.config._disable},set:function(e){b.config._disable=be(e)}});var s="time"===r.mode;if(!r.dateFormat&&(r.enableTime||s)){var o=E.defaultConfig.dateFormat||n.dateFormat;a.dateFormat=r.noCalendar||s?"H:i"+(r.enableSeconds?":S":""):o+" H:i"+(r.enableSeconds?":S":"")}if(r.altInput&&(r.enableTime||s)&&!r.altFormat){var c=E.defaultConfig.altFormat||n.altFormat;a.altFormat=r.noCalendar||s?"h:i"+(r.enableSeconds?":S K":" K"):c+" h:i"+(r.enableSeconds?":S":"")+" K"}Object.defineProperty(b.config,"minDate",{get:function(){return b.config._minDate},set:ue("min")}),Object.defineProperty(b.config,"maxDate",{get:function(){return b.config._maxDate},set:ue("max")});var u=function(e){return function(t){b.config["min"===e?"_minTime":"_maxTime"]=b.parseDate(t,"H:i:S")}};Object.defineProperty(b.config,"minTime",{get:function(){return b.config._minTime},set:u("min")}),Object.defineProperty(b.config,"maxTime",{get:function(){return b.config._maxTime},set:u("max")}),"time"===r.mode&&(b.config.noCalendar=!0,b.config.enableTime=!0);Object.assign(b.config,a,r);for(var d=0;d<t.length;d++)b.config[t[d]]=!0===b.config[t[d]]||"true"===b.config[t[d]];i.filter((function(e){return void 0!==b.config[e]})).forEach((function(e){b.config[e]=l(b.config[e]||[]).map(D)})),b.isMobile=!b.config.disableMobile&&!b.config.inline&&"single"===b.config.mode&&!b.config.disable.length&&!b.config.enable&&!b.config.weekNumbers&&/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);for(d=0;d<b.config.plugins.length;d++){var h=b.config.plugins[d](b)||{};for(var f in h)i.indexOf(f)>-1?b.config[f]=l(h[f]).map(D).concat(b.config[f]):void 0===r[f]&&(b.config[f]=h[f])}r.altInputClass||(b.config.altInputClass=de().className+" "+b.config.altInputClass);_e("onParseConfig")}(),he(),function(){if(b.input=de(),!b.input)return void b.config.errorHandler(new Error("Invalid input element specified"));b.input._type=b.input.type,b.input.type="text",b.input.classList.add("flatpickr-input"),b._input=b.input,b.config.altInput&&(b.altInput=u(b.input.nodeName,b.config.altInputClass),b._input=b.altInput,b.altInput.placeholder=b.input.placeholder,b.altInput.disabled=b.input.disabled,b.altInput.required=b.input.required,b.altInput.tabIndex=b.input.tabIndex,b.altInput.type="text",b.input.setAttribute("type","hidden"),!b.config.static&&b.input.parentNode&&b.input.parentNode.insertBefore(b.altInput,b.input.nextSibling));b.config.allowInput||b._input.setAttribute("readonly","readonly");xe()}(),function(){b.selectedDates=[],b.now=b.parseDate(b.config.now)||new Date;var e=b.config.defaultDate||("INPUT"!==b.input.nodeName&&"TEXTAREA"!==b.input.nodeName||!b.input.placeholder||b.input.value!==b.input.placeholder?b.input.value:null);e&&ye(e,b.config.dateFormat);b._initialDate=b.selectedDates.length>0?b.selectedDates[0]:b.config.minDate&&b.config.minDate.getTime()>b.now.getTime()?b.config.minDate:b.config.maxDate&&b.config.maxDate.getTime()<b.now.getTime()?b.config.maxDate:b.now,b.currentYear=b._initialDate.getFullYear(),b.currentMonth=b._initialDate.getMonth(),b.selectedDates.length>0&&(b.latestSelectedDateObj=b.selectedDates[0]);void 0!==b.config.minTime&&(b.config.minTime=b.parseDate(b.config.minTime,"H:i"));void 0!==b.config.maxTime&&(b.config.maxTime=b.parseDate(b.config.maxTime,"H:i"));b.minDateHasTime=!!b.config.minDate&&(b.config.minDate.getHours()>0||b.config.minDate.getMinutes()>0||b.config.minDate.getSeconds()>0),b.maxDateHasTime=!!b.config.maxDate&&(b.config.maxDate.getHours()>0||b.config.maxDate.getMinutes()>0||b.config.maxDate.getSeconds()>0)}(),b.utils={getDaysInMonth:function(e,t){return void 0===e&&(e=b.currentMonth),void 0===t&&(t=b.currentYear),1===e&&(t%4==0&&t%100!=0||t%400==0)?29:b.l10n.daysInMonth[e]}},b.isMobile||function(){var e=window.document.createDocumentFragment();if(b.calendarContainer=u("div","flatpickr-calendar"),b.calendarContainer.tabIndex=-1,!b.config.noCalendar){if(e.appendChild((b.monthNav=u("div","flatpickr-months"),b.yearElements=[],b.monthElements=[],b.prevMonthNav=u("span","flatpickr-prev-month"),b.prevMonthNav.innerHTML=b.config.prevArrow,b.nextMonthNav=u("span","flatpickr-next-month"),b.nextMonthNav.innerHTML=b.config.nextArrow,K(),Object.defineProperty(b,"_hidePrevMonthArrow",{get:function(){return b.__hidePrevMonthArrow},set:function(e){b.__hidePrevMonthArrow!==e&&(c(b.prevMonthNav,"flatpickr-disabled",e),b.__hidePrevMonthArrow=e)}}),Object.defineProperty(b,"_hideNextMonthArrow",{get:function(){return b.__hideNextMonthArrow},set:function(e){b.__hideNextMonthArrow!==e&&(c(b.nextMonthNav,"flatpickr-disabled",e),b.__hideNextMonthArrow=e)}}),b.currentYearElement=b.yearElements[0],Me(),b.monthNav)),b.innerContainer=u("div","flatpickr-innerContainer"),b.config.weekNumbers){var t=function(){b.calendarContainer.classList.add("hasWeeks");var e=u("div","flatpickr-weekwrapper");e.appendChild(u("span","flatpickr-weekday",b.l10n.weekAbbreviation));var t=u("div","flatpickr-weeks");return e.appendChild(t),{weekWrapper:e,weekNumbers:t}}(),i=t.weekWrapper,n=t.weekNumbers;b.innerContainer.appendChild(i),b.weekNumbers=n,b.weekWrapper=i}b.rContainer=u("div","flatpickr-rContainer"),b.rContainer.appendChild(J()),b.daysContainer||(b.daysContainer=u("div","flatpickr-days"),b.daysContainer.tabIndex=-1),X(),b.rContainer.appendChild(b.daysContainer),b.innerContainer.appendChild(b.rContainer),e.appendChild(b.innerContainer)}b.config.enableTime&&e.appendChild(function(){b.calendarContainer.classList.add("hasTime"),b.config.noCalendar&&b.calendarContainer.classList.add("noCalendar");var e=L(b.config);b.timeContainer=u("div","flatpickr-time"),b.timeContainer.tabIndex=-1;var t=u("span","flatpickr-time-separator",":"),i=f("flatpickr-hour",{"aria-label":b.l10n.hourAriaLabel});b.hourElement=i.getElementsByTagName("input")[0];var n=f("flatpickr-minute",{"aria-label":b.l10n.minuteAriaLabel});b.minuteElement=n.getElementsByTagName("input")[0],b.hourElement.tabIndex=b.minuteElement.tabIndex=-1,b.hourElement.value=a(b.latestSelectedDateObj?b.latestSelectedDateObj.getHours():b.config.time_24hr?e.hours:function(e){switch(e%24){case 0:case 12:return 12;default:return e%12}}(e.hours)),b.minuteElement.value=a(b.latestSelectedDateObj?b.latestSelectedDateObj.getMinutes():e.minutes),b.hourElement.setAttribute("step",b.config.hourIncrement.toString()),b.minuteElement.setAttribute("step",b.config.minuteIncrement.toString()),b.hourElement.setAttribute("min",b.config.time_24hr?"0":"1"),b.hourElement.setAttribute("max",b.config.time_24hr?"23":"12"),b.hourElement.setAttribute("maxlength","2"),b.minuteElement.setAttribute("min","0"),b.minuteElement.setAttribute("max","59"),b.minuteElement.setAttribute("maxlength","2"),b.timeContainer.appendChild(i),b.timeContainer.appendChild(t),b.timeContainer.appendChild(n),b.config.time_24hr&&b.timeContainer.classList.add("time24hr");if(b.config.enableSeconds){b.timeContainer.classList.add("hasSeconds");var r=f("flatpickr-second");b.secondElement=r.getElementsByTagName("input")[0],b.secondElement.value=a(b.latestSelectedDateObj?b.latestSelectedDateObj.getSeconds():e.seconds),b.secondElement.setAttribute("step",b.minuteElement.getAttribute("step")),b.secondElement.setAttribute("min","0"),b.secondElement.setAttribute("max","59"),b.secondElement.setAttribute("maxlength","2"),b.timeContainer.appendChild(u("span","flatpickr-time-separator",":")),b.timeContainer.appendChild(r)}b.config.time_24hr||(b.amPM=u("span","flatpickr-am-pm",b.l10n.amPM[s((b.latestSelectedDateObj?b.hourElement.value:b.config.defaultHour)>11)]),b.amPM.title=b.l10n.toggleTitle,b.amPM.tabIndex=-1,b.timeContainer.appendChild(b.amPM));return b.timeContainer}());c(b.calendarContainer,"rangeMode","range"===b.config.mode),c(b.calendarContainer,"animate",!0===b.config.animate),c(b.calendarContainer,"multiMonth",b.config.showMonths>1),b.calendarContainer.appendChild(e);var r=void 0!==b.config.appendTo&&void 0!==b.config.appendTo.nodeType;if((b.config.inline||b.config.static)&&(b.calendarContainer.classList.add(b.config.inline?"inline":"static"),b.config.inline&&(!r&&b.element.parentNode?b.element.parentNode.insertBefore(b.calendarContainer,b._input.nextSibling):void 0!==b.config.appendTo&&b.config.appendTo.appendChild(b.calendarContainer)),b.config.static)){var o=u("div","flatpickr-wrapper");b.element.parentNode&&b.element.parentNode.insertBefore(o,b.element),o.appendChild(b.element),b.altInput&&o.appendChild(b.altInput),o.appendChild(b.calendarContainer)}b.config.static||b.config.inline||(void 0!==b.config.appendTo?b.config.appendTo:window.document.body).appendChild(b.calendarContainer)}(),function(){b.config.wrap&&["open","close","toggle","clear"].forEach((function(e){Array.prototype.forEach.call(b.element.querySelectorAll("[data-"+e+"]"),(function(t){return H(t,"click",b[e])}))}));if(b.isMobile)return void function(){var e=b.config.enableTime?b.config.noCalendar?"time":"datetime-local":"date";b.mobileInput=u("input",b.input.className+" flatpickr-mobile"),b.mobileInput.tabIndex=1,b.mobileInput.type=e,b.mobileInput.disabled=b.input.disabled,b.mobileInput.required=b.input.required,b.mobileInput.placeholder=b.input.placeholder,b.mobileFormatStr="datetime-local"===e?"Y-m-d\\TH:i:S":"date"===e?"Y-m-d":"H:i:S",b.selectedDates.length>0&&(b.mobileInput.defaultValue=b.mobileInput.value=b.formatDate(b.selectedDates[0],b.mobileFormatStr));b.config.minDate&&(b.mobileInput.min=b.formatDate(b.config.minDate,"Y-m-d"));b.config.maxDate&&(b.mobileInput.max=b.formatDate(b.config.maxDate,"Y-m-d"));b.input.getAttribute("step")&&(b.mobileInput.step=String(b.input.getAttribute("step")));b.input.type="hidden",void 0!==b.altInput&&(b.altInput.type="hidden");try{b.input.parentNode&&b.input.parentNode.insertBefore(b.mobileInput,b.input.nextSibling)}catch(e){}H(b.mobileInput,"change",(function(e){b.setDate(p(e).value,!1,b.mobileFormatStr),_e("onChange"),_e("onClose")}))}();var e=o(ce,50);b._debouncedChange=o(F,T),b.daysContainer&&!/iPhone|iPad|iPod/i.test(navigator.userAgent)&&H(b.daysContainer,"mouseover",(function(e){"range"===b.config.mode&&le(p(e))}));H(b._input,"keydown",oe),void 0!==b.calendarContainer&&H(b.calendarContainer,"keydown",oe);b.config.inline||b.config.static||H(window,"resize",e);void 0!==window.ontouchstart?H(window.document,"touchstart",ie):H(window.document,"mousedown",ie);H(window.document,"focus",ie,{capture:!0}),!0===b.config.clickOpens&&(H(b._input,"focus",b.open),H(b._input,"click",b.open));void 0!==b.daysContainer&&(H(b.monthNav,"click",Le),H(b.monthNav,["keyup","increment"],j),H(b.daysContainer,"click",ge));if(void 0!==b.timeContainer&&void 0!==b.minuteElement&&void 0!==b.hourElement){var t=function(e){return p(e).select()};H(b.timeContainer,["increment"],P),H(b.timeContainer,"blur",P,{capture:!0}),H(b.timeContainer,"click",z),H([b.hourElement,b.minuteElement],["focus","click"],t),void 0!==b.secondElement&&H(b.secondElement,"focus",(function(){return b.secondElement&&b.secondElement.select()})),void 0!==b.amPM&&H(b.amPM,"click",(function(e){P(e)}))}b.config.allowInput&&H(b._input,"blur",se)}(),(b.selectedDates.length||b.config.noCalendar)&&(b.config.enableTime&&I(b.config.noCalendar?b.latestSelectedDateObj:void 0),Ae(!1)),O();var t=/^((?!chrome|android).)*safari/i.test(navigator.userAgent);!b.isMobile&&t&&fe(),_e("onReady")}(),b}function D(e,t){for(var i=Array.prototype.slice.call(e).filter((function(e){return e instanceof HTMLElement})),n=[],r=0;r<i.length;r++){var a=i[r];try{if(null!==a.getAttribute("data-fp-omit"))continue;void 0!==a._flatpickr&&(a._flatpickr.destroy(),a._flatpickr=void 0),a._flatpickr=C(a,t||{}),n.push(a._flatpickr)}catch(e){console.error(e)}}return 1===n.length?n[0]:n}"undefined"!=typeof HTMLElement&&"undefined"!=typeof HTMLCollection&&"undefined"!=typeof NodeList&&(HTMLCollection.prototype.flatpickr=NodeList.prototype.flatpickr=function(e){return D(this,e)},HTMLElement.prototype.flatpickr=function(e){return D([this],e)});var E=function(e,t){return"string"==typeof e?D(window.document.querySelectorAll(e),t):e instanceof Node?D([e],t):D(e,t)};return E.defaultConfig={},E.l10ns={en:e({},r),default:e({},r)},E.localize=function(t){E.l10ns.default=e(e({},E.l10ns.default),t)},E.setDefaults=function(t){E.defaultConfig=e(e({},E.defaultConfig),t)},E.parseDate=_({}),E.formatDate=x({}),E.compareDates=w,"undefined"!=typeof jQuery&&void 0!==jQuery.fn&&(jQuery.fn.flatpickr=function(e){return D(this,e)}),Date.prototype.fp_incr=function(e){return new Date(this.getFullYear(),this.getMonth(),this.getDate()+("string"==typeof e?parseInt(e,10):e))},"undefined"!=typeof window&&(window.flatpickr=E),E})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).ar={})}(this,(function(e){"use strict";var t="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},i={weekdays:{shorthand:["أحد","اثنين","ثلاثاء","أربعاء","خميس","جمعة","سبت"],longhand:["الأحد","الاثنين","الثلاثاء","الأربعاء","الخميس","الجمعة","السبت"]},months:{shorthand:["1","2","3","4","5","6","7","8","9","10","11","12"],longhand:["يناير","فبراير","مارس","أبريل","مايو","يونيو","يوليو","أغسطس","سبتمبر","أكتوبر","نوفمبر","ديسمبر"]},firstDayOfWeek:6,rangeSeparator:" إلى ",weekAbbreviation:"Wk",scrollTitle:"قم بالتمرير للزيادة",toggleTitle:"اضغط للتبديل",amPM:["ص","م"],yearAriaLabel:"سنة",monthAriaLabel:"شهر",hourAriaLabel:"ساعة",minuteAriaLabel:"دقيقة",time_24hr:!1};t.l10ns.ar=i;var n=t.l10ns;e.Arabic=i,e.default=n,Object.defineProperty(e,"__esModule",{value:!0})})),
/*!
 * https://github.com/paulmillr/es6-shim
 * @license es6-shim Copyright 2013-2016 by Paul Miller (http://paulmillr.com)
 *   and contributors,  MIT License
 * es6-shim: v0.35.4
 * see https://github.com/paulmillr/es6-shim/blob/0.35.3/LICENSE
 * Details and documentation:
 * https://github.com/paulmillr/es6-shim/
 */
function(e,t){"function"==typeof define&&define.amd?define(t):"object"==typeof exports?module.exports=t():e.returnExports=t()}(this,(function(){"use strict";var e,t,i=Function.call.bind(Function.apply),n=Function.call.bind(Function.call),r=Array.isArray,a=Object.keys,s=function(e){try{return e(),!1}catch(e){return!0}},o=function(e){try{return e()}catch(e){return!1}},l=(e=s,function(){return!i(e,this,arguments)}),c=!!Object.defineProperty&&!s((function(){return Object.defineProperty({},"x",{get:function(){}})})),u="foo"===function(){}.name,d=Function.call.bind(Array.prototype.forEach),h=Function.call.bind(Array.prototype.reduce),f=Function.call.bind(Array.prototype.filter),p=Function.call.bind(Array.prototype.some),m=function(e,t,i,n){!n&&t in e||(c?Object.defineProperty(e,t,{configurable:!0,enumerable:!1,writable:!0,value:i}):e[t]=i)},g=function(e,t,i){d(a(t),(function(n){var r=t[n];m(e,n,r,!!i)}))},v=Function.call.bind(Object.prototype.toString),y="function"==typeof/abc/?function(e){return"function"==typeof e&&"[object Function]"===v(e)}:function(e){return"function"==typeof e},b=function(e,t,i){if(!c)throw new TypeError("getters require true ES5 support");Object.defineProperty(e,t,{configurable:!0,enumerable:!1,get:i})},x=function(e,t,i){if(!c)throw new TypeError("getters require true ES5 support");var n=Object.getOwnPropertyDescriptor(e,t);Object.defineProperty(i,t,{configurable:n.configurable,enumerable:n.enumerable,get:function(){return e[t]},set:function(i){e[t]=i}})},_=function(e,t,i){if(c){var n=Object.getOwnPropertyDescriptor(e,t);n.value=i,Object.defineProperty(e,t,n)}else e[t]=i},w=function(e,t,i){c?Object.defineProperty(e,t,i):"value"in i&&(e[t]=i.value)},k=function(e,t){t&&y(t.toString)&&m(e,"toString",t.toString.bind(t),!0)},M=Object.create||function(e,t){var i=function(){};i.prototype=e;var n=new i;return void 0!==t&&a(t).forEach((function(e){w(n,e,t[e])})),n},S=function(e,t){return!!Object.setPrototypeOf&&o((function(){var i=function t(i){var n=new e(i);return Object.setPrototypeOf(n,t.prototype),n};return Object.setPrototypeOf(i,e),i.prototype=M(e.prototype,{constructor:{value:i}}),t(i)}))},A=function(){if("undefined"!=typeof self)return self;if("undefined"!=typeof window)return window;if("undefined"!=typeof global)return global;throw new Error("unable to locate global object")}(),L=A.isFinite,T=Function.call.bind(String.prototype.indexOf),C=Function.apply.bind(Array.prototype.indexOf),D=Function.call.bind(Array.prototype.concat),E=Function.call.bind(String.prototype.slice),O=Function.call.bind(Array.prototype.push),P=Function.apply.bind(Array.prototype.push),Y=Function.call.bind(Array.prototype.join),I=Function.call.bind(Array.prototype.shift),N=Math.max,j=Math.min,H=Math.floor,F=Math.abs,R=Math.exp,z=Math.log,B=Math.sqrt,V=Function.call.bind(Object.prototype.hasOwnProperty),W=function(){},U=A.Map,q=U&&U.prototype.delete,$=U&&U.prototype.get,X=U&&U.prototype.has,G=U&&U.prototype.set,Z=A.Symbol||{},K=Z.species||"@@species",J=Number.isNaN||function(e){return e!=e},Q=Number.isFinite||function(e){return"number"==typeof e&&L(e)},ee=y(Math.sign)?Math.sign:function(e){var t=Number(e);return 0===t||J(t)?t:t<0?-1:1},te=function(e){var t=Number(e);return t<-1||J(t)?NaN:0===t||t===1/0?t:-1===t?-1/0:1+t-1==0?t:t*(z(1+t)/(1+t-1))},ie=function(e){return"[object Arguments]"===v(e)},ne=ie(arguments)?ie:function(e){return null!==e&&"object"==typeof e&&"number"==typeof e.length&&e.length>=0&&"[object Array]"!==v(e)&&"[object Function]"===v(e.callee)},re=function(e){return null===e||"function"!=typeof e&&"object"!=typeof e},ae=function(e){return"[object String]"===v(e)},se=function(e){return"[object RegExp]"===v(e)},oe=function(e){return"function"==typeof A.Symbol&&"symbol"==typeof e},le=function(e,t,i){var n=e[t];m(e,t,i,!0),k(e[t],n)},ce="function"==typeof Z&&"function"==typeof Z.for&&oe(Z()),ue=oe(Z.iterator)?Z.iterator:"_es6-shim iterator_";A.Set&&"function"==typeof(new A.Set)["@@iterator"]&&(ue="@@iterator"),A.Reflect||m(A,"Reflect",{},!0);var de,he=A.Reflect,fe=String,pe="undefined"!=typeof document&&document?document.all:null,me=null==pe?function(e){return null==e}:function(e){return null==e&&e!==pe},ge={Call:function(e,t){var n=arguments.length>2?arguments[2]:[];if(!ge.IsCallable(e))throw new TypeError(e+" is not a function");return i(e,t,n)},RequireObjectCoercible:function(e,t){if(me(e))throw new TypeError(t||"Cannot call method on "+e);return e},TypeIsObject:function(e){return null!=e&&!0!==e&&!1!==e&&("function"==typeof e||"object"==typeof e||e===pe)},ToObject:function(e,t){return Object(ge.RequireObjectCoercible(e,t))},IsCallable:y,IsConstructor:function(e){return ge.IsCallable(e)},ToInt32:function(e){return ge.ToNumber(e)|0},ToUint32:function(e){return ge.ToNumber(e)>>>0},ToNumber:function(e){if(ce&&"[object Symbol]"===v(e))throw new TypeError("Cannot convert a Symbol value to a number");return+e},ToInteger:function(e){var t=ge.ToNumber(e);return J(t)?0:0!==t&&Q(t)?(t>0?1:-1)*H(F(t)):t},ToLength:function(e){var t=ge.ToInteger(e);return t<=0?0:t>Number.MAX_SAFE_INTEGER?Number.MAX_SAFE_INTEGER:t},SameValue:function(e,t){return e===t?0!==e||1/e==1/t:J(e)&&J(t)},SameValueZero:function(e,t){return e===t||J(e)&&J(t)},GetIterator:function(e){if(ne(e))return new t(e,"value");var i=ge.GetMethod(e,ue);if(!ge.IsCallable(i))throw new TypeError("value is not an iterable");var n=ge.Call(i,e);if(!ge.TypeIsObject(n))throw new TypeError("bad iterator");return n},GetMethod:function(e,t){var i=ge.ToObject(e)[t];if(!me(i)){if(!ge.IsCallable(i))throw new TypeError("Method not callable: "+t);return i}},IteratorComplete:function(e){return!!e.done},IteratorClose:function(e,t){var i=ge.GetMethod(e,"return");if(void 0!==i){var n,r;try{n=ge.Call(i,e)}catch(e){r=e}if(!t){if(r)throw r;if(!ge.TypeIsObject(n))throw new TypeError("Iterator's return method returned a non-object.")}}},IteratorNext:function(e){var t=arguments.length>1?e.next(arguments[1]):e.next();if(!ge.TypeIsObject(t))throw new TypeError("bad iterator");return t},IteratorStep:function(e){var t=ge.IteratorNext(e);return!ge.IteratorComplete(t)&&t},Construct:function(e,t,i,n){var r=void 0===i?e:i;if(!n&&he.construct)return he.construct(e,t,r);var a=r.prototype;ge.TypeIsObject(a)||(a=Object.prototype);var s=M(a),o=ge.Call(e,s,t);return ge.TypeIsObject(o)?o:s},SpeciesConstructor:function(e,t){var i=e.constructor;if(void 0===i)return t;if(!ge.TypeIsObject(i))throw new TypeError("Bad constructor");var n=i[K];if(me(n))return t;if(!ge.IsConstructor(n))throw new TypeError("Bad @@species");return n},CreateHTML:function(e,t,i,n){var r=ge.ToString(e),a="<"+t;""!==i&&(a+=" "+i+'="'+ge.ToString(n).replace(/"/g,"&quot;")+'"');return a+">"+r+"</"+t+">"},IsRegExp:function(e){if(!ge.TypeIsObject(e))return!1;var t=e[Z.match];return void 0!==t?!!t:se(e)},ToString:function(e){if(ce&&"[object Symbol]"===v(e))throw new TypeError("Cannot convert a Symbol value to a number");return fe(e)}};if(c&&ce){var ve=function(e){if(oe(Z[e]))return Z[e];var t=Z.for("Symbol."+e);return Object.defineProperty(Z,e,{configurable:!1,enumerable:!1,writable:!1,value:t}),t};if(!oe(Z.search)){var ye=ve("search"),be=String.prototype.search;m(RegExp.prototype,ye,(function(e){return ge.Call(be,e,[this])}));le(String.prototype,"search",(function(e){var t=ge.RequireObjectCoercible(this);if(!me(e)){var i=ge.GetMethod(e,ye);if(void 0!==i)return ge.Call(i,e,[t])}return ge.Call(be,t,[ge.ToString(e)])}))}if(!oe(Z.replace)){var xe=ve("replace"),_e=String.prototype.replace;m(RegExp.prototype,xe,(function(e,t){return ge.Call(_e,e,[this,t])}));le(String.prototype,"replace",(function(e,t){var i=ge.RequireObjectCoercible(this);if(!me(e)){var n=ge.GetMethod(e,xe);if(void 0!==n)return ge.Call(n,e,[i,t])}return ge.Call(_e,i,[ge.ToString(e),t])}))}if(!oe(Z.split)){var we=ve("split"),ke=String.prototype.split;m(RegExp.prototype,we,(function(e,t){return ge.Call(ke,e,[this,t])}));le(String.prototype,"split",(function(e,t){var i=ge.RequireObjectCoercible(this);if(!me(e)){var n=ge.GetMethod(e,we);if(void 0!==n)return ge.Call(n,e,[i,t])}return ge.Call(ke,i,[ge.ToString(e),t])}))}var Me=oe(Z.match),Se=Me&&((de={})[Z.match]=function(){return 42},42!=="a".match(de));if(!Me||Se){var Ae=ve("match"),Le=String.prototype.match;m(RegExp.prototype,Ae,(function(e){return ge.Call(Le,e,[this])}));le(String.prototype,"match",(function(e){var t=ge.RequireObjectCoercible(this);if(!me(e)){var i=ge.GetMethod(e,Ae);if(void 0!==i)return ge.Call(i,e,[t])}return ge.Call(Le,t,[ge.ToString(e)])}))}}var Te=function(e,t,i){k(t,e),Object.setPrototypeOf&&Object.setPrototypeOf(e,t),c?d(Object.getOwnPropertyNames(e),(function(n){n in W||i[n]||x(e,n,t)})):d(Object.keys(e),(function(n){n in W||i[n]||(t[n]=e[n])})),t.prototype=e.prototype,_(e.prototype,"constructor",t)},Ce=function(){return this},De=function(e){c&&!V(e,K)&&b(e,K,Ce)},Ee=function(e,t){var i=t||function(){return this};m(e,ue,i),!e[ue]&&oe(ue)&&(e[ue]=i)},Oe=function(e,t,i){if(function(e,t,i){c?Object.defineProperty(e,t,{configurable:!0,enumerable:!0,writable:!0,value:i}):e[t]=i}(e,t,i),!ge.SameValue(e[t],i))throw new TypeError("property is nonconfigurable")},Pe=function(e,t,i,n){if(!ge.TypeIsObject(e))throw new TypeError("Constructor requires `new`: "+t.name);var r=t.prototype;ge.TypeIsObject(r)||(r=i);var a=M(r);for(var s in n)if(V(n,s)){var o=n[s];m(a,s,o,!0)}return a};if(String.fromCodePoint&&1!==String.fromCodePoint.length){var Ye=String.fromCodePoint;le(String,"fromCodePoint",(function(e){return ge.Call(Ye,this,arguments)}))}var Ie={fromCodePoint:function(e){for(var t,i=[],n=0,r=arguments.length;n<r;n++){if(t=Number(arguments[n]),!ge.SameValue(t,ge.ToInteger(t))||t<0||t>1114111)throw new RangeError("Invalid code point "+t);t<65536?O(i,String.fromCharCode(t)):(t-=65536,O(i,String.fromCharCode(55296+(t>>10))),O(i,String.fromCharCode(t%1024+56320)))}return Y(i,"")},raw:function(e){var t=ge.ToObject(e,"bad template"),i=ge.ToObject(t.raw,"bad raw value"),n=i.length,r=ge.ToLength(n);if(r<=0)return"";for(var a,s,o,l,c=[],u=0;u<r&&(a=ge.ToString(u),o=ge.ToString(i[a]),O(c,o),!(u+1>=r));)s=u+1<arguments.length?arguments[u+1]:"",l=ge.ToString(s),O(c,l),u+=1;return Y(c,"")}};String.raw&&"xy"!==String.raw({raw:{0:"x",1:"y",length:2}})&&le(String,"raw",Ie.raw),g(String,Ie);var Ne=function e(t,i){if(i<1)return"";if(i%2)return e(t,i-1)+t;var n=e(t,i/2);return n+n},je=1/0,He={repeat:function(e){var t=ge.ToString(ge.RequireObjectCoercible(this)),i=ge.ToInteger(e);if(i<0||i>=je)throw new RangeError("repeat count must be less than infinity and not overflow maximum string size");return Ne(t,i)},startsWith:function(e){var t=ge.ToString(ge.RequireObjectCoercible(this));if(ge.IsRegExp(e))throw new TypeError('Cannot call method "startsWith" with a regex');var i,n=ge.ToString(e);arguments.length>1&&(i=arguments[1]);var r=N(ge.ToInteger(i),0);return E(t,r,r+n.length)===n},endsWith:function(e){var t=ge.ToString(ge.RequireObjectCoercible(this));if(ge.IsRegExp(e))throw new TypeError('Cannot call method "endsWith" with a regex');var i,n=ge.ToString(e),r=t.length;arguments.length>1&&(i=arguments[1]);var a=void 0===i?r:ge.ToInteger(i),s=j(N(a,0),r);return E(t,s-n.length,s)===n},includes:function(e){if(ge.IsRegExp(e))throw new TypeError('"includes" does not accept a RegExp');var t,i=ge.ToString(e);return arguments.length>1&&(t=arguments[1]),-1!==T(this,i,t)},codePointAt:function(e){var t=ge.ToString(ge.RequireObjectCoercible(this)),i=ge.ToInteger(e),n=t.length;if(i>=0&&i<n){var r=t.charCodeAt(i);if(r<55296||r>56319||i+1===n)return r;var a=t.charCodeAt(i+1);return a<56320||a>57343?r:1024*(r-55296)+(a-56320)+65536}}};if(String.prototype.includes&&!1!=="a".includes("a",1/0)&&le(String.prototype,"includes",He.includes),String.prototype.startsWith&&String.prototype.endsWith){var Fe=s((function(){return"/a/".startsWith(/a/)})),Re=o((function(){return!1==="abc".startsWith("a",1/0)}));Fe&&Re||(le(String.prototype,"startsWith",He.startsWith),le(String.prototype,"endsWith",He.endsWith))}ce&&(o((function(){var e=/a/;return e[Z.match]=!1,"/a/".startsWith(e)}))||le(String.prototype,"startsWith",He.startsWith),o((function(){var e=/a/;return e[Z.match]=!1,"/a/".endsWith(e)}))||le(String.prototype,"endsWith",He.endsWith),o((function(){var e=/a/;return e[Z.match]=!1,"/a/".includes(e)}))||le(String.prototype,"includes",He.includes));g(String.prototype,He);var ze=["\t\n\v\f\r   ᠎    ","         　\u2028","\u2029\ufeff"].join(""),Be=new RegExp("(^["+ze+"]+)|(["+ze+"]+$)","g"),Ve=function(){return ge.ToString(ge.RequireObjectCoercible(this)).replace(Be,"")},We=["","​",""].join(""),Ue=new RegExp("["+We+"]","g"),qe=/^[-+]0x[0-9a-f]+$/i,$e=We.trim().length!==We.length;m(String.prototype,"trim",Ve,$e);var Xe=function(e){return{value:e,done:0===arguments.length}},Ge=function(e){ge.RequireObjectCoercible(e),m(this,"_s",ge.ToString(e)),m(this,"_i",0)};Ge.prototype.next=function(){var e=this._s,t=this._i;if(void 0===e||t>=e.length)return this._s=void 0,Xe();var i,n,r=e.charCodeAt(t);return n=r<55296||r>56319||t+1===e.length||(i=e.charCodeAt(t+1))<56320||i>57343?1:2,this._i=t+n,Xe(e.substr(t,n))},Ee(Ge.prototype),Ee(String.prototype,(function(){return new Ge(this)}));var Ze={from:function(e){var t,i,r,a,s,o,l=this;if(arguments.length>1&&(t=arguments[1]),void 0===t)i=!1;else{if(!ge.IsCallable(t))throw new TypeError("Array.from: when provided, the second argument must be a function");arguments.length>2&&(r=arguments[2]),i=!0}if(void 0!==(ne(e)||ge.GetMethod(e,ue))){s=ge.IsConstructor(l)?Object(new l):[];var c,u,d=ge.GetIterator(e);for(o=0;!1!==(c=ge.IteratorStep(d));){u=c.value;try{i&&(u=void 0===r?t(u,o):n(t,r,u,o)),s[o]=u}catch(e){throw ge.IteratorClose(d,!0),e}o+=1}a=o}else{var h,f=ge.ToObject(e);for(a=ge.ToLength(f.length),s=ge.IsConstructor(l)?Object(new l(a)):new Array(a),o=0;o<a;++o)h=f[o],i&&(h=void 0===r?t(h,o):n(t,r,h,o)),Oe(s,o,h)}return s.length=a,s},of:function(){for(var e=arguments.length,t=this,i=r(t)||!ge.IsCallable(t)?new Array(e):ge.Construct(t,[e]),n=0;n<e;++n)Oe(i,n,arguments[n]);return i.length=e,i}};g(Array,Ze),De(Array),g((t=function(e,t){m(this,"i",0),m(this,"array",e),m(this,"kind",t)}).prototype,{next:function(){var e=this.i,i=this.array;if(!(this instanceof t))throw new TypeError("Not an ArrayIterator");if(void 0!==i&&e<ge.ToLength(i.length)){var n,r=this.kind;return"key"===r?n=e:"value"===r?n=i[e]:"entry"===r&&(n=[e,i[e]]),this.i=e+1,Xe(n)}return this.array=void 0,Xe()}}),Ee(t.prototype),Array.of===Ze.of||function(){var e=function(e){this.length=e};e.prototype=[];var t=Array.of.apply(e,[1,2]);return t instanceof e&&2===t.length}()||le(Array,"of",Ze.of);var Ke={copyWithin:function(e,t){var i,n=ge.ToObject(this),r=ge.ToLength(n.length),a=ge.ToInteger(e),s=ge.ToInteger(t),o=a<0?N(r+a,0):j(a,r),l=s<0?N(r+s,0):j(s,r);arguments.length>2&&(i=arguments[2]);var c=void 0===i?r:ge.ToInteger(i),u=c<0?N(r+c,0):j(c,r),d=j(u-l,r-o),h=1;for(l<o&&o<l+d&&(h=-1,l+=d-1,o+=d-1);d>0;)l in n?n[o]=n[l]:delete n[o],l+=h,o+=h,d-=1;return n},fill:function(e){var t,i;arguments.length>1&&(t=arguments[1]),arguments.length>2&&(i=arguments[2]);var n=ge.ToObject(this),r=ge.ToLength(n.length);t=ge.ToInteger(void 0===t?0:t);for(var a=(i=ge.ToInteger(void 0===i?r:i))<0?r+i:i,s=t<0?N(r+t,0):j(t,r);s<r&&s<a;++s)n[s]=e;return n},find:function(e){var t=ge.ToObject(this),i=ge.ToLength(t.length);if(!ge.IsCallable(e))throw new TypeError("Array#find: predicate must be a function");for(var r,a=arguments.length>1?arguments[1]:null,s=0;s<i;s++)if(r=t[s],a){if(n(e,a,r,s,t))return r}else if(e(r,s,t))return r},findIndex:function(e){var t=ge.ToObject(this),i=ge.ToLength(t.length);if(!ge.IsCallable(e))throw new TypeError("Array#findIndex: predicate must be a function");for(var r=arguments.length>1?arguments[1]:null,a=0;a<i;a++)if(r){if(n(e,r,t[a],a,t))return a}else if(e(t[a],a,t))return a;return-1},keys:function(){return new t(this,"key")},values:function(){return new t(this,"value")},entries:function(){return new t(this,"entry")}};if(Array.prototype.keys&&!ge.IsCallable([1].keys().next)&&delete Array.prototype.keys,Array.prototype.entries&&!ge.IsCallable([1].entries().next)&&delete Array.prototype.entries,Array.prototype.keys&&Array.prototype.entries&&!Array.prototype.values&&Array.prototype[ue]&&(g(Array.prototype,{values:Array.prototype[ue]}),oe(Z.unscopables)&&(Array.prototype[Z.unscopables].values=!0)),u&&Array.prototype.values&&"values"!==Array.prototype.values.name){var Je=Array.prototype.values;le(Array.prototype,"values",(function(){return ge.Call(Je,this,arguments)})),m(Array.prototype,ue,Array.prototype.values,!0)}if(g(Array.prototype,Ke),1/[!0].indexOf(!0,-0)<0&&m(Array.prototype,"indexOf",(function(e){var t=C(this,arguments);return 0===t&&1/t<0?0:t}),!0),Ee(Array.prototype,(function(){return this.values()})),Object.getPrototypeOf){var Qe=Object.getPrototypeOf([].values());Qe&&Ee(Qe)}var et,tt=o((function(){return 0===Array.from({length:-1}).length})),it=1===(et=Array.from([0].entries())).length&&r(et[0])&&0===et[0][0]&&0===et[0][1];if(tt&&it||le(Array,"from",Ze.from),!o((function(){return Array.from([0],void 0)}))){var nt=Array.from;le(Array,"from",(function(e){return arguments.length>1&&void 0!==arguments[1]?ge.Call(nt,this,arguments):n(nt,this,e)}))}var rt=-(Math.pow(2,32)-1),at=function(e,t){var i={length:rt};return i[t?(i.length>>>0)-1:0]=!0,o((function(){return n(e,i,(function(){throw new RangeError("should not reach here")}),[]),!0}))};if(!at(Array.prototype.forEach)){var st=Array.prototype.forEach;le(Array.prototype,"forEach",(function(e){return ge.Call(st,this.length>=0?this:[],arguments)}))}if(!at(Array.prototype.map)){var ot=Array.prototype.map;le(Array.prototype,"map",(function(e){return ge.Call(ot,this.length>=0?this:[],arguments)}))}if(!at(Array.prototype.filter)){var lt=Array.prototype.filter;le(Array.prototype,"filter",(function(e){return ge.Call(lt,this.length>=0?this:[],arguments)}))}if(!at(Array.prototype.some)){var ct=Array.prototype.some;le(Array.prototype,"some",(function(e){return ge.Call(ct,this.length>=0?this:[],arguments)}))}if(!at(Array.prototype.every)){var ut=Array.prototype.every;le(Array.prototype,"every",(function(e){return ge.Call(ut,this.length>=0?this:[],arguments)}))}if(!at(Array.prototype.reduce)){var dt=Array.prototype.reduce;le(Array.prototype,"reduce",(function(e){return ge.Call(dt,this.length>=0?this:[],arguments)}))}if(!at(Array.prototype.reduceRight,!0)){var ht=Array.prototype.reduceRight;le(Array.prototype,"reduceRight",(function(e){return ge.Call(ht,this.length>=0?this:[],arguments)}))}var ft=8!==Number("0o10"),pt=2!==Number("0b10"),mt=p(We,(function(e){return 0===Number(e+0+e)}));if(ft||pt||mt){var gt=Number,vt=/^0b[01]+$/i,yt=/^0o[0-7]+$/i,bt=vt.test.bind(vt),xt=yt.test.bind(yt),_t=Ue.test.bind(Ue),wt=qe.test.bind(qe),kt=function(){var e=function(t){var i;"string"==typeof(i=arguments.length>0?re(t)?t:function(e,t){var i;if("function"==typeof e.valueOf&&(i=e.valueOf(),re(i)))return i;if("function"==typeof e.toString&&(i=e.toString(),re(i)))return i;throw new TypeError("No default value")}(t):0)&&(i=ge.Call(Ve,i),bt(i)?i=parseInt(E(i,2),2):xt(i)?i=parseInt(E(i,2),8):(_t(i)||wt(i))&&(i=NaN));var n=this,r=o((function(){return gt.prototype.valueOf.call(n),!0}));return n instanceof e&&!r?new gt(i):gt(i)};return e}();Te(gt,kt,{}),g(kt,{NaN:gt.NaN,MAX_VALUE:gt.MAX_VALUE,MIN_VALUE:gt.MIN_VALUE,NEGATIVE_INFINITY:gt.NEGATIVE_INFINITY,POSITIVE_INFINITY:gt.POSITIVE_INFINITY}),Number=kt,_(A,"Number",kt)}var Mt=Math.pow(2,53)-1;g(Number,{MAX_SAFE_INTEGER:Mt,MIN_SAFE_INTEGER:-Mt,EPSILON:2220446049250313e-31,parseInt:A.parseInt,parseFloat:A.parseFloat,isFinite:Q,isInteger:function(e){return Q(e)&&ge.ToInteger(e)===e},isSafeInteger:function(e){return Number.isInteger(e)&&F(e)<=Number.MAX_SAFE_INTEGER},isNaN:J}),m(Number,"parseInt",A.parseInt,Number.parseInt!==A.parseInt),1===[,1].find((function(){return!0}))&&le(Array.prototype,"find",Ke.find),0!==[,1].findIndex((function(){return!0}))&&le(Array.prototype,"findIndex",Ke.findIndex);var St,At,Lt,Tt=Function.bind.call(Function.bind,Object.prototype.propertyIsEnumerable),Ct=function(e,t){c&&Tt(e,t)&&Object.defineProperty(e,t,{enumerable:!1})},Dt=function(){for(var e=Number(this),t=arguments.length,i=t-e,n=new Array(i<0?0:i),r=e;r<t;++r)n[r-e]=arguments[r];return n},Et=function(e){return function(t,i){return t[i]=e[i],t}},Ot=function(e,t){var i,n=a(Object(t));return ge.IsCallable(Object.getOwnPropertySymbols)&&(i=f(Object.getOwnPropertySymbols(Object(t)),Tt(t))),h(D(n,i||[]),Et(t),e)},Pt={assign:function(e,t){var i=ge.ToObject(e,"Cannot convert undefined or null to object");return h(ge.Call(Dt,1,arguments),Ot,i)},is:function(e,t){return ge.SameValue(e,t)}};if(Object.assign&&Object.preventExtensions&&function(){var e=Object.preventExtensions({1:2});try{Object.assign(e,"xy")}catch(t){return"y"===e[1]}}()&&le(Object,"assign",Pt.assign),g(Object,Pt),c){var Yt={setPrototypeOf:function(e){var t,i=function(e,i){return function(e,t){if(!ge.TypeIsObject(e))throw new TypeError("cannot set prototype on a non-object");if(null!==t&&!ge.TypeIsObject(t))throw new TypeError("can only set prototype to an object or null"+t)}(e,i),n(t,e,i),e};try{t=e.getOwnPropertyDescriptor(e.prototype,"__proto__").set,n(t,{},null)}catch(n){if(e.prototype!=={}.__proto__)return;t=function(e){this.__proto__=e},i.polyfill=i(i({},null),e.prototype)instanceof e}return i}(Object)};g(Object,Yt)}if(Object.setPrototypeOf&&Object.getPrototypeOf&&null!==Object.getPrototypeOf(Object.setPrototypeOf({},null))&&null===Object.getPrototypeOf(Object.create(null))&&(St=Object.create(null),At=Object.getPrototypeOf,Lt=Object.setPrototypeOf,Object.getPrototypeOf=function(e){var t=At(e);return t===St?null:t},Object.setPrototypeOf=function(e,t){return Lt(e,null===t?St:t)},Object.setPrototypeOf.polyfill=!1),!!s((function(){return Object.keys("foo")}))){var It=Object.keys;le(Object,"keys",(function(e){return It(ge.ToObject(e))})),a=Object.keys}if(s((function(){return Object.keys(/a/g)}))){var Nt=Object.keys;le(Object,"keys",(function(e){if(se(e)){var t=[];for(var i in e)V(e,i)&&O(t,i);return t}return Nt(e)})),a=Object.keys}if(Object.getOwnPropertyNames&&!!s((function(){return Object.getOwnPropertyNames("foo")}))){var jt="object"==typeof window?Object.getOwnPropertyNames(window):[],Ht=Object.getOwnPropertyNames;le(Object,"getOwnPropertyNames",(function(e){var t=ge.ToObject(e);if("[object Window]"===v(t))try{return Ht(t)}catch(e){return D([],jt)}return Ht(t)}))}if(Object.getOwnPropertyDescriptor&&!!s((function(){return Object.getOwnPropertyDescriptor("foo","bar")}))){var Ft=Object.getOwnPropertyDescriptor;le(Object,"getOwnPropertyDescriptor",(function(e,t){return Ft(ge.ToObject(e),t)}))}if(Object.seal&&!!s((function(){return Object.seal("foo")}))){var Rt=Object.seal;le(Object,"seal",(function(e){return ge.TypeIsObject(e)?Rt(e):e}))}if(Object.isSealed&&!!s((function(){return Object.isSealed("foo")}))){var zt=Object.isSealed;le(Object,"isSealed",(function(e){return!ge.TypeIsObject(e)||zt(e)}))}if(Object.freeze&&!!s((function(){return Object.freeze("foo")}))){var Bt=Object.freeze;le(Object,"freeze",(function(e){return ge.TypeIsObject(e)?Bt(e):e}))}if(Object.isFrozen&&!!s((function(){return Object.isFrozen("foo")}))){var Vt=Object.isFrozen;le(Object,"isFrozen",(function(e){return!ge.TypeIsObject(e)||Vt(e)}))}if(Object.preventExtensions&&!!s((function(){return Object.preventExtensions("foo")}))){var Wt=Object.preventExtensions;le(Object,"preventExtensions",(function(e){return ge.TypeIsObject(e)?Wt(e):e}))}if(Object.isExtensible&&!!s((function(){return Object.isExtensible("foo")}))){var Ut=Object.isExtensible;le(Object,"isExtensible",(function(e){return!!ge.TypeIsObject(e)&&Ut(e)}))}if(Object.getPrototypeOf&&!!s((function(){return Object.getPrototypeOf("foo")}))){var qt=Object.getPrototypeOf;le(Object,"getPrototypeOf",(function(e){return qt(ge.ToObject(e))}))}var $t,Xt=c&&(($t=Object.getOwnPropertyDescriptor(RegExp.prototype,"flags"))&&ge.IsCallable($t.get));if(c&&!Xt){b(RegExp.prototype,"flags",(function(){if(!ge.TypeIsObject(this))throw new TypeError("Method called on incompatible type: must be an object.");var e="";return this.global&&(e+="g"),this.ignoreCase&&(e+="i"),this.multiline&&(e+="m"),this.unicode&&(e+="u"),this.sticky&&(e+="y"),e}))}var Gt,Zt=c&&o((function(){return"/a/i"===String(new RegExp(/a/g,"i"))})),Kt=ce&&c&&((Gt=/./)[Z.match]=!1,RegExp(Gt)===Gt),Jt=o((function(){return"/abc/"===RegExp.prototype.toString.call({source:"abc"})})),Qt=Jt&&o((function(){return"/a/b"===RegExp.prototype.toString.call({source:"a",flags:"b"})}));if(!Jt||!Qt){var ei=RegExp.prototype.toString;m(RegExp.prototype,"toString",(function(){var e=ge.RequireObjectCoercible(this);return se(e)?n(ei,e):"/"+fe(e.source)+"/"+fe(e.flags)}),!0),k(RegExp.prototype.toString,ei),RegExp.prototype.toString.prototype=void 0}if(c&&(!Zt||Kt)){var ti=Object.getOwnPropertyDescriptor(RegExp.prototype,"flags").get,ii=Object.getOwnPropertyDescriptor(RegExp.prototype,"source")||{},ni=ge.IsCallable(ii.get)?ii.get:function(){return this.source},ri=RegExp,ai=function e(t,i){var n=ge.IsRegExp(t);return this instanceof e||!n||void 0!==i||t.constructor!==e?se(t)?new e(ge.Call(ni,t),void 0===i?ge.Call(ti,t):i):(n&&(t.source,void 0===i&&t.flags),new ri(t,i)):t};Te(ri,ai,{$input:!0}),RegExp=ai,_(A,"RegExp",ai)}if(c){var si={input:"$_",lastMatch:"$&",lastParen:"$+",leftContext:"$`",rightContext:"$'"};d(a(si),(function(e){e in RegExp&&!(si[e]in RegExp)&&b(RegExp,si[e],(function(){return RegExp[e]}))}))}De(RegExp);var oi=1/Number.EPSILON,li=Math.pow(2,-23),ci=Math.pow(2,127)*(2-li),ui=Math.pow(2,-126),di=Math.E,hi=Math.LOG2E,fi=Math.LOG10E,pi=Number.prototype.clz;delete Number.prototype.clz;var mi={acosh:function(e){var t=Number(e);if(J(t)||e<1)return NaN;if(1===t)return 0;if(t===1/0)return t;var i=1/(t*t);if(t<2)return te(t-1+B(1-i)*t);var n=t/2;return te(n+B(1-i)*n-1)+1/hi},asinh:function(e){var t=Number(e);if(0===t||!L(t))return t;var i=F(t),n=i*i,r=ee(t);return i<1?r*te(i+n/(B(n+1)+1)):r*(te(i/2+B(1+1/n)*i/2-1)+1/hi)},atanh:function(e){var t=Number(e);if(0===t)return t;if(-1===t)return-1/0;if(1===t)return 1/0;if(J(t)||t<-1||t>1)return NaN;var i=F(t);return ee(t)*te(2*i/(1-i))/2},cbrt:function(e){var t=Number(e);if(0===t)return t;var i,n=t<0;return n&&(t=-t),i=t===1/0?1/0:(t/((i=R(z(t)/3))*i)+2*i)/3,n?-i:i},clz32:function(e){var t=Number(e),i=ge.ToUint32(t);return 0===i?32:pi?ge.Call(pi,i):31-H(z(i+.5)*hi)},cosh:function(e){var t=Number(e);if(0===t)return 1;if(J(t))return NaN;if(!L(t))return 1/0;var i=R(F(t)-1);return(i+1/(i*di*di))*(di/2)},expm1:function(e){var t=Number(e);if(t===-1/0)return-1;if(!L(t)||0===t)return t;if(F(t)>.5)return R(t)-1;for(var i=t,n=0,r=1;n+i!==n;)n+=i,i*=t/(r+=1);return n},hypot:function(e,t){for(var i=0,n=0,r=0;r<arguments.length;++r){var a=F(Number(arguments[r]));n<a?(i*=n/a*(n/a),i+=1,n=a):i+=a>0?a/n*(a/n):a}return n===1/0?1/0:n*B(i)},log2:function(e){return z(e)*hi},log10:function(e){return z(e)*fi},log1p:te,sign:ee,sinh:function(e){var t=Number(e);if(!L(t)||0===t)return t;var i=F(t);if(i<1){var n=Math.expm1(i);return ee(t)*n*(1+1/(n+1))/2}var r=R(i-1);return ee(t)*(r-1/(r*di*di))*(di/2)},tanh:function(e){var t=Number(e);return J(t)||0===t?t:t>=20?1:t<=-20?-1:(Math.expm1(t)-Math.expm1(-t))/(R(t)+R(-t))},trunc:function(e){var t=Number(e);return t<0?-H(-t):H(t)},imul:function(e,t){var i=ge.ToUint32(e),n=ge.ToUint32(t),r=65535&i,a=65535&n;return r*a+((i>>>16&65535)*a+r*(n>>>16&65535)<<16>>>0)|0},fround:function(e){var t=Number(e);if(0===t||t===1/0||t===-1/0||J(t))return t;var i=ee(t),n=F(t);if(n<ui)return i*(n/ui/li+oi-oi)*ui*li;var r=(1+li/Number.EPSILON)*n,a=r-(r-n);return a>ci||J(a)?i*(1/0):i*a}},gi=function(e,t,i){return F(1-e/t)/Number.EPSILON<(i||8)};g(Math,mi),m(Math,"sinh",mi.sinh,Math.sinh(710)===1/0),m(Math,"cosh",mi.cosh,Math.cosh(710)===1/0),m(Math,"log1p",mi.log1p,-1e-17!==Math.log1p(-1e-17)),m(Math,"asinh",mi.asinh,Math.asinh(-1e7)!==-Math.asinh(1e7)),m(Math,"asinh",mi.asinh,Math.asinh(1e300)===1/0),m(Math,"atanh",mi.atanh,0===Math.atanh(1e-300)),m(Math,"tanh",mi.tanh,-2e-17!==Math.tanh(-2e-17)),m(Math,"acosh",mi.acosh,Math.acosh(Number.MAX_VALUE)===1/0),m(Math,"acosh",mi.acosh,!gi(Math.acosh(1+Number.EPSILON),Math.sqrt(2*Number.EPSILON))),m(Math,"cbrt",mi.cbrt,!gi(Math.cbrt(1e-300),1e-100)),m(Math,"sinh",mi.sinh,-2e-17!==Math.sinh(-2e-17));var vi=Math.expm1(10);m(Math,"expm1",mi.expm1,vi>22025.465794806718||vi<22025.465794806718),m(Math,"hypot",mi.hypot,Math.hypot(1/0,NaN)!==1/0);var yi=Math.round,bi=0===Math.round(.5-Number.EPSILON/4)&&1===Math.round(Number.EPSILON/3.99-.5),xi=[oi+1,2*oi-1].every((function(e){return Math.round(e)===e}));m(Math,"round",(function(e){var t=H(e);return e-t<.5?t:-1===t?-0:t+1}),!bi||!xi),k(Math.round,yi);var _i=Math.imul;-5!==Math.imul(4294967295,5)&&(Math.imul=mi.imul,k(Math.imul,_i)),2!==Math.imul.length&&le(Math,"imul",(function(e,t){return ge.Call(_i,Math,arguments)}));var wi,ki,Mi=function(){var e=A.setTimeout;if("function"==typeof e||"object"==typeof e){ge.IsPromise=function(e){return!!ge.TypeIsObject(e)&&void 0!==e._promise};var t,i=function(e){if(!ge.IsConstructor(e))throw new TypeError("Bad promise constructor");var t=this;if(t.resolve=void 0,t.reject=void 0,t.promise=new e((function(e,i){if(void 0!==t.resolve||void 0!==t.reject)throw new TypeError("Bad Promise implementation!");t.resolve=e,t.reject=i})),!ge.IsCallable(t.resolve)||!ge.IsCallable(t.reject))throw new TypeError("Bad promise constructor")};"undefined"!=typeof window&&ge.IsCallable(window.postMessage)&&(t=function(){var e=[],t="zero-timeout-message";return window.addEventListener("message",(function(i){if(i.source===window&&i.data===t){if(i.stopPropagation(),0===e.length)return;I(e)()}}),!0),function(i){O(e,i),window.postMessage(t,"*")}});var r,a,s,o,l=ge.IsCallable(A.setImmediate)?A.setImmediate:"object"==typeof process&&process.nextTick?process.nextTick:(r=A.Promise,(a=r&&r.resolve&&r.resolve())&&function(e){return a.then(e)}||(ge.IsCallable(t)?t():function(t){e(t,0)})),c=function(e){return e},u=function(e){throw e},d={},h=function(e,t,i){l((function(){f(e,t,i)}))},f=function(e,t,i){var n,r;if(t===d)return e(i);try{n=e(i),r=t.resolve}catch(e){n=e,r=t.reject}r(n)},p=function(e,t){var i=e._promise,n=i.reactionLength;if(n>0&&(h(i.fulfillReactionHandler0,i.reactionCapability0,t),i.fulfillReactionHandler0=void 0,i.rejectReactions0=void 0,i.reactionCapability0=void 0,n>1))for(var r=1,a=0;r<n;r++,a+=3)h(i[a+0],i[a+2],t),e[a+0]=void 0,e[a+1]=void 0,e[a+2]=void 0;i.result=t,i.state=1,i.reactionLength=0},m=function(e,t){var i=e._promise,n=i.reactionLength;if(n>0&&(h(i.rejectReactionHandler0,i.reactionCapability0,t),i.fulfillReactionHandler0=void 0,i.rejectReactions0=void 0,i.reactionCapability0=void 0,n>1))for(var r=1,a=0;r<n;r++,a+=3)h(i[a+1],i[a+2],t),e[a+0]=void 0,e[a+1]=void 0,e[a+2]=void 0;i.result=t,i.state=2,i.reactionLength=0},v=function(e){var t=!1;return{resolve:function(i){var n;if(!t){if(t=!0,i===e)return m(e,new TypeError("Self resolution"));if(!ge.TypeIsObject(i))return p(e,i);try{n=i.then}catch(t){return m(e,t)}if(!ge.IsCallable(n))return p(e,i);l((function(){b(e,i,n)}))}},reject:function(i){if(!t)return t=!0,m(e,i)}}},y=function(e,t,i,r){e===o?n(e,t,i,r,d):n(e,t,i,r)},b=function(e,t,i){var n=v(e),r=n.resolve,a=n.reject;try{y(i,t,r,a)}catch(e){a(e)}},x=function(){var e=function(t){if(!(this instanceof e))throw new TypeError('Constructor Promise requires "new"');if(this&&this._promise)throw new TypeError("Bad construction");if(!ge.IsCallable(t))throw new TypeError("not a valid resolver");var i=Pe(this,e,s,{_promise:{result:void 0,state:0,reactionLength:0,fulfillReactionHandler0:void 0,rejectReactionHandler0:void 0,reactionCapability0:void 0}}),n=v(i),r=n.reject;try{t(n.resolve,r)}catch(e){r(e)}return i};return e}();s=x.prototype;var _=function(e,t,i,n){var r=!1;return function(a){r||(r=!0,t[e]=a,0==--n.count&&(0,i.resolve)(t))}};return g(x,{all:function(e){var t=this;if(!ge.TypeIsObject(t))throw new TypeError("Promise is not object");var n,r,a=new i(t);try{return function(e,t,i){for(var n,r,a=e.iterator,s=[],o={count:1},l=0;;){try{if(!1===(n=ge.IteratorStep(a))){e.done=!0;break}r=n.value}catch(t){throw e.done=!0,t}s[l]=void 0;var c=t.resolve(r),u=_(l,s,i,o);o.count+=1,y(c.then,c,u,i.reject),l+=1}return 0==--o.count&&(0,i.resolve)(s),i.promise}(r={iterator:n=ge.GetIterator(e),done:!1},t,a)}catch(e){var s=e;if(r&&!r.done)try{ge.IteratorClose(n,!0)}catch(e){s=e}return(0,a.reject)(s),a.promise}},race:function(e){var t=this;if(!ge.TypeIsObject(t))throw new TypeError("Promise is not object");var n,r,a=new i(t);try{return function(e,t,i){for(var n,r,a,s=e.iterator;;){try{if(!1===(n=ge.IteratorStep(s))){e.done=!0;break}r=n.value}catch(t){throw e.done=!0,t}a=t.resolve(r),y(a.then,a,i.resolve,i.reject)}return i.promise}(r={iterator:n=ge.GetIterator(e),done:!1},t,a)}catch(e){var s=e;if(r&&!r.done)try{ge.IteratorClose(n,!0)}catch(e){s=e}return(0,a.reject)(s),a.promise}},reject:function(e){if(!ge.TypeIsObject(this))throw new TypeError("Bad promise constructor");var t=new i(this);return(0,t.reject)(e),t.promise},resolve:function(e){var t=this;if(!ge.TypeIsObject(t))throw new TypeError("Bad promise constructor");if(ge.IsPromise(e)&&e.constructor===t)return e;var n=new i(t);return(0,n.resolve)(e),n.promise}}),g(s,{catch:function(e){return this.then(null,e)},then:function(e,t){var n=this;if(!ge.IsPromise(n))throw new TypeError("not a promise");var r,a=ge.SpeciesConstructor(n,x);r=arguments.length>2&&arguments[2]===d&&a===x?d:new i(a);var s,o=ge.IsCallable(e)?e:c,l=ge.IsCallable(t)?t:u,f=n._promise;if(0===f.state){if(0===f.reactionLength)f.fulfillReactionHandler0=o,f.rejectReactionHandler0=l,f.reactionCapability0=r;else{var p=3*(f.reactionLength-1);f[p+0]=o,f[p+1]=l,f[p+2]=r}f.reactionLength+=1}else if(1===f.state)s=f.result,h(o,r,s);else{if(2!==f.state)throw new TypeError("unexpected Promise state");s=f.result,h(l,r,s)}return r.promise}}),d=new i(x),o=s.then,x}}();if(A.Promise&&(delete A.Promise.accept,delete A.Promise.defer,delete A.Promise.prototype.chain),"function"==typeof Mi){g(A,{Promise:Mi});var Si=S(A.Promise,(function(e){return e.resolve(42).then((function(){}))instanceof e})),Ai=!s((function(){return A.Promise.reject(42).then(null,5).then(null,W)})),Li=s((function(){return A.Promise.call(3,W)})),Ti=function(e){var t=e.resolve(5);t.constructor={};var i=e.resolve(t);try{i.then(null,W).then(null,W)}catch(e){return!0}return t===i}(A.Promise),Ci=c&&(wi=0,ki=Object.defineProperty({},"then",{get:function(){wi+=1}}),Promise.resolve(ki),1===wi),Di=function e(t){var i=new Promise(t);t(3,(function(){})),this.then=i.then,this.constructor=e};Di.prototype=Promise.prototype,Di.all=Promise.all;var Ei=o((function(){return!!Di.all([1,2])}));if(Si&&Ai&&Li&&!Ti&&Ci&&!Ei||(Promise=Mi,le(A,"Promise",Mi)),1!==Promise.all.length){var Oi=Promise.all;le(Promise,"all",(function(e){return ge.Call(Oi,this,arguments)}))}if(1!==Promise.race.length){var Pi=Promise.race;le(Promise,"race",(function(e){return ge.Call(Pi,this,arguments)}))}if(1!==Promise.resolve.length){var Yi=Promise.resolve;le(Promise,"resolve",(function(e){return ge.Call(Yi,this,arguments)}))}if(1!==Promise.reject.length){var Ii=Promise.reject;le(Promise,"reject",(function(e){return ge.Call(Ii,this,arguments)}))}Ct(Promise,"all"),Ct(Promise,"race"),Ct(Promise,"resolve"),Ct(Promise,"reject"),De(Promise)}var Ni,ji,Hi=function(e){var t=a(h(e,(function(e,t){return e[t]=!0,e}),{}));return e.join(":")===t.join(":")},Fi=Hi(["z","a","bb"]),Ri=Hi(["z",1,"a","3",2]);if(c){var zi=function(e,t){return t||Fi?me(e)?"^"+ge.ToString(e):"string"==typeof e?"$"+e:"number"==typeof e?Ri?e:"n"+e:"boolean"==typeof e?"b"+e:null:null},Bi=function(){return Object.create?Object.create(null):{}},Vi=function(e,t,i){if(r(i)||ae(i))d(i,(function(e){if(!ge.TypeIsObject(e))throw new TypeError("Iterator value "+e+" is not an entry object");t.set(e[0],e[1])}));else if(i instanceof e)n(e.prototype.forEach,i,(function(e,i){t.set(i,e)}));else{var a,s;if(!me(i)){if(s=t.set,!ge.IsCallable(s))throw new TypeError("bad map");a=ge.GetIterator(i)}if(void 0!==a)for(;;){var o=ge.IteratorStep(a);if(!1===o)break;var l=o.value;try{if(!ge.TypeIsObject(l))throw new TypeError("Iterator value "+l+" is not an entry object");n(s,t,l[0],l[1])}catch(e){throw ge.IteratorClose(a,!0),e}}}},Wi=function(e,t,i){if(r(i)||ae(i))d(i,(function(e){t.add(e)}));else if(i instanceof e)n(e.prototype.forEach,i,(function(e){t.add(e)}));else{var a,s;if(!me(i)){if(s=t.add,!ge.IsCallable(s))throw new TypeError("bad set");a=ge.GetIterator(i)}if(void 0!==a)for(;;){var o=ge.IteratorStep(a);if(!1===o)break;var l=o.value;try{n(s,t,l)}catch(e){throw ge.IteratorClose(a,!0),e}}}},Ui={Map:function(){var e={},t=function(e,t){this.key=e,this.value=t,this.next=null,this.prev=null};t.prototype.isRemoved=function(){return this.key===e};var i,r=function(e,t){if(!ge.TypeIsObject(e)||!function(e){return!!e._es6map}(e))throw new TypeError("Method Map.prototype."+t+" called on incompatible receiver "+ge.ToString(e))},a=function(e,t){r(e,"[[MapIterator]]"),m(this,"head",e._head),m(this,"i",this.head),m(this,"kind",t)};Ee(a.prototype={isMapIterator:!0,next:function(){if(!this.isMapIterator)throw new TypeError("Not a MapIterator");var e,t=this.i,i=this.kind,n=this.head;if(void 0===this.i)return Xe();for(;t.isRemoved()&&t!==n;)t=t.prev;for(;t.next!==n;)if(!(t=t.next).isRemoved())return e="key"===i?t.key:"value"===i?t.value:[t.key,t.value],this.i=t,Xe(e);return this.i=void 0,Xe()}});var s=function e(){if(!(this instanceof e))throw new TypeError('Constructor Map requires "new"');if(this&&this._es6map)throw new TypeError("Bad construction");var n=Pe(this,e,i,{_es6map:!0,_head:null,_map:U?new U:null,_size:0,_storage:Bi()}),r=new t(null,null);return r.next=r.prev=r,n._head=r,arguments.length>0&&Vi(e,n,arguments[0]),n};return b(i=s.prototype,"size",(function(){if(void 0===this._size)throw new TypeError("size method called on incompatible Map");return this._size})),g(i,{get:function(e){var t;r(this,"get");var i=zi(e,!0);if(null!==i)return(t=this._storage[i])?t.value:void 0;if(this._map)return(t=$.call(this._map,e))?t.value:void 0;for(var n=this._head,a=n;(a=a.next)!==n;)if(ge.SameValueZero(a.key,e))return a.value},has:function(e){r(this,"has");var t=zi(e,!0);if(null!==t)return void 0!==this._storage[t];if(this._map)return X.call(this._map,e);for(var i=this._head,n=i;(n=n.next)!==i;)if(ge.SameValueZero(n.key,e))return!0;return!1},set:function(e,i){r(this,"set");var n,a=this._head,s=a,o=zi(e,!0);if(null!==o){if(void 0!==this._storage[o])return this._storage[o].value=i,this;n=this._storage[o]=new t(e,i),s=a.prev}else this._map&&(X.call(this._map,e)?$.call(this._map,e).value=i:(n=new t(e,i),G.call(this._map,e,n),s=a.prev));for(;(s=s.next)!==a;)if(ge.SameValueZero(s.key,e))return s.value=i,this;return n=n||new t(e,i),ge.SameValue(-0,e)&&(n.key=0),n.next=this._head,n.prev=this._head.prev,n.prev.next=n,n.next.prev=n,this._size+=1,this},delete:function(t){r(this,"delete");var i=this._head,n=i,a=zi(t,!0);if(null!==a){if(void 0===this._storage[a])return!1;n=this._storage[a].prev,delete this._storage[a]}else if(this._map){if(!X.call(this._map,t))return!1;n=$.call(this._map,t).prev,q.call(this._map,t)}for(;(n=n.next)!==i;)if(ge.SameValueZero(n.key,t))return n.key=e,n.value=e,n.prev.next=n.next,n.next.prev=n.prev,this._size-=1,!0;return!1},clear:function(){r(this,"clear"),this._map=U?new U:null,this._size=0,this._storage=Bi();for(var t=this._head,i=t,n=i.next;(i=n)!==t;)i.key=e,i.value=e,n=i.next,i.next=i.prev=t;t.next=t.prev=t},keys:function(){return r(this,"keys"),new a(this,"key")},values:function(){return r(this,"values"),new a(this,"value")},entries:function(){return r(this,"entries"),new a(this,"key+value")},forEach:function(e){r(this,"forEach");for(var t=arguments.length>1?arguments[1]:null,i=this.entries(),a=i.next();!a.done;a=i.next())t?n(e,t,a.value[1],a.value[0],this):e(a.value[1],a.value[0],this)}}),Ee(i,i.entries),s}(),Set:function(){var e,t=function(e,t){if(!ge.TypeIsObject(e)||!function(e){return e._es6set&&void 0!==e._storage}(e))throw new TypeError("Set.prototype."+t+" called on incompatible receiver "+ge.ToString(e))},i=function t(){if(!(this instanceof t))throw new TypeError('Constructor Set requires "new"');if(this&&this._es6set)throw new TypeError("Bad construction");var i=Pe(this,t,e,{_es6set:!0,"[[SetData]]":null,_storage:Bi()});if(!i._es6set)throw new TypeError("bad set");return arguments.length>0&&Wi(t,i,arguments[0]),i};e=i.prototype;var r=function(e){if(!e["[[SetData]]"]){var t=new Ui.Map;e["[[SetData]]"]=t,d(a(e._storage),(function(e){var i=function(e){var t=e;if("^null"===t)return null;if("^undefined"!==t){var i=t.charAt(0);return"$"===i?E(t,1):"n"===i?+E(t,1):"b"===i?"btrue"===t:+t}}(e);t.set(i,i)})),e["[[SetData]]"]=t}e._storage=null};b(i.prototype,"size",(function(){return t(this,"size"),this._storage?a(this._storage).length:(r(this),this["[[SetData]]"].size)})),g(i.prototype,{has:function(e){var i;return t(this,"has"),this._storage&&null!==(i=zi(e))?!!this._storage[i]:(r(this),this["[[SetData]]"].has(e))},add:function(e){var i;return t(this,"add"),this._storage&&null!==(i=zi(e))?(this._storage[i]=!0,this):(r(this),this["[[SetData]]"].set(e,e),this)},delete:function(e){var i;if(t(this,"delete"),this._storage&&null!==(i=zi(e))){var n=V(this._storage,i);return delete this._storage[i]&&n}return r(this),this["[[SetData]]"].delete(e)},clear:function(){t(this,"clear"),this._storage&&(this._storage=Bi()),this["[[SetData]]"]&&this["[[SetData]]"].clear()},values:function(){return t(this,"values"),r(this),new s(this["[[SetData]]"].values())},entries:function(){return t(this,"entries"),r(this),new s(this["[[SetData]]"].entries())},forEach:function(e){t(this,"forEach");var i=arguments.length>1?arguments[1]:null,a=this;r(a),this["[[SetData]]"].forEach((function(t,r){i?n(e,i,r,r,a):e(r,r,a)}))}}),m(i.prototype,"keys",i.prototype.values,!0),Ee(i.prototype,i.prototype.values);var s=function(e){m(this,"it",e)};return s.prototype={isSetIterator:!0,next:function(){if(!this.isSetIterator)throw new TypeError("Not a SetIterator");return this.it.next()}},Ee(s.prototype),i}()};if(A.Set&&!Set.prototype.delete&&Set.prototype.remove&&Set.prototype.items&&Set.prototype.map&&Array.isArray((new Set).keys)&&(A.Set=Ui.Set),A.Map||A.Set){o((function(){return 2===new Map([[1,2]]).get(1)}))||(A.Map=function e(){if(!(this instanceof e))throw new TypeError('Constructor Map requires "new"');var t=new U;return arguments.length>0&&Vi(e,t,arguments[0]),delete t.constructor,Object.setPrototypeOf(t,A.Map.prototype),t},A.Map.prototype=M(U.prototype),m(A.Map.prototype,"constructor",A.Map,!0),k(A.Map,U));var qi=new Map,$i=((ji=new Map([[1,0],[2,0],[3,0],[4,0]])).set(-0,ji),ji.get(0)===ji&&ji.get(-0)===ji&&ji.has(0)&&ji.has(-0)),Xi=qi.set(1,2)===qi;$i&&Xi||le(Map.prototype,"set",(function(e,t){return n(G,this,0===e?0:e,t),this})),$i||(g(Map.prototype,{get:function(e){return n($,this,0===e?0:e)},has:function(e){return n(X,this,0===e?0:e)}},!0),k(Map.prototype.get,$),k(Map.prototype.has,X));var Gi=new Set,Zi=Set.prototype.delete&&Set.prototype.add&&Set.prototype.has&&((Ni=Gi).delete(0),Ni.add(-0),!Ni.has(0)),Ki=Gi.add(1)===Gi;if(!Zi||!Ki){var Ji=Set.prototype.add;Set.prototype.add=function(e){return n(Ji,this,0===e?0:e),this},k(Set.prototype.add,Ji)}if(!Zi){var Qi=Set.prototype.has;Set.prototype.has=function(e){return n(Qi,this,0===e?0:e)},k(Set.prototype.has,Qi);var en=Set.prototype.delete;Set.prototype.delete=function(e){return n(en,this,0===e?0:e)},k(Set.prototype.delete,en)}var tn=S(A.Map,(function(e){var t=new e([]);return t.set(42,42),t instanceof e})),nn=Object.setPrototypeOf&&!tn,rn=function(){try{return!(A.Map()instanceof A.Map)}catch(e){return e instanceof TypeError}}();0===A.Map.length&&!nn&&rn||(A.Map=function e(){if(!(this instanceof e))throw new TypeError('Constructor Map requires "new"');var t=new U;return arguments.length>0&&Vi(e,t,arguments[0]),delete t.constructor,Object.setPrototypeOf(t,e.prototype),t},A.Map.prototype=U.prototype,m(A.Map.prototype,"constructor",A.Map,!0),k(A.Map,U));var an=S(A.Set,(function(e){var t=new e([]);return t.add(42,42),t instanceof e})),sn=Object.setPrototypeOf&&!an,on=function(){try{return!(A.Set()instanceof A.Set)}catch(e){return e instanceof TypeError}}();if(0!==A.Set.length||sn||!on){var ln=A.Set;A.Set=function e(){if(!(this instanceof e))throw new TypeError('Constructor Set requires "new"');var t=new ln;return arguments.length>0&&Wi(e,t,arguments[0]),delete t.constructor,Object.setPrototypeOf(t,e.prototype),t},A.Set.prototype=ln.prototype,m(A.Set.prototype,"constructor",A.Set,!0),k(A.Set,ln)}var cn=new A.Map,un=!o((function(){return cn.keys().next().done}));if(("function"!=typeof A.Map.prototype.clear||0!==(new A.Set).size||0!==cn.size||"function"!=typeof A.Map.prototype.keys||"function"!=typeof A.Set.prototype.keys||"function"!=typeof A.Map.prototype.forEach||"function"!=typeof A.Set.prototype.forEach||l(A.Map)||l(A.Set)||"function"!=typeof cn.keys().next||un||!tn)&&g(A,{Map:Ui.Map,Set:Ui.Set},!0),A.Set.prototype.keys!==A.Set.prototype.values&&m(A.Set.prototype,"keys",A.Set.prototype.values,!0),Ee(Object.getPrototypeOf((new A.Map).keys())),Ee(Object.getPrototypeOf((new A.Set).keys())),u&&"has"!==A.Set.prototype.has.name){var dn=A.Set.prototype.has;le(A.Set.prototype,"has",(function(e){return n(dn,this,e)}))}}g(A,Ui),De(A.Map),De(A.Set)}var hn=function(e){if(!ge.TypeIsObject(e))throw new TypeError("target must be an object")},fn={apply:function(){return ge.Call(ge.Call,null,arguments)},construct:function(e,t){if(!ge.IsConstructor(e))throw new TypeError("First argument must be a constructor.");var i=arguments.length>2?arguments[2]:e;if(!ge.IsConstructor(i))throw new TypeError("new.target must be a constructor.");return ge.Construct(e,t,i,"internal")},deleteProperty:function(e,t){if(hn(e),c){var i=Object.getOwnPropertyDescriptor(e,t);if(i&&!i.configurable)return!1}return delete e[t]},has:function(e,t){return hn(e),t in e}};Object.getOwnPropertyNames&&Object.assign(fn,{ownKeys:function(e){hn(e);var t=Object.getOwnPropertyNames(e);return ge.IsCallable(Object.getOwnPropertySymbols)&&P(t,Object.getOwnPropertySymbols(e)),t}});var pn=function(e){return!s(e)};if(Object.preventExtensions&&Object.assign(fn,{isExtensible:function(e){return hn(e),Object.isExtensible(e)},preventExtensions:function(e){return hn(e),pn((function(){return Object.preventExtensions(e)}))}}),c){var mn=function(e,t,i){var n=Object.getOwnPropertyDescriptor(e,t);if(!n){var r=Object.getPrototypeOf(e);if(null===r)return;return mn(r,t,i)}return"value"in n?n.value:n.get?ge.Call(n.get,i):void 0},gn=function(e,t,i,r){var a=Object.getOwnPropertyDescriptor(e,t);if(!a){var s=Object.getPrototypeOf(e);if(null!==s)return gn(s,t,i,r);a={value:void 0,writable:!0,enumerable:!0,configurable:!0}}return"value"in a?!!a.writable&&(!!ge.TypeIsObject(r)&&(Object.getOwnPropertyDescriptor(r,t)?he.defineProperty(r,t,{value:i}):he.defineProperty(r,t,{value:i,writable:!0,enumerable:!0,configurable:!0}))):!!a.set&&(n(a.set,r,i),!0)};Object.assign(fn,{defineProperty:function(e,t,i){return hn(e),pn((function(){return Object.defineProperty(e,t,i)}))},getOwnPropertyDescriptor:function(e,t){return hn(e),Object.getOwnPropertyDescriptor(e,t)},get:function(e,t){return hn(e),mn(e,t,arguments.length>2?arguments[2]:e)},set:function(e,t,i){return hn(e),gn(e,t,i,arguments.length>3?arguments[3]:e)}})}if(Object.getPrototypeOf){var vn=Object.getPrototypeOf;fn.getPrototypeOf=function(e){return hn(e),vn(e)}}if(Object.setPrototypeOf&&fn.getPrototypeOf){Object.assign(fn,{setPrototypeOf:function(e,t){if(hn(e),null!==t&&!ge.TypeIsObject(t))throw new TypeError("proto must be an object or null");return t===he.getPrototypeOf(e)||!(he.isExtensible&&!he.isExtensible(e))&&(!function(e,t){for(var i=t;i;){if(e===i)return!0;i=fn.getPrototypeOf(i)}return!1}(e,t)&&(Object.setPrototypeOf(e,t),!0))}})}Object.keys(fn).forEach((function(e){!function(e,t){ge.IsCallable(A.Reflect[e])?o((function(){return A.Reflect[e](1),A.Reflect[e](NaN),A.Reflect[e](!0),!0}))&&le(A.Reflect,e,t):m(A.Reflect,e,t)}(e,fn[e])}));var yn=A.Reflect.getPrototypeOf;if(u&&yn&&"getPrototypeOf"!==yn.name&&le(A.Reflect,"getPrototypeOf",(function(e){return n(yn,A.Reflect,e)})),A.Reflect.setPrototypeOf&&o((function(){return A.Reflect.setPrototypeOf(1,{}),!0}))&&le(A.Reflect,"setPrototypeOf",fn.setPrototypeOf),A.Reflect.defineProperty&&(o((function(){var e=!A.Reflect.defineProperty(1,"test",{value:1}),t="function"!=typeof Object.preventExtensions||!A.Reflect.defineProperty(Object.preventExtensions({}),"test",{});return e&&t}))||le(A.Reflect,"defineProperty",fn.defineProperty)),A.Reflect.construct&&(o((function(){var e=function(){};return A.Reflect.construct((function(){}),[],e)instanceof e}))||le(A.Reflect,"construct",fn.construct)),"Invalid Date"!==String(new Date(NaN))){var bn=Date.prototype.toString;le(Date.prototype,"toString",(function(){var e=+this;return e!=e?"Invalid Date":ge.Call(bn,this)}))}var xn={anchor:function(e){return ge.CreateHTML(this,"a","name",e)},big:function(){return ge.CreateHTML(this,"big","","")},blink:function(){return ge.CreateHTML(this,"blink","","")},bold:function(){return ge.CreateHTML(this,"b","","")},fixed:function(){return ge.CreateHTML(this,"tt","","")},fontcolor:function(e){return ge.CreateHTML(this,"font","color",e)},fontsize:function(e){return ge.CreateHTML(this,"font","size",e)},italics:function(){return ge.CreateHTML(this,"i","","")},link:function(e){return ge.CreateHTML(this,"a","href",e)},small:function(){return ge.CreateHTML(this,"small","","")},strike:function(){return ge.CreateHTML(this,"strike","","")},sub:function(){return ge.CreateHTML(this,"sub","","")},sup:function(){return ge.CreateHTML(this,"sup","","")}};d(Object.keys(xn),(function(e){var t=String.prototype[e],i=!1;if(ge.IsCallable(t)){var r=n(t,"",' " '),a=D([],r.match(/"/g)).length;i=r!==r.toLowerCase()||a>2}else i=!0;i&&le(String.prototype,e,xn[e])}));var _n=function(){if(!ce)return!1;var e="object"==typeof JSON&&"function"==typeof JSON.stringify?JSON.stringify:null;if(!e)return!1;if(void 0!==e(Z()))return!0;if("[null]"!==e([Z()]))return!0;var t={a:Z()};return t[Z()]=!0,"{}"!==e(t)}(),wn=o((function(){return!ce||"{}"===JSON.stringify(Object(Z()))&&"[{}]"===JSON.stringify([Object(Z())])}));if(_n||!wn){var kn=JSON.stringify;le(JSON,"stringify",(function(e){if("symbol"!=typeof e){var t;arguments.length>1&&(t=arguments[1]);var i=[e];if(r(t))i.push(t);else{var a=ge.IsCallable(t)?t:null;i.push((function(e,t){var i=a?n(a,this,e,t):t;if("symbol"!=typeof i)return oe(i)?Et({})(i):i}))}return arguments.length>2&&i.push(arguments[2]),kn.apply(this,i)}}))}return A})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).FormValidation={})}(this,(function(e){"use strict";var t,i={exports:{}},n={};i.exports=function(){if(t)return n;t=1;var e={luhn:function(e){for(var t=e.length,i=[[0,1,2,3,4,5,6,7,8,9],[0,2,4,6,8,1,3,5,7,9]],n=0,r=0;t--;)r+=i[n][parseInt(e.charAt(t),10)],n=1-n;return r%10==0&&r>0},mod11And10:function(e){for(var t=e.length,i=5,n=0;n<t;n++)i=(2*(i||10)%11+parseInt(e.charAt(n),10))%10;return 1===i},mod37And36:function(e,t){void 0===t&&(t="0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ");for(var i=e.length,n=t.length,r=Math.floor(n/2),a=0;a<i;a++)r=(2*(r||n)%(n+1)+t.indexOf(e.charAt(a)))%n;return 1===r},mod97And10:function(e){for(var t=function(e){return e.split("").map((function(e){var t=e.charCodeAt(0);return t>=65&&t<=90?t-55:e})).join("").split("").map((function(e){return parseInt(e,10)}))}(e),i=0,n=t.length,r=0;r<n-1;++r)i=10*(i+t[r])%97;return(i+=t[n-1])%97==1},verhoeff:function(e){for(var t=[[0,1,2,3,4,5,6,7,8,9],[1,2,3,4,0,6,7,8,9,5],[2,3,4,0,1,7,8,9,5,6],[3,4,0,1,2,8,9,5,6,7],[4,0,1,2,3,9,5,6,7,8],[5,9,8,7,6,0,4,3,2,1],[6,5,9,8,7,1,0,4,3,2],[7,6,5,9,8,2,1,0,4,3],[8,7,6,5,9,3,2,1,0,4],[9,8,7,6,5,4,3,2,1,0]],i=[[0,1,2,3,4,5,6,7,8,9],[1,5,7,6,2,8,3,0,9,4],[5,8,0,3,7,9,6,1,4,2],[8,9,1,6,0,4,3,5,2,7],[9,4,5,3,1,2,6,8,7,0],[4,2,8,6,5,7,3,9,0,1],[2,7,9,3,8,0,6,4,1,5],[7,0,4,6,9,1,3,2,5,8]],n=e.reverse(),r=0,a=0;a<n.length;a++)r=t[r][i[a%8][n[a]]];return 0===r}},i=function(){function e(e,t){this.fields={},this.elements={},this.ee={fns:{},clear:function(){this.fns={}},emit:function(e){for(var t=[],i=1;i<arguments.length;i++)t[i-1]=arguments[i];(this.fns[e]||[]).map((function(e){return e.apply(e,t)}))},off:function(e,t){if(this.fns[e]){var i=this.fns[e].indexOf(t);i>=0&&this.fns[e].splice(i,1)}},on:function(e,t){(this.fns[e]=this.fns[e]||[]).push(t)}},this.filter={filters:{},add:function(e,t){(this.filters[e]=this.filters[e]||[]).push(t)},clear:function(){this.filters={}},execute:function(e,t,i){if(!this.filters[e]||!this.filters[e].length)return t;for(var n=t,r=this.filters[e],a=r.length,s=0;s<a;s++)n=r[s].apply(n,i);return n},remove:function(e,t){this.filters[e]&&(this.filters[e]=this.filters[e].filter((function(e){return e!==t})))}},this.plugins={},this.results=new Map,this.validators={},this.form=e,this.fields=t}return e.prototype.on=function(e,t){return this.ee.on(e,t),this},e.prototype.off=function(e,t){return this.ee.off(e,t),this},e.prototype.emit=function(e){for(var t,i=[],n=1;n<arguments.length;n++)i[n-1]=arguments[n];return(t=this.ee).emit.apply(t,function(e,t,i){if(i||2===arguments.length)for(var n,r=0,a=t.length;r<a;r++)!n&&r in t||(n||(n=Array.prototype.slice.call(t,0,r)),n[r]=t[r]);return e.concat(n||Array.prototype.slice.call(t))}([e],i,!1)),this},e.prototype.registerPlugin=function(e,t){if(this.plugins[e])throw new Error("The plguin ".concat(e," is registered"));return t.setCore(this),t.install(),this.plugins[e]=t,this},e.prototype.deregisterPlugin=function(e){var t=this.plugins[e];return t&&t.uninstall(),delete this.plugins[e],this},e.prototype.enablePlugin=function(e){var t=this.plugins[e];return t&&t.enable(),this},e.prototype.disablePlugin=function(e){var t=this.plugins[e];return t&&t.disable(),this},e.prototype.isPluginEnabled=function(e){var t=this.plugins[e];return!!t&&t.isPluginEnabled()},e.prototype.registerValidator=function(e,t){if(this.validators[e])throw new Error("The validator ".concat(e," is registered"));return this.validators[e]=t,this},e.prototype.registerFilter=function(e,t){return this.filter.add(e,t),this},e.prototype.deregisterFilter=function(e,t){return this.filter.remove(e,t),this},e.prototype.executeFilter=function(e,t,i){return this.filter.execute(e,t,i)},e.prototype.addField=function(e,t){var i=Object.assign({},{selector:"",validators:{}},t);return this.fields[e]=this.fields[e]?{selector:i.selector||this.fields[e].selector,validators:Object.assign({},this.fields[e].validators,i.validators)}:i,this.elements[e]=this.queryElements(e),this.emit("core.field.added",{elements:this.elements[e],field:e,options:this.fields[e]}),this},e.prototype.removeField=function(e){if(!this.fields[e])throw new Error("The field ".concat(e," validators are not defined. Please ensure the field is added first"));var t=this.elements[e],i=this.fields[e];return delete this.elements[e],delete this.fields[e],this.emit("core.field.removed",{elements:t,field:e,options:i}),this},e.prototype.validate=function(){var e=this;return this.emit("core.form.validating",{formValidation:this}),this.filter.execute("validate-pre",Promise.resolve(),[]).then((function(){return Promise.all(Object.keys(e.fields).map((function(t){return e.validateField(t)}))).then((function(t){switch(!0){case-1!==t.indexOf("Invalid"):return e.emit("core.form.invalid",{formValidation:e}),Promise.resolve("Invalid");case-1!==t.indexOf("NotValidated"):return e.emit("core.form.notvalidated",{formValidation:e}),Promise.resolve("NotValidated");default:return e.emit("core.form.valid",{formValidation:e}),Promise.resolve("Valid")}}))}))},e.prototype.validateField=function(e){var t=this,i=this.results.get(e);if("Valid"===i||"Invalid"===i)return Promise.resolve(i);this.emit("core.field.validating",e);var n=this.elements[e];if(0===n.length)return this.emit("core.field.valid",e),Promise.resolve("Valid");var r=n[0].getAttribute("type");return"radio"===r||"checkbox"===r||1===n.length?this.validateElement(e,n[0]):Promise.all(n.map((function(i){return t.validateElement(e,i)}))).then((function(i){switch(!0){case-1!==i.indexOf("Invalid"):return t.emit("core.field.invalid",e),t.results.set(e,"Invalid"),Promise.resolve("Invalid");case-1!==i.indexOf("NotValidated"):return t.emit("core.field.notvalidated",e),t.results.delete(e),Promise.resolve("NotValidated");default:return t.emit("core.field.valid",e),t.results.set(e,"Valid"),Promise.resolve("Valid")}}))},e.prototype.validateElement=function(e,t){var i=this;this.results.delete(e);var n=this.elements[e];if(this.filter.execute("element-ignored",!1,[e,t,n]))return this.emit("core.element.ignored",{element:t,elements:n,field:e}),Promise.resolve("Ignored");var r=this.fields[e].validators;this.emit("core.element.validating",{element:t,elements:n,field:e});var a=Object.keys(r).map((function(n){return function(){return i.executeValidator(e,t,n,r[n])}}));return this.waterfall(a).then((function(r){var a=-1===r.indexOf("Invalid");i.emit("core.element.validated",{element:t,elements:n,field:e,valid:a});var s=t.getAttribute("type");return"radio"!==s&&"checkbox"!==s&&1!==n.length||i.emit(a?"core.field.valid":"core.field.invalid",e),Promise.resolve(a?"Valid":"Invalid")})).catch((function(r){return i.emit("core.element.notvalidated",{element:t,elements:n,field:e}),Promise.resolve(r)}))},e.prototype.executeValidator=function(e,t,i,n){var r=this,a=this.elements[e],s=this.filter.execute("validator-name",i,[i,e]);if(n.message=this.filter.execute("validator-message",n.message,[this.locale,e,s]),!this.validators[s]||!1===n.enabled)return this.emit("core.validator.validated",{element:t,elements:a,field:e,result:this.normalizeResult(e,s,{valid:!0}),validator:s}),Promise.resolve("Valid");var o=this.validators[s],l=this.getElementValue(e,t,s);if(!this.filter.execute("field-should-validate",!0,[e,t,l,i]))return this.emit("core.validator.notvalidated",{element:t,elements:a,field:e,validator:i}),Promise.resolve("NotValidated");this.emit("core.validator.validating",{element:t,elements:a,field:e,validator:i});var c=o().validate({element:t,elements:a,field:e,l10n:this.localization,options:n,value:l});if("function"==typeof c.then)return c.then((function(n){var s=r.normalizeResult(e,i,n);return r.emit("core.validator.validated",{element:t,elements:a,field:e,result:s,validator:i}),s.valid?"Valid":"Invalid"}));var u=this.normalizeResult(e,i,c);return this.emit("core.validator.validated",{element:t,elements:a,field:e,result:u,validator:i}),Promise.resolve(u.valid?"Valid":"Invalid")},e.prototype.getElementValue=function(e,t,i){var n=function(e,t,i,n){var r=(i.getAttribute("type")||"").toLowerCase(),a=i.tagName.toLowerCase();if("textarea"===a)return i.value;if("select"===a){var s=i,o=s.selectedIndex;return o>=0?s.options.item(o).value:""}if("input"===a){if("radio"===r||"checkbox"===r){var l=n.filter((function(e){return e.checked})).length;return 0===l?"":l+""}return i.value}return""}(this.form,0,t,this.elements[e]);return this.filter.execute("field-value",n,[n,e,t,i])},e.prototype.getElements=function(e){return this.elements[e]},e.prototype.getFields=function(){return this.fields},e.prototype.getFormElement=function(){return this.form},e.prototype.getLocale=function(){return this.locale},e.prototype.getPlugin=function(e){return this.plugins[e]},e.prototype.updateFieldStatus=function(e,t,i){var n=this,r=this.elements[e],a=r[0].getAttribute("type");if(("radio"===a||"checkbox"===a?[r[0]]:r).forEach((function(r){return n.updateElementStatus(e,r,t,i)})),i)"Invalid"===t&&(this.emit("core.field.invalid",e),this.results.set(e,"Invalid"));else switch(t){case"NotValidated":this.emit("core.field.notvalidated",e),this.results.delete(e);break;case"Validating":this.emit("core.field.validating",e),this.results.delete(e);break;case"Valid":this.emit("core.field.valid",e),this.results.set(e,"Valid");break;case"Invalid":this.emit("core.field.invalid",e),this.results.set(e,"Invalid")}return this},e.prototype.updateElementStatus=function(e,t,i,n){var r=this,a=this.elements[e],s=this.fields[e].validators,o=n?[n]:Object.keys(s);switch(i){case"NotValidated":o.forEach((function(i){return r.emit("core.validator.notvalidated",{element:t,elements:a,field:e,validator:i})})),this.emit("core.element.notvalidated",{element:t,elements:a,field:e});break;case"Validating":o.forEach((function(i){return r.emit("core.validator.validating",{element:t,elements:a,field:e,validator:i})})),this.emit("core.element.validating",{element:t,elements:a,field:e});break;case"Valid":o.forEach((function(i){return r.emit("core.validator.validated",{element:t,elements:a,field:e,result:{message:s[i].message,valid:!0},validator:i})})),this.emit("core.element.validated",{element:t,elements:a,field:e,valid:!0});break;case"Invalid":o.forEach((function(i){return r.emit("core.validator.validated",{element:t,elements:a,field:e,result:{message:s[i].message,valid:!1},validator:i})})),this.emit("core.element.validated",{element:t,elements:a,field:e,valid:!1})}return this},e.prototype.resetForm=function(e){var t=this;return Object.keys(this.fields).forEach((function(i){return t.resetField(i,e)})),this.emit("core.form.reset",{formValidation:this,reset:e}),this},e.prototype.resetField=function(e,t){if(t){var i=this.elements[e],n=i[0].getAttribute("type");i.forEach((function(e){"radio"===n||"checkbox"===n?(e.removeAttribute("selected"),e.removeAttribute("checked"),e.checked=!1):(e.setAttribute("value",""),(e instanceof HTMLInputElement||e instanceof HTMLTextAreaElement)&&(e.value=""))}))}return this.updateFieldStatus(e,"NotValidated"),this.emit("core.field.reset",{field:e,reset:t}),this},e.prototype.revalidateField=function(e){return this.fields[e]?(this.updateFieldStatus(e,"NotValidated"),this.validateField(e)):Promise.resolve("Ignored")},e.prototype.disableValidator=function(e,t){if(!this.fields[e])return this;var i=this.elements[e];return this.toggleValidator(!1,e,t),this.emit("core.validator.disabled",{elements:i,field:e,formValidation:this,validator:t}),this},e.prototype.enableValidator=function(e,t){if(!this.fields[e])return this;var i=this.elements[e];return this.toggleValidator(!0,e,t),this.emit("core.validator.enabled",{elements:i,field:e,formValidation:this,validator:t}),this},e.prototype.updateValidatorOption=function(e,t,i,n){return this.fields[e]&&this.fields[e].validators&&this.fields[e].validators[t]&&(this.fields[e].validators[t][i]=n),this},e.prototype.setFieldOptions=function(e,t){return this.fields[e]=t,this},e.prototype.destroy=function(){var e=this;return Object.keys(this.plugins).forEach((function(t){return e.plugins[t].uninstall()})),this.ee.clear(),this.filter.clear(),this.results.clear(),this.plugins={},this},e.prototype.setLocale=function(e,t){return this.locale=e,this.localization=t,this},e.prototype.waterfall=function(e){return e.reduce((function(e,t){return e.then((function(e){return t().then((function(t){return e.push(t),e}))}))}),Promise.resolve([]))},e.prototype.queryElements=function(e){var t=this.fields[e].selector?"#"===this.fields[e].selector.charAt(0)?'[id="'.concat(this.fields[e].selector.substring(1),'"]'):this.fields[e].selector:'[name="'.concat(e.replace(/"/g,'\\"'),'"]');return[].slice.call(this.form.querySelectorAll(t))},e.prototype.normalizeResult=function(e,t,i){var n=this.fields[e].validators[t];return Object.assign({},i,{message:i.message||(n?n.message:"")||(this.localization&&this.localization[t]&&this.localization[t].default?this.localization[t].default:"")||"The field ".concat(e," is not valid")})},e.prototype.toggleValidator=function(e,t,i){var n=this,r=this.fields[t].validators;return i&&r&&r[i]?this.fields[t].validators[i].enabled=e:i||Object.keys(r).forEach((function(i){return n.fields[t].validators[i].enabled=e})),this.updateFieldStatus(t,"NotValidated",i)},e}(),r=function(){function e(e){this.opts=e,this.isEnabled=!0}return e.prototype.setCore=function(e){return this.core=e,this},e.prototype.enable=function(){return this.isEnabled=!0,this.onEnabled(),this},e.prototype.disable=function(){return this.isEnabled=!1,this.onDisabled(),this},e.prototype.isPluginEnabled=function(){return this.isEnabled},e.prototype.onEnabled=function(){},e.prototype.onDisabled=function(){},e.prototype.install=function(){},e.prototype.uninstall=function(){},e}(),a=function(e,t){var i=e.matches||e.webkitMatchesSelector||e.mozMatchesSelector||e.msMatchesSelector;return i?i.call(e,t):[].slice.call(e.parentElement.querySelectorAll(t)).indexOf(e)>=0},s={call:function(e,t){if("function"==typeof e)return e.apply(this,t);if("string"==typeof e){var i=e;"()"===i.substring(i.length-2)&&(i=i.substring(0,i.length-2));for(var n=i.split("."),r=n.pop(),a=window,s=0,o=n;s<o.length;s++)a=a[o[s]];return void 0===a[r]?null:a[r].apply(this,t)}},classSet:function(e,t){var i=[],n=[];Object.keys(t).forEach((function(e){e&&(t[e]?i.push(e):n.push(e))})),n.forEach((function(t){return function(e,t){t.split(" ").forEach((function(t){e.classList?e.classList.remove(t):e.className=e.className.replace(t,"")}))}(e,t)})),i.forEach((function(t){return function(e,t){t.split(" ").forEach((function(t){e.classList?e.classList.add(t):" ".concat(e.className," ").indexOf(" ".concat(t," "))&&(e.className+=" ".concat(t))}))}(e,t)}))},closest:function(e,t){for(var i=e;i&&!a(i,t);)i=i.parentElement;return i},fetch:function(e,t){return new Promise((function(i,n){var r,a=Object.assign({},{crossDomain:!1,headers:{},method:"GET",params:{}},t),s=Object.keys(a.params).map((function(e){return"".concat(encodeURIComponent(e),"=").concat(encodeURIComponent(a.params[e]))})).join("&"),o=e.indexOf("?")>-1,l="GET"===a.method?"".concat(e).concat(o?"&":"?").concat(s):e;if(a.crossDomain){var c=document.createElement("script"),u="___FormValidationFetch_".concat(Array(12).fill("").map((function(e){return Math.random().toString(36).charAt(2)})).join(""),"___");window[u]=function(e){delete window[u],i(e)},c.src="".concat(l).concat(o?"&":"?","callback=").concat(u),c.async=!0,c.addEventListener("load",(function(){c.parentNode.removeChild(c)})),c.addEventListener("error",(function(){return n})),document.head.appendChild(c)}else{var d=new XMLHttpRequest;d.open(a.method,l),d.setRequestHeader("X-Requested-With","XMLHttpRequest"),"POST"===a.method&&d.setRequestHeader("Content-Type","application/x-www-form-urlencoded"),Object.keys(a.headers).forEach((function(e){return d.setRequestHeader(e,a.headers[e])})),d.addEventListener("load",(function(){i(JSON.parse(this.responseText))})),d.addEventListener("error",(function(){return n})),d.send((r=a.params,Object.keys(r).map((function(e){return"".concat(encodeURIComponent(e),"=").concat(encodeURIComponent(r[e]))})).join("&")))}}))},format:function(e,t){var i=Array.isArray(t)?t:[t],n=e;return i.forEach((function(e){n=n.replace("%s",e)})),n},hasClass:function(e,t){return e.classList?e.classList.contains(t):new RegExp("(^| )".concat(t,"( |$)"),"gi").test(e.className)},isValidDate:function(e,t,i,n){if(isNaN(e)||isNaN(t)||isNaN(i))return!1;if(e<1e3||e>9999||t<=0||t>12)return!1;if(i<=0||i>[31,e%400==0||e%100!=0&&e%4==0?29:28,31,30,31,30,31,31,30,31,30,31][t-1])return!1;if(!0===n){var r=new Date,a=r.getFullYear(),s=r.getMonth(),o=r.getDate();return e<a||e===a&&t-1<s||e===a&&t-1===s&&i<o}return!0},removeUndefined:function(e){return e?Object.entries(e).reduce((function(e,t){var i=t[0],n=t[1];return void 0===n||(e[i]=n),e}),{}):{}}};return n.Plugin=r,n.algorithms=e,n.formValidation=function(e,t){var n=Object.assign({},{fields:{},locale:"en_US",plugins:{},init:function(e){}},t),r=new i(e,n.fields);return r.setLocale(n.locale,n.localization),Object.keys(n.plugins).forEach((function(e){return r.registerPlugin(e,n.plugins[e])})),n.init(r),Object.keys(n.fields).forEach((function(e){return r.addField(e,n.fields[e])})),r},n.utils=s,n}();var r,a=i.exports,s={exports:{}},o={};s.exports=function(){if(r)return o;r=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.opts=e||{},i.validatorNameFilter=i.getValidatorName.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.registerFilter("validator-name",this.validatorNameFilter)},i.prototype.uninstall=function(){this.core.deregisterFilter("validator-name",this.validatorNameFilter)},i.prototype.getValidatorName=function(e,t){return this.isEnabled&&this.opts[e]||e},i}(a.Plugin);return o.Alias=t,o}();var l,c=s.exports,u={exports:{}},d={};u.exports=function(){if(l)return d;l=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(){var e=t.call(this,{})||this;return e.elementValidatedHandler=e.onElementValidated.bind(e),e.fieldValidHandler=e.onFieldValid.bind(e),e.fieldInvalidHandler=e.onFieldInvalid.bind(e),e.messageDisplayedHandler=e.onMessageDisplayed.bind(e),e}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("core.field.valid",this.fieldValidHandler).on("core.field.invalid",this.fieldInvalidHandler).on("core.element.validated",this.elementValidatedHandler).on("plugins.message.displayed",this.messageDisplayedHandler)},i.prototype.uninstall=function(){this.core.off("core.field.valid",this.fieldValidHandler).off("core.field.invalid",this.fieldInvalidHandler).off("core.element.validated",this.elementValidatedHandler).off("plugins.message.displayed",this.messageDisplayedHandler)},i.prototype.onElementValidated=function(e){e.valid&&(e.element.setAttribute("aria-invalid","false"),e.element.removeAttribute("aria-describedby"))},i.prototype.onFieldValid=function(e){var t=this.core.getElements(e);t&&t.forEach((function(e){e.setAttribute("aria-invalid","false"),e.removeAttribute("aria-describedby")}))},i.prototype.onFieldInvalid=function(e){var t=this.core.getElements(e);t&&t.forEach((function(e){return e.setAttribute("aria-invalid","true")}))},i.prototype.onMessageDisplayed=function(e){e.messageElement.setAttribute("role","alert"),e.messageElement.setAttribute("aria-hidden","false");var t=this.core.getElements(e.field),i=t.indexOf(e.element),n="js-fv-".concat(e.field,"-").concat(i,"-").concat(Date.now(),"-message");e.messageElement.setAttribute("id",n),e.element.setAttribute("aria-describedby",n);var r=e.element.getAttribute("type");"radio"!==r&&"checkbox"!==r||t.forEach((function(e){return e.setAttribute("aria-describedby",n)}))},i}(a.Plugin);return d.Aria=t,d}();var h,f=u.exports,p={exports:{}},m={};p.exports=function(){if(h)return m;h=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.addedFields=new Map,i.opts=Object.assign({},{html5Input:!1,pluginPrefix:"data-fvp-",prefix:"data-fv-"},e),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){var e=this;this.parsePlugins();var t=this.parseOptions();Object.keys(t).forEach((function(i){e.addedFields.has(i)||e.addedFields.set(i,!0),e.core.addField(i,t[i])})),this.core.on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler)},i.prototype.uninstall=function(){this.addedFields.clear(),this.core.off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler)},i.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&0!==i.length&&!this.addedFields.has(e.field)&&(this.addedFields.set(e.field,!0),i.forEach((function(i){var n=t.parseElement(i);if(!t.isEmptyOption(n)){var r={selector:e.options.selector,validators:Object.assign({},e.options.validators||{},n.validators)};t.core.setFieldOptions(e.field,r)}})))},i.prototype.onFieldRemoved=function(e){e.field&&this.addedFields.has(e.field)&&this.addedFields.delete(e.field)},i.prototype.parseOptions=function(){var e=this,t=this.opts.prefix,i={},n=this.core.getFields(),r=this.core.getFormElement();return[].slice.call(r.querySelectorAll("[name], [".concat(t,"field]"))).forEach((function(n){var r=e.parseElement(n);if(!e.isEmptyOption(r)){var a=n.getAttribute("name")||n.getAttribute("".concat(t,"field"));i[a]=Object.assign({},i[a],r)}})),Object.keys(i).forEach((function(e){Object.keys(i[e].validators).forEach((function(t){i[e].validators[t].enabled=i[e].validators[t].enabled||!1,n[e]&&n[e].validators&&n[e].validators[t]&&Object.assign(i[e].validators[t],n[e].validators[t])}))})),Object.assign({},n,i)},i.prototype.createPluginInstance=function(e,t){for(var i=e.split("."),n=window||this,r=0,a=i.length;r<a;r++)n=n[i[r]];if("function"!=typeof n)throw new Error("the plugin ".concat(e," doesn't exist"));return new n(t)},i.prototype.parsePlugins=function(){for(var e,t=this,i=this.core.getFormElement(),n=new RegExp("^".concat(this.opts.pluginPrefix,"([a-z0-9-]+)(___)*([a-z0-9-]+)*$")),r=i.attributes.length,a={},s=0;s<r;s++){var o=i.attributes[s].name,l=i.attributes[s].value,c=n.exec(o);if(c&&4===c.length){var u=this.toCamelCase(c[1]);a[u]=Object.assign({},c[3]?((e={})[this.toCamelCase(c[3])]=l,e):{enabled:""===l||"true"===l},a[u])}}Object.keys(a).forEach((function(e){var i=a[e],n=i.enabled,r=i.class;if(n&&r){delete i.enabled,delete i.clazz;var s=t.createPluginInstance(r,i);t.core.registerPlugin(e,s)}}))},i.prototype.isEmptyOption=function(e){var t=e.validators;return 0===Object.keys(t).length&&t.constructor===Object},i.prototype.parseElement=function(e){for(var t=new RegExp("^".concat(this.opts.prefix,"([a-z0-9-]+)(___)*([a-z0-9-]+)*$")),i=e.attributes.length,n={},r=e.getAttribute("type"),a=0;a<i;a++){var s=e.attributes[a].name,o=e.attributes[a].value;if(this.opts.html5Input)switch(!0){case"minlength"===s:n.stringLength=Object.assign({},{enabled:!0,min:parseInt(o,10)},n.stringLength);break;case"maxlength"===s:n.stringLength=Object.assign({},{enabled:!0,max:parseInt(o,10)},n.stringLength);break;case"pattern"===s:n.regexp=Object.assign({},{enabled:!0,regexp:o},n.regexp);break;case"required"===s:n.notEmpty=Object.assign({},{enabled:!0},n.notEmpty);break;case"type"===s&&"color"===o:n.color=Object.assign({},{enabled:!0,type:"hex"},n.color);break;case"type"===s&&"email"===o:n.emailAddress=Object.assign({},{enabled:!0},n.emailAddress);break;case"type"===s&&"url"===o:n.uri=Object.assign({},{enabled:!0},n.uri);break;case"type"===s&&"range"===o:n.between=Object.assign({},{enabled:!0,max:parseFloat(e.getAttribute("max")),min:parseFloat(e.getAttribute("min"))},n.between);break;case"min"===s&&"date"!==r&&"range"!==r:n.greaterThan=Object.assign({},{enabled:!0,min:parseFloat(o)},n.greaterThan);break;case"max"===s&&"date"!==r&&"range"!==r:n.lessThan=Object.assign({},{enabled:!0,max:parseFloat(o)},n.lessThan)}var l=t.exec(s);if(l&&4===l.length){var c=this.toCamelCase(l[1]);n[c]||(n[c]={}),l[3]?n[c][this.toCamelCase(l[3])]=this.normalizeValue(o):!0===n[c].enabled&&!1===n[c].enabled||(n[c].enabled=""===o||"true"===o)}}return{validators:n}},i.prototype.normalizeValue=function(e){return"true"===e||""===e||"false"!==e&&e},i.prototype.toUpperCase=function(e){return e.charAt(1).toUpperCase()},i.prototype.toCamelCase=function(e){return e.replace(/-./g,this.toUpperCase)},i}(a.Plugin);return m.Declarative=t,m}();var g,v=p.exports,y={exports:{}},b={};y.exports=function(){if(g)return b;g=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(){var e=t.call(this,{})||this;return e.onValidHandler=e.onFormValid.bind(e),e}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){if(this.core.getFormElement().querySelectorAll('[type="submit"][name="submit"]').length)throw new Error("Do not use `submit` for the name attribute of submit button");this.core.on("core.form.valid",this.onValidHandler)},i.prototype.uninstall=function(){this.core.off("core.form.valid",this.onValidHandler)},i.prototype.onFormValid=function(){var e=this.core.getFormElement();this.isEnabled&&e instanceof HTMLFormElement&&e.submit()},i}(a.Plugin);return b.DefaultSubmit=t,b}();var x,_=y.exports,w={exports:{}},k={};w.exports=function(){if(x)return k;x=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.opts=e||{},i.triggerExecutedHandler=i.onTriggerExecuted.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("plugins.trigger.executed",this.triggerExecutedHandler)},i.prototype.uninstall=function(){this.core.off("plugins.trigger.executed",this.triggerExecutedHandler)},i.prototype.onTriggerExecuted=function(e){if(this.isEnabled&&this.opts[e.field])for(var t=0,i=this.opts[e.field].split(" ");t<i.length;t++){var n=i[t].trim();this.opts[n]&&this.core.revalidateField(n)}},i}(a.Plugin);return k.Dependency=t,k}();var M,S=w.exports,A={exports:{}},L={};A.exports=function(){if(M)return L;M=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.removeUndefined,n=function(e){function n(t){var r=e.call(this,t)||this;return r.opts=Object.assign({},{excluded:n.defaultIgnore},i(t)),r.ignoreValidationFilter=r.ignoreValidation.bind(r),r}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.defaultIgnore=function(e,t,i){var n=!!(t.offsetWidth||t.offsetHeight||t.getClientRects().length),r=t.getAttribute("disabled");return""===r||"disabled"===r||"hidden"===t.getAttribute("type")||!n},n.prototype.install=function(){this.core.registerFilter("element-ignored",this.ignoreValidationFilter)},n.prototype.uninstall=function(){this.core.deregisterFilter("element-ignored",this.ignoreValidationFilter)},n.prototype.ignoreValidation=function(e,t,i){return!!this.isEnabled&&this.opts.excluded.apply(this,[e,t,i])},n}(e.Plugin);return L.Excluded=n,L}();var T,C=A.exports,D={exports:{}},E={};D.exports=function(){if(T)return E;T=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.statuses=new Map,i.opts=Object.assign({},{onStatusChanged:function(){}},e),i.elementValidatingHandler=i.onElementValidating.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.elementNotValidatedHandler=i.onElementNotValidated.bind(i),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("core.element.validating",this.elementValidatingHandler).on("core.element.validated",this.elementValidatedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("core.element.ignored",this.elementIgnoredHandler).on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler)},i.prototype.uninstall=function(){this.statuses.clear(),this.core.off("core.element.validating",this.elementValidatingHandler).off("core.element.validated",this.elementValidatedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("core.element.ignored",this.elementIgnoredHandler).off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler)},i.prototype.areFieldsValid=function(){return Array.from(this.statuses.values()).every((function(e){return"Valid"===e||"NotValidated"===e||"Ignored"===e}))},i.prototype.getStatuses=function(){return this.isEnabled?this.statuses:new Map},i.prototype.onFieldAdded=function(e){this.statuses.set(e.field,"NotValidated")},i.prototype.onFieldRemoved=function(e){this.statuses.has(e.field)&&this.statuses.delete(e.field),this.handleStatusChanged(this.areFieldsValid())},i.prototype.onElementValidating=function(e){this.statuses.set(e.field,"Validating"),this.handleStatusChanged(!1)},i.prototype.onElementValidated=function(e){this.statuses.set(e.field,e.valid?"Valid":"Invalid"),e.valid?this.handleStatusChanged(this.areFieldsValid()):this.handleStatusChanged(!1)},i.prototype.onElementNotValidated=function(e){this.statuses.set(e.field,"NotValidated"),this.handleStatusChanged(!1)},i.prototype.onElementIgnored=function(e){this.statuses.set(e.field,"Ignored"),this.handleStatusChanged(this.areFieldsValid())},i.prototype.handleStatusChanged=function(e){this.isEnabled&&this.opts.onStatusChanged(e)},i}(a.Plugin);return E.FieldStatus=t,E}();var O,P=D.exports,Y={exports:{}},I={},N={exports:{}},j={};N.exports=function(){if(O)return j;O=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.classSet,n=function(e){function n(t){var i=e.call(this,t)||this;return i.useDefaultContainer=!1,i.messages=new Map,i.defaultContainer=document.createElement("div"),i.useDefaultContainer=!t||!t.container,i.opts=Object.assign({},{container:function(e,t){return i.defaultContainer}},t),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i.validatorValidatedHandler=i.onValidatorValidated.bind(i),i.validatorNotValidatedHandler=i.onValidatorNotValidated.bind(i),i}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.getClosestContainer=function(e,t,i){for(var n=e;n&&n!==t&&(n=n.parentElement,!i.test(n.className)););return n},n.prototype.install=function(){this.useDefaultContainer&&this.core.getFormElement().appendChild(this.defaultContainer),this.core.on("core.element.ignored",this.elementIgnoredHandler).on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler).on("core.validator.validated",this.validatorValidatedHandler).on("core.validator.notvalidated",this.validatorNotValidatedHandler)},n.prototype.uninstall=function(){this.useDefaultContainer&&this.core.getFormElement().removeChild(this.defaultContainer),this.messages.forEach((function(e){return e.parentNode.removeChild(e)})),this.messages.clear(),this.core.off("core.element.ignored",this.elementIgnoredHandler).off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler).off("core.validator.validated",this.validatorValidatedHandler).off("core.validator.notvalidated",this.validatorNotValidatedHandler)},n.prototype.onEnabled=function(){this.messages.forEach((function(e,t,n){i(t,{"fv-plugins-message-container--enabled":!0,"fv-plugins-message-container--disabled":!1})}))},n.prototype.onDisabled=function(){this.messages.forEach((function(e,t,n){i(t,{"fv-plugins-message-container--enabled":!1,"fv-plugins-message-container--disabled":!0})}))},n.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&(i.forEach((function(e){var i=t.messages.get(e);i&&(i.parentNode.removeChild(i),t.messages.delete(e))})),this.prepareFieldContainer(e.field,i))},n.prototype.onFieldRemoved=function(e){var t=this;if(e.elements.length&&e.field){var i=e.elements[0].getAttribute("type");("radio"===i||"checkbox"===i?[e.elements[0]]:e.elements).forEach((function(e){if(t.messages.has(e)){var i=t.messages.get(e);i.parentNode.removeChild(i),t.messages.delete(e)}}))}},n.prototype.prepareFieldContainer=function(e,t){var i=this;if(t.length){var n=t[0].getAttribute("type");"radio"===n||"checkbox"===n?this.prepareElementContainer(e,t[0],t):t.forEach((function(n){return i.prepareElementContainer(e,n,t)}))}},n.prototype.prepareElementContainer=function(e,t,n){var r;if("string"==typeof this.opts.container){var a="#"===this.opts.container.charAt(0)?'[id="'.concat(this.opts.container.substring(1),'"]'):this.opts.container;r=this.core.getFormElement().querySelector(a)}else r=this.opts.container(e,t);var s=document.createElement("div");r.appendChild(s),i(s,{"fv-plugins-message-container":!0,"fv-plugins-message-container--enabled":this.isEnabled,"fv-plugins-message-container--disabled":!this.isEnabled}),this.core.emit("plugins.message.placed",{element:t,elements:n,field:e,messageElement:s}),this.messages.set(t,s)},n.prototype.getMessage=function(e){return"string"==typeof e.message?e.message:e.message[this.core.getLocale()]},n.prototype.onValidatorValidated=function(e){var t,n=e.elements,r=e.element.getAttribute("type"),a=("radio"===r||"checkbox"===r)&&n.length>0?n[0]:e.element;if(this.messages.has(a)){var s=this.messages.get(a),o=s.querySelector('[data-field="'.concat(e.field.replace(/"/g,'\\"'),'"][data-validator="').concat(e.validator.replace(/"/g,'\\"'),'"]'));if(o||e.result.valid)o&&!e.result.valid?(o.innerHTML=this.getMessage(e.result),this.core.emit("plugins.message.displayed",{element:e.element,field:e.field,message:e.result.message,messageElement:o,meta:e.result.meta,validator:e.validator})):o&&e.result.valid&&s.removeChild(o);else{var l=document.createElement("div");l.innerHTML=this.getMessage(e.result),l.setAttribute("data-field",e.field),l.setAttribute("data-validator",e.validator),this.opts.clazz&&i(l,((t={})[this.opts.clazz]=!0,t)),s.appendChild(l),this.core.emit("plugins.message.displayed",{element:e.element,field:e.field,message:e.result.message,messageElement:l,meta:e.result.meta,validator:e.validator})}}},n.prototype.onValidatorNotValidated=function(e){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element;if(this.messages.has(n)){var r=this.messages.get(n),a=r.querySelector('[data-field="'.concat(e.field.replace(/"/g,'\\"'),'"][data-validator="').concat(e.validator.replace(/"/g,'\\"'),'"]'));a&&r.removeChild(a)}},n.prototype.onElementIgnored=function(e){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element;if(this.messages.has(n)){var r=this.messages.get(n);[].slice.call(r.querySelectorAll('[data-field="'.concat(e.field.replace(/"/g,'\\"'),'"]'))).forEach((function(e){r.removeChild(e)}))}},n}(e.Plugin);return j.Message=n,j}();var H,F=N.exports;
/** 
     * FormValidation (https://formvalidation.io)
     * The best validation library for JavaScript
     * (c) 2013 - 2023 Nguyen Huu Phuoc <me@phuoc.ng>
     *
     * @license https://formvalidation.io/license
     * @package @form-validation/plugin-framework
     * @version 2.4.0
     */Y.exports=function(){if(H)return I;H=1;var e=a,t=F,i=function(e,t){return i=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},i(e,t)},n=e.utils.classSet,r=e.utils.closest,s=function(e){function a(t){var i=e.call(this,t)||this;return i.results=new Map,i.containers=new Map,i.opts=Object.assign({},{defaultMessageContainer:!0,eleInvalidClass:"",eleValidClass:"",rowClasses:"",rowValidatingClass:""},t),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.elementValidatingHandler=i.onElementValidating.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.elementNotValidatedHandler=i.onElementNotValidated.bind(i),i.iconPlacedHandler=i.onIconPlaced.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i.messagePlacedHandler=i.onMessagePlaced.bind(i),i}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}i(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}(a,e),a.prototype.install=function(){var e,i=this;n(this.core.getFormElement(),((e={})[this.opts.formClass]=!0,e["fv-plugins-framework"]=!0,e)),this.core.on("core.element.ignored",this.elementIgnoredHandler).on("core.element.validating",this.elementValidatingHandler).on("core.element.validated",this.elementValidatedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("plugins.icon.placed",this.iconPlacedHandler).on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler),this.opts.defaultMessageContainer&&(this.core.registerPlugin(a.MESSAGE_PLUGIN,new t.Message({clazz:this.opts.messageClass,container:function(e,n){var a="string"==typeof i.opts.rowSelector?i.opts.rowSelector:i.opts.rowSelector(e,n),s=r(n,a);return t.Message.getClosestContainer(n,s,i.opts.rowPattern)}})),this.core.on("plugins.message.placed",this.messagePlacedHandler))},a.prototype.uninstall=function(){var e;this.results.clear(),this.containers.clear(),n(this.core.getFormElement(),((e={})[this.opts.formClass]=!1,e["fv-plugins-framework"]=!1,e)),this.core.off("core.element.ignored",this.elementIgnoredHandler).off("core.element.validating",this.elementValidatingHandler).off("core.element.validated",this.elementValidatedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("plugins.icon.placed",this.iconPlacedHandler).off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler),this.opts.defaultMessageContainer&&(this.core.deregisterPlugin(a.MESSAGE_PLUGIN),this.core.off("plugins.message.placed",this.messagePlacedHandler))},a.prototype.onEnabled=function(){var e;n(this.core.getFormElement(),((e={})[this.opts.formClass]=!0,e)),this.opts.defaultMessageContainer&&this.core.enablePlugin(a.MESSAGE_PLUGIN)},a.prototype.onDisabled=function(){var e;n(this.core.getFormElement(),((e={})[this.opts.formClass]=!1,e)),this.opts.defaultMessageContainer&&this.core.disablePlugin(a.MESSAGE_PLUGIN)},a.prototype.onIconPlaced=function(e){},a.prototype.onMessagePlaced=function(e){},a.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&(i.forEach((function(e){var i,r=t.containers.get(e);r&&(n(r,((i={})[t.opts.rowInvalidClass]=!1,i[t.opts.rowValidatingClass]=!1,i[t.opts.rowValidClass]=!1,i["fv-plugins-icon-container"]=!1,i)),t.containers.delete(e))})),this.prepareFieldContainer(e.field,i))},a.prototype.onFieldRemoved=function(e){var t=this;e.elements.forEach((function(e){var i,r=t.containers.get(e);r&&n(r,((i={})[t.opts.rowInvalidClass]=!1,i[t.opts.rowValidatingClass]=!1,i[t.opts.rowValidClass]=!1,i))}))},a.prototype.prepareFieldContainer=function(e,t){var i=this;if(t.length){var n=t[0].getAttribute("type");"radio"===n||"checkbox"===n?this.prepareElementContainer(e,t[0]):t.forEach((function(t){return i.prepareElementContainer(e,t)}))}},a.prototype.prepareElementContainer=function(e,t){var i,a="string"==typeof this.opts.rowSelector?this.opts.rowSelector:this.opts.rowSelector(e,t),s=r(t,a);s!==t&&(n(s,((i={})[this.opts.rowClasses]=!0,i["fv-plugins-icon-container"]=!0,i)),this.containers.set(t,s))},a.prototype.onElementValidating=function(e){this.removeClasses(e.element,e.elements)},a.prototype.onElementNotValidated=function(e){this.removeClasses(e.element,e.elements)},a.prototype.onElementIgnored=function(e){this.removeClasses(e.element,e.elements)},a.prototype.removeClasses=function(e,t){var i,r=this,a=e.getAttribute("type"),s="radio"===a||"checkbox"===a?t[0]:e;t.forEach((function(e){var t;n(e,((t={})[r.opts.eleValidClass]=!1,t[r.opts.eleInvalidClass]=!1,t))}));var o=this.containers.get(s);o&&n(o,((i={})[this.opts.rowInvalidClass]=!1,i[this.opts.rowValidatingClass]=!1,i[this.opts.rowValidClass]=!1,i))},a.prototype.onElementValidated=function(e){var t,i,r=this,a=e.elements,s=e.element.getAttribute("type"),o="radio"===s||"checkbox"===s?a[0]:e.element;a.forEach((function(t){var i;n(t,((i={})[r.opts.eleValidClass]=e.valid,i[r.opts.eleInvalidClass]=!e.valid,i))}));var l=this.containers.get(o);if(l)if(e.valid){this.results.delete(o);var c=!0;this.containers.forEach((function(e,t){e===l&&!1===r.results.get(t)&&(c=!1)})),c&&n(l,((i={})[this.opts.rowInvalidClass]=!1,i[this.opts.rowValidatingClass]=!1,i[this.opts.rowValidClass]=!0,i))}else this.results.set(o,!1),n(l,((t={})[this.opts.rowInvalidClass]=!0,t[this.opts.rowValidatingClass]=!1,t[this.opts.rowValidClass]=!1,t))},a.MESSAGE_PLUGIN="___frameworkMessage",a}(e.Plugin);return I.Framework=s,I}();var R,z=Y.exports,B={exports:{}},V={};B.exports=function(){if(R)return V;R=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.classSet,n=function(e){function n(t){var i=e.call(this,t)||this;return i.icons=new Map,i.opts=Object.assign({},{invalid:"fv-plugins-icon--invalid",onPlaced:function(){},onSet:function(){},valid:"fv-plugins-icon--valid",validating:"fv-plugins-icon--validating"},t),i.elementValidatingHandler=i.onElementValidating.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.elementNotValidatedHandler=i.onElementNotValidated.bind(i),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.prototype.install=function(){this.core.on("core.element.validating",this.elementValidatingHandler).on("core.element.validated",this.elementValidatedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("core.element.ignored",this.elementIgnoredHandler).on("core.field.added",this.fieldAddedHandler)},n.prototype.uninstall=function(){this.icons.forEach((function(e){return e.parentNode.removeChild(e)})),this.icons.clear(),this.core.off("core.element.validating",this.elementValidatingHandler).off("core.element.validated",this.elementValidatedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("core.element.ignored",this.elementIgnoredHandler).off("core.field.added",this.fieldAddedHandler)},n.prototype.onEnabled=function(){this.icons.forEach((function(e,t,n){i(t,{"fv-plugins-icon--enabled":!0,"fv-plugins-icon--disabled":!1})}))},n.prototype.onDisabled=function(){this.icons.forEach((function(e,t,n){i(t,{"fv-plugins-icon--enabled":!1,"fv-plugins-icon--disabled":!0})}))},n.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&(i.forEach((function(e){var i=t.icons.get(e);i&&(i.parentNode.removeChild(i),t.icons.delete(e))})),this.prepareFieldIcon(e.field,i))},n.prototype.prepareFieldIcon=function(e,t){var i=this;if(t.length){var n=t[0].getAttribute("type");"radio"===n||"checkbox"===n?this.prepareElementIcon(e,t[0]):t.forEach((function(t){return i.prepareElementIcon(e,t)}))}},n.prototype.prepareElementIcon=function(e,t){var n=document.createElement("i");n.setAttribute("data-field",e),t.parentNode.insertBefore(n,t.nextSibling),i(n,{"fv-plugins-icon":!0,"fv-plugins-icon--enabled":this.isEnabled,"fv-plugins-icon--disabled":!this.isEnabled});var r={classes:{invalid:this.opts.invalid,valid:this.opts.valid,validating:this.opts.validating},element:t,field:e,iconElement:n};this.core.emit("plugins.icon.placed",r),this.opts.onPlaced(r),this.icons.set(t,n)},n.prototype.onElementValidating=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!1,t[this.opts.valid]=!1,t[this.opts.validating]=!0,t)),n={element:e.element,field:e.field,iconElement:i,status:"Validating"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.onElementValidated=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!e.valid,t[this.opts.valid]=e.valid,t[this.opts.validating]=!1,t)),n={element:e.element,field:e.field,iconElement:i,status:e.valid?"Valid":"Invalid"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.onElementNotValidated=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!1,t[this.opts.valid]=!1,t[this.opts.validating]=!1,t)),n={element:e.element,field:e.field,iconElement:i,status:"NotValidated"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.onElementIgnored=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!1,t[this.opts.valid]=!1,t[this.opts.validating]=!1,t)),n={element:e.element,field:e.field,iconElement:i,status:"Ignored"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.setClasses=function(e,t,n,r){var a=t.getAttribute("type"),s="radio"===a||"checkbox"===a?n[0]:t;if(this.icons.has(s)){var o=this.icons.get(s);return i(o,r),o}return null},n}(e.Plugin);return V.Icon=n,V}();var W,U=B.exports,q={exports:{}},$={};q.exports=function(){if(W)return $;W=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.removeUndefined,n=function(e){function n(t){var n=e.call(this,t)||this;return n.invalidFields=new Map,n.opts=Object.assign({},{enabled:!0},i(t)),n.validatorHandler=n.onValidatorValidated.bind(n),n.shouldValidateFilter=n.shouldValidate.bind(n),n.fieldAddedHandler=n.onFieldAdded.bind(n),n.elementNotValidatedHandler=n.onElementNotValidated.bind(n),n.elementValidatingHandler=n.onElementValidating.bind(n),n}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.prototype.install=function(){this.core.on("core.validator.validated",this.validatorHandler).on("core.field.added",this.fieldAddedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("core.element.validating",this.elementValidatingHandler).registerFilter("field-should-validate",this.shouldValidateFilter)},n.prototype.uninstall=function(){this.invalidFields.clear(),this.core.off("core.validator.validated",this.validatorHandler).off("core.field.added",this.fieldAddedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("core.element.validating",this.elementValidatingHandler).deregisterFilter("field-should-validate",this.shouldValidateFilter)},n.prototype.shouldValidate=function(e,t,i,n){return!this.isEnabled||!((!0===this.opts.enabled||!0===this.opts.enabled[e])&&this.invalidFields.has(t)&&this.invalidFields.get(t).length&&-1===this.invalidFields.get(t).indexOf(n))},n.prototype.onValidatorValidated=function(e){var t=this.invalidFields.has(e.element)?this.invalidFields.get(e.element):[],i=t.indexOf(e.validator);e.result.valid&&i>=0?t.splice(i,1):e.result.valid||-1!==i||t.push(e.validator),this.invalidFields.set(e.element,t)},n.prototype.onFieldAdded=function(e){e.elements&&this.clearInvalidFields(e.elements)},n.prototype.onElementNotValidated=function(e){this.clearInvalidFields(e.elements)},n.prototype.onElementValidating=function(e){this.clearInvalidFields(e.elements)},n.prototype.clearInvalidFields=function(e){var t=this;e.forEach((function(e){return t.invalidFields.delete(e)}))},n}(e.Plugin);return $.Sequence=n,$}();var X,G=q.exports,Z={exports:{}},K={};Z.exports=function(){if(X)return K;X=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.isFormValid=!1,i.isButtonClicked=!1,i.opts=Object.assign({},{aspNetButton:!1,buttons:function(e){return[].slice.call(e.querySelectorAll('[type="submit"]:not([formnovalidate])'))},liveMode:!0},e),i.submitHandler=i.handleSubmitEvent.bind(i),i.buttonClickHandler=i.handleClickEvent.bind(i),i.ignoreValidationFilter=i.ignoreValidation.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){var e=this;if(this.core.getFormElement()instanceof HTMLFormElement){var t=this.core.getFormElement();this.submitButtons=this.opts.buttons(t),t.setAttribute("novalidate","novalidate"),t.addEventListener("submit",this.submitHandler),this.hiddenClickedEle=document.createElement("input"),this.hiddenClickedEle.setAttribute("type","hidden"),t.appendChild(this.hiddenClickedEle),this.submitButtons.forEach((function(t){t.addEventListener("click",e.buttonClickHandler)})),this.core.registerFilter("element-ignored",this.ignoreValidationFilter)}},i.prototype.uninstall=function(){var e=this,t=this.core.getFormElement();t instanceof HTMLFormElement&&t.removeEventListener("submit",this.submitHandler),this.submitButtons.forEach((function(t){t.removeEventListener("click",e.buttonClickHandler)})),this.hiddenClickedEle.parentElement.removeChild(this.hiddenClickedEle),this.core.deregisterFilter("element-ignored",this.ignoreValidationFilter)},i.prototype.handleSubmitEvent=function(e){this.validateForm(e)},i.prototype.handleClickEvent=function(e){var t=e.currentTarget;if(this.isButtonClicked=!0,t instanceof HTMLElement)if(this.opts.aspNetButton&&!0===this.isFormValid);else{this.core.getFormElement().removeEventListener("submit",this.submitHandler),this.clickedButton=e.target;var i=this.clickedButton.getAttribute("name"),n=this.clickedButton.getAttribute("value");i&&n&&(this.hiddenClickedEle.setAttribute("name",i),this.hiddenClickedEle.setAttribute("value",n)),this.validateForm(e)}},i.prototype.validateForm=function(e){var t=this;this.isEnabled&&(e.preventDefault(),this.core.validate().then((function(e){"Valid"===e&&t.opts.aspNetButton&&!t.isFormValid&&t.clickedButton&&(t.isFormValid=!0,t.clickedButton.removeEventListener("click",t.buttonClickHandler),t.clickedButton.click())})))},i.prototype.ignoreValidation=function(e,t,i){return!!this.isEnabled&&!this.opts.liveMode&&!this.isButtonClicked},i}(a.Plugin);return K.SubmitButton=t,K}();var J,Q=Z.exports,ee={exports:{}},te={};ee.exports=function(){if(J)return te;J=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.classSet,n=function(e){function n(t){var i=e.call(this,t)||this;return i.messages=new Map,i.opts=Object.assign({},{placement:"top",trigger:"click"},t),i.iconPlacedHandler=i.onIconPlaced.bind(i),i.validatorValidatedHandler=i.onValidatorValidated.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.documentClickHandler=i.onDocumentClicked.bind(i),i}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.prototype.install=function(){var e;this.tip=document.createElement("div"),i(this.tip,((e={"fv-plugins-tooltip":!0})["fv-plugins-tooltip--".concat(this.opts.placement)]=!0,e)),document.body.appendChild(this.tip),this.core.on("plugins.icon.placed",this.iconPlacedHandler).on("core.validator.validated",this.validatorValidatedHandler).on("core.element.validated",this.elementValidatedHandler),"click"===this.opts.trigger&&document.addEventListener("click",this.documentClickHandler)},n.prototype.uninstall=function(){this.messages.clear(),document.body.removeChild(this.tip),this.core.off("plugins.icon.placed",this.iconPlacedHandler).off("core.validator.validated",this.validatorValidatedHandler).off("core.element.validated",this.elementValidatedHandler),"click"===this.opts.trigger&&document.removeEventListener("click",this.documentClickHandler)},n.prototype.onIconPlaced=function(e){var t=this;i(e.iconElement,{"fv-plugins-tooltip-icon":!0}),"hover"===this.opts.trigger?(e.iconElement.addEventListener("mouseenter",(function(i){return t.show(e.element,i)})),e.iconElement.addEventListener("mouseleave",(function(e){return t.hide()}))):e.iconElement.addEventListener("click",(function(i){return t.show(e.element,i)}))},n.prototype.onValidatorValidated=function(e){if(!e.result.valid){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element,r="string"==typeof e.result.message?e.result.message:e.result.message[this.core.getLocale()];this.messages.set(n,r)}},n.prototype.onElementValidated=function(e){if(e.valid){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element;this.messages.delete(n)}},n.prototype.onDocumentClicked=function(e){this.hide()},n.prototype.show=function(e,t){if(this.isEnabled&&(t.preventDefault(),t.stopPropagation(),this.messages.has(e))){i(this.tip,{"fv-plugins-tooltip--hide":!1}),this.tip.innerHTML='<div class="fv-plugins-tooltip__content">'.concat(this.messages.get(e),"</div>");var n=t.target.getBoundingClientRect(),r=this.tip.getBoundingClientRect(),a=r.height,s=r.width,o=0,l=0;switch(this.opts.placement){case"bottom":o=n.top+n.height,l=n.left+n.width/2-s/2;break;case"bottom-left":o=n.top+n.height,l=n.left;break;case"bottom-right":o=n.top+n.height,l=n.left+n.width-s;break;case"left":o=n.top+n.height/2-a/2,l=n.left-s;break;case"right":o=n.top+n.height/2-a/2,l=n.left+n.width;break;case"top-left":o=n.top-a,l=n.left;break;case"top-right":o=n.top-a,l=n.left+n.width-s;break;default:o=n.top-a,l=n.left+n.width/2-s/2}o+=window.scrollY||document.documentElement.scrollTop||document.body.scrollTop||0,l+=window.scrollX||document.documentElement.scrollLeft||document.body.scrollLeft||0,this.tip.setAttribute("style","top: ".concat(o,"px; left: ").concat(l,"px"))}},n.prototype.hide=function(){this.isEnabled&&i(this.tip,{"fv-plugins-tooltip--hide":!0})},n}(e.Plugin);return te.Tooltip=n,te}();var ie,ne=ee.exports,re={exports:{}},ae={};re.exports=function(){if(ie)return ae;ie=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;i.handlers=[],i.timers=new Map;var n=document.createElement("div");return i.defaultEvent="oninput"in n?"input":"keyup",i.opts=Object.assign({},{delay:0,event:i.defaultEvent,threshold:0},e),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler)},i.prototype.uninstall=function(){this.handlers.forEach((function(e){return e.element.removeEventListener(e.event,e.handler)})),this.handlers=[],this.timers.forEach((function(e){return window.clearTimeout(e)})),this.timers.clear(),this.core.off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler)},i.prototype.prepareHandler=function(e,t){var i=this;t.forEach((function(t){var n=[];if(i.opts.event&&!1===i.opts.event[e])n=[];else if(i.opts.event&&i.opts.event[e]&&"function"!=typeof i.opts.event[e])n=i.opts.event[e].split(" ");else if("string"==typeof i.opts.event&&i.opts.event!==i.defaultEvent)n=i.opts.event.split(" ");else{var r=t.getAttribute("type"),a=t.tagName.toLowerCase();n=["radio"===r||"checkbox"===r||"file"===r||"select"===a?"change":i.ieVersion>=10&&t.getAttribute("placeholder")?"keyup":i.defaultEvent]}n.forEach((function(n){var r=function(n){return i.handleEvent(n,e,t)};i.handlers.push({element:t,event:n,field:e,handler:r}),t.addEventListener(n,r)}))}))},i.prototype.handleEvent=function(e,t,i){var n=this;if(this.isEnabled&&this.exceedThreshold(t,i)&&this.core.executeFilter("plugins-trigger-should-validate",!0,[t,i])){var r=function(){return n.core.validateElement(t,i).then((function(r){n.core.emit("plugins.trigger.executed",{element:i,event:e,field:t})}))},a=this.opts.delay[t]||this.opts.delay;if(0===a)r();else{var s=this.timers.get(i);s&&window.clearTimeout(s),this.timers.set(i,window.setTimeout(r,1e3*a))}}},i.prototype.onFieldAdded=function(e){this.handlers.filter((function(t){return t.field===e.field})).forEach((function(e){return e.element.removeEventListener(e.event,e.handler)})),this.prepareHandler(e.field,e.elements)},i.prototype.onFieldRemoved=function(e){this.handlers.filter((function(t){return t.field===e.field&&e.elements.indexOf(t.element)>=0})).forEach((function(e){return e.element.removeEventListener(e.event,e.handler)}))},i.prototype.exceedThreshold=function(e,t){var i=0!==this.opts.threshold[e]&&0!==this.opts.threshold&&(this.opts.threshold[e]||this.opts.threshold);if(!i)return!0;var n=t.getAttribute("type");return-1!==["button","checkbox","file","hidden","image","radio","reset","submit"].indexOf(n)||this.core.getElementValue(e,t).length>=i},i}(a.Plugin);return ae.Trigger=t,ae}();var se,oe=re.exports,le={exports:{}},ce={};le.exports=function(){if(se)return ce;se=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return ce.between=function(){var e=function(e){return parseFloat("".concat(e).replace(",","."))};return{validate:function(n){var r=n.value;if(""===r)return{valid:!0};var a=Object.assign({},{inclusive:!0,message:""},i(n.options)),s=e(a.min),o=e(a.max);return a.inclusive?{message:t(n.l10n?a.message||n.l10n.between.default:a.message,["".concat(s),"".concat(o)]),valid:parseFloat(r)>=s&&parseFloat(r)<=o}:{message:t(n.l10n?a.message||n.l10n.between.notInclusive:a.message,["".concat(s),"".concat(o)]),valid:parseFloat(r)>s&&parseFloat(r)<o}}}},ce}();var ue,de=le.exports,he={exports:{}},fe={};he.exports=(ue||(ue=1,fe.blank=function(){return{validate:function(e){return{valid:!0}}}}),fe);var pe,me=he.exports,ge={exports:{}},ve={};ge.exports=function(){if(pe)return ve;pe=1;var e=a.utils.call;return ve.callback=function(){return{validate:function(t){var i=e(t.options.callback,[t]);return"boolean"==typeof i?{valid:i}:i}}},ve}();var ye,be=ge.exports,xe={exports:{}},_e={};xe.exports=function(){if(ye)return _e;ye=1;var e=a.utils.format;return _e.choice=function(){return{validate:function(t){var i="select"===t.element.tagName.toLowerCase()?t.element.querySelectorAll("option:checked").length:t.elements.filter((function(e){return e.checked})).length,n=t.options.min?"".concat(t.options.min):"",r=t.options.max?"".concat(t.options.max):"",a=t.l10n?t.options.message||t.l10n.choice.default:t.options.message,s=!(n&&i<parseInt(n,10)||r&&i>parseInt(r,10));switch(!0){case!!n&&!!r:a=e(t.l10n?t.l10n.choice.between:t.options.message,[n,r]);break;case!!n:a=e(t.l10n?t.l10n.choice.more:t.options.message,n);break;case!!r:a=e(t.l10n?t.l10n.choice.less:t.options.message,r)}return{message:a,valid:s}}}},_e}();var we,ke=xe.exports,Me={exports:{}},Se={};Me.exports=function(){if(we)return Se;we=1;var e=a.algorithms.luhn,t={AMERICAN_EXPRESS:{length:[15],prefix:["34","37"]},DANKORT:{length:[16],prefix:["5019"]},DINERS_CLUB:{length:[14],prefix:["300","301","302","303","304","305","36"]},DINERS_CLUB_US:{length:[16],prefix:["54","55"]},DISCOVER:{length:[16],prefix:["6011","622126","622127","622128","622129","62213","62214","62215","62216","62217","62218","62219","6222","6223","6224","6225","6226","6227","6228","62290","62291","622920","622921","622922","622923","622924","622925","644","645","646","647","648","649","65"]},ELO:{length:[16],prefix:["4011","4312","4389","4514","4573","4576","5041","5066","5067","509","6277","6362","6363","650","6516","6550"]},FORBRUGSFORENINGEN:{length:[16],prefix:["600722"]},JCB:{length:[16],prefix:["3528","3529","353","354","355","356","357","358"]},LASER:{length:[16,17,18,19],prefix:["6304","6706","6771","6709"]},MAESTRO:{length:[12,13,14,15,16,17,18,19],prefix:["5018","5020","5038","5868","6304","6759","6761","6762","6763","6764","6765","6766"]},MASTERCARD:{length:[16],prefix:["51","52","53","54","55"]},SOLO:{length:[16,18,19],prefix:["6334","6767"]},UNIONPAY:{length:[16,17,18,19],prefix:["622126","622127","622128","622129","62213","62214","62215","62216","62217","62218","62219","6222","6223","6224","6225","6226","6227","6228","62290","62291","622920","622921","622922","622923","622924","622925"]},VISA:{length:[16],prefix:["4"]},VISA_ELECTRON:{length:[16],prefix:["4026","417500","4405","4508","4844","4913","4917"]}};return Se.CREDIT_CARD_TYPES=t,Se.creditCard=function(){return{validate:function(i){if(""===i.value)return{meta:{type:null},valid:!0};if(/[^0-9-\s]+/.test(i.value))return{meta:{type:null},valid:!1};var n=i.value.replace(/\D/g,"");if(!e(n))return{meta:{type:null},valid:!1};for(var r=0,a=Object.keys(t);r<a.length;r++){var s=a[r];for(var o in t[s].prefix)if(i.value.substr(0,t[s].prefix[o].length)===t[s].prefix[o]&&-1!==t[s].length.indexOf(n.length))return{meta:{type:s},valid:!0}}return{meta:{type:null},valid:!1}}}},Se}();var Ae,Le=Me.exports,Te={exports:{}},Ce={};Te.exports=function(){if(Ae)return Ce;Ae=1;var e=a,t=e.utils.format,i=e.utils.isValidDate,n=e.utils.removeUndefined,r=function(e,t,i){var n=t.indexOf("YYYY"),r=t.indexOf("MM"),a=t.indexOf("DD");if(-1===n||-1===r||-1===a)return null;var s=e.split(" "),o=s[0].split(i);if(o.length<3)return null;var l=new Date(parseInt(o[n],10),parseInt(o[r],10)-1,parseInt(o[a],10)),c=s.length>2?s[2]:null;if(s.length>1){var u=s[1].split(":"),d=u.length>0?parseInt(u[0],10):0;l.setHours(c&&"PM"===c.toUpperCase()&&d<12?d+12:d),l.setMinutes(u.length>1?parseInt(u[1],10):0),l.setSeconds(u.length>2?parseInt(u[2],10):0)}return l},s=function(e,t){var i=t.replace(/Y/g,"y").replace(/M/g,"m").replace(/D/g,"d").replace(/:m/g,":M").replace(/:mm/g,":MM").replace(/:S/,":s").replace(/:SS/,":ss"),n=e.getDate(),r=n<10?"0".concat(n):n,a=e.getMonth()+1,s=a<10?"0".concat(a):a,o="".concat(e.getFullYear()).substr(2),l=e.getFullYear(),c=e.getHours()%12||12,u=c<10?"0".concat(c):c,d=e.getHours(),h=d<10?"0".concat(d):d,f=e.getMinutes(),p=f<10?"0".concat(f):f,m=e.getSeconds(),g=m<10?"0".concat(m):m,v={H:"".concat(d),HH:"".concat(h),M:"".concat(f),MM:"".concat(p),d:"".concat(n),dd:"".concat(r),h:"".concat(c),hh:"".concat(u),m:"".concat(a),mm:"".concat(s),s:"".concat(m),ss:"".concat(g),yy:"".concat(o),yyyy:"".concat(l)};return i.replace(/d{1,4}|m{1,4}|yy(?:yy)?|([HhMs])\1?|"[^"]*"|'[^']*'/g,(function(e){return v[e]?v[e]:e.slice(1,e.length-1)}))};return Ce.date=function(){return{validate:function(e){if(""===e.value)return{meta:{date:null},valid:!0};var a=Object.assign({},{format:e.element&&"date"===e.element.getAttribute("type")?"YYYY-MM-DD":"MM/DD/YYYY",message:""},n(e.options)),o=e.l10n?e.l10n.date.default:a.message,l={message:"".concat(o),meta:{date:null},valid:!1},c=a.format.split(" "),u=c.length>1?c[1]:null,d=c.length>2?c[2]:null,h=e.value.split(" "),f=h[0],p=h.length>1?h[1]:null,m=h.length>2?h[2]:null;if(c.length!==h.length)return l;var g=a.separator||(-1!==f.indexOf("/")?"/":-1!==f.indexOf("-")?"-":-1!==f.indexOf(".")?".":"/");if(null===g||-1===f.indexOf(g))return l;var v=f.split(g),y=c[0].split(g);if(v.length!==y.length)return l;var b=v[y.indexOf("YYYY")],x=v[y.indexOf("MM")],_=v[y.indexOf("DD")];if(!/^\d+$/.test(b)||!/^\d+$/.test(x)||!/^\d+$/.test(_)||b.length>4||x.length>2||_.length>2)return l;var w=parseInt(b,10),k=parseInt(x,10),M=parseInt(_,10);if(!i(w,k,M))return l;var S=new Date(w,k-1,M);if(u){var A=p.split(":");if(u.split(":").length!==A.length)return l;var L=A.length>0?A[0].length<=2&&/^\d+$/.test(A[0])?parseInt(A[0],10):-1:0,T=A.length>1?A[1].length<=2&&/^\d+$/.test(A[1])?parseInt(A[1],10):-1:0,C=A.length>2?A[2].length<=2&&/^\d+$/.test(A[2])?parseInt(A[2],10):-1:0;if(-1===L||-1===T||-1===C)return l;if(C<0||C>60)return l;if(L<0||L>=24||d&&L>12)return l;if(T<0||T>59)return l;S.setHours(m&&"PM"===m.toUpperCase()&&L<12?L+12:L),S.setMinutes(T),S.setSeconds(C)}var D="function"==typeof a.min?a.min():a.min,E=D instanceof Date?D:D?r(D,y,g):S,O="function"==typeof a.max?a.max():a.max,P=O instanceof Date?O:O?r(O,y,g):S,Y=D instanceof Date?s(E,a.format):D,I=O instanceof Date?s(P,a.format):O;switch(!0){case!!Y&&!I:return{message:t(e.l10n?e.l10n.date.min:o,Y),meta:{date:S},valid:S.getTime()>=E.getTime()};case!!I&&!Y:return{message:t(e.l10n?e.l10n.date.max:o,I),meta:{date:S},valid:S.getTime()<=P.getTime()};case!!I&&!!Y:return{message:t(e.l10n?e.l10n.date.range:o,[Y,I]),meta:{date:S},valid:S.getTime()<=P.getTime()&&S.getTime()>=E.getTime()};default:return{message:"".concat(o),meta:{date:S},valid:!0}}}}},Ce}();var De,Ee=Te.exports,Oe={exports:{}},Pe={};Oe.exports=(De||(De=1,Pe.different=function(){return{validate:function(e){var t="function"==typeof e.options.compare?e.options.compare.call(this):e.options.compare;return{valid:""===t||e.value!==t}}}}),Pe);var Ye,Ie=Oe.exports,Ne={exports:{}},je={};Ne.exports=(Ye||(Ye=1,je.digits=function(){return{validate:function(e){return{valid:""===e.value||/^\d+$/.test(e.value)}}}}),je);var He,Fe=Ne.exports,Re={exports:{}},ze={};Re.exports=function(){if(He)return ze;He=1;var e=a.utils.removeUndefined,t=/^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/,i=/^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+$/;return ze.emailAddress=function(){return{validate:function(n){if(""===n.value)return{valid:!0};var r=Object.assign({},{multiple:!1,requireGlobalDomain:!1,separator:/[,;]/},e(n.options)),a=r.requireGlobalDomain?i:t;if(!0===r.multiple||"true"==="".concat(r.multiple)){for(var s=r.separator||/[,;]/,o=function(e,t){for(var i=e.split(/"/),n=i.length,r=[],a="",s=0;s<n;s++)if(s%2==0){var o=i[s].split(t),l=o.length;if(1===l)a+=o[0];else{r.push(a+o[0]);for(var c=1;c<l-1;c++)r.push(o[c]);a=o[l-1]}}else a+='"'+i[s],s<n-1&&(a+='"');return r.push(a),r}(n.value,s),l=o.length,c=0;c<l;c++)if(!a.test(o[c]))return{valid:!1};return{valid:!0}}return{valid:a.test(n.value)}}}},ze}();var Be,Ve=Re.exports,We={exports:{}},Ue={};We.exports=function(){if(Be)return Ue;Be=1;var e=function(e){return-1===e.indexOf(".")?e:e.split(".").slice(0,-1).join(".")};return Ue.file=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i,n,r=t.options.extension?t.options.extension.toLowerCase().split(",").map((function(e){return e.trim()})):[],a=t.options.type?t.options.type.toLowerCase().split(",").map((function(e){return e.trim()})):[];if(window.File&&window.FileList&&window.FileReader){var s=t.element.files,o=s.length,l=0;if(t.options.maxFiles&&o>parseInt("".concat(t.options.maxFiles),10))return{meta:{error:"INVALID_MAX_FILES"},valid:!1};if(t.options.minFiles&&o<parseInt("".concat(t.options.minFiles),10))return{meta:{error:"INVALID_MIN_FILES"},valid:!1};for(var c={},u=0;u<o;u++){if(l+=s[u].size,c={ext:i=s[u].name.substr(s[u].name.lastIndexOf(".")+1),file:s[u],size:s[u].size,type:s[u].type},t.options.minSize&&s[u].size<parseInt("".concat(t.options.minSize),10))return{meta:Object.assign({},{error:"INVALID_MIN_SIZE"},c),valid:!1};if(t.options.maxSize&&s[u].size>parseInt("".concat(t.options.maxSize),10))return{meta:Object.assign({},{error:"INVALID_MAX_SIZE"},c),valid:!1};if(r.length>0&&-1===r.indexOf(i.toLowerCase()))return{meta:Object.assign({},{error:"INVALID_EXTENSION"},c),valid:!1};if(a.length>0&&s[u].type&&-1===a.indexOf(s[u].type.toLowerCase()))return{meta:Object.assign({},{error:"INVALID_TYPE"},c),valid:!1};if(t.options.validateFileName&&!t.options.validateFileName(e(s[u].name)))return{meta:Object.assign({},{error:"INVALID_NAME"},c),valid:!1}}if(t.options.maxTotalSize&&l>parseInt("".concat(t.options.maxTotalSize),10))return{meta:Object.assign({},{error:"INVALID_MAX_TOTAL_SIZE",totalSize:l},c),valid:!1};if(t.options.minTotalSize&&l<parseInt("".concat(t.options.minTotalSize),10))return{meta:Object.assign({},{error:"INVALID_MIN_TOTAL_SIZE",totalSize:l},c),valid:!1}}else{if(i=t.value.substr(t.value.lastIndexOf(".")+1),r.length>0&&-1===r.indexOf(i.toLowerCase()))return{meta:{error:"INVALID_EXTENSION",ext:i},valid:!1};if(n=e(t.value),t.options.validateFileName&&!t.options.validateFileName(n))return{meta:{error:"INVALID_NAME",name:n},valid:!1}}return{valid:!0}}}},Ue}();var qe,$e=We.exports,Xe={exports:{}},Ge={};Xe.exports=function(){if(qe)return Ge;qe=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return Ge.greaterThan=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var n=Object.assign({},{inclusive:!0,message:""},i(e.options)),r=parseFloat("".concat(n.min).replace(",","."));return n.inclusive?{message:t(e.l10n?n.message||e.l10n.greaterThan.default:n.message,"".concat(r)),valid:parseFloat(e.value)>=r}:{message:t(e.l10n?n.message||e.l10n.greaterThan.notInclusive:n.message,"".concat(r)),valid:parseFloat(e.value)>r}}}},Ge}();var Ze,Ke=Xe.exports,Je={exports:{}},Qe={};Je.exports=(Ze||(Ze=1,Qe.identical=function(){return{validate:function(e){var t="function"==typeof e.options.compare?e.options.compare.call(this):e.options.compare;return{valid:""===t||e.value===t}}}}),Qe);var et,tt=Je.exports,it={exports:{}},nt={};it.exports=function(){if(et)return nt;et=1;var e=a.utils.removeUndefined;return nt.integer=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{decimalSeparator:".",thousandsSeparator:""},e(t.options)),n="."===i.decimalSeparator?"\\.":i.decimalSeparator,r="."===i.thousandsSeparator?"\\.":i.thousandsSeparator,a=new RegExp("^-?[0-9]{1,3}(".concat(r,"[0-9]{3})*(").concat(n,"[0-9]+)?$")),s=new RegExp(r,"g"),o="".concat(t.value);if(!a.test(o))return{valid:!1};r&&(o=o.replace(s,"")),n&&(o=o.replace(n,"."));var l=parseFloat(o);return{valid:!isNaN(l)&&isFinite(l)&&Math.floor(l)===l}}}},nt}();var rt,at=it.exports,st={exports:{}},ot={};st.exports=function(){if(rt)return ot;rt=1;var e=a.utils.removeUndefined;return ot.ip=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{ipv4:!0,ipv6:!0},e(t.options)),n=/^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(\/([0-9]|[1-2][0-9]|3[0-2]))?$/,r=/^\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(%.+)?\s*(\/(\d|\d\d|1[0-1]\d|12[0-8]))?$/;switch(!0){case i.ipv4&&!i.ipv6:return{message:t.l10n?i.message||t.l10n.ip.ipv4:i.message,valid:n.test(t.value)};case!i.ipv4&&i.ipv6:return{message:t.l10n?i.message||t.l10n.ip.ipv6:i.message,valid:r.test(t.value)};case i.ipv4&&i.ipv6:default:return{message:t.l10n?i.message||t.l10n.ip.default:i.message,valid:n.test(t.value)||r.test(t.value)}}}}},ot}();var lt,ct=st.exports,ut={exports:{}},dt={};ut.exports=function(){if(lt)return dt;lt=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return dt.lessThan=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var n=Object.assign({},{inclusive:!0,message:""},i(e.options)),r=parseFloat("".concat(n.max).replace(",","."));return n.inclusive?{message:t(e.l10n?n.message||e.l10n.lessThan.default:n.message,"".concat(r)),valid:parseFloat(e.value)<=r}:{message:t(e.l10n?n.message||e.l10n.lessThan.notInclusive:n.message,"".concat(r)),valid:parseFloat(e.value)<r}}}},dt}();var ht,ft=ut.exports,pt={exports:{}},mt={};pt.exports=(ht||(ht=1,mt.notEmpty=function(){return{validate:function(e){var t=!!e.options&&!!e.options.trim,i=e.value;return{valid:!t&&""!==i||t&&""!==i&&""!==i.trim()}}}}),mt);var gt,vt=pt.exports,yt={exports:{}},bt={};yt.exports=function(){if(gt)return bt;gt=1;var e=a.utils.removeUndefined;return bt.numeric=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{decimalSeparator:".",thousandsSeparator:""},e(t.options)),n="".concat(t.value);n.substr(0,1)===i.decimalSeparator?n="0".concat(i.decimalSeparator).concat(n.substr(1)):n.substr(0,2)==="-".concat(i.decimalSeparator)&&(n="-0".concat(i.decimalSeparator).concat(n.substr(2)));var r="."===i.decimalSeparator?"\\.":i.decimalSeparator,a="."===i.thousandsSeparator?"\\.":i.thousandsSeparator,s=new RegExp("^-?[0-9]{1,3}(".concat(a,"[0-9]{3})*(").concat(r,"[0-9]+)?$")),o=new RegExp(a,"g");if(!s.test(n))return{valid:!1};a&&(n=n.replace(o,"")),r&&(n=n.replace(r,"."));var l=parseFloat(n);return{valid:!isNaN(l)&&isFinite(l)}}}},bt}();var xt,_t=yt.exports,wt={exports:{}},kt={};wt.exports=function(){if(xt)return kt;xt=1;var e=a.utils.call;return kt.promise=function(){return{validate:function(t){return e(t.options.promise,[t])}}},kt}();var Mt,St=wt.exports,At={exports:{}},Lt={};At.exports=(Mt||(Mt=1,Lt.regexp=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var t=e.options.regexp;if(t instanceof RegExp)return{valid:t.test(e.value)};var i=t.toString();return{valid:(e.options.flags?new RegExp(i,e.options.flags):new RegExp(i)).test(e.value)}}}}),Lt);var Tt,Ct=At.exports,Dt={exports:{}},Et={};Dt.exports=function(){if(Tt)return Et;Tt=1;var e=a,t=e.utils.fetch,i=e.utils.removeUndefined;return Et.remote=function(){var e={crossDomain:!1,data:{},headers:{},method:"GET",validKey:"valid"};return{validate:function(n){if(""===n.value)return Promise.resolve({valid:!0});var r=Object.assign({},e,i(n.options)),a=r.data;"function"==typeof r.data&&(a=r.data.call(this,n)),"string"==typeof a&&(a=JSON.parse(a)),a[r.name||n.field]=n.value;var s="function"==typeof r.url?r.url.call(this,n):r.url;return t(s,{crossDomain:r.crossDomain,headers:r.headers,method:r.method,params:a}).then((function(e){return Promise.resolve({message:e.message,meta:e,valid:"true"==="".concat(e[r.validKey])})})).catch((function(e){return Promise.reject({valid:!1})}))}}},Et}();var Ot,Pt=Dt.exports,Yt={exports:{}},It={};Yt.exports=function(){if(Ot)return It;Ot=1;var e=a.utils.removeUndefined;return It.stringCase=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{case:"lower"},e(t.options)),n=(i.case||"lower").toLowerCase();return{message:i.message||(t.l10n?"upper"===n?t.l10n.stringCase.upper:t.l10n.stringCase.default:i.message),valid:"upper"===n?t.value===t.value.toUpperCase():t.value===t.value.toLowerCase()}}}},It}();var Nt,jt=Yt.exports,Ht={exports:{}},Ft={};Ht.exports=function(){if(Nt)return Ft;Nt=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return Ft.stringLength=function(){return{validate:function(e){var n=Object.assign({},{message:"",trim:!1,utf8Bytes:!1},i(e.options)),r=!0===n.trim||"true"==="".concat(n.trim)?e.value.trim():e.value;if(""===r)return{valid:!0};var a=n.min?"".concat(n.min):"",s=n.max?"".concat(n.max):"",o=n.utf8Bytes?function(e){for(var t=e.length,i=e.length-1;i>=0;i--){var n=e.charCodeAt(i);n>127&&n<=2047?t++:n>2047&&n<=65535&&(t+=2),n>=56320&&n<=57343&&i--}return t}(r):r.length,l=!0,c=e.l10n?n.message||e.l10n.stringLength.default:n.message;switch((a&&o<parseInt(a,10)||s&&o>parseInt(s,10))&&(l=!1),!0){case!!a&&!!s:c=t(e.l10n?n.message||e.l10n.stringLength.between:n.message,[a,s]);break;case!!a:c=t(e.l10n?n.message||e.l10n.stringLength.more:n.message,"".concat(parseInt(a,10)));break;case!!s:c=t(e.l10n?n.message||e.l10n.stringLength.less:n.message,"".concat(parseInt(s,10)))}return{message:c,valid:l}}}},Ft}();var Rt,zt=Ht.exports,Bt={exports:{}},Vt={};Bt.exports=function(){if(Rt)return Vt;Rt=1;var e=a.utils.removeUndefined;return Vt.uri=function(){var t={allowEmptyProtocol:!1,allowLocal:!1,protocol:"http, https, ftp"};return{validate:function(i){if(""===i.value)return{valid:!0};var n=Object.assign({},t,e(i.options)),r=!0===n.allowLocal||"true"==="".concat(n.allowLocal),a=!0===n.allowEmptyProtocol||"true"==="".concat(n.allowEmptyProtocol),s=n.protocol.split(",").join("|").replace(/\s/g,"");return{valid:new RegExp("^(?:(?:"+s+")://)"+(a?"?":"")+"(?:\\S+(?::\\S*)?@)?(?:"+(r?"":"(?!(?:10|127)(?:\\.\\d{1,3}){3})(?!(?:169\\.254|192\\.168)(?:\\.\\d{1,3}){2})(?!172\\.(?:1[6-9]|2\\d|3[0-1])(?:\\.\\d{1,3}){2})")+"(?:[1-9]\\d?|1\\d\\d|2[01]\\d|22[0-3])(?:\\.(?:1?\\d{1,2}|2[0-4]\\d|25[0-5])){2}(?:\\.(?:[1-9]\\d?|1\\d\\d|2[0-4]\\d|25[0-4]))|(?:(?:[a-z\\u00a1-\\uffff0-9]-?)*[a-z\\u00a1-\\uffff0-9]+)(?:\\.(?:[a-z\\u00a1-\\uffff0-9]-?)*[a-z\\u00a1-\\uffff0-9])*(?:\\.(?:[a-z\\u00a1-\\uffff]{2,}))"+(r?"?":"")+")(?::\\d{2,5})?(?:/[^\\s]*)?$","i").test(i.value)}}}},Vt}();var Wt=Bt.exports,Ut={Alias:c.Alias,Aria:f.Aria,Declarative:v.Declarative,DefaultSubmit:_.DefaultSubmit,Dependency:S.Dependency,Excluded:C.Excluded,FieldStatus:P.FieldStatus,Framework:z.Framework,Icon:U.Icon,Message:F.Message,Sequence:G.Sequence,SubmitButton:Q.SubmitButton,Tooltip:ne.Tooltip,Trigger:oe.Trigger},qt={between:de.between,blank:me.blank,callback:be.callback,choice:ke.choice,creditCard:Le.creditCard,date:Ee.date,different:Ie.different,digits:Fe.digits,emailAddress:Ve.emailAddress,file:$e.file,greaterThan:Ke.greaterThan,identical:tt.identical,integer:at.integer,ip:ct.ip,lessThan:ft.lessThan,notEmpty:vt.notEmpty,numeric:_t.numeric,promise:St.promise,regexp:Ct.regexp,remote:Pt.remote,stringCase:jt.stringCase,stringLength:zt.stringLength,uri:Wt.uri};e.Plugin=a.Plugin,e.algorithms=a.algorithms,e.formValidation=function(e,t){var i=a.formValidation(e,t);return Object.keys(qt).forEach((function(e){return i.registerValidator(e,qt[e])})),i},e.plugins=Ut,e.utils=a.utils,e.validators=qt})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).FormValidation={})}(this,(function(e){"use strict";var t,i={exports:{}},n={};i.exports=function(){if(t)return n;t=1;var e={luhn:function(e){for(var t=e.length,i=[[0,1,2,3,4,5,6,7,8,9],[0,2,4,6,8,1,3,5,7,9]],n=0,r=0;t--;)r+=i[n][parseInt(e.charAt(t),10)],n=1-n;return r%10==0&&r>0},mod11And10:function(e){for(var t=e.length,i=5,n=0;n<t;n++)i=(2*(i||10)%11+parseInt(e.charAt(n),10))%10;return 1===i},mod37And36:function(e,t){void 0===t&&(t="0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ");for(var i=e.length,n=t.length,r=Math.floor(n/2),a=0;a<i;a++)r=(2*(r||n)%(n+1)+t.indexOf(e.charAt(a)))%n;return 1===r},mod97And10:function(e){for(var t=function(e){return e.split("").map((function(e){var t=e.charCodeAt(0);return t>=65&&t<=90?t-55:e})).join("").split("").map((function(e){return parseInt(e,10)}))}(e),i=0,n=t.length,r=0;r<n-1;++r)i=10*(i+t[r])%97;return(i+=t[n-1])%97==1},verhoeff:function(e){for(var t=[[0,1,2,3,4,5,6,7,8,9],[1,2,3,4,0,6,7,8,9,5],[2,3,4,0,1,7,8,9,5,6],[3,4,0,1,2,8,9,5,6,7],[4,0,1,2,3,9,5,6,7,8],[5,9,8,7,6,0,4,3,2,1],[6,5,9,8,7,1,0,4,3,2],[7,6,5,9,8,2,1,0,4,3],[8,7,6,5,9,3,2,1,0,4],[9,8,7,6,5,4,3,2,1,0]],i=[[0,1,2,3,4,5,6,7,8,9],[1,5,7,6,2,8,3,0,9,4],[5,8,0,3,7,9,6,1,4,2],[8,9,1,6,0,4,3,5,2,7],[9,4,5,3,1,2,6,8,7,0],[4,2,8,6,5,7,3,9,0,1],[2,7,9,3,8,0,6,4,1,5],[7,0,4,6,9,1,3,2,5,8]],n=e.reverse(),r=0,a=0;a<n.length;a++)r=t[r][i[a%8][n[a]]];return 0===r}},i=function(){function e(e,t){this.fields={},this.elements={},this.ee={fns:{},clear:function(){this.fns={}},emit:function(e){for(var t=[],i=1;i<arguments.length;i++)t[i-1]=arguments[i];(this.fns[e]||[]).map((function(e){return e.apply(e,t)}))},off:function(e,t){if(this.fns[e]){var i=this.fns[e].indexOf(t);i>=0&&this.fns[e].splice(i,1)}},on:function(e,t){(this.fns[e]=this.fns[e]||[]).push(t)}},this.filter={filters:{},add:function(e,t){(this.filters[e]=this.filters[e]||[]).push(t)},clear:function(){this.filters={}},execute:function(e,t,i){if(!this.filters[e]||!this.filters[e].length)return t;for(var n=t,r=this.filters[e],a=r.length,s=0;s<a;s++)n=r[s].apply(n,i);return n},remove:function(e,t){this.filters[e]&&(this.filters[e]=this.filters[e].filter((function(e){return e!==t})))}},this.plugins={},this.results=new Map,this.validators={},this.form=e,this.fields=t}return e.prototype.on=function(e,t){return this.ee.on(e,t),this},e.prototype.off=function(e,t){return this.ee.off(e,t),this},e.prototype.emit=function(e){for(var t,i=[],n=1;n<arguments.length;n++)i[n-1]=arguments[n];return(t=this.ee).emit.apply(t,function(e,t,i){if(i||2===arguments.length)for(var n,r=0,a=t.length;r<a;r++)!n&&r in t||(n||(n=Array.prototype.slice.call(t,0,r)),n[r]=t[r]);return e.concat(n||Array.prototype.slice.call(t))}([e],i,!1)),this},e.prototype.registerPlugin=function(e,t){if(this.plugins[e])throw new Error("The plguin ".concat(e," is registered"));return t.setCore(this),t.install(),this.plugins[e]=t,this},e.prototype.deregisterPlugin=function(e){var t=this.plugins[e];return t&&t.uninstall(),delete this.plugins[e],this},e.prototype.enablePlugin=function(e){var t=this.plugins[e];return t&&t.enable(),this},e.prototype.disablePlugin=function(e){var t=this.plugins[e];return t&&t.disable(),this},e.prototype.isPluginEnabled=function(e){var t=this.plugins[e];return!!t&&t.isPluginEnabled()},e.prototype.registerValidator=function(e,t){if(this.validators[e])throw new Error("The validator ".concat(e," is registered"));return this.validators[e]=t,this},e.prototype.registerFilter=function(e,t){return this.filter.add(e,t),this},e.prototype.deregisterFilter=function(e,t){return this.filter.remove(e,t),this},e.prototype.executeFilter=function(e,t,i){return this.filter.execute(e,t,i)},e.prototype.addField=function(e,t){var i=Object.assign({},{selector:"",validators:{}},t);return this.fields[e]=this.fields[e]?{selector:i.selector||this.fields[e].selector,validators:Object.assign({},this.fields[e].validators,i.validators)}:i,this.elements[e]=this.queryElements(e),this.emit("core.field.added",{elements:this.elements[e],field:e,options:this.fields[e]}),this},e.prototype.removeField=function(e){if(!this.fields[e])throw new Error("The field ".concat(e," validators are not defined. Please ensure the field is added first"));var t=this.elements[e],i=this.fields[e];return delete this.elements[e],delete this.fields[e],this.emit("core.field.removed",{elements:t,field:e,options:i}),this},e.prototype.validate=function(){var e=this;return this.emit("core.form.validating",{formValidation:this}),this.filter.execute("validate-pre",Promise.resolve(),[]).then((function(){return Promise.all(Object.keys(e.fields).map((function(t){return e.validateField(t)}))).then((function(t){switch(!0){case-1!==t.indexOf("Invalid"):return e.emit("core.form.invalid",{formValidation:e}),Promise.resolve("Invalid");case-1!==t.indexOf("NotValidated"):return e.emit("core.form.notvalidated",{formValidation:e}),Promise.resolve("NotValidated");default:return e.emit("core.form.valid",{formValidation:e}),Promise.resolve("Valid")}}))}))},e.prototype.validateField=function(e){var t=this,i=this.results.get(e);if("Valid"===i||"Invalid"===i)return Promise.resolve(i);this.emit("core.field.validating",e);var n=this.elements[e];if(0===n.length)return this.emit("core.field.valid",e),Promise.resolve("Valid");var r=n[0].getAttribute("type");return"radio"===r||"checkbox"===r||1===n.length?this.validateElement(e,n[0]):Promise.all(n.map((function(i){return t.validateElement(e,i)}))).then((function(i){switch(!0){case-1!==i.indexOf("Invalid"):return t.emit("core.field.invalid",e),t.results.set(e,"Invalid"),Promise.resolve("Invalid");case-1!==i.indexOf("NotValidated"):return t.emit("core.field.notvalidated",e),t.results.delete(e),Promise.resolve("NotValidated");default:return t.emit("core.field.valid",e),t.results.set(e,"Valid"),Promise.resolve("Valid")}}))},e.prototype.validateElement=function(e,t){var i=this;this.results.delete(e);var n=this.elements[e];if(this.filter.execute("element-ignored",!1,[e,t,n]))return this.emit("core.element.ignored",{element:t,elements:n,field:e}),Promise.resolve("Ignored");var r=this.fields[e].validators;this.emit("core.element.validating",{element:t,elements:n,field:e});var a=Object.keys(r).map((function(n){return function(){return i.executeValidator(e,t,n,r[n])}}));return this.waterfall(a).then((function(r){var a=-1===r.indexOf("Invalid");i.emit("core.element.validated",{element:t,elements:n,field:e,valid:a});var s=t.getAttribute("type");return"radio"!==s&&"checkbox"!==s&&1!==n.length||i.emit(a?"core.field.valid":"core.field.invalid",e),Promise.resolve(a?"Valid":"Invalid")})).catch((function(r){return i.emit("core.element.notvalidated",{element:t,elements:n,field:e}),Promise.resolve(r)}))},e.prototype.executeValidator=function(e,t,i,n){var r=this,a=this.elements[e],s=this.filter.execute("validator-name",i,[i,e]);if(n.message=this.filter.execute("validator-message",n.message,[this.locale,e,s]),!this.validators[s]||!1===n.enabled)return this.emit("core.validator.validated",{element:t,elements:a,field:e,result:this.normalizeResult(e,s,{valid:!0}),validator:s}),Promise.resolve("Valid");var o=this.validators[s],l=this.getElementValue(e,t,s);if(!this.filter.execute("field-should-validate",!0,[e,t,l,i]))return this.emit("core.validator.notvalidated",{element:t,elements:a,field:e,validator:i}),Promise.resolve("NotValidated");this.emit("core.validator.validating",{element:t,elements:a,field:e,validator:i});var c=o().validate({element:t,elements:a,field:e,l10n:this.localization,options:n,value:l});if("function"==typeof c.then)return c.then((function(n){var s=r.normalizeResult(e,i,n);return r.emit("core.validator.validated",{element:t,elements:a,field:e,result:s,validator:i}),s.valid?"Valid":"Invalid"}));var u=this.normalizeResult(e,i,c);return this.emit("core.validator.validated",{element:t,elements:a,field:e,result:u,validator:i}),Promise.resolve(u.valid?"Valid":"Invalid")},e.prototype.getElementValue=function(e,t,i){var n=function(e,t,i,n){var r=(i.getAttribute("type")||"").toLowerCase(),a=i.tagName.toLowerCase();if("textarea"===a)return i.value;if("select"===a){var s=i,o=s.selectedIndex;return o>=0?s.options.item(o).value:""}if("input"===a){if("radio"===r||"checkbox"===r){var l=n.filter((function(e){return e.checked})).length;return 0===l?"":l+""}return i.value}return""}(this.form,0,t,this.elements[e]);return this.filter.execute("field-value",n,[n,e,t,i])},e.prototype.getElements=function(e){return this.elements[e]},e.prototype.getFields=function(){return this.fields},e.prototype.getFormElement=function(){return this.form},e.prototype.getLocale=function(){return this.locale},e.prototype.getPlugin=function(e){return this.plugins[e]},e.prototype.updateFieldStatus=function(e,t,i){var n=this,r=this.elements[e],a=r[0].getAttribute("type");if(("radio"===a||"checkbox"===a?[r[0]]:r).forEach((function(r){return n.updateElementStatus(e,r,t,i)})),i)"Invalid"===t&&(this.emit("core.field.invalid",e),this.results.set(e,"Invalid"));else switch(t){case"NotValidated":this.emit("core.field.notvalidated",e),this.results.delete(e);break;case"Validating":this.emit("core.field.validating",e),this.results.delete(e);break;case"Valid":this.emit("core.field.valid",e),this.results.set(e,"Valid");break;case"Invalid":this.emit("core.field.invalid",e),this.results.set(e,"Invalid")}return this},e.prototype.updateElementStatus=function(e,t,i,n){var r=this,a=this.elements[e],s=this.fields[e].validators,o=n?[n]:Object.keys(s);switch(i){case"NotValidated":o.forEach((function(i){return r.emit("core.validator.notvalidated",{element:t,elements:a,field:e,validator:i})})),this.emit("core.element.notvalidated",{element:t,elements:a,field:e});break;case"Validating":o.forEach((function(i){return r.emit("core.validator.validating",{element:t,elements:a,field:e,validator:i})})),this.emit("core.element.validating",{element:t,elements:a,field:e});break;case"Valid":o.forEach((function(i){return r.emit("core.validator.validated",{element:t,elements:a,field:e,result:{message:s[i].message,valid:!0},validator:i})})),this.emit("core.element.validated",{element:t,elements:a,field:e,valid:!0});break;case"Invalid":o.forEach((function(i){return r.emit("core.validator.validated",{element:t,elements:a,field:e,result:{message:s[i].message,valid:!1},validator:i})})),this.emit("core.element.validated",{element:t,elements:a,field:e,valid:!1})}return this},e.prototype.resetForm=function(e){var t=this;return Object.keys(this.fields).forEach((function(i){return t.resetField(i,e)})),this.emit("core.form.reset",{formValidation:this,reset:e}),this},e.prototype.resetField=function(e,t){if(t){var i=this.elements[e],n=i[0].getAttribute("type");i.forEach((function(e){"radio"===n||"checkbox"===n?(e.removeAttribute("selected"),e.removeAttribute("checked"),e.checked=!1):(e.setAttribute("value",""),(e instanceof HTMLInputElement||e instanceof HTMLTextAreaElement)&&(e.value=""))}))}return this.updateFieldStatus(e,"NotValidated"),this.emit("core.field.reset",{field:e,reset:t}),this},e.prototype.revalidateField=function(e){return this.fields[e]?(this.updateFieldStatus(e,"NotValidated"),this.validateField(e)):Promise.resolve("Ignored")},e.prototype.disableValidator=function(e,t){if(!this.fields[e])return this;var i=this.elements[e];return this.toggleValidator(!1,e,t),this.emit("core.validator.disabled",{elements:i,field:e,formValidation:this,validator:t}),this},e.prototype.enableValidator=function(e,t){if(!this.fields[e])return this;var i=this.elements[e];return this.toggleValidator(!0,e,t),this.emit("core.validator.enabled",{elements:i,field:e,formValidation:this,validator:t}),this},e.prototype.updateValidatorOption=function(e,t,i,n){return this.fields[e]&&this.fields[e].validators&&this.fields[e].validators[t]&&(this.fields[e].validators[t][i]=n),this},e.prototype.setFieldOptions=function(e,t){return this.fields[e]=t,this},e.prototype.destroy=function(){var e=this;return Object.keys(this.plugins).forEach((function(t){return e.plugins[t].uninstall()})),this.ee.clear(),this.filter.clear(),this.results.clear(),this.plugins={},this},e.prototype.setLocale=function(e,t){return this.locale=e,this.localization=t,this},e.prototype.waterfall=function(e){return e.reduce((function(e,t){return e.then((function(e){return t().then((function(t){return e.push(t),e}))}))}),Promise.resolve([]))},e.prototype.queryElements=function(e){var t=this.fields[e].selector?"#"===this.fields[e].selector.charAt(0)?'[id="'.concat(this.fields[e].selector.substring(1),'"]'):this.fields[e].selector:'[name="'.concat(e.replace(/"/g,'\\"'),'"]');return[].slice.call(this.form.querySelectorAll(t))},e.prototype.normalizeResult=function(e,t,i){var n=this.fields[e].validators[t];return Object.assign({},i,{message:i.message||(n?n.message:"")||(this.localization&&this.localization[t]&&this.localization[t].default?this.localization[t].default:"")||"The field ".concat(e," is not valid")})},e.prototype.toggleValidator=function(e,t,i){var n=this,r=this.fields[t].validators;return i&&r&&r[i]?this.fields[t].validators[i].enabled=e:i||Object.keys(r).forEach((function(i){return n.fields[t].validators[i].enabled=e})),this.updateFieldStatus(t,"NotValidated",i)},e}(),r=function(){function e(e){this.opts=e,this.isEnabled=!0}return e.prototype.setCore=function(e){return this.core=e,this},e.prototype.enable=function(){return this.isEnabled=!0,this.onEnabled(),this},e.prototype.disable=function(){return this.isEnabled=!1,this.onDisabled(),this},e.prototype.isPluginEnabled=function(){return this.isEnabled},e.prototype.onEnabled=function(){},e.prototype.onDisabled=function(){},e.prototype.install=function(){},e.prototype.uninstall=function(){},e}(),a=function(e,t){var i=e.matches||e.webkitMatchesSelector||e.mozMatchesSelector||e.msMatchesSelector;return i?i.call(e,t):[].slice.call(e.parentElement.querySelectorAll(t)).indexOf(e)>=0},s={call:function(e,t){if("function"==typeof e)return e.apply(this,t);if("string"==typeof e){var i=e;"()"===i.substring(i.length-2)&&(i=i.substring(0,i.length-2));for(var n=i.split("."),r=n.pop(),a=window,s=0,o=n;s<o.length;s++)a=a[o[s]];return void 0===a[r]?null:a[r].apply(this,t)}},classSet:function(e,t){var i=[],n=[];Object.keys(t).forEach((function(e){e&&(t[e]?i.push(e):n.push(e))})),n.forEach((function(t){return function(e,t){t.split(" ").forEach((function(t){e.classList?e.classList.remove(t):e.className=e.className.replace(t,"")}))}(e,t)})),i.forEach((function(t){return function(e,t){t.split(" ").forEach((function(t){e.classList?e.classList.add(t):" ".concat(e.className," ").indexOf(" ".concat(t," "))&&(e.className+=" ".concat(t))}))}(e,t)}))},closest:function(e,t){for(var i=e;i&&!a(i,t);)i=i.parentElement;return i},fetch:function(e,t){return new Promise((function(i,n){var r,a=Object.assign({},{crossDomain:!1,headers:{},method:"GET",params:{}},t),s=Object.keys(a.params).map((function(e){return"".concat(encodeURIComponent(e),"=").concat(encodeURIComponent(a.params[e]))})).join("&"),o=e.indexOf("?")>-1,l="GET"===a.method?"".concat(e).concat(o?"&":"?").concat(s):e;if(a.crossDomain){var c=document.createElement("script"),u="___FormValidationFetch_".concat(Array(12).fill("").map((function(e){return Math.random().toString(36).charAt(2)})).join(""),"___");window[u]=function(e){delete window[u],i(e)},c.src="".concat(l).concat(o?"&":"?","callback=").concat(u),c.async=!0,c.addEventListener("load",(function(){c.parentNode.removeChild(c)})),c.addEventListener("error",(function(){return n})),document.head.appendChild(c)}else{var d=new XMLHttpRequest;d.open(a.method,l),d.setRequestHeader("X-Requested-With","XMLHttpRequest"),"POST"===a.method&&d.setRequestHeader("Content-Type","application/x-www-form-urlencoded"),Object.keys(a.headers).forEach((function(e){return d.setRequestHeader(e,a.headers[e])})),d.addEventListener("load",(function(){i(JSON.parse(this.responseText))})),d.addEventListener("error",(function(){return n})),d.send((r=a.params,Object.keys(r).map((function(e){return"".concat(encodeURIComponent(e),"=").concat(encodeURIComponent(r[e]))})).join("&")))}}))},format:function(e,t){var i=Array.isArray(t)?t:[t],n=e;return i.forEach((function(e){n=n.replace("%s",e)})),n},hasClass:function(e,t){return e.classList?e.classList.contains(t):new RegExp("(^| )".concat(t,"( |$)"),"gi").test(e.className)},isValidDate:function(e,t,i,n){if(isNaN(e)||isNaN(t)||isNaN(i))return!1;if(e<1e3||e>9999||t<=0||t>12)return!1;if(i<=0||i>[31,e%400==0||e%100!=0&&e%4==0?29:28,31,30,31,30,31,31,30,31,30,31][t-1])return!1;if(!0===n){var r=new Date,a=r.getFullYear(),s=r.getMonth(),o=r.getDate();return e<a||e===a&&t-1<s||e===a&&t-1===s&&i<o}return!0},removeUndefined:function(e){return e?Object.entries(e).reduce((function(e,t){var i=t[0],n=t[1];return void 0===n||(e[i]=n),e}),{}):{}}};return n.Plugin=r,n.algorithms=e,n.formValidation=function(e,t){var n=Object.assign({},{fields:{},locale:"en_US",plugins:{},init:function(e){}},t),r=new i(e,n.fields);return r.setLocale(n.locale,n.localization),Object.keys(n.plugins).forEach((function(e){return r.registerPlugin(e,n.plugins[e])})),n.init(r),Object.keys(n.fields).forEach((function(e){return r.addField(e,n.fields[e])})),r},n.utils=s,n}();var r,a=i.exports,s={exports:{}},o={};s.exports=function(){if(r)return o;r=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.opts=e||{},i.validatorNameFilter=i.getValidatorName.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.registerFilter("validator-name",this.validatorNameFilter)},i.prototype.uninstall=function(){this.core.deregisterFilter("validator-name",this.validatorNameFilter)},i.prototype.getValidatorName=function(e,t){return this.isEnabled&&this.opts[e]||e},i}(a.Plugin);return o.Alias=t,o}();var l,c=s.exports,u={exports:{}},d={};u.exports=function(){if(l)return d;l=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(){var e=t.call(this,{})||this;return e.elementValidatedHandler=e.onElementValidated.bind(e),e.fieldValidHandler=e.onFieldValid.bind(e),e.fieldInvalidHandler=e.onFieldInvalid.bind(e),e.messageDisplayedHandler=e.onMessageDisplayed.bind(e),e}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("core.field.valid",this.fieldValidHandler).on("core.field.invalid",this.fieldInvalidHandler).on("core.element.validated",this.elementValidatedHandler).on("plugins.message.displayed",this.messageDisplayedHandler)},i.prototype.uninstall=function(){this.core.off("core.field.valid",this.fieldValidHandler).off("core.field.invalid",this.fieldInvalidHandler).off("core.element.validated",this.elementValidatedHandler).off("plugins.message.displayed",this.messageDisplayedHandler)},i.prototype.onElementValidated=function(e){e.valid&&(e.element.setAttribute("aria-invalid","false"),e.element.removeAttribute("aria-describedby"))},i.prototype.onFieldValid=function(e){var t=this.core.getElements(e);t&&t.forEach((function(e){e.setAttribute("aria-invalid","false"),e.removeAttribute("aria-describedby")}))},i.prototype.onFieldInvalid=function(e){var t=this.core.getElements(e);t&&t.forEach((function(e){return e.setAttribute("aria-invalid","true")}))},i.prototype.onMessageDisplayed=function(e){e.messageElement.setAttribute("role","alert"),e.messageElement.setAttribute("aria-hidden","false");var t=this.core.getElements(e.field),i=t.indexOf(e.element),n="js-fv-".concat(e.field,"-").concat(i,"-").concat(Date.now(),"-message");e.messageElement.setAttribute("id",n),e.element.setAttribute("aria-describedby",n);var r=e.element.getAttribute("type");"radio"!==r&&"checkbox"!==r||t.forEach((function(e){return e.setAttribute("aria-describedby",n)}))},i}(a.Plugin);return d.Aria=t,d}();var h,f=u.exports,p={exports:{}},m={};p.exports=function(){if(h)return m;h=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.addedFields=new Map,i.opts=Object.assign({},{html5Input:!1,pluginPrefix:"data-fvp-",prefix:"data-fv-"},e),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){var e=this;this.parsePlugins();var t=this.parseOptions();Object.keys(t).forEach((function(i){e.addedFields.has(i)||e.addedFields.set(i,!0),e.core.addField(i,t[i])})),this.core.on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler)},i.prototype.uninstall=function(){this.addedFields.clear(),this.core.off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler)},i.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&0!==i.length&&!this.addedFields.has(e.field)&&(this.addedFields.set(e.field,!0),i.forEach((function(i){var n=t.parseElement(i);if(!t.isEmptyOption(n)){var r={selector:e.options.selector,validators:Object.assign({},e.options.validators||{},n.validators)};t.core.setFieldOptions(e.field,r)}})))},i.prototype.onFieldRemoved=function(e){e.field&&this.addedFields.has(e.field)&&this.addedFields.delete(e.field)},i.prototype.parseOptions=function(){var e=this,t=this.opts.prefix,i={},n=this.core.getFields(),r=this.core.getFormElement();return[].slice.call(r.querySelectorAll("[name], [".concat(t,"field]"))).forEach((function(n){var r=e.parseElement(n);if(!e.isEmptyOption(r)){var a=n.getAttribute("name")||n.getAttribute("".concat(t,"field"));i[a]=Object.assign({},i[a],r)}})),Object.keys(i).forEach((function(e){Object.keys(i[e].validators).forEach((function(t){i[e].validators[t].enabled=i[e].validators[t].enabled||!1,n[e]&&n[e].validators&&n[e].validators[t]&&Object.assign(i[e].validators[t],n[e].validators[t])}))})),Object.assign({},n,i)},i.prototype.createPluginInstance=function(e,t){for(var i=e.split("."),n=window||this,r=0,a=i.length;r<a;r++)n=n[i[r]];if("function"!=typeof n)throw new Error("the plugin ".concat(e," doesn't exist"));return new n(t)},i.prototype.parsePlugins=function(){for(var e,t=this,i=this.core.getFormElement(),n=new RegExp("^".concat(this.opts.pluginPrefix,"([a-z0-9-]+)(___)*([a-z0-9-]+)*$")),r=i.attributes.length,a={},s=0;s<r;s++){var o=i.attributes[s].name,l=i.attributes[s].value,c=n.exec(o);if(c&&4===c.length){var u=this.toCamelCase(c[1]);a[u]=Object.assign({},c[3]?((e={})[this.toCamelCase(c[3])]=l,e):{enabled:""===l||"true"===l},a[u])}}Object.keys(a).forEach((function(e){var i=a[e],n=i.enabled,r=i.class;if(n&&r){delete i.enabled,delete i.clazz;var s=t.createPluginInstance(r,i);t.core.registerPlugin(e,s)}}))},i.prototype.isEmptyOption=function(e){var t=e.validators;return 0===Object.keys(t).length&&t.constructor===Object},i.prototype.parseElement=function(e){for(var t=new RegExp("^".concat(this.opts.prefix,"([a-z0-9-]+)(___)*([a-z0-9-]+)*$")),i=e.attributes.length,n={},r=e.getAttribute("type"),a=0;a<i;a++){var s=e.attributes[a].name,o=e.attributes[a].value;if(this.opts.html5Input)switch(!0){case"minlength"===s:n.stringLength=Object.assign({},{enabled:!0,min:parseInt(o,10)},n.stringLength);break;case"maxlength"===s:n.stringLength=Object.assign({},{enabled:!0,max:parseInt(o,10)},n.stringLength);break;case"pattern"===s:n.regexp=Object.assign({},{enabled:!0,regexp:o},n.regexp);break;case"required"===s:n.notEmpty=Object.assign({},{enabled:!0},n.notEmpty);break;case"type"===s&&"color"===o:n.color=Object.assign({},{enabled:!0,type:"hex"},n.color);break;case"type"===s&&"email"===o:n.emailAddress=Object.assign({},{enabled:!0},n.emailAddress);break;case"type"===s&&"url"===o:n.uri=Object.assign({},{enabled:!0},n.uri);break;case"type"===s&&"range"===o:n.between=Object.assign({},{enabled:!0,max:parseFloat(e.getAttribute("max")),min:parseFloat(e.getAttribute("min"))},n.between);break;case"min"===s&&"date"!==r&&"range"!==r:n.greaterThan=Object.assign({},{enabled:!0,min:parseFloat(o)},n.greaterThan);break;case"max"===s&&"date"!==r&&"range"!==r:n.lessThan=Object.assign({},{enabled:!0,max:parseFloat(o)},n.lessThan)}var l=t.exec(s);if(l&&4===l.length){var c=this.toCamelCase(l[1]);n[c]||(n[c]={}),l[3]?n[c][this.toCamelCase(l[3])]=this.normalizeValue(o):!0===n[c].enabled&&!1===n[c].enabled||(n[c].enabled=""===o||"true"===o)}}return{validators:n}},i.prototype.normalizeValue=function(e){return"true"===e||""===e||"false"!==e&&e},i.prototype.toUpperCase=function(e){return e.charAt(1).toUpperCase()},i.prototype.toCamelCase=function(e){return e.replace(/-./g,this.toUpperCase)},i}(a.Plugin);return m.Declarative=t,m}();var g,v=p.exports,y={exports:{}},b={};y.exports=function(){if(g)return b;g=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(){var e=t.call(this,{})||this;return e.onValidHandler=e.onFormValid.bind(e),e}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){if(this.core.getFormElement().querySelectorAll('[type="submit"][name="submit"]').length)throw new Error("Do not use `submit` for the name attribute of submit button");this.core.on("core.form.valid",this.onValidHandler)},i.prototype.uninstall=function(){this.core.off("core.form.valid",this.onValidHandler)},i.prototype.onFormValid=function(){var e=this.core.getFormElement();this.isEnabled&&e instanceof HTMLFormElement&&e.submit()},i}(a.Plugin);return b.DefaultSubmit=t,b}();var x,_=y.exports,w={exports:{}},k={};w.exports=function(){if(x)return k;x=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.opts=e||{},i.triggerExecutedHandler=i.onTriggerExecuted.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("plugins.trigger.executed",this.triggerExecutedHandler)},i.prototype.uninstall=function(){this.core.off("plugins.trigger.executed",this.triggerExecutedHandler)},i.prototype.onTriggerExecuted=function(e){if(this.isEnabled&&this.opts[e.field])for(var t=0,i=this.opts[e.field].split(" ");t<i.length;t++){var n=i[t].trim();this.opts[n]&&this.core.revalidateField(n)}},i}(a.Plugin);return k.Dependency=t,k}();var M,S=w.exports,A={exports:{}},L={};A.exports=function(){if(M)return L;M=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.removeUndefined,n=function(e){function n(t){var r=e.call(this,t)||this;return r.opts=Object.assign({},{excluded:n.defaultIgnore},i(t)),r.ignoreValidationFilter=r.ignoreValidation.bind(r),r}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.defaultIgnore=function(e,t,i){var n=!!(t.offsetWidth||t.offsetHeight||t.getClientRects().length),r=t.getAttribute("disabled");return""===r||"disabled"===r||"hidden"===t.getAttribute("type")||!n},n.prototype.install=function(){this.core.registerFilter("element-ignored",this.ignoreValidationFilter)},n.prototype.uninstall=function(){this.core.deregisterFilter("element-ignored",this.ignoreValidationFilter)},n.prototype.ignoreValidation=function(e,t,i){return!!this.isEnabled&&this.opts.excluded.apply(this,[e,t,i])},n}(e.Plugin);return L.Excluded=n,L}();var T,C=A.exports,D={exports:{}},E={};D.exports=function(){if(T)return E;T=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.statuses=new Map,i.opts=Object.assign({},{onStatusChanged:function(){}},e),i.elementValidatingHandler=i.onElementValidating.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.elementNotValidatedHandler=i.onElementNotValidated.bind(i),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("core.element.validating",this.elementValidatingHandler).on("core.element.validated",this.elementValidatedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("core.element.ignored",this.elementIgnoredHandler).on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler)},i.prototype.uninstall=function(){this.statuses.clear(),this.core.off("core.element.validating",this.elementValidatingHandler).off("core.element.validated",this.elementValidatedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("core.element.ignored",this.elementIgnoredHandler).off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler)},i.prototype.areFieldsValid=function(){return Array.from(this.statuses.values()).every((function(e){return"Valid"===e||"NotValidated"===e||"Ignored"===e}))},i.prototype.getStatuses=function(){return this.isEnabled?this.statuses:new Map},i.prototype.onFieldAdded=function(e){this.statuses.set(e.field,"NotValidated")},i.prototype.onFieldRemoved=function(e){this.statuses.has(e.field)&&this.statuses.delete(e.field),this.handleStatusChanged(this.areFieldsValid())},i.prototype.onElementValidating=function(e){this.statuses.set(e.field,"Validating"),this.handleStatusChanged(!1)},i.prototype.onElementValidated=function(e){this.statuses.set(e.field,e.valid?"Valid":"Invalid"),e.valid?this.handleStatusChanged(this.areFieldsValid()):this.handleStatusChanged(!1)},i.prototype.onElementNotValidated=function(e){this.statuses.set(e.field,"NotValidated"),this.handleStatusChanged(!1)},i.prototype.onElementIgnored=function(e){this.statuses.set(e.field,"Ignored"),this.handleStatusChanged(this.areFieldsValid())},i.prototype.handleStatusChanged=function(e){this.isEnabled&&this.opts.onStatusChanged(e)},i}(a.Plugin);return E.FieldStatus=t,E}();var O,P=D.exports,Y={exports:{}},I={},N={exports:{}},j={};N.exports=function(){if(O)return j;O=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.classSet,n=function(e){function n(t){var i=e.call(this,t)||this;return i.useDefaultContainer=!1,i.messages=new Map,i.defaultContainer=document.createElement("div"),i.useDefaultContainer=!t||!t.container,i.opts=Object.assign({},{container:function(e,t){return i.defaultContainer}},t),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i.validatorValidatedHandler=i.onValidatorValidated.bind(i),i.validatorNotValidatedHandler=i.onValidatorNotValidated.bind(i),i}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.getClosestContainer=function(e,t,i){for(var n=e;n&&n!==t&&(n=n.parentElement,!i.test(n.className)););return n},n.prototype.install=function(){this.useDefaultContainer&&this.core.getFormElement().appendChild(this.defaultContainer),this.core.on("core.element.ignored",this.elementIgnoredHandler).on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler).on("core.validator.validated",this.validatorValidatedHandler).on("core.validator.notvalidated",this.validatorNotValidatedHandler)},n.prototype.uninstall=function(){this.useDefaultContainer&&this.core.getFormElement().removeChild(this.defaultContainer),this.messages.forEach((function(e){return e.parentNode.removeChild(e)})),this.messages.clear(),this.core.off("core.element.ignored",this.elementIgnoredHandler).off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler).off("core.validator.validated",this.validatorValidatedHandler).off("core.validator.notvalidated",this.validatorNotValidatedHandler)},n.prototype.onEnabled=function(){this.messages.forEach((function(e,t,n){i(t,{"fv-plugins-message-container--enabled":!0,"fv-plugins-message-container--disabled":!1})}))},n.prototype.onDisabled=function(){this.messages.forEach((function(e,t,n){i(t,{"fv-plugins-message-container--enabled":!1,"fv-plugins-message-container--disabled":!0})}))},n.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&(i.forEach((function(e){var i=t.messages.get(e);i&&(i.parentNode.removeChild(i),t.messages.delete(e))})),this.prepareFieldContainer(e.field,i))},n.prototype.onFieldRemoved=function(e){var t=this;if(e.elements.length&&e.field){var i=e.elements[0].getAttribute("type");("radio"===i||"checkbox"===i?[e.elements[0]]:e.elements).forEach((function(e){if(t.messages.has(e)){var i=t.messages.get(e);i.parentNode.removeChild(i),t.messages.delete(e)}}))}},n.prototype.prepareFieldContainer=function(e,t){var i=this;if(t.length){var n=t[0].getAttribute("type");"radio"===n||"checkbox"===n?this.prepareElementContainer(e,t[0],t):t.forEach((function(n){return i.prepareElementContainer(e,n,t)}))}},n.prototype.prepareElementContainer=function(e,t,n){var r;if("string"==typeof this.opts.container){var a="#"===this.opts.container.charAt(0)?'[id="'.concat(this.opts.container.substring(1),'"]'):this.opts.container;r=this.core.getFormElement().querySelector(a)}else r=this.opts.container(e,t);var s=document.createElement("div");r.appendChild(s),i(s,{"fv-plugins-message-container":!0,"fv-plugins-message-container--enabled":this.isEnabled,"fv-plugins-message-container--disabled":!this.isEnabled}),this.core.emit("plugins.message.placed",{element:t,elements:n,field:e,messageElement:s}),this.messages.set(t,s)},n.prototype.getMessage=function(e){return"string"==typeof e.message?e.message:e.message[this.core.getLocale()]},n.prototype.onValidatorValidated=function(e){var t,n=e.elements,r=e.element.getAttribute("type"),a=("radio"===r||"checkbox"===r)&&n.length>0?n[0]:e.element;if(this.messages.has(a)){var s=this.messages.get(a),o=s.querySelector('[data-field="'.concat(e.field.replace(/"/g,'\\"'),'"][data-validator="').concat(e.validator.replace(/"/g,'\\"'),'"]'));if(o||e.result.valid)o&&!e.result.valid?(o.innerHTML=this.getMessage(e.result),this.core.emit("plugins.message.displayed",{element:e.element,field:e.field,message:e.result.message,messageElement:o,meta:e.result.meta,validator:e.validator})):o&&e.result.valid&&s.removeChild(o);else{var l=document.createElement("div");l.innerHTML=this.getMessage(e.result),l.setAttribute("data-field",e.field),l.setAttribute("data-validator",e.validator),this.opts.clazz&&i(l,((t={})[this.opts.clazz]=!0,t)),s.appendChild(l),this.core.emit("plugins.message.displayed",{element:e.element,field:e.field,message:e.result.message,messageElement:l,meta:e.result.meta,validator:e.validator})}}},n.prototype.onValidatorNotValidated=function(e){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element;if(this.messages.has(n)){var r=this.messages.get(n),a=r.querySelector('[data-field="'.concat(e.field.replace(/"/g,'\\"'),'"][data-validator="').concat(e.validator.replace(/"/g,'\\"'),'"]'));a&&r.removeChild(a)}},n.prototype.onElementIgnored=function(e){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element;if(this.messages.has(n)){var r=this.messages.get(n);[].slice.call(r.querySelectorAll('[data-field="'.concat(e.field.replace(/"/g,'\\"'),'"]'))).forEach((function(e){r.removeChild(e)}))}},n}(e.Plugin);return j.Message=n,j}();var H,F=N.exports;
/** 
     * FormValidation (https://formvalidation.io)
     * The best validation library for JavaScript
     * (c) 2013 - 2023 Nguyen Huu Phuoc <me@phuoc.ng>
     *
     * @license https://formvalidation.io/license
     * @package @form-validation/plugin-framework
     * @version 2.4.0
     */Y.exports=function(){if(H)return I;H=1;var e=a,t=F,i=function(e,t){return i=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},i(e,t)},n=e.utils.classSet,r=e.utils.closest,s=function(e){function a(t){var i=e.call(this,t)||this;return i.results=new Map,i.containers=new Map,i.opts=Object.assign({},{defaultMessageContainer:!0,eleInvalidClass:"",eleValidClass:"",rowClasses:"",rowValidatingClass:""},t),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.elementValidatingHandler=i.onElementValidating.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.elementNotValidatedHandler=i.onElementNotValidated.bind(i),i.iconPlacedHandler=i.onIconPlaced.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i.messagePlacedHandler=i.onMessagePlaced.bind(i),i}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}i(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}(a,e),a.prototype.install=function(){var e,i=this;n(this.core.getFormElement(),((e={})[this.opts.formClass]=!0,e["fv-plugins-framework"]=!0,e)),this.core.on("core.element.ignored",this.elementIgnoredHandler).on("core.element.validating",this.elementValidatingHandler).on("core.element.validated",this.elementValidatedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("plugins.icon.placed",this.iconPlacedHandler).on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler),this.opts.defaultMessageContainer&&(this.core.registerPlugin(a.MESSAGE_PLUGIN,new t.Message({clazz:this.opts.messageClass,container:function(e,n){var a="string"==typeof i.opts.rowSelector?i.opts.rowSelector:i.opts.rowSelector(e,n),s=r(n,a);return t.Message.getClosestContainer(n,s,i.opts.rowPattern)}})),this.core.on("plugins.message.placed",this.messagePlacedHandler))},a.prototype.uninstall=function(){var e;this.results.clear(),this.containers.clear(),n(this.core.getFormElement(),((e={})[this.opts.formClass]=!1,e["fv-plugins-framework"]=!1,e)),this.core.off("core.element.ignored",this.elementIgnoredHandler).off("core.element.validating",this.elementValidatingHandler).off("core.element.validated",this.elementValidatedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("plugins.icon.placed",this.iconPlacedHandler).off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler),this.opts.defaultMessageContainer&&(this.core.deregisterPlugin(a.MESSAGE_PLUGIN),this.core.off("plugins.message.placed",this.messagePlacedHandler))},a.prototype.onEnabled=function(){var e;n(this.core.getFormElement(),((e={})[this.opts.formClass]=!0,e)),this.opts.defaultMessageContainer&&this.core.enablePlugin(a.MESSAGE_PLUGIN)},a.prototype.onDisabled=function(){var e;n(this.core.getFormElement(),((e={})[this.opts.formClass]=!1,e)),this.opts.defaultMessageContainer&&this.core.disablePlugin(a.MESSAGE_PLUGIN)},a.prototype.onIconPlaced=function(e){},a.prototype.onMessagePlaced=function(e){},a.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&(i.forEach((function(e){var i,r=t.containers.get(e);r&&(n(r,((i={})[t.opts.rowInvalidClass]=!1,i[t.opts.rowValidatingClass]=!1,i[t.opts.rowValidClass]=!1,i["fv-plugins-icon-container"]=!1,i)),t.containers.delete(e))})),this.prepareFieldContainer(e.field,i))},a.prototype.onFieldRemoved=function(e){var t=this;e.elements.forEach((function(e){var i,r=t.containers.get(e);r&&n(r,((i={})[t.opts.rowInvalidClass]=!1,i[t.opts.rowValidatingClass]=!1,i[t.opts.rowValidClass]=!1,i))}))},a.prototype.prepareFieldContainer=function(e,t){var i=this;if(t.length){var n=t[0].getAttribute("type");"radio"===n||"checkbox"===n?this.prepareElementContainer(e,t[0]):t.forEach((function(t){return i.prepareElementContainer(e,t)}))}},a.prototype.prepareElementContainer=function(e,t){var i,a="string"==typeof this.opts.rowSelector?this.opts.rowSelector:this.opts.rowSelector(e,t),s=r(t,a);s!==t&&(n(s,((i={})[this.opts.rowClasses]=!0,i["fv-plugins-icon-container"]=!0,i)),this.containers.set(t,s))},a.prototype.onElementValidating=function(e){this.removeClasses(e.element,e.elements)},a.prototype.onElementNotValidated=function(e){this.removeClasses(e.element,e.elements)},a.prototype.onElementIgnored=function(e){this.removeClasses(e.element,e.elements)},a.prototype.removeClasses=function(e,t){var i,r=this,a=e.getAttribute("type"),s="radio"===a||"checkbox"===a?t[0]:e;t.forEach((function(e){var t;n(e,((t={})[r.opts.eleValidClass]=!1,t[r.opts.eleInvalidClass]=!1,t))}));var o=this.containers.get(s);o&&n(o,((i={})[this.opts.rowInvalidClass]=!1,i[this.opts.rowValidatingClass]=!1,i[this.opts.rowValidClass]=!1,i))},a.prototype.onElementValidated=function(e){var t,i,r=this,a=e.elements,s=e.element.getAttribute("type"),o="radio"===s||"checkbox"===s?a[0]:e.element;a.forEach((function(t){var i;n(t,((i={})[r.opts.eleValidClass]=e.valid,i[r.opts.eleInvalidClass]=!e.valid,i))}));var l=this.containers.get(o);if(l)if(e.valid){this.results.delete(o);var c=!0;this.containers.forEach((function(e,t){e===l&&!1===r.results.get(t)&&(c=!1)})),c&&n(l,((i={})[this.opts.rowInvalidClass]=!1,i[this.opts.rowValidatingClass]=!1,i[this.opts.rowValidClass]=!0,i))}else this.results.set(o,!1),n(l,((t={})[this.opts.rowInvalidClass]=!0,t[this.opts.rowValidatingClass]=!1,t[this.opts.rowValidClass]=!1,t))},a.MESSAGE_PLUGIN="___frameworkMessage",a}(e.Plugin);return I.Framework=s,I}();var R,z=Y.exports,B={exports:{}},V={};B.exports=function(){if(R)return V;R=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.classSet,n=function(e){function n(t){var i=e.call(this,t)||this;return i.icons=new Map,i.opts=Object.assign({},{invalid:"fv-plugins-icon--invalid",onPlaced:function(){},onSet:function(){},valid:"fv-plugins-icon--valid",validating:"fv-plugins-icon--validating"},t),i.elementValidatingHandler=i.onElementValidating.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.elementNotValidatedHandler=i.onElementNotValidated.bind(i),i.elementIgnoredHandler=i.onElementIgnored.bind(i),i.fieldAddedHandler=i.onFieldAdded.bind(i),i}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.prototype.install=function(){this.core.on("core.element.validating",this.elementValidatingHandler).on("core.element.validated",this.elementValidatedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("core.element.ignored",this.elementIgnoredHandler).on("core.field.added",this.fieldAddedHandler)},n.prototype.uninstall=function(){this.icons.forEach((function(e){return e.parentNode.removeChild(e)})),this.icons.clear(),this.core.off("core.element.validating",this.elementValidatingHandler).off("core.element.validated",this.elementValidatedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("core.element.ignored",this.elementIgnoredHandler).off("core.field.added",this.fieldAddedHandler)},n.prototype.onEnabled=function(){this.icons.forEach((function(e,t,n){i(t,{"fv-plugins-icon--enabled":!0,"fv-plugins-icon--disabled":!1})}))},n.prototype.onDisabled=function(){this.icons.forEach((function(e,t,n){i(t,{"fv-plugins-icon--enabled":!1,"fv-plugins-icon--disabled":!0})}))},n.prototype.onFieldAdded=function(e){var t=this,i=e.elements;i&&(i.forEach((function(e){var i=t.icons.get(e);i&&(i.parentNode.removeChild(i),t.icons.delete(e))})),this.prepareFieldIcon(e.field,i))},n.prototype.prepareFieldIcon=function(e,t){var i=this;if(t.length){var n=t[0].getAttribute("type");"radio"===n||"checkbox"===n?this.prepareElementIcon(e,t[0]):t.forEach((function(t){return i.prepareElementIcon(e,t)}))}},n.prototype.prepareElementIcon=function(e,t){var n=document.createElement("i");n.setAttribute("data-field",e),t.parentNode.insertBefore(n,t.nextSibling),i(n,{"fv-plugins-icon":!0,"fv-plugins-icon--enabled":this.isEnabled,"fv-plugins-icon--disabled":!this.isEnabled});var r={classes:{invalid:this.opts.invalid,valid:this.opts.valid,validating:this.opts.validating},element:t,field:e,iconElement:n};this.core.emit("plugins.icon.placed",r),this.opts.onPlaced(r),this.icons.set(t,n)},n.prototype.onElementValidating=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!1,t[this.opts.valid]=!1,t[this.opts.validating]=!0,t)),n={element:e.element,field:e.field,iconElement:i,status:"Validating"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.onElementValidated=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!e.valid,t[this.opts.valid]=e.valid,t[this.opts.validating]=!1,t)),n={element:e.element,field:e.field,iconElement:i,status:e.valid?"Valid":"Invalid"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.onElementNotValidated=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!1,t[this.opts.valid]=!1,t[this.opts.validating]=!1,t)),n={element:e.element,field:e.field,iconElement:i,status:"NotValidated"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.onElementIgnored=function(e){var t,i=this.setClasses(e.field,e.element,e.elements,((t={})[this.opts.invalid]=!1,t[this.opts.valid]=!1,t[this.opts.validating]=!1,t)),n={element:e.element,field:e.field,iconElement:i,status:"Ignored"};this.core.emit("plugins.icon.set",n),this.opts.onSet(n)},n.prototype.setClasses=function(e,t,n,r){var a=t.getAttribute("type"),s="radio"===a||"checkbox"===a?n[0]:t;if(this.icons.has(s)){var o=this.icons.get(s);return i(o,r),o}return null},n}(e.Plugin);return V.Icon=n,V}();var W,U=B.exports,q={exports:{}},$={};q.exports=function(){if(W)return $;W=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.removeUndefined,n=function(e){function n(t){var n=e.call(this,t)||this;return n.invalidFields=new Map,n.opts=Object.assign({},{enabled:!0},i(t)),n.validatorHandler=n.onValidatorValidated.bind(n),n.shouldValidateFilter=n.shouldValidate.bind(n),n.fieldAddedHandler=n.onFieldAdded.bind(n),n.elementNotValidatedHandler=n.onElementNotValidated.bind(n),n.elementValidatingHandler=n.onElementValidating.bind(n),n}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.prototype.install=function(){this.core.on("core.validator.validated",this.validatorHandler).on("core.field.added",this.fieldAddedHandler).on("core.element.notvalidated",this.elementNotValidatedHandler).on("core.element.validating",this.elementValidatingHandler).registerFilter("field-should-validate",this.shouldValidateFilter)},n.prototype.uninstall=function(){this.invalidFields.clear(),this.core.off("core.validator.validated",this.validatorHandler).off("core.field.added",this.fieldAddedHandler).off("core.element.notvalidated",this.elementNotValidatedHandler).off("core.element.validating",this.elementValidatingHandler).deregisterFilter("field-should-validate",this.shouldValidateFilter)},n.prototype.shouldValidate=function(e,t,i,n){return!this.isEnabled||!((!0===this.opts.enabled||!0===this.opts.enabled[e])&&this.invalidFields.has(t)&&this.invalidFields.get(t).length&&-1===this.invalidFields.get(t).indexOf(n))},n.prototype.onValidatorValidated=function(e){var t=this.invalidFields.has(e.element)?this.invalidFields.get(e.element):[],i=t.indexOf(e.validator);e.result.valid&&i>=0?t.splice(i,1):e.result.valid||-1!==i||t.push(e.validator),this.invalidFields.set(e.element,t)},n.prototype.onFieldAdded=function(e){e.elements&&this.clearInvalidFields(e.elements)},n.prototype.onElementNotValidated=function(e){this.clearInvalidFields(e.elements)},n.prototype.onElementValidating=function(e){this.clearInvalidFields(e.elements)},n.prototype.clearInvalidFields=function(e){var t=this;e.forEach((function(e){return t.invalidFields.delete(e)}))},n}(e.Plugin);return $.Sequence=n,$}();var X,G=q.exports,Z={exports:{}},K={};Z.exports=function(){if(X)return K;X=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;return i.isFormValid=!1,i.isButtonClicked=!1,i.opts=Object.assign({},{aspNetButton:!1,buttons:function(e){return[].slice.call(e.querySelectorAll('[type="submit"]:not([formnovalidate])'))},liveMode:!0},e),i.submitHandler=i.handleSubmitEvent.bind(i),i.buttonClickHandler=i.handleClickEvent.bind(i),i.ignoreValidationFilter=i.ignoreValidation.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){var e=this;if(this.core.getFormElement()instanceof HTMLFormElement){var t=this.core.getFormElement();this.submitButtons=this.opts.buttons(t),t.setAttribute("novalidate","novalidate"),t.addEventListener("submit",this.submitHandler),this.hiddenClickedEle=document.createElement("input"),this.hiddenClickedEle.setAttribute("type","hidden"),t.appendChild(this.hiddenClickedEle),this.submitButtons.forEach((function(t){t.addEventListener("click",e.buttonClickHandler)})),this.core.registerFilter("element-ignored",this.ignoreValidationFilter)}},i.prototype.uninstall=function(){var e=this,t=this.core.getFormElement();t instanceof HTMLFormElement&&t.removeEventListener("submit",this.submitHandler),this.submitButtons.forEach((function(t){t.removeEventListener("click",e.buttonClickHandler)})),this.hiddenClickedEle.parentElement.removeChild(this.hiddenClickedEle),this.core.deregisterFilter("element-ignored",this.ignoreValidationFilter)},i.prototype.handleSubmitEvent=function(e){this.validateForm(e)},i.prototype.handleClickEvent=function(e){var t=e.currentTarget;if(this.isButtonClicked=!0,t instanceof HTMLElement)if(this.opts.aspNetButton&&!0===this.isFormValid);else{this.core.getFormElement().removeEventListener("submit",this.submitHandler),this.clickedButton=e.target;var i=this.clickedButton.getAttribute("name"),n=this.clickedButton.getAttribute("value");i&&n&&(this.hiddenClickedEle.setAttribute("name",i),this.hiddenClickedEle.setAttribute("value",n)),this.validateForm(e)}},i.prototype.validateForm=function(e){var t=this;this.isEnabled&&(e.preventDefault(),this.core.validate().then((function(e){"Valid"===e&&t.opts.aspNetButton&&!t.isFormValid&&t.clickedButton&&(t.isFormValid=!0,t.clickedButton.removeEventListener("click",t.buttonClickHandler),t.clickedButton.click())})))},i.prototype.ignoreValidation=function(e,t,i){return!!this.isEnabled&&!this.opts.liveMode&&!this.isButtonClicked},i}(a.Plugin);return K.SubmitButton=t,K}();var J,Q=Z.exports,ee={exports:{}},te={};ee.exports=function(){if(J)return te;J=1;var e=a,t=function(e,i){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},t(e,i)},i=e.utils.classSet,n=function(e){function n(t){var i=e.call(this,t)||this;return i.messages=new Map,i.opts=Object.assign({},{placement:"top",trigger:"click"},t),i.iconPlacedHandler=i.onIconPlaced.bind(i),i.validatorValidatedHandler=i.onValidatorValidated.bind(i),i.elementValidatedHandler=i.onElementValidated.bind(i),i.documentClickHandler=i.onDocumentClicked.bind(i),i}return function(e,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=e}t(e,i),e.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(n,e),n.prototype.install=function(){var e;this.tip=document.createElement("div"),i(this.tip,((e={"fv-plugins-tooltip":!0})["fv-plugins-tooltip--".concat(this.opts.placement)]=!0,e)),document.body.appendChild(this.tip),this.core.on("plugins.icon.placed",this.iconPlacedHandler).on("core.validator.validated",this.validatorValidatedHandler).on("core.element.validated",this.elementValidatedHandler),"click"===this.opts.trigger&&document.addEventListener("click",this.documentClickHandler)},n.prototype.uninstall=function(){this.messages.clear(),document.body.removeChild(this.tip),this.core.off("plugins.icon.placed",this.iconPlacedHandler).off("core.validator.validated",this.validatorValidatedHandler).off("core.element.validated",this.elementValidatedHandler),"click"===this.opts.trigger&&document.removeEventListener("click",this.documentClickHandler)},n.prototype.onIconPlaced=function(e){var t=this;i(e.iconElement,{"fv-plugins-tooltip-icon":!0}),"hover"===this.opts.trigger?(e.iconElement.addEventListener("mouseenter",(function(i){return t.show(e.element,i)})),e.iconElement.addEventListener("mouseleave",(function(e){return t.hide()}))):e.iconElement.addEventListener("click",(function(i){return t.show(e.element,i)}))},n.prototype.onValidatorValidated=function(e){if(!e.result.valid){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element,r="string"==typeof e.result.message?e.result.message:e.result.message[this.core.getLocale()];this.messages.set(n,r)}},n.prototype.onElementValidated=function(e){if(e.valid){var t=e.elements,i=e.element.getAttribute("type"),n="radio"===i||"checkbox"===i?t[0]:e.element;this.messages.delete(n)}},n.prototype.onDocumentClicked=function(e){this.hide()},n.prototype.show=function(e,t){if(this.isEnabled&&(t.preventDefault(),t.stopPropagation(),this.messages.has(e))){i(this.tip,{"fv-plugins-tooltip--hide":!1}),this.tip.innerHTML='<div class="fv-plugins-tooltip__content">'.concat(this.messages.get(e),"</div>");var n=t.target.getBoundingClientRect(),r=this.tip.getBoundingClientRect(),a=r.height,s=r.width,o=0,l=0;switch(this.opts.placement){case"bottom":o=n.top+n.height,l=n.left+n.width/2-s/2;break;case"bottom-left":o=n.top+n.height,l=n.left;break;case"bottom-right":o=n.top+n.height,l=n.left+n.width-s;break;case"left":o=n.top+n.height/2-a/2,l=n.left-s;break;case"right":o=n.top+n.height/2-a/2,l=n.left+n.width;break;case"top-left":o=n.top-a,l=n.left;break;case"top-right":o=n.top-a,l=n.left+n.width-s;break;default:o=n.top-a,l=n.left+n.width/2-s/2}o+=window.scrollY||document.documentElement.scrollTop||document.body.scrollTop||0,l+=window.scrollX||document.documentElement.scrollLeft||document.body.scrollLeft||0,this.tip.setAttribute("style","top: ".concat(o,"px; left: ").concat(l,"px"))}},n.prototype.hide=function(){this.isEnabled&&i(this.tip,{"fv-plugins-tooltip--hide":!0})},n}(e.Plugin);return te.Tooltip=n,te}();var ie,ne=ee.exports,re={exports:{}},ae={};re.exports=function(){if(ie)return ae;ie=1;var e=function(t,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},e(t,i)},t=function(t){function i(e){var i=t.call(this,e)||this;i.handlers=[],i.timers=new Map;var n=document.createElement("div");return i.defaultEvent="oninput"in n?"input":"keyup",i.opts=Object.assign({},{delay:0,event:i.defaultEvent,threshold:0},e),i.fieldAddedHandler=i.onFieldAdded.bind(i),i.fieldRemovedHandler=i.onFieldRemoved.bind(i),i}return function(t,i){if("function"!=typeof i&&null!==i)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");function n(){this.constructor=t}e(t,i),t.prototype=null===i?Object.create(i):(n.prototype=i.prototype,new n)}(i,t),i.prototype.install=function(){this.core.on("core.field.added",this.fieldAddedHandler).on("core.field.removed",this.fieldRemovedHandler)},i.prototype.uninstall=function(){this.handlers.forEach((function(e){return e.element.removeEventListener(e.event,e.handler)})),this.handlers=[],this.timers.forEach((function(e){return window.clearTimeout(e)})),this.timers.clear(),this.core.off("core.field.added",this.fieldAddedHandler).off("core.field.removed",this.fieldRemovedHandler)},i.prototype.prepareHandler=function(e,t){var i=this;t.forEach((function(t){var n=[];if(i.opts.event&&!1===i.opts.event[e])n=[];else if(i.opts.event&&i.opts.event[e]&&"function"!=typeof i.opts.event[e])n=i.opts.event[e].split(" ");else if("string"==typeof i.opts.event&&i.opts.event!==i.defaultEvent)n=i.opts.event.split(" ");else{var r=t.getAttribute("type"),a=t.tagName.toLowerCase();n=["radio"===r||"checkbox"===r||"file"===r||"select"===a?"change":i.ieVersion>=10&&t.getAttribute("placeholder")?"keyup":i.defaultEvent]}n.forEach((function(n){var r=function(n){return i.handleEvent(n,e,t)};i.handlers.push({element:t,event:n,field:e,handler:r}),t.addEventListener(n,r)}))}))},i.prototype.handleEvent=function(e,t,i){var n=this;if(this.isEnabled&&this.exceedThreshold(t,i)&&this.core.executeFilter("plugins-trigger-should-validate",!0,[t,i])){var r=function(){return n.core.validateElement(t,i).then((function(r){n.core.emit("plugins.trigger.executed",{element:i,event:e,field:t})}))},a=this.opts.delay[t]||this.opts.delay;if(0===a)r();else{var s=this.timers.get(i);s&&window.clearTimeout(s),this.timers.set(i,window.setTimeout(r,1e3*a))}}},i.prototype.onFieldAdded=function(e){this.handlers.filter((function(t){return t.field===e.field})).forEach((function(e){return e.element.removeEventListener(e.event,e.handler)})),this.prepareHandler(e.field,e.elements)},i.prototype.onFieldRemoved=function(e){this.handlers.filter((function(t){return t.field===e.field&&e.elements.indexOf(t.element)>=0})).forEach((function(e){return e.element.removeEventListener(e.event,e.handler)}))},i.prototype.exceedThreshold=function(e,t){var i=0!==this.opts.threshold[e]&&0!==this.opts.threshold&&(this.opts.threshold[e]||this.opts.threshold);if(!i)return!0;var n=t.getAttribute("type");return-1!==["button","checkbox","file","hidden","image","radio","reset","submit"].indexOf(n)||this.core.getElementValue(e,t).length>=i},i}(a.Plugin);return ae.Trigger=t,ae}();var se,oe=re.exports,le={exports:{}},ce={};le.exports=function(){if(se)return ce;se=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return ce.between=function(){var e=function(e){return parseFloat("".concat(e).replace(",","."))};return{validate:function(n){var r=n.value;if(""===r)return{valid:!0};var a=Object.assign({},{inclusive:!0,message:""},i(n.options)),s=e(a.min),o=e(a.max);return a.inclusive?{message:t(n.l10n?a.message||n.l10n.between.default:a.message,["".concat(s),"".concat(o)]),valid:parseFloat(r)>=s&&parseFloat(r)<=o}:{message:t(n.l10n?a.message||n.l10n.between.notInclusive:a.message,["".concat(s),"".concat(o)]),valid:parseFloat(r)>s&&parseFloat(r)<o}}}},ce}();var ue,de=le.exports,he={exports:{}},fe={};he.exports=(ue||(ue=1,fe.blank=function(){return{validate:function(e){return{valid:!0}}}}),fe);var pe,me=he.exports,ge={exports:{}},ve={};ge.exports=function(){if(pe)return ve;pe=1;var e=a.utils.call;return ve.callback=function(){return{validate:function(t){var i=e(t.options.callback,[t]);return"boolean"==typeof i?{valid:i}:i}}},ve}();var ye,be=ge.exports,xe={exports:{}},_e={};xe.exports=function(){if(ye)return _e;ye=1;var e=a.utils.format;return _e.choice=function(){return{validate:function(t){var i="select"===t.element.tagName.toLowerCase()?t.element.querySelectorAll("option:checked").length:t.elements.filter((function(e){return e.checked})).length,n=t.options.min?"".concat(t.options.min):"",r=t.options.max?"".concat(t.options.max):"",a=t.l10n?t.options.message||t.l10n.choice.default:t.options.message,s=!(n&&i<parseInt(n,10)||r&&i>parseInt(r,10));switch(!0){case!!n&&!!r:a=e(t.l10n?t.l10n.choice.between:t.options.message,[n,r]);break;case!!n:a=e(t.l10n?t.l10n.choice.more:t.options.message,n);break;case!!r:a=e(t.l10n?t.l10n.choice.less:t.options.message,r)}return{message:a,valid:s}}}},_e}();var we,ke=xe.exports,Me={exports:{}},Se={};Me.exports=function(){if(we)return Se;we=1;var e=a.algorithms.luhn,t={AMERICAN_EXPRESS:{length:[15],prefix:["34","37"]},DANKORT:{length:[16],prefix:["5019"]},DINERS_CLUB:{length:[14],prefix:["300","301","302","303","304","305","36"]},DINERS_CLUB_US:{length:[16],prefix:["54","55"]},DISCOVER:{length:[16],prefix:["6011","622126","622127","622128","622129","62213","62214","62215","62216","62217","62218","62219","6222","6223","6224","6225","6226","6227","6228","62290","62291","622920","622921","622922","622923","622924","622925","644","645","646","647","648","649","65"]},ELO:{length:[16],prefix:["4011","4312","4389","4514","4573","4576","5041","5066","5067","509","6277","6362","6363","650","6516","6550"]},FORBRUGSFORENINGEN:{length:[16],prefix:["600722"]},JCB:{length:[16],prefix:["3528","3529","353","354","355","356","357","358"]},LASER:{length:[16,17,18,19],prefix:["6304","6706","6771","6709"]},MAESTRO:{length:[12,13,14,15,16,17,18,19],prefix:["5018","5020","5038","5868","6304","6759","6761","6762","6763","6764","6765","6766"]},MASTERCARD:{length:[16],prefix:["51","52","53","54","55"]},SOLO:{length:[16,18,19],prefix:["6334","6767"]},UNIONPAY:{length:[16,17,18,19],prefix:["622126","622127","622128","622129","62213","62214","62215","62216","62217","62218","62219","6222","6223","6224","6225","6226","6227","6228","62290","62291","622920","622921","622922","622923","622924","622925"]},VISA:{length:[16],prefix:["4"]},VISA_ELECTRON:{length:[16],prefix:["4026","417500","4405","4508","4844","4913","4917"]}};return Se.CREDIT_CARD_TYPES=t,Se.creditCard=function(){return{validate:function(i){if(""===i.value)return{meta:{type:null},valid:!0};if(/[^0-9-\s]+/.test(i.value))return{meta:{type:null},valid:!1};var n=i.value.replace(/\D/g,"");if(!e(n))return{meta:{type:null},valid:!1};for(var r=0,a=Object.keys(t);r<a.length;r++){var s=a[r];for(var o in t[s].prefix)if(i.value.substr(0,t[s].prefix[o].length)===t[s].prefix[o]&&-1!==t[s].length.indexOf(n.length))return{meta:{type:s},valid:!0}}return{meta:{type:null},valid:!1}}}},Se}();var Ae,Le=Me.exports,Te={exports:{}},Ce={};Te.exports=function(){if(Ae)return Ce;Ae=1;var e=a,t=e.utils.format,i=e.utils.isValidDate,n=e.utils.removeUndefined,r=function(e,t,i){var n=t.indexOf("YYYY"),r=t.indexOf("MM"),a=t.indexOf("DD");if(-1===n||-1===r||-1===a)return null;var s=e.split(" "),o=s[0].split(i);if(o.length<3)return null;var l=new Date(parseInt(o[n],10),parseInt(o[r],10)-1,parseInt(o[a],10)),c=s.length>2?s[2]:null;if(s.length>1){var u=s[1].split(":"),d=u.length>0?parseInt(u[0],10):0;l.setHours(c&&"PM"===c.toUpperCase()&&d<12?d+12:d),l.setMinutes(u.length>1?parseInt(u[1],10):0),l.setSeconds(u.length>2?parseInt(u[2],10):0)}return l},s=function(e,t){var i=t.replace(/Y/g,"y").replace(/M/g,"m").replace(/D/g,"d").replace(/:m/g,":M").replace(/:mm/g,":MM").replace(/:S/,":s").replace(/:SS/,":ss"),n=e.getDate(),r=n<10?"0".concat(n):n,a=e.getMonth()+1,s=a<10?"0".concat(a):a,o="".concat(e.getFullYear()).substr(2),l=e.getFullYear(),c=e.getHours()%12||12,u=c<10?"0".concat(c):c,d=e.getHours(),h=d<10?"0".concat(d):d,f=e.getMinutes(),p=f<10?"0".concat(f):f,m=e.getSeconds(),g=m<10?"0".concat(m):m,v={H:"".concat(d),HH:"".concat(h),M:"".concat(f),MM:"".concat(p),d:"".concat(n),dd:"".concat(r),h:"".concat(c),hh:"".concat(u),m:"".concat(a),mm:"".concat(s),s:"".concat(m),ss:"".concat(g),yy:"".concat(o),yyyy:"".concat(l)};return i.replace(/d{1,4}|m{1,4}|yy(?:yy)?|([HhMs])\1?|"[^"]*"|'[^']*'/g,(function(e){return v[e]?v[e]:e.slice(1,e.length-1)}))};return Ce.date=function(){return{validate:function(e){if(""===e.value)return{meta:{date:null},valid:!0};var a=Object.assign({},{format:e.element&&"date"===e.element.getAttribute("type")?"YYYY-MM-DD":"MM/DD/YYYY",message:""},n(e.options)),o=e.l10n?e.l10n.date.default:a.message,l={message:"".concat(o),meta:{date:null},valid:!1},c=a.format.split(" "),u=c.length>1?c[1]:null,d=c.length>2?c[2]:null,h=e.value.split(" "),f=h[0],p=h.length>1?h[1]:null,m=h.length>2?h[2]:null;if(c.length!==h.length)return l;var g=a.separator||(-1!==f.indexOf("/")?"/":-1!==f.indexOf("-")?"-":-1!==f.indexOf(".")?".":"/");if(null===g||-1===f.indexOf(g))return l;var v=f.split(g),y=c[0].split(g);if(v.length!==y.length)return l;var b=v[y.indexOf("YYYY")],x=v[y.indexOf("MM")],_=v[y.indexOf("DD")];if(!/^\d+$/.test(b)||!/^\d+$/.test(x)||!/^\d+$/.test(_)||b.length>4||x.length>2||_.length>2)return l;var w=parseInt(b,10),k=parseInt(x,10),M=parseInt(_,10);if(!i(w,k,M))return l;var S=new Date(w,k-1,M);if(u){var A=p.split(":");if(u.split(":").length!==A.length)return l;var L=A.length>0?A[0].length<=2&&/^\d+$/.test(A[0])?parseInt(A[0],10):-1:0,T=A.length>1?A[1].length<=2&&/^\d+$/.test(A[1])?parseInt(A[1],10):-1:0,C=A.length>2?A[2].length<=2&&/^\d+$/.test(A[2])?parseInt(A[2],10):-1:0;if(-1===L||-1===T||-1===C)return l;if(C<0||C>60)return l;if(L<0||L>=24||d&&L>12)return l;if(T<0||T>59)return l;S.setHours(m&&"PM"===m.toUpperCase()&&L<12?L+12:L),S.setMinutes(T),S.setSeconds(C)}var D="function"==typeof a.min?a.min():a.min,E=D instanceof Date?D:D?r(D,y,g):S,O="function"==typeof a.max?a.max():a.max,P=O instanceof Date?O:O?r(O,y,g):S,Y=D instanceof Date?s(E,a.format):D,I=O instanceof Date?s(P,a.format):O;switch(!0){case!!Y&&!I:return{message:t(e.l10n?e.l10n.date.min:o,Y),meta:{date:S},valid:S.getTime()>=E.getTime()};case!!I&&!Y:return{message:t(e.l10n?e.l10n.date.max:o,I),meta:{date:S},valid:S.getTime()<=P.getTime()};case!!I&&!!Y:return{message:t(e.l10n?e.l10n.date.range:o,[Y,I]),meta:{date:S},valid:S.getTime()<=P.getTime()&&S.getTime()>=E.getTime()};default:return{message:"".concat(o),meta:{date:S},valid:!0}}}}},Ce}();var De,Ee=Te.exports,Oe={exports:{}},Pe={};Oe.exports=(De||(De=1,Pe.different=function(){return{validate:function(e){var t="function"==typeof e.options.compare?e.options.compare.call(this):e.options.compare;return{valid:""===t||e.value!==t}}}}),Pe);var Ye,Ie=Oe.exports,Ne={exports:{}},je={};Ne.exports=(Ye||(Ye=1,je.digits=function(){return{validate:function(e){return{valid:""===e.value||/^\d+$/.test(e.value)}}}}),je);var He,Fe=Ne.exports,Re={exports:{}},ze={};Re.exports=function(){if(He)return ze;He=1;var e=a.utils.removeUndefined,t=/^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/,i=/^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+$/;return ze.emailAddress=function(){return{validate:function(n){if(""===n.value)return{valid:!0};var r=Object.assign({},{multiple:!1,requireGlobalDomain:!1,separator:/[,;]/},e(n.options)),a=r.requireGlobalDomain?i:t;if(!0===r.multiple||"true"==="".concat(r.multiple)){for(var s=r.separator||/[,;]/,o=function(e,t){for(var i=e.split(/"/),n=i.length,r=[],a="",s=0;s<n;s++)if(s%2==0){var o=i[s].split(t),l=o.length;if(1===l)a+=o[0];else{r.push(a+o[0]);for(var c=1;c<l-1;c++)r.push(o[c]);a=o[l-1]}}else a+='"'+i[s],s<n-1&&(a+='"');return r.push(a),r}(n.value,s),l=o.length,c=0;c<l;c++)if(!a.test(o[c]))return{valid:!1};return{valid:!0}}return{valid:a.test(n.value)}}}},ze}();var Be,Ve=Re.exports,We={exports:{}},Ue={};We.exports=function(){if(Be)return Ue;Be=1;var e=function(e){return-1===e.indexOf(".")?e:e.split(".").slice(0,-1).join(".")};return Ue.file=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i,n,r=t.options.extension?t.options.extension.toLowerCase().split(",").map((function(e){return e.trim()})):[],a=t.options.type?t.options.type.toLowerCase().split(",").map((function(e){return e.trim()})):[];if(window.File&&window.FileList&&window.FileReader){var s=t.element.files,o=s.length,l=0;if(t.options.maxFiles&&o>parseInt("".concat(t.options.maxFiles),10))return{meta:{error:"INVALID_MAX_FILES"},valid:!1};if(t.options.minFiles&&o<parseInt("".concat(t.options.minFiles),10))return{meta:{error:"INVALID_MIN_FILES"},valid:!1};for(var c={},u=0;u<o;u++){if(l+=s[u].size,c={ext:i=s[u].name.substr(s[u].name.lastIndexOf(".")+1),file:s[u],size:s[u].size,type:s[u].type},t.options.minSize&&s[u].size<parseInt("".concat(t.options.minSize),10))return{meta:Object.assign({},{error:"INVALID_MIN_SIZE"},c),valid:!1};if(t.options.maxSize&&s[u].size>parseInt("".concat(t.options.maxSize),10))return{meta:Object.assign({},{error:"INVALID_MAX_SIZE"},c),valid:!1};if(r.length>0&&-1===r.indexOf(i.toLowerCase()))return{meta:Object.assign({},{error:"INVALID_EXTENSION"},c),valid:!1};if(a.length>0&&s[u].type&&-1===a.indexOf(s[u].type.toLowerCase()))return{meta:Object.assign({},{error:"INVALID_TYPE"},c),valid:!1};if(t.options.validateFileName&&!t.options.validateFileName(e(s[u].name)))return{meta:Object.assign({},{error:"INVALID_NAME"},c),valid:!1}}if(t.options.maxTotalSize&&l>parseInt("".concat(t.options.maxTotalSize),10))return{meta:Object.assign({},{error:"INVALID_MAX_TOTAL_SIZE",totalSize:l},c),valid:!1};if(t.options.minTotalSize&&l<parseInt("".concat(t.options.minTotalSize),10))return{meta:Object.assign({},{error:"INVALID_MIN_TOTAL_SIZE",totalSize:l},c),valid:!1}}else{if(i=t.value.substr(t.value.lastIndexOf(".")+1),r.length>0&&-1===r.indexOf(i.toLowerCase()))return{meta:{error:"INVALID_EXTENSION",ext:i},valid:!1};if(n=e(t.value),t.options.validateFileName&&!t.options.validateFileName(n))return{meta:{error:"INVALID_NAME",name:n},valid:!1}}return{valid:!0}}}},Ue}();var qe,$e=We.exports,Xe={exports:{}},Ge={};Xe.exports=function(){if(qe)return Ge;qe=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return Ge.greaterThan=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var n=Object.assign({},{inclusive:!0,message:""},i(e.options)),r=parseFloat("".concat(n.min).replace(",","."));return n.inclusive?{message:t(e.l10n?n.message||e.l10n.greaterThan.default:n.message,"".concat(r)),valid:parseFloat(e.value)>=r}:{message:t(e.l10n?n.message||e.l10n.greaterThan.notInclusive:n.message,"".concat(r)),valid:parseFloat(e.value)>r}}}},Ge}();var Ze,Ke=Xe.exports,Je={exports:{}},Qe={};Je.exports=(Ze||(Ze=1,Qe.identical=function(){return{validate:function(e){var t="function"==typeof e.options.compare?e.options.compare.call(this):e.options.compare;return{valid:""===t||e.value===t}}}}),Qe);var et,tt=Je.exports,it={exports:{}},nt={};it.exports=function(){if(et)return nt;et=1;var e=a.utils.removeUndefined;return nt.integer=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{decimalSeparator:".",thousandsSeparator:""},e(t.options)),n="."===i.decimalSeparator?"\\.":i.decimalSeparator,r="."===i.thousandsSeparator?"\\.":i.thousandsSeparator,a=new RegExp("^-?[0-9]{1,3}(".concat(r,"[0-9]{3})*(").concat(n,"[0-9]+)?$")),s=new RegExp(r,"g"),o="".concat(t.value);if(!a.test(o))return{valid:!1};r&&(o=o.replace(s,"")),n&&(o=o.replace(n,"."));var l=parseFloat(o);return{valid:!isNaN(l)&&isFinite(l)&&Math.floor(l)===l}}}},nt}();var rt,at=it.exports,st={exports:{}},ot={};st.exports=function(){if(rt)return ot;rt=1;var e=a.utils.removeUndefined;return ot.ip=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{ipv4:!0,ipv6:!0},e(t.options)),n=/^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(\/([0-9]|[1-2][0-9]|3[0-2]))?$/,r=/^\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(%.+)?\s*(\/(\d|\d\d|1[0-1]\d|12[0-8]))?$/;switch(!0){case i.ipv4&&!i.ipv6:return{message:t.l10n?i.message||t.l10n.ip.ipv4:i.message,valid:n.test(t.value)};case!i.ipv4&&i.ipv6:return{message:t.l10n?i.message||t.l10n.ip.ipv6:i.message,valid:r.test(t.value)};case i.ipv4&&i.ipv6:default:return{message:t.l10n?i.message||t.l10n.ip.default:i.message,valid:n.test(t.value)||r.test(t.value)}}}}},ot}();var lt,ct=st.exports,ut={exports:{}},dt={};ut.exports=function(){if(lt)return dt;lt=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return dt.lessThan=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var n=Object.assign({},{inclusive:!0,message:""},i(e.options)),r=parseFloat("".concat(n.max).replace(",","."));return n.inclusive?{message:t(e.l10n?n.message||e.l10n.lessThan.default:n.message,"".concat(r)),valid:parseFloat(e.value)<=r}:{message:t(e.l10n?n.message||e.l10n.lessThan.notInclusive:n.message,"".concat(r)),valid:parseFloat(e.value)<r}}}},dt}();var ht,ft=ut.exports,pt={exports:{}},mt={};pt.exports=(ht||(ht=1,mt.notEmpty=function(){return{validate:function(e){var t=!!e.options&&!!e.options.trim,i=e.value;return{valid:!t&&""!==i||t&&""!==i&&""!==i.trim()}}}}),mt);var gt,vt=pt.exports,yt={exports:{}},bt={};yt.exports=function(){if(gt)return bt;gt=1;var e=a.utils.removeUndefined;return bt.numeric=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{decimalSeparator:".",thousandsSeparator:""},e(t.options)),n="".concat(t.value);n.substr(0,1)===i.decimalSeparator?n="0".concat(i.decimalSeparator).concat(n.substr(1)):n.substr(0,2)==="-".concat(i.decimalSeparator)&&(n="-0".concat(i.decimalSeparator).concat(n.substr(2)));var r="."===i.decimalSeparator?"\\.":i.decimalSeparator,a="."===i.thousandsSeparator?"\\.":i.thousandsSeparator,s=new RegExp("^-?[0-9]{1,3}(".concat(a,"[0-9]{3})*(").concat(r,"[0-9]+)?$")),o=new RegExp(a,"g");if(!s.test(n))return{valid:!1};a&&(n=n.replace(o,"")),r&&(n=n.replace(r,"."));var l=parseFloat(n);return{valid:!isNaN(l)&&isFinite(l)}}}},bt}();var xt,_t=yt.exports,wt={exports:{}},kt={};wt.exports=function(){if(xt)return kt;xt=1;var e=a.utils.call;return kt.promise=function(){return{validate:function(t){return e(t.options.promise,[t])}}},kt}();var Mt,St=wt.exports,At={exports:{}},Lt={};At.exports=(Mt||(Mt=1,Lt.regexp=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var t=e.options.regexp;if(t instanceof RegExp)return{valid:t.test(e.value)};var i=t.toString();return{valid:(e.options.flags?new RegExp(i,e.options.flags):new RegExp(i)).test(e.value)}}}}),Lt);var Tt,Ct=At.exports,Dt={exports:{}},Et={};Dt.exports=function(){if(Tt)return Et;Tt=1;var e=a,t=e.utils.fetch,i=e.utils.removeUndefined;return Et.remote=function(){var e={crossDomain:!1,data:{},headers:{},method:"GET",validKey:"valid"};return{validate:function(n){if(""===n.value)return Promise.resolve({valid:!0});var r=Object.assign({},e,i(n.options)),a=r.data;"function"==typeof r.data&&(a=r.data.call(this,n)),"string"==typeof a&&(a=JSON.parse(a)),a[r.name||n.field]=n.value;var s="function"==typeof r.url?r.url.call(this,n):r.url;return t(s,{crossDomain:r.crossDomain,headers:r.headers,method:r.method,params:a}).then((function(e){return Promise.resolve({message:e.message,meta:e,valid:"true"==="".concat(e[r.validKey])})})).catch((function(e){return Promise.reject({valid:!1})}))}}},Et}();var Ot,Pt=Dt.exports,Yt={exports:{}},It={};Yt.exports=function(){if(Ot)return It;Ot=1;var e=a.utils.removeUndefined;return It.stringCase=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=Object.assign({},{case:"lower"},e(t.options)),n=(i.case||"lower").toLowerCase();return{message:i.message||(t.l10n?"upper"===n?t.l10n.stringCase.upper:t.l10n.stringCase.default:i.message),valid:"upper"===n?t.value===t.value.toUpperCase():t.value===t.value.toLowerCase()}}}},It}();var Nt,jt=Yt.exports,Ht={exports:{}},Ft={};Ht.exports=function(){if(Nt)return Ft;Nt=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return Ft.stringLength=function(){return{validate:function(e){var n=Object.assign({},{message:"",trim:!1,utf8Bytes:!1},i(e.options)),r=!0===n.trim||"true"==="".concat(n.trim)?e.value.trim():e.value;if(""===r)return{valid:!0};var a=n.min?"".concat(n.min):"",s=n.max?"".concat(n.max):"",o=n.utf8Bytes?function(e){for(var t=e.length,i=e.length-1;i>=0;i--){var n=e.charCodeAt(i);n>127&&n<=2047?t++:n>2047&&n<=65535&&(t+=2),n>=56320&&n<=57343&&i--}return t}(r):r.length,l=!0,c=e.l10n?n.message||e.l10n.stringLength.default:n.message;switch((a&&o<parseInt(a,10)||s&&o>parseInt(s,10))&&(l=!1),!0){case!!a&&!!s:c=t(e.l10n?n.message||e.l10n.stringLength.between:n.message,[a,s]);break;case!!a:c=t(e.l10n?n.message||e.l10n.stringLength.more:n.message,"".concat(parseInt(a,10)));break;case!!s:c=t(e.l10n?n.message||e.l10n.stringLength.less:n.message,"".concat(parseInt(s,10)))}return{message:c,valid:l}}}},Ft}();var Rt,zt=Ht.exports,Bt={exports:{}},Vt={};Bt.exports=function(){if(Rt)return Vt;Rt=1;var e=a.utils.removeUndefined;return Vt.uri=function(){var t={allowEmptyProtocol:!1,allowLocal:!1,protocol:"http, https, ftp"};return{validate:function(i){if(""===i.value)return{valid:!0};var n=Object.assign({},t,e(i.options)),r=!0===n.allowLocal||"true"==="".concat(n.allowLocal),a=!0===n.allowEmptyProtocol||"true"==="".concat(n.allowEmptyProtocol),s=n.protocol.split(",").join("|").replace(/\s/g,"");return{valid:new RegExp("^(?:(?:"+s+")://)"+(a?"?":"")+"(?:\\S+(?::\\S*)?@)?(?:"+(r?"":"(?!(?:10|127)(?:\\.\\d{1,3}){3})(?!(?:169\\.254|192\\.168)(?:\\.\\d{1,3}){2})(?!172\\.(?:1[6-9]|2\\d|3[0-1])(?:\\.\\d{1,3}){2})")+"(?:[1-9]\\d?|1\\d\\d|2[01]\\d|22[0-3])(?:\\.(?:1?\\d{1,2}|2[0-4]\\d|25[0-5])){2}(?:\\.(?:[1-9]\\d?|1\\d\\d|2[0-4]\\d|25[0-4]))|(?:(?:[a-z\\u00a1-\\uffff0-9]-?)*[a-z\\u00a1-\\uffff0-9]+)(?:\\.(?:[a-z\\u00a1-\\uffff0-9]-?)*[a-z\\u00a1-\\uffff0-9])*(?:\\.(?:[a-z\\u00a1-\\uffff]{2,}))"+(r?"?":"")+")(?::\\d{2,5})?(?:/[^\\s]*)?$","i").test(i.value)}}}},Vt}();var Wt,Ut=Bt.exports,qt={exports:{}},$t={};qt.exports=(Wt||(Wt=1,$t.base64=function(){return{validate:function(e){return{valid:""===e.value||/^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{4})$/.test(e.value)}}}}),$t);var Xt,Gt=qt.exports,Zt={exports:{}},Kt={};Zt.exports=(Xt||(Xt=1,Kt.bic=function(){return{validate:function(e){return{valid:""===e.value||/^[a-zA-Z]{6}[a-zA-Z0-9]{2}([a-zA-Z0-9]{3})?$/.test(e.value)}}}}),Kt);var Jt,Qt=Zt.exports,ei={exports:{}},ti={};ei.exports=(Jt||(Jt=1,ti.color=function(){var e=["hex","rgb","rgba","hsl","hsla","keyword"],t=["aliceblue","antiquewhite","aqua","aquamarine","azure","beige","bisque","black","blanchedalmond","blue","blueviolet","brown","burlywood","cadetblue","chartreuse","chocolate","coral","cornflowerblue","cornsilk","crimson","cyan","darkblue","darkcyan","darkgoldenrod","darkgray","darkgreen","darkgrey","darkkhaki","darkmagenta","darkolivegreen","darkorange","darkorchid","darkred","darksalmon","darkseagreen","darkslateblue","darkslategray","darkslategrey","darkturquoise","darkviolet","deeppink","deepskyblue","dimgray","dimgrey","dodgerblue","firebrick","floralwhite","forestgreen","fuchsia","gainsboro","ghostwhite","gold","goldenrod","gray","green","greenyellow","grey","honeydew","hotpink","indianred","indigo","ivory","khaki","lavender","lavenderblush","lawngreen","lemonchiffon","lightblue","lightcoral","lightcyan","lightgoldenrodyellow","lightgray","lightgreen","lightgrey","lightpink","lightsalmon","lightseagreen","lightskyblue","lightslategray","lightslategrey","lightsteelblue","lightyellow","lime","limegreen","linen","magenta","maroon","mediumaquamarine","mediumblue","mediumorchid","mediumpurple","mediumseagreen","mediumslateblue","mediumspringgreen","mediumturquoise","mediumvioletred","midnightblue","mintcream","mistyrose","moccasin","navajowhite","navy","oldlace","olive","olivedrab","orange","orangered","orchid","palegoldenrod","palegreen","paleturquoise","palevioletred","papayawhip","peachpuff","peru","pink","plum","powderblue","purple","red","rosybrown","royalblue","saddlebrown","salmon","sandybrown","seagreen","seashell","sienna","silver","skyblue","slateblue","slategray","slategrey","snow","springgreen","steelblue","tan","teal","thistle","tomato","transparent","turquoise","violet","wheat","white","whitesmoke","yellow","yellowgreen"],i=function(e){return/^hsl\((\s*(-?\d+)\s*,)(\s*(\b(0?\d{1,2}|100)\b%)\s*,)(\s*(\b(0?\d{1,2}|100)\b%)\s*)\)$/.test(e)},n=function(e){return/^hsla\((\s*(-?\d+)\s*,)(\s*(\b(0?\d{1,2}|100)\b%)\s*,){2}(\s*(0?(\.\d+)?|1(\.0+)?)\s*)\)$/.test(e)},r=function(e){return t.indexOf(e)>=0},a=function(e){return/^rgb\((\s*(\b([01]?\d{1,2}|2[0-4]\d|25[0-5])\b)\s*,){2}(\s*(\b([01]?\d{1,2}|2[0-4]\d|25[0-5])\b)\s*)\)$/.test(e)||/^rgb\((\s*(\b(0?\d{1,2}|100)\b%)\s*,){2}(\s*(\b(0?\d{1,2}|100)\b%)\s*)\)$/.test(e)},s=function(e){return/^rgba\((\s*(\b([01]?\d{1,2}|2[0-4]\d|25[0-5])\b)\s*,){3}(\s*(0?(\.\d+)?|1(\.0+)?)\s*)\)$/.test(e)||/^rgba\((\s*(\b(0?\d{1,2}|100)\b%)\s*,){3}(\s*(0?(\.\d+)?|1(\.0+)?)\s*)\)$/.test(e)};return{validate:function(t){if(""===t.value)return{valid:!0};for(var o,l=0,c="string"==typeof t.options.type?t.options.type.toString().replace(/s/g,"").split(","):t.options.type||e;l<c.length;l++){var u=c[l].toLowerCase();if(-1!==e.indexOf(u)){var d=!0;switch(u){case"hex":o=t.value,d=/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i.test(o);break;case"hsl":d=i(t.value);break;case"hsla":d=n(t.value);break;case"keyword":d=r(t.value);break;case"rgb":d=a(t.value);break;case"rgba":d=s(t.value)}if(d)return{valid:!0}}}return{valid:!1}}}}),ti);var ii,ni=ei.exports,ri={exports:{}},ai={};ri.exports=(ii||(ii=1,ai.cusip=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var t=e.value.toUpperCase();if(!/^[0123456789ABCDEFGHJKLMNPQRSTUVWXYZ*@#]{9}$/.test(t))return{valid:!1};var i=t.split(""),n=i.pop(),r=i.map((function(e){var t=e.charCodeAt(0);switch(!0){case"*"===e:return 36;case"@"===e:return 37;case"#"===e:return 38;case t>="A".charCodeAt(0)&&t<="Z".charCodeAt(0):return t-"A".charCodeAt(0)+10;default:return parseInt(e,10)}})).map((function(e,t){var i=t%2==0?e:2*e;return Math.floor(i/10)+i%10})).reduce((function(e,t){return e+t}),0);return{valid:n==="".concat((10-r%10)%10)}}}}),ai);var si,oi=ri.exports,li={exports:{}},ci={};li.exports=(si||(si=1,ci.ean=function(){return{validate:function(e){if(""===e.value)return{valid:!0};if(!/^(\d{8}|\d{12}|\d{13}|\d{14})$/.test(e.value))return{valid:!1};for(var t=e.value.length,i=0,n=8===t?[3,1]:[1,3],r=0;r<t-1;r++)i+=parseInt(e.value.charAt(r),10)*n[r%2];return{valid:"".concat(i=(10-i%10)%10)===e.value.charAt(t-1)}}}}),ci);var ui,di=li.exports,hi={exports:{}},fi={};hi.exports=(ui||(ui=1,fi.ein=function(){var e={ANDOVER:["10","12"],ATLANTA:["60","67"],AUSTIN:["50","53"],BROOKHAVEN:["01","02","03","04","05","06","11","13","14","16","21","22","23","25","34","51","52","54","55","56","57","58","59","65"],CINCINNATI:["30","32","35","36","37","38","61"],FRESNO:["15","24"],INTERNET:["20","26","27","45","46","47"],KANSAS_CITY:["40","44"],MEMPHIS:["94","95"],OGDEN:["80","90"],PHILADELPHIA:["33","39","41","42","43","48","62","63","64","66","68","71","72","73","74","75","76","77","81","82","83","84","85","86","87","88","91","92","93","98","99"],SMALL_BUSINESS_ADMINISTRATION:["31"]};return{validate:function(t){if(""===t.value)return{meta:null,valid:!0};if(!/^[0-9]{2}-?[0-9]{7}$/.test(t.value))return{meta:null,valid:!1};var i="".concat(t.value.substr(0,2));for(var n in e)if(-1!==e[n].indexOf(i))return{meta:{campus:n},valid:!0};return{meta:null,valid:!1}}}}),fi);var pi,mi=hi.exports,gi={exports:{}},vi={};gi.exports=function(){if(pi)return vi;pi=1;var e=a.algorithms.mod37And36;return vi.grid=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=t.value.toUpperCase();return/^[GRID:]*([0-9A-Z]{2})[-\s]*([0-9A-Z]{5})[-\s]*([0-9A-Z]{10})[-\s]*([0-9A-Z]{1})$/g.test(i)?("GRID:"===(i=i.replace(/\s/g,"").replace(/-/g,"")).substr(0,5)&&(i=i.substr(5)),{valid:e(i)}):{valid:!1}}}},vi}();var yi,bi=gi.exports,xi={exports:{}},_i={};xi.exports=(yi||(yi=1,_i.hex=function(){return{validate:function(e){return{valid:""===e.value||/^[0-9a-fA-F]+$/.test(e.value)}}}}),_i);var wi,ki=xi.exports,Mi={exports:{}},Si={};Mi.exports=function(){if(wi)return Si;wi=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return Si.iban=function(){var e={AD:"AD[0-9]{2}[0-9]{4}[0-9]{4}[A-Z0-9]{12}",AE:"AE[0-9]{2}[0-9]{3}[0-9]{16}",AL:"AL[0-9]{2}[0-9]{8}[A-Z0-9]{16}",AO:"AO[0-9]{2}[0-9]{21}",AT:"AT[0-9]{2}[0-9]{5}[0-9]{11}",AZ:"AZ[0-9]{2}[A-Z]{4}[A-Z0-9]{20}",BA:"BA[0-9]{2}[0-9]{3}[0-9]{3}[0-9]{8}[0-9]{2}",BE:"BE[0-9]{2}[0-9]{3}[0-9]{7}[0-9]{2}",BF:"BF[0-9]{2}[0-9]{23}",BG:"BG[0-9]{2}[A-Z]{4}[0-9]{4}[0-9]{2}[A-Z0-9]{8}",BH:"BH[0-9]{2}[A-Z]{4}[A-Z0-9]{14}",BI:"BI[0-9]{2}[0-9]{12}",BJ:"BJ[0-9]{2}[A-Z]{1}[0-9]{23}",BR:"BR[0-9]{2}[0-9]{8}[0-9]{5}[0-9]{10}[A-Z][A-Z0-9]",CH:"CH[0-9]{2}[0-9]{5}[A-Z0-9]{12}",CI:"CI[0-9]{2}[A-Z]{1}[0-9]{23}",CM:"CM[0-9]{2}[0-9]{23}",CR:"CR[0-9]{2}[0-9][0-9]{3}[0-9]{14}",CV:"CV[0-9]{2}[0-9]{21}",CY:"CY[0-9]{2}[0-9]{3}[0-9]{5}[A-Z0-9]{16}",CZ:"CZ[0-9]{2}[0-9]{20}",DE:"DE[0-9]{2}[0-9]{8}[0-9]{10}",DK:"DK[0-9]{2}[0-9]{14}",DO:"DO[0-9]{2}[A-Z0-9]{4}[0-9]{20}",DZ:"DZ[0-9]{2}[0-9]{20}",EE:"EE[0-9]{2}[0-9]{2}[0-9]{2}[0-9]{11}[0-9]{1}",ES:"ES[0-9]{2}[0-9]{4}[0-9]{4}[0-9]{1}[0-9]{1}[0-9]{10}",FI:"FI[0-9]{2}[0-9]{6}[0-9]{7}[0-9]{1}",FO:"FO[0-9]{2}[0-9]{4}[0-9]{9}[0-9]{1}",FR:"FR[0-9]{2}[0-9]{5}[0-9]{5}[A-Z0-9]{11}[0-9]{2}",GB:"GB[0-9]{2}[A-Z]{4}[0-9]{6}[0-9]{8}",GE:"GE[0-9]{2}[A-Z]{2}[0-9]{16}",GI:"GI[0-9]{2}[A-Z]{4}[A-Z0-9]{15}",GL:"GL[0-9]{2}[0-9]{4}[0-9]{9}[0-9]{1}",GR:"GR[0-9]{2}[0-9]{3}[0-9]{4}[A-Z0-9]{16}",GT:"GT[0-9]{2}[A-Z0-9]{4}[A-Z0-9]{20}",HR:"HR[0-9]{2}[0-9]{7}[0-9]{10}",HU:"HU[0-9]{2}[0-9]{3}[0-9]{4}[0-9]{1}[0-9]{15}[0-9]{1}",IE:"IE[0-9]{2}[A-Z]{4}[0-9]{6}[0-9]{8}",IL:"IL[0-9]{2}[0-9]{3}[0-9]{3}[0-9]{13}",IR:"IR[0-9]{2}[0-9]{22}",IS:"IS[0-9]{2}[0-9]{4}[0-9]{2}[0-9]{6}[0-9]{10}",IT:"IT[0-9]{2}[A-Z]{1}[0-9]{5}[0-9]{5}[A-Z0-9]{12}",JO:"JO[0-9]{2}[A-Z]{4}[0-9]{4}[0]{8}[A-Z0-9]{10}",KW:"KW[0-9]{2}[A-Z]{4}[0-9]{22}",KZ:"KZ[0-9]{2}[0-9]{3}[A-Z0-9]{13}",LB:"LB[0-9]{2}[0-9]{4}[A-Z0-9]{20}",LI:"LI[0-9]{2}[0-9]{5}[A-Z0-9]{12}",LT:"LT[0-9]{2}[0-9]{5}[0-9]{11}",LU:"LU[0-9]{2}[0-9]{3}[A-Z0-9]{13}",LV:"LV[0-9]{2}[A-Z]{4}[A-Z0-9]{13}",MC:"MC[0-9]{2}[0-9]{5}[0-9]{5}[A-Z0-9]{11}[0-9]{2}",MD:"MD[0-9]{2}[A-Z0-9]{20}",ME:"ME[0-9]{2}[0-9]{3}[0-9]{13}[0-9]{2}",MG:"MG[0-9]{2}[0-9]{23}",MK:"MK[0-9]{2}[0-9]{3}[A-Z0-9]{10}[0-9]{2}",ML:"ML[0-9]{2}[A-Z]{1}[0-9]{23}",MR:"MR13[0-9]{5}[0-9]{5}[0-9]{11}[0-9]{2}",MT:"MT[0-9]{2}[A-Z]{4}[0-9]{5}[A-Z0-9]{18}",MU:"MU[0-9]{2}[A-Z]{4}[0-9]{2}[0-9]{2}[0-9]{12}[0-9]{3}[A-Z]{3}",MZ:"MZ[0-9]{2}[0-9]{21}",NL:"NL[0-9]{2}[A-Z]{4}[0-9]{10}",NO:"NO[0-9]{2}[0-9]{4}[0-9]{6}[0-9]{1}",PK:"PK[0-9]{2}[A-Z]{4}[A-Z0-9]{16}",PL:"PL[0-9]{2}[0-9]{8}[0-9]{16}",PS:"PS[0-9]{2}[A-Z]{4}[A-Z0-9]{21}",PT:"PT[0-9]{2}[0-9]{4}[0-9]{4}[0-9]{11}[0-9]{2}",QA:"QA[0-9]{2}[A-Z]{4}[A-Z0-9]{21}",RO:"RO[0-9]{2}[A-Z]{4}[A-Z0-9]{16}",RS:"RS[0-9]{2}[0-9]{3}[0-9]{13}[0-9]{2}",SA:"SA[0-9]{2}[0-9]{2}[A-Z0-9]{18}",SE:"SE[0-9]{2}[0-9]{3}[0-9]{16}[0-9]{1}",SI:"SI[0-9]{2}[0-9]{5}[0-9]{8}[0-9]{2}",SK:"SK[0-9]{2}[0-9]{4}[0-9]{6}[0-9]{10}",SM:"SM[0-9]{2}[A-Z]{1}[0-9]{5}[0-9]{5}[A-Z0-9]{12}",SN:"SN[0-9]{2}[A-Z]{1}[0-9]{23}",TL:"TL38[0-9]{3}[0-9]{14}[0-9]{2}",TN:"TN59[0-9]{2}[0-9]{3}[0-9]{13}[0-9]{2}",TR:"TR[0-9]{2}[0-9]{5}[A-Z0-9]{1}[A-Z0-9]{16}",VG:"VG[0-9]{2}[A-Z]{4}[0-9]{16}",XK:"XK[0-9]{2}[0-9]{4}[0-9]{10}[0-9]{2}"},n=["AT","BE","BG","CH","CY","CZ","DE","DK","EE","ES","FI","FR","GB","GI","GR","HR","HU","IE","IS","IT","LI","LT","LU","LV","MC","MT","NL","NO","PL","PT","RO","SE","SI","SK","SM"];return{validate:function(r){if(""===r.value)return{valid:!0};var a=Object.assign({},{message:""},i(r.options)),s=r.value.replace(/[^a-zA-Z0-9]/g,"").toUpperCase(),o=a.country||s.substr(0,2);if(!e[o])return{message:a.message,valid:!1};if(void 0!==a.sepa){var l=-1!==n.indexOf(o);if(("true"===a.sepa||!0===a.sepa)&&!l||("false"===a.sepa||!1===a.sepa)&&l)return{message:a.message,valid:!1}}var c=t(r.l10n?a.message||r.l10n.iban.country:a.message,r.l10n?r.l10n.iban.countries[o]:o);if(!new RegExp("^".concat(e[o],"$")).test(r.value))return{message:c,valid:!1};s=(s="".concat(s.substr(4)).concat(s.substr(0,4))).split("").map((function(e){var t=e.charCodeAt(0);return t>="A".charCodeAt(0)&&t<="Z".charCodeAt(0)?t-"A".charCodeAt(0)+10:e})).join("");for(var u=parseInt(s.substr(0,1),10),d=s.length,h=1;h<d;++h)u=(10*u+parseInt(s.substr(h,1),10))%97;return{message:c,valid:1===u}}}},Si}();var Ai,Li=Mi.exports,Ti={exports:{}},Ci={};Ti.exports=function(){if(Ai)return Ci;Ai=1;var e=a;function t(e,t){if(!/^\d{13}$/.test(e))return!1;var i=parseInt(e.substr(0,2),10),n=parseInt(e.substr(2,2),10),r=parseInt(e.substr(7,2),10),a=parseInt(e.substr(12,1),10);if(i>31||n>12)return!1;for(var s=0,o=0;o<6;o++)s+=(7-o)*(parseInt(e.charAt(o),10)+parseInt(e.charAt(o+6),10));if(10!=(s=11-s%11)&&11!==s||(s=0),s!==a)return!1;switch(t.toUpperCase()){case"BA":return 10<=r&&r<=19;case"MK":return 41<=r&&r<=49;case"ME":return 20<=r&&r<=29;case"RS":return 70<=r&&r<=99;case"SI":return 50<=r&&r<=59;default:return!0}}var i=e.utils.isValidDate,n=e.utils.isValidDate,r=e.utils.isValidDate;function s(e){if(!/^\d{9,10}$/.test(e))return{meta:{},valid:!1};var t=1900+parseInt(e.substr(0,2),10),i=parseInt(e.substr(2,2),10)%50%20,n=parseInt(e.substr(4,2),10);if(9===e.length){if(t>=1980&&(t-=100),t>1953)return{meta:{},valid:!1}}else t<1954&&(t+=100);if(!r(t,i,n))return{meta:{},valid:!1};if(10===e.length){var a=parseInt(e.substr(0,9),10)%11;return t<1985&&(a%=10),{meta:{},valid:"".concat(a)===e.substr(9,1)}}return{meta:{},valid:!0}}var o=e.utils.isValidDate,l=e.utils.isValidDate,c=e.algorithms.mod11And10,u=e.algorithms.verhoeff,d=e.algorithms.luhn,h=e.utils.isValidDate,f=e.utils.isValidDate,p=e.utils.isValidDate;function m(e){if(!/^[0-9]{11}$/.test(e))return{meta:{},valid:!1};var t=parseInt(e.charAt(0),10),i=parseInt(e.substr(1,2),10),n=parseInt(e.substr(3,2),10),r=parseInt(e.substr(5,2),10);if(!p(i=100*(t%2==0?17+t/2:17+(t+1)/2)+i,n,r,!0))return{meta:{},valid:!1};var a,s=[1,2,3,4,5,6,7,8,9,1],o=0;for(a=0;a<10;a++)o+=parseInt(e.charAt(a),10)*s[a];if(10!=(o%=11))return{meta:{},valid:"".concat(o)===e.charAt(10)};for(o=0,s=[3,4,5,6,7,8,9,1,2,3],a=0;a<10;a++)o+=parseInt(e.charAt(a),10)*s[a];return 10==(o%=11)&&(o=0),{meta:{},valid:"".concat(o)===e.charAt(10)}}var g=e.utils.isValidDate,v=e.utils.isValidDate,y=e.utils.isValidDate,b=e.utils.isValidDate,x=e.algorithms.luhn,_=e.utils.isValidDate,w=e.algorithms.luhn,k=e.utils.isValidDate,M=e.utils.format,S=e.utils.removeUndefined;return Ci.id=function(){var e=["AR","BA","BG","BR","CH","CL","CN","CO","CZ","DK","EE","ES","FI","FR","HK","HR","ID","IE","IL","IS","KR","LT","LV","ME","MK","MX","MY","NL","NO","PE","PL","RO","RS","SE","SI","SK","SM","TH","TR","TW","UY","ZA"];return{validate:function(r){if(""===r.value)return{valid:!0};var a=Object.assign({},{message:""},S(r.options)),p=r.value.substr(0,2);if(p="function"==typeof a.country?a.country.call(this):a.country,-1===e.indexOf(p))return{valid:!0};var A,L={meta:{},valid:!0};switch(p.toLowerCase()){case"ar":A=r.value.replace(/\./g,""),L={meta:{},valid:/^\d{7,8}$/.test(A)};break;case"ba":L=function(e){return{meta:{},valid:t(e,"BA")}}(r.value);break;case"bg":L=function(e){if(!/^\d{10}$/.test(e)&&!/^\d{6}\s\d{3}\s\d{1}$/.test(e))return{meta:{},valid:!1};var t=e.replace(/\s/g,""),n=parseInt(t.substr(0,2),10)+1900,r=parseInt(t.substr(2,2),10),a=parseInt(t.substr(4,2),10);if(r>40?(n+=100,r-=40):r>20&&(n-=100,r-=20),!i(n,r,a))return{meta:{},valid:!1};for(var s=0,o=[2,4,8,5,10,9,7,3,6],l=0;l<9;l++)s+=parseInt(t.charAt(l),10)*o[l];return{meta:{},valid:"".concat(s=s%11%10)===t.substr(9,1)}}(r.value);break;case"br":L=function(e){var t=e.replace(/\D/g,"");if(!/^\d{11}$/.test(t)||/^1{11}|2{11}|3{11}|4{11}|5{11}|6{11}|7{11}|8{11}|9{11}|0{11}$/.test(t))return{meta:{},valid:!1};var i,n=0;for(i=0;i<9;i++)n+=(10-i)*parseInt(t.charAt(i),10);if(10!=(n=11-n%11)&&11!==n||(n=0),"".concat(n)!==t.charAt(9))return{meta:{},valid:!1};var r=0;for(i=0;i<10;i++)r+=(11-i)*parseInt(t.charAt(i),10);return 10!=(r=11-r%11)&&11!==r||(r=0),{meta:{},valid:"".concat(r)===t.charAt(10)}}(r.value);break;case"ch":L=function(e){if(!/^756[.]{0,1}[0-9]{4}[.]{0,1}[0-9]{4}[.]{0,1}[0-9]{2}$/.test(e))return{meta:{},valid:!1};for(var t=e.replace(/\D/g,"").substr(3),i=t.length,n=8===i?[3,1]:[1,3],r=0,a=0;a<i-1;a++)r+=parseInt(t.charAt(a),10)*n[a%2];return{meta:{},valid:"".concat(r=10-r%10)===t.charAt(i-1)}}(r.value);break;case"cl":L=function(e){if(!/^\d{7,8}[-]{0,1}[0-9K]$/i.test(e))return{meta:{},valid:!1};for(var t=e.replace(/-/g,"");t.length<9;)t="0".concat(t);for(var i=[3,2,7,6,5,4,3,2],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];var a="".concat(n=11-n%11);return 11===n?a="0":10===n&&(a="K"),{meta:{},valid:a===t.charAt(8).toUpperCase()}}(r.value);break;case"cn":L=function(e){var t=e.trim();if(!/^\d{15}$/.test(t)&&!/^\d{17}[\dXx]{1}$/.test(t))return{meta:{},valid:!1};var i={11:{0:[0],1:[[0,9],[11,17]],2:[0,28,29]},12:{0:[0],1:[[0,16]],2:[0,21,23,25]},13:{0:[0],1:[[0,5],7,8,21,[23,33],[81,85]],2:[[0,5],[7,9],[23,25],27,29,30,81,83],3:[[0,4],[21,24]],4:[[0,4],6,21,[23,35],81],5:[[0,3],[21,35],81,82],6:[[0,4],[21,38],[81,84]],7:[[0,3],5,6,[21,33]],8:[[0,4],[21,28]],9:[[0,3],[21,30],[81,84]],10:[[0,3],[22,26],28,81,82],11:[[0,2],[21,28],81,82]},14:{0:[0],1:[0,1,[5,10],[21,23],81],2:[[0,3],11,12,[21,27]],3:[[0,3],11,21,22],4:[[0,2],11,21,[23,31],81],5:[[0,2],21,22,24,25,81],6:[[0,3],[21,24]],7:[[0,2],[21,29],81],8:[[0,2],[21,30],81,82],9:[[0,2],[21,32],81],10:[[0,2],[21,34],81,82],11:[[0,2],[21,30],81,82],23:[[0,3],22,23,[25,30],32,33]},15:{0:[0],1:[[0,5],[21,25]],2:[[0,7],[21,23]],3:[[0,4]],4:[[0,4],[21,26],[28,30]],5:[[0,2],[21,26],81],6:[[0,2],[21,27]],7:[[0,3],[21,27],[81,85]],8:[[0,2],[21,26]],9:[[0,2],[21,29],81],22:[[0,2],[21,24]],25:[[0,2],[22,31]],26:[[0,2],[24,27],[29,32],34],28:[0,1,[22,27]],29:[0,[21,23]]},21:{0:[0],1:[[0,6],[11,14],[22,24],81],2:[[0,4],[11,13],24,[81,83]],3:[[0,4],11,21,23,81],4:[[0,4],11,[21,23]],5:[[0,5],21,22],6:[[0,4],24,81,82],7:[[0,3],11,26,27,81,82],8:[[0,4],11,81,82],9:[[0,5],11,21,22],10:[[0,5],11,21,81],11:[[0,3],21,22],12:[[0,2],4,21,23,24,81,82],13:[[0,3],21,22,24,81,82],14:[[0,4],21,22,81]},22:{0:[0],1:[[0,6],12,22,[81,83]],2:[[0,4],11,21,[81,84]],3:[[0,3],22,23,81,82],4:[[0,3],21,22],5:[[0,3],21,23,24,81,82],6:[[0,2],4,5,[21,23],25,81],7:[[0,2],[21,24],81],8:[[0,2],21,22,81,82],24:[[0,6],24,26]},23:{0:[0],1:[[0,12],21,[23,29],[81,84]],2:[[0,8],21,[23,25],27,[29,31],81],3:[[0,7],21,81,82],4:[[0,7],21,22],5:[[0,3],5,6,[21,24]],6:[[0,6],[21,24]],7:[[0,16],22,81],8:[[0,5],11,22,26,28,33,81,82],9:[[0,4],21],10:[[0,5],24,25,81,[83,85]],11:[[0,2],21,23,24,81,82],12:[[0,2],[21,26],[81,83]],27:[[0,4],[21,23]]},31:{0:[0],1:[0,1,[3,10],[12,20]],2:[0,30]},32:{0:[0],1:[[0,7],11,[13,18],24,25],2:[[0,6],11,81,82],3:[[0,5],11,12,[21,24],81,82],4:[[0,2],4,5,11,12,81,82],5:[[0,9],[81,85]],6:[[0,2],11,12,21,23,[81,84]],7:[0,1,3,5,6,[21,24]],8:[[0,4],11,26,[29,31]],9:[[0,3],[21,25],28,81,82],10:[[0,3],11,12,23,81,84,88],11:[[0,2],11,12,[81,83]],12:[[0,4],[81,84]],13:[[0,2],11,[21,24]]},33:{0:[0],1:[[0,6],[8,10],22,27,82,83,85],2:[0,1,[3,6],11,12,25,26,[81,83]],3:[[0,4],22,24,[26,29],81,82],4:[[0,2],11,21,24,[81,83]],5:[[0,3],[21,23]],6:[[0,2],21,24,[81,83]],7:[[0,3],23,26,27,[81,84]],8:[[0,3],22,24,25,81],9:[[0,3],21,22],10:[[0,4],[21,24],81,82],11:[[0,2],[21,27],81]},34:{0:[0],1:[[0,4],11,[21,24],81],2:[[0,4],7,8,[21,23],25],3:[[0,4],11,[21,23]],4:[[0,6],21],5:[[0,4],6,[21,23]],6:[[0,4],21],7:[[0,3],11,21],8:[[0,3],11,[22,28],81],10:[[0,4],[21,24]],11:[[0,3],22,[24,26],81,82],12:[[0,4],21,22,25,26,82],13:[[0,2],[21,24]],14:[[0,2],[21,24]],15:[[0,3],[21,25]],16:[[0,2],[21,23]],17:[[0,2],[21,23]],18:[[0,2],[21,25],81]},35:{0:[0],1:[[0,5],11,[21,25],28,81,82],2:[[0,6],[11,13]],3:[[0,5],22],4:[[0,3],21,[23,30],81],5:[[0,5],21,[24,27],[81,83]],6:[[0,3],[22,29],81],7:[[0,2],[21,25],[81,84]],8:[[0,2],[21,25],81],9:[[0,2],[21,26],81,82]},36:{0:[0],1:[[0,5],11,[21,24]],2:[[0,3],22,81],3:[[0,2],13,[21,23]],4:[[0,3],21,[23,30],81,82],5:[[0,2],21],6:[[0,2],22,81],7:[[0,2],[21,35],81,82],8:[[0,3],[21,30],81],9:[[0,2],[21,26],[81,83]],10:[[0,2],[21,30]],11:[[0,2],[21,30],81]},37:{0:[0],1:[[0,5],12,13,[24,26],81],2:[[0,3],5,[11,14],[81,85]],3:[[0,6],[21,23]],4:[[0,6],81],5:[[0,3],[21,23]],6:[[0,2],[11,13],34,[81,87]],7:[[0,5],24,25,[81,86]],8:[[0,2],11,[26,32],[81,83]],9:[[0,3],11,21,23,82,83],10:[[0,2],[81,83]],11:[[0,3],21,22],12:[[0,3]],13:[[0,2],11,12,[21,29]],14:[[0,2],[21,28],81,82],15:[[0,2],[21,26],81],16:[[0,2],[21,26]],17:[[0,2],[21,28]]},41:{0:[0],1:[[0,6],8,22,[81,85]],2:[[0,5],11,[21,25]],3:[[0,7],11,[22,29],81],4:[[0,4],11,[21,23],25,81,82],5:[[0,3],5,6,22,23,26,27,81],6:[[0,3],11,21,22],7:[[0,4],11,21,[24,28],81,82],8:[[0,4],11,[21,23],25,[81,83]],9:[[0,2],22,23,[26,28]],10:[[0,2],[23,25],81,82],11:[[0,4],[21,23]],12:[[0,2],21,22,24,81,82],13:[[0,3],[21,30],81],14:[[0,3],[21,26],81],15:[[0,3],[21,28]],16:[[0,2],[21,28],81],17:[[0,2],[21,29]],90:[0,1]},42:{0:[0],1:[[0,7],[11,17]],2:[[0,5],22,81],3:[[0,3],[21,25],81],5:[[0,6],[25,29],[81,83]],6:[[0,2],6,7,[24,26],[82,84]],7:[[0,4]],8:[[0,2],4,21,22,81],9:[[0,2],[21,23],81,82,84],10:[[0,3],[22,24],81,83,87],11:[[0,2],[21,27],81,82],12:[[0,2],[21,24],81],13:[[0,3],21,81],28:[[0,2],22,23,[25,28]],90:[0,[4,6],21]},43:{0:[0],1:[[0,5],11,12,21,22,24,81],2:[[0,4],11,21,[23,25],81],3:[[0,2],4,21,81,82],4:[0,1,[5,8],12,[21,24],26,81,82],5:[[0,3],11,[21,25],[27,29],81],6:[[0,3],11,21,23,24,26,81,82],7:[[0,3],[21,26],81],8:[[0,2],11,21,22],9:[[0,3],[21,23],81],10:[[0,3],[21,28],81],11:[[0,3],[21,29]],12:[[0,2],[21,30],81],13:[[0,2],21,22,81,82],31:[0,1,[22,27],30]},44:{0:[0],1:[[0,7],[11,16],83,84],2:[[0,5],21,22,24,29,32,33,81,82],3:[0,1,[3,8]],4:[[0,4]],5:[0,1,[6,15],23,82,83],6:[0,1,[4,8]],7:[0,1,[3,5],81,[83,85]],8:[[0,4],11,23,25,[81,83]],9:[[0,3],23,[81,83]],12:[[0,3],[23,26],83,84],13:[[0,3],[22,24],81],14:[[0,2],[21,24],26,27,81],15:[[0,2],21,23,81],16:[[0,2],[21,25]],17:[[0,2],21,23,81],18:[[0,3],21,23,[25,27],81,82],19:[0],20:[0],51:[[0,3],21,22],52:[[0,3],21,22,24,81],53:[[0,2],[21,23],81]},45:{0:[0],1:[[0,9],[21,27]],2:[[0,5],[21,26]],3:[[0,5],11,12,[21,32]],4:[0,1,[3,6],11,[21,23],81],5:[[0,3],12,21],6:[[0,3],21,81],7:[[0,3],21,22],8:[[0,4],21,81],9:[[0,3],[21,24],81],10:[[0,2],[21,31]],11:[[0,2],[21,23]],12:[[0,2],[21,29],81],13:[[0,2],[21,24],81],14:[[0,2],[21,25],81]},46:{0:[0],1:[0,1,[5,8]],2:[0,1],3:[0,[21,23]],90:[[0,3],[5,7],[21,39]]},50:{0:[0],1:[[0,19]],2:[0,[22,38],[40,43]],3:[0,[81,84]]},51:{0:[0],1:[0,1,[4,8],[12,15],[21,24],29,31,32,[81,84]],3:[[0,4],11,21,22],4:[[0,3],11,21,22],5:[[0,4],21,22,24,25],6:[0,1,3,23,26,[81,83]],7:[0,1,3,4,[22,27],81],8:[[0,2],11,12,[21,24]],9:[[0,4],[21,23]],10:[[0,2],11,24,25,28],11:[[0,2],[11,13],23,24,26,29,32,33,81],13:[[0,4],[21,25],81],14:[[0,2],[21,25]],15:[[0,3],[21,29]],16:[[0,3],[21,23],81],17:[[0,3],[21,25],81],18:[[0,3],[21,27]],19:[[0,3],[21,23]],20:[[0,2],21,22,81],32:[0,[21,33]],33:[0,[21,38]],34:[0,1,[22,37]]},52:{0:[0],1:[[0,3],[11,15],[21,23],81],2:[0,1,3,21,22],3:[[0,3],[21,30],81,82],4:[[0,2],[21,25]],5:[[0,2],[21,27]],6:[[0,3],[21,28]],22:[0,1,[22,30]],23:[0,1,[22,28]],24:[0,1,[22,28]],26:[0,1,[22,36]],27:[[0,2],22,23,[25,32]]},53:{0:[0],1:[[0,3],[11,14],21,22,[24,29],81],3:[[0,2],[21,26],28,81],4:[[0,2],[21,28]],5:[[0,2],[21,24]],6:[[0,2],[21,30]],7:[[0,2],[21,24]],8:[[0,2],[21,29]],9:[[0,2],[21,27]],23:[0,1,[22,29],31],25:[[0,4],[22,32]],26:[0,1,[21,28]],27:[0,1,[22,30]],28:[0,1,22,23],29:[0,1,[22,32]],31:[0,2,3,[22,24]],34:[0,[21,23]],33:[0,21,[23,25]],35:[0,[21,28]]},54:{0:[0],1:[[0,2],[21,27]],21:[0,[21,29],32,33],22:[0,[21,29],[31,33]],23:[0,1,[22,38]],24:[0,[21,31]],25:[0,[21,27]],26:[0,[21,27]]},61:{0:[0],1:[[0,4],[11,16],22,[24,26]],2:[[0,4],22],3:[[0,4],[21,24],[26,31]],4:[[0,4],[22,31],81],5:[[0,2],[21,28],81,82],6:[[0,2],[21,32]],7:[[0,2],[21,30]],8:[[0,2],[21,31]],9:[[0,2],[21,29]],10:[[0,2],[21,26]]},62:{0:[0],1:[[0,5],11,[21,23]],2:[0,1],3:[[0,2],21],4:[[0,3],[21,23]],5:[[0,3],[21,25]],6:[[0,2],[21,23]],7:[[0,2],[21,25]],8:[[0,2],[21,26]],9:[[0,2],[21,24],81,82],10:[[0,2],[21,27]],11:[[0,2],[21,26]],12:[[0,2],[21,28]],24:[0,21,[24,29]],26:[0,21,[23,30]],29:[0,1,[21,27]],30:[0,1,[21,27]]},63:{0:[0],1:[[0,5],[21,23]],2:[0,2,[21,25]],21:[0,[21,23],[26,28]],22:[0,[21,24]],23:[0,[21,24]],25:[0,[21,25]],26:[0,[21,26]],27:[0,1,[21,26]],28:[[0,2],[21,23]]},64:{0:[0],1:[0,1,[4,6],21,22,81],2:[[0,3],5,[21,23]],3:[[0,3],[21,24],81],4:[[0,2],[21,25]],5:[[0,2],21,22]},65:{0:[0],1:[[0,9],21],2:[[0,5]],21:[0,1,22,23],22:[0,1,22,23],23:[[0,3],[23,25],27,28],28:[0,1,[22,29]],29:[0,1,[22,29]],30:[0,1,[22,24]],31:[0,1,[21,31]],32:[0,1,[21,27]],40:[0,2,3,[21,28]],42:[[0,2],21,[23,26]],43:[0,1,[21,26]],90:[[0,4]],27:[[0,2],22,23]},71:{0:[0]},81:{0:[0]},82:{0:[0]}},r=parseInt(t.substr(0,2),10),a=parseInt(t.substr(2,2),10),s=parseInt(t.substr(4,2),10);if(!i[r]||!i[r][a])return{meta:{},valid:!1};var o,l,c=!1,u=i[r][a];for(o=0;o<u.length;o++)if(Array.isArray(u[o])&&u[o][0]<=s&&s<=u[o][1]||!Array.isArray(u[o])&&s===u[o]){c=!0;break}if(!c)return{meta:{},valid:!1};l=18===t.length?t.substr(6,8):"19".concat(t.substr(6,6));var d=parseInt(l.substr(0,4),10),h=parseInt(l.substr(4,2),10),f=parseInt(l.substr(6,2),10);if(!n(d,h,f))return{meta:{},valid:!1};if(18===t.length){var p=[7,9,10,5,8,4,2,1,6,3,7,9,10,5,8,4,2],m=0;for(o=0;o<17;o++)m+=parseInt(t.charAt(o),10)*p[o];return m=(12-m%11)%11,{meta:{},valid:("X"!==t.charAt(17).toUpperCase()?parseInt(t.charAt(17),10):10)===m}}return{meta:{},valid:!0}}(r.value);break;case"co":L=function(e){var t=e.replace(/\./g,"").replace("-","");if(!/^\d{8,16}$/.test(t))return{meta:{},valid:!1};for(var i=t.length,n=[3,7,13,17,19,23,29,37,41,43,47,53,59,67,71],r=0,a=i-2;a>=0;a--)r+=parseInt(t.charAt(a),10)*n[a];return(r%=11)>=2&&(r=11-r),{meta:{},valid:"".concat(r)===t.substr(i-1)}}(r.value);break;case"cz":case"sk":L=s(r.value);break;case"dk":L=function(e){if(!/^[0-9]{6}[-]{0,1}[0-9]{4}$/.test(e))return{meta:{},valid:!1};var t=e.replace(/-/g,""),i=parseInt(t.substr(0,2),10),n=parseInt(t.substr(2,2),10),r=parseInt(t.substr(4,2),10);switch(!0){case-1!=="5678".indexOf(t.charAt(6))&&r>=58:r+=1800;break;case-1!=="0123".indexOf(t.charAt(6)):case-1!=="49".indexOf(t.charAt(6))&&r>=37:r+=1900;break;default:r+=2e3}return{meta:{},valid:o(r,n,i)}}(r.value);break;case"ee":case"lt":L=m(r.value);break;case"es":L=function(e){var t=/^[0-9]{8}[-]{0,1}[A-HJ-NP-TV-Z]$/.test(e),i=/^[XYZ][-]{0,1}[0-9]{7}[-]{0,1}[A-HJ-NP-TV-Z]$/.test(e),n=/^[A-HNPQS][-]{0,1}[0-9]{7}[-]{0,1}[0-9A-J]$/.test(e);if(!t&&!i&&!n)return{meta:{},valid:!1};var r,a,s=e.replace(/-/g,"");if(t||i){a="DNI";var o="XYZ".indexOf(s.charAt(0));return-1!==o&&(s=o+s.substr(1)+"",a="NIE"),{meta:{type:a},valid:(r="TRWAGMYFPDXBNJZSQVHLCKE"[(r=parseInt(s.substr(0,8),10))%23])===s.substr(8,1)}}r=s.substr(1,7),a="CIF";for(var l=s[0],c=s.substr(-1),u=0,d=0;d<r.length;d++)if(d%2!=0)u+=parseInt(r[d],10);else{var h=""+2*parseInt(r[d],10);u+=parseInt(h[0],10),2===h.length&&(u+=parseInt(h[1],10))}var f=u-10*Math.floor(u/10);return 0!==f&&(f=10-f),{meta:{type:a},valid:-1!=="KQS".indexOf(l)?c==="JABCDEFGHI"[f]:-1!=="ABEH".indexOf(l)?c===""+f:c===""+f||c==="JABCDEFGHI"[f]}}(r.value);break;case"fi":L=function(e){if(!/^[0-9]{6}[-+A][0-9]{3}[0-9ABCDEFHJKLMNPRSTUVWXY]$/.test(e))return{meta:{},valid:!1};var t=parseInt(e.substr(0,2),10),i=parseInt(e.substr(2,2),10),n=parseInt(e.substr(4,2),10);if(n={"+":1800,"-":1900,A:2e3}[e.charAt(6)]+n,!l(n,i,t))return{meta:{},valid:!1};if(parseInt(e.substr(7,3),10)<2)return{meta:{},valid:!1};var r=parseInt(e.substr(0,6)+e.substr(7,3)+"",10);return{meta:{},valid:"0123456789ABCDEFHJKLMNPRSTUVWXY".charAt(r%31)===e.charAt(10)}}(r.value);break;case"fr":L=function(e){var t=e.toUpperCase();if(!/^(1|2)\d{2}\d{2}(\d{2}|\d[A-Z]|\d{3})\d{2,3}\d{3}\d{2}$/.test(t))return{meta:{},valid:!1};var i=t.substr(5,2);switch(!0){case/^\d{2}$/.test(i):t=e;break;case"2A"===i:t="".concat(e.substr(0,5),"19").concat(e.substr(7));break;case"2B"===i:t="".concat(e.substr(0,5),"18").concat(e.substr(7));break;default:return{meta:{},valid:!1}}var n=97-parseInt(t.substr(0,13),10)%97;return{meta:{},valid:(n<10?"0".concat(n):"".concat(n))===t.substr(13)}}(r.value);break;case"hk":L=function(e){var t=e.toUpperCase();if(!/^[A-MP-Z]{1,2}[0-9]{6}[0-9A]$/.test(t))return{meta:{},valid:!1};var i="ABCDEFGHIJKLMNOPQRSTUVWXYZ",n=t.charAt(0),r=t.charAt(1),a=0,s=t;/^[A-Z]$/.test(r)?(a+=9*(10+i.indexOf(n)),a+=8*(10+i.indexOf(r)),s=t.substr(2)):(a+=324,a+=8*(10+i.indexOf(n)),s=t.substr(1));for(var o=s.length,l=0;l<o-1;l++)a+=(7-l)*parseInt(s.charAt(l),10);var c=a%11;return{meta:{},valid:(0===c?"0":11-c==10?"A":"".concat(11-c))===s.charAt(o-1)}}(r.value);break;case"hr":L=function(e){return{meta:{},valid:/^[0-9]{11}$/.test(e)&&c(e)}}(r.value);break;case"id":L=function(e){if(!/^[2-9]\d{11}$/.test(e))return{meta:{},valid:!1};var t=e.split("").map((function(e){return parseInt(e,10)}));return{meta:{},valid:u(t)}}(r.value);break;case"ie":L=function(e){if(!/^\d{7}[A-W][AHWTX]?$/.test(e))return{meta:{},valid:!1};var t=function(e){for(var t=e;t.length<7;)t="0".concat(t);for(var i="WABCDEFGHIJKLMNOPQRSTUV",n=0,r=0;r<7;r++)n+=parseInt(t.charAt(r),10)*(8-r);return n+=9*i.indexOf(t.substr(7)),i[n%23]};return{meta:{},valid:9!==e.length||"A"!==e.charAt(8)&&"H"!==e.charAt(8)?e.charAt(7)===t(e.substr(0,7)):e.charAt(7)===t(e.substr(0,7)+e.substr(8)+"")}}(r.value);break;case"il":L=function(e){return/^\d{1,9}$/.test(e)?{meta:{},valid:d(e)}:{meta:{},valid:!1}}(r.value);break;case"is":L=function(e){if(!/^[0-9]{6}[-]{0,1}[0-9]{4}$/.test(e))return{meta:{},valid:!1};var t=e.replace(/-/g,""),i=parseInt(t.substr(0,2),10),n=parseInt(t.substr(2,2),10),r=parseInt(t.substr(4,2),10),a=parseInt(t.charAt(9),10);if(!h(r=9===a?1900+r:100*(20+a)+r,n,i,!0))return{meta:{},valid:!1};for(var s=[3,2,7,6,5,4,3,2],o=0,l=0;l<8;l++)o+=parseInt(t.charAt(l),10)*s[l];return{meta:{},valid:"".concat(o=11-o%11)===t.charAt(8)}}(r.value);break;case"kr":L=function(e){var t=e.replace("-","");if(!/^\d{13}$/.test(t))return{meta:{},valid:!1};var i=t.charAt(6),n=parseInt(t.substr(0,2),10),r=parseInt(t.substr(2,2),10),a=parseInt(t.substr(4,2),10);switch(i){case"1":case"2":case"5":case"6":n+=1900;break;case"3":case"4":case"7":case"8":n+=2e3;break;default:n+=1800}if(!f(n,r,a))return{meta:{},valid:!1};for(var s=[2,3,4,5,6,7,8,9,2,3,4,5],o=t.length,l=0,c=0;c<o-1;c++)l+=s[c]*parseInt(t.charAt(c),10);return{meta:{},valid:"".concat((11-l%11)%10)===t.charAt(o-1)}}(r.value);break;case"lv":L=function(e){if(!/^[0-9]{6}[-]{0,1}[0-9]{5}$/.test(e))return{meta:{},valid:!1};var t=e.replace(/\D/g,""),i=parseInt(t.substr(0,2),10),n=parseInt(t.substr(2,2),10),r=parseInt(t.substr(4,2),10);if(r=r+1800+100*parseInt(t.charAt(6),10),!g(r,n,i,!0))return{meta:{},valid:!1};for(var a=0,s=[10,5,8,4,2,1,6,3,7,9],o=0;o<10;o++)a+=parseInt(t.charAt(o),10)*s[o];return{meta:{},valid:"".concat(a=(a+1)%11%10)===t.charAt(10)}}(r.value);break;case"me":L=function(e){return{meta:{},valid:t(e,"ME")}}(r.value);break;case"mk":L=function(e){return{meta:{},valid:t(e,"MK")}}(r.value);break;case"mx":L=function(e){var t=e.toUpperCase();if(!/^[A-Z]{4}\d{6}[A-Z]{6}[0-9A-Z]\d$/.test(t))return{meta:{},valid:!1};var i=t.substr(0,4);if(["BACA","BAKA","BUEI","BUEY","CACA","CACO","CAGA","CAGO","CAKA","CAKO","COGE","COGI","COJA","COJE","COJI","COJO","COLA","CULO","FALO","FETO","GETA","GUEI","GUEY","JETA","JOTO","KACA","KACO","KAGA","KAGO","KAKA","KAKO","KOGE","KOGI","KOJA","KOJE","KOJI","KOJO","KOLA","KULO","LILO","LOCA","LOCO","LOKA","LOKO","MAME","MAMO","MEAR","MEAS","MEON","MIAR","MION","MOCO","MOKO","MULA","MULO","NACA","NACO","PEDA","PEDO","PENE","PIPI","PITO","POPO","PUTA","PUTO","QULO","RATA","ROBA","ROBE","ROBO","RUIN","SENO","TETA","VACA","VAGA","VAGO","VAKA","VUEI","VUEY","WUEI","WUEY"].indexOf(i)>=0)return{meta:{},valid:!1};var n=parseInt(t.substr(4,2),10),r=parseInt(t.substr(6,2),10),a=parseInt(t.substr(6,2),10);if(/^[0-9]$/.test(t.charAt(16))?n+=1900:n+=2e3,!v(n,r,a))return{meta:{},valid:!1};var s=t.charAt(10);if("H"!==s&&"M"!==s)return{meta:{},valid:!1};var o=t.substr(11,2);if(-1===["AS","BC","BS","CC","CH","CL","CM","CS","DF","DG","GR","GT","HG","JC","MC","MN","MS","NE","NL","NT","OC","PL","QR","QT","SL","SP","SR","TC","TL","TS","VZ","YN","ZS"].indexOf(o))return{meta:{},valid:!1};for(var l=0,c=t.length,u=0;u<c-1;u++)l+=(18-u)*"0123456789ABCDEFGHIJKLMN&OPQRSTUVWXYZ".indexOf(t.charAt(u));return{meta:{},valid:"".concat(l=(10-l%10)%10)===t.charAt(c-1)}}(r.value);break;case"my":L=function(e){if(!/^\d{12}$/.test(e))return{meta:{},valid:!1};var t=parseInt(e.substr(0,2),10),i=parseInt(e.substr(2,2),10),n=parseInt(e.substr(4,2),10);if(!y(t+1900,i,n)&&!y(t+2e3,i,n))return{meta:{},valid:!1};var r=e.substr(6,2);return{meta:{},valid:-1===["17","18","19","20","69","70","73","80","81","94","95","96","97"].indexOf(r)}}(r.value);break;case"nl":L=function(e){if(e.length<8)return{meta:{},valid:!1};var t=e;if(8===t.length&&(t="0".concat(t)),!/^[0-9]{4}[.]{0,1}[0-9]{2}[.]{0,1}[0-9]{3}$/.test(t))return{meta:{},valid:!1};if(t=t.replace(/\./g,""),0===parseInt(t,10))return{meta:{},valid:!1};for(var i=0,n=t.length,r=0;r<n-1;r++)i+=(9-r)*parseInt(t.charAt(r),10);return 10==(i%=11)&&(i=0),{meta:{},valid:"".concat(i)===t.charAt(n-1)}}(r.value);break;case"no":L=function(e){return/^\d{11}$/.test(e)?{meta:{},valid:"".concat(function(e){for(var t=[3,7,6,1,8,9,4,5,2],i=0,n=0;n<9;n++)i+=t[n]*parseInt(e.charAt(n),10);return 11-i%11}(e))===e.substr(-2,1)&&"".concat(function(e){for(var t=[5,4,3,2,7,6,5,4,3,2],i=0,n=0;n<10;n++)i+=t[n]*parseInt(e.charAt(n),10);return 11-i%11}(e))===e.substr(-1)}:{meta:{},valid:!1}}(r.value);break;case"pe":L=function(e){if(!/^\d{8}[0-9A-Z]*$/.test(e))return{meta:{},valid:!1};if(8===e.length)return{meta:{},valid:!0};for(var t=[3,2,7,6,5,4,3,2],i=0,n=0;n<8;n++)i+=t[n]*parseInt(e.charAt(n),10);var r=i%11,a=[6,5,4,3,2,1,1,0,9,8,7][r],s="KJIHGFEDCBA".charAt(r);return{meta:{},valid:e.charAt(8)==="".concat(a)||e.charAt(8)===s}}(r.value);break;case"pl":L=function(e){if(!/^[0-9]{11}$/.test(e))return{meta:{},valid:!1};for(var t=0,i=e.length,n=[1,3,7,9,1,3,7,9,1,3,7],r=0;r<i-1;r++)t+=n[r]*parseInt(e.charAt(r),10);return 0==(t%=10)&&(t=10),{meta:{},valid:"".concat(t=10-t)===e.charAt(i-1)}}(r.value);break;case"ro":L=function(e){if(!/^[0-9]{13}$/.test(e))return{meta:{},valid:!1};var t=parseInt(e.charAt(0),10);if(0===t||7===t||8===t)return{meta:{},valid:!1};var i=parseInt(e.substr(1,2),10),n=parseInt(e.substr(3,2),10),r=parseInt(e.substr(5,2),10);if(r>31&&n>12)return{meta:{},valid:!1};if(9!==t&&!b(i={1:1900,2:1900,3:1800,4:1800,5:2e3,6:2e3}[t+""]+i,n,r))return{meta:{},valid:!1};for(var a=0,s=[2,7,9,1,4,6,3,5,8,2,7,9],o=e.length,l=0;l<o-1;l++)a+=parseInt(e.charAt(l),10)*s[l];return 10==(a%=11)&&(a=1),{meta:{},valid:"".concat(a)===e.charAt(o-1)}}(r.value);break;case"rs":L=function(e){return{meta:{},valid:t(e,"RS")}}(r.value);break;case"se":L=function(e){if(!/^[0-9]{10}$/.test(e)&&!/^[0-9]{6}[-|+][0-9]{4}$/.test(e))return{meta:{},valid:!1};var t=e.replace(/[^0-9]/g,""),i=parseInt(t.substr(0,2),10)+1900,n=parseInt(t.substr(2,2),10),r=parseInt(t.substr(4,2),10);return _(i,n,r)?{meta:{},valid:x(t)}:{meta:{},valid:!1}}(r.value);break;case"si":L=function(e){return{meta:{},valid:t(e,"SI")}}(r.value);break;case"sm":L=function(e){return{meta:{},valid:/^\d{5}$/.test(e)}}(r.value);break;case"th":L=function(e){if(13!==e.length)return{meta:{},valid:!1};for(var t=0,i=0;i<12;i++)t+=parseInt(e.charAt(i),10)*(13-i);return{meta:{},valid:(11-t%11)%10===parseInt(e.charAt(12),10)}}(r.value);break;case"tr":L=function(e){if(11!==e.length)return{meta:{},valid:!1};for(var t=0,i=0;i<10;i++)t+=parseInt(e.charAt(i),10);return{meta:{},valid:t%10===parseInt(e.charAt(10),10)}}(r.value);break;case"tw":L=function(e){var t=e.toUpperCase();if(!/^[A-Z][12][0-9]{8}$/.test(t))return{meta:{},valid:!1};for(var i=t.length,n="ABCDEFGHJKLMNPQRSTUVXYWZIO".indexOf(t.charAt(0))+10,r=Math.floor(n/10)+n%10*(i-1),a=0,s=1;s<i-1;s++)a+=parseInt(t.charAt(s),10)*(i-1-s);return{meta:{},valid:(r+a+parseInt(t.charAt(i-1),10))%10==0}}(r.value);break;case"uy":L=function(e){if(!/^\d{8}$/.test(e))return{meta:{},valid:!1};for(var t=[2,9,8,7,6,3,4],i=0,n=0;n<7;n++)i+=parseInt(e.charAt(n),10)*t[n];return(i%=10)>0&&(i=10-i),{meta:{},valid:"".concat(i)===e.charAt(7)}}(r.value);break;case"za":L=function(e){if(!/^[0-9]{10}[0|1][8|9][0-9]$/.test(e))return{meta:{},valid:!1};var t=parseInt(e.substr(0,2),10),i=(new Date).getFullYear()%100,n=parseInt(e.substr(2,2),10),r=parseInt(e.substr(4,2),10);return k(t=t>=i?t+1900:t+2e3,n,r)?{meta:{},valid:w(e)}:{meta:{},valid:!1}}(r.value)}var T=M(r.l10n&&r.l10n.id?a.message||r.l10n.id.country:a.message,r.l10n&&r.l10n.id&&r.l10n.id.countries?r.l10n.id.countries[p.toUpperCase()]:p.toUpperCase());return Object.assign({},{message:T},L)}}},Ci}();var Di,Ei=Ti.exports,Oi={exports:{}},Pi={};Oi.exports=function(){if(Di)return Pi;Di=1;var e=a.algorithms.luhn;return Pi.imei=function(){return{validate:function(t){if(""===t.value)return{valid:!0};switch(!0){case/^\d{15}$/.test(t.value):case/^\d{2}-\d{6}-\d{6}-\d{1}$/.test(t.value):case/^\d{2}\s\d{6}\s\d{6}\s\d{1}$/.test(t.value):return{valid:e(t.value.replace(/[^0-9]/g,""))};case/^\d{14}$/.test(t.value):case/^\d{16}$/.test(t.value):case/^\d{2}-\d{6}-\d{6}(|-\d{2})$/.test(t.value):case/^\d{2}\s\d{6}\s\d{6}(|\s\d{2})$/.test(t.value):return{valid:!0};default:return{valid:!1}}}}},Pi}();var Yi,Ii=Oi.exports,Ni={exports:{}},ji={};Ni.exports=(Yi||(Yi=1,ji.imo=function(){return{validate:function(e){if(""===e.value)return{valid:!0};if(!/^IMO \d{7}$/i.test(e.value))return{valid:!1};for(var t=e.value.replace(/^.*(\d{7})$/,"$1"),i=0,n=6;n>=1;n--)i+=parseInt(t.slice(6-n,-n),10)*(n+1);return{valid:i%10===parseInt(t.charAt(6),10)}}}}),ji);var Hi,Fi=Ni.exports,Ri={exports:{}},zi={};Ri.exports=(Hi||(Hi=1,zi.isbn=function(){return{validate:function(e){if(""===e.value)return{meta:{type:null},valid:!0};var t;switch(!0){case/^\d{9}[\dX]$/.test(e.value):case 13===e.value.length&&/^(\d+)-(\d+)-(\d+)-([\dX])$/.test(e.value):case 13===e.value.length&&/^(\d+)\s(\d+)\s(\d+)\s([\dX])$/.test(e.value):t="ISBN10";break;case/^(978|979)\d{9}[\dX]$/.test(e.value):case 17===e.value.length&&/^(978|979)-(\d+)-(\d+)-(\d+)-([\dX])$/.test(e.value):case 17===e.value.length&&/^(978|979)\s(\d+)\s(\d+)\s(\d+)\s([\dX])$/.test(e.value):t="ISBN13";break;default:return{meta:{type:null},valid:!1}}var i,n,r=e.value.replace(/[^0-9X]/gi,"").split(""),a=r.length,s=0;switch(t){case"ISBN10":for(s=0,i=0;i<a-1;i++)s+=parseInt(r[i],10)*(10-i);return 11==(n=11-s%11)?n=0:10===n&&(n="X"),{meta:{type:t},valid:"".concat(n)===r[a-1]};case"ISBN13":for(s=0,i=0;i<a-1;i++)s+=i%2==0?parseInt(r[i],10):3*parseInt(r[i],10);return 10==(n=10-s%10)&&(n="0"),{meta:{type:t},valid:"".concat(n)===r[a-1]}}}}}),zi);var Bi,Vi=Ri.exports,Wi={exports:{}},Ui={};Wi.exports=(Bi||(Bi=1,Ui.isin=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var t=e.value.toUpperCase();if(!new RegExp("^(AF|AX|AL|DZ|AS|AD|AO|AI|AQ|AG|AR|AM|AW|AU|AT|AZ|BS|BH|BD|BB|BY|BE|BZ|BJ|BM|BT|BO|BQ|BA|BW|BV|BR|IO|BN|BG|BF|BI|KH|CM|CA|CV|KY|CF|TD|CL|CN|CX|CC|CO|KM|CG|CD|CK|CR|CI|HR|CU|CW|CY|CZ|DK|DJ|DM|DO|EC|EG|SV|GQ|ER|EE|ET|FK|FO|FJ|FI|FR|GF|PF|TF|GA|GM|GE|DE|GH|GI|GR|GL|GD|GP|GU|GT|GG|GN|GW|GY|HT|HM|VA|HN|HK|HU|IS|IN|ID|IR|IQ|IE|IM|IL|IT|JM|JP|JE|JO|KZ|KE|KI|KP|KR|KW|KG|LA|LV|LB|LS|LR|LY|LI|LT|LU|MO|MK|MG|MW|MY|MV|ML|MT|MH|MQ|MR|MU|YT|MX|FM|MD|MC|MN|ME|MS|MA|MZ|MM|NA|NR|NP|NL|NC|NZ|NI|NE|NG|NU|NF|MP|NO|OM|PK|PW|PS|PA|PG|PY|PE|PH|PN|PL|PT|PR|QA|RE|RO|RU|RW|BL|SH|KN|LC|MF|PM|VC|WS|SM|ST|SA|SN|RS|SC|SL|SG|SX|SK|SI|SB|SO|ZA|GS|SS|ES|LK|SD|SR|SJ|SZ|SE|CH|SY|TW|TJ|TZ|TH|TL|TG|TK|TO|TT|TN|TR|TM|TC|TV|UG|UA|AE|GB|US|UM|UY|UZ|VU|VE|VN|VG|VI|WF|EH|YE|ZM|ZW)[0-9A-Z]{10}$").test(e.value))return{valid:!1};var i,n=t.length,r="";for(i=0;i<n-1;i++){var a=t.charCodeAt(i);r+=a>57?(a-55).toString():t.charAt(i)}var s="",o=r.length,l=o%2!=0?0:1;for(i=0;i<o;i++)s+=parseInt(r[i],10)*(i%2===l?2:1)+"";var c=0;for(i=0;i<s.length;i++)c+=parseInt(s.charAt(i),10);return{valid:"".concat(c=(10-c%10)%10)===t.charAt(n-1)}}}}),Ui);var qi,$i=Wi.exports,Xi={exports:{}},Gi={};Xi.exports=(qi||(qi=1,Gi.ismn=function(){return{validate:function(e){if(""===e.value)return{meta:null,valid:!0};var t;switch(!0){case/^M\d{9}$/.test(e.value):case/^M-\d{4}-\d{4}-\d{1}$/.test(e.value):case/^M\s\d{4}\s\d{4}\s\d{1}$/.test(e.value):t="ISMN10";break;case/^9790\d{9}$/.test(e.value):case/^979-0-\d{4}-\d{4}-\d{1}$/.test(e.value):case/^979\s0\s\d{4}\s\d{4}\s\d{1}$/.test(e.value):t="ISMN13";break;default:return{meta:null,valid:!1}}var i=e.value;"ISMN10"===t&&(i="9790".concat(i.substr(1)));for(var n=0,r=(i=i.replace(/[^0-9]/gi,"")).length,a=[1,3],s=0;s<r-1;s++)n+=parseInt(i.charAt(s),10)*a[s%2];return{meta:{type:t},valid:"".concat(n=(10-n%10)%10)===i.charAt(r-1)}}}}),Gi);var Zi,Ki=Xi.exports,Ji={exports:{}},Qi={};Ji.exports=(Zi||(Zi=1,Qi.issn=function(){return{validate:function(e){if(""===e.value)return{valid:!0};if(!/^\d{4}-\d{3}[\dX]$/.test(e.value))return{valid:!1};var t=e.value.replace(/[^0-9X]/gi,"").split(""),i=t.length,n=0;"X"===t[7]&&(t[7]="10");for(var r=0;r<i;r++)n+=parseInt(t[r],10)*(8-r);return{valid:n%11==0}}}}),Qi);var en,tn=Ji.exports,nn={exports:{}},rn={};nn.exports=(en||(en=1,rn.mac=function(){return{validate:function(e){return{valid:""===e.value||/^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/.test(e.value)||/^([0-9A-Fa-f]{4}\.){2}([0-9A-Fa-f]{4})$/.test(e.value)}}}}),rn);var an,sn=nn.exports,on={exports:{}},ln={};on.exports=function(){if(an)return ln;an=1;var e=a.algorithms.luhn;return ln.meid=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=t.value;if(/^[0-9A-F]{15}$/i.test(i)||/^[0-9A-F]{2}[- ][0-9A-F]{6}[- ][0-9A-F]{6}[- ][0-9A-F]$/i.test(i)||/^\d{19}$/.test(i)||/^\d{5}[- ]\d{5}[- ]\d{4}[- ]\d{4}[- ]\d$/.test(i)){var n=i.charAt(i.length-1).toUpperCase();if((i=i.replace(/[- ]/g,"")).match(/^\d*$/i))return{valid:e(i)};i=i.slice(0,-1);var r="",a=void 0;for(a=1;a<=13;a+=2)r+=(2*parseInt(i.charAt(a),16)).toString(16);var s=0;for(a=0;a<r.length;a++)s+=parseInt(r.charAt(a),16);return{valid:s%10==0?"0"===n:n===(2*(10*Math.floor((s+10)/10)-s)).toString(16).toUpperCase()}}return/^[0-9A-F]{14}$/i.test(i)||/^[0-9A-F]{2}[- ][0-9A-F]{6}[- ][0-9A-F]{6}$/i.test(i)||/^\d{18}$/.test(i)||/^\d{5}[- ]\d{5}[- ]\d{4}[- ]\d{4}$/.test(i)?{valid:!0}:{valid:!1}}}},ln}();var cn,un=on.exports,dn={exports:{}},hn={};dn.exports=function(){if(cn)return hn;cn=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return hn.phone=function(){var e=["AE","BG","BR","CN","CZ","DE","DK","ES","FR","GB","IN","MA","NL","PK","RO","RU","SK","TH","US","VE"];return{validate:function(n){if(""===n.value)return{valid:!0};var r=Object.assign({},{message:""},i(n.options)),a=n.value.trim(),s=a.substr(0,2);if(!(s="function"==typeof r.country?r.country.call(this):r.country)||-1===e.indexOf(s.toUpperCase()))return{valid:!0};var o=!0;switch(s.toUpperCase()){case"AE":o=/^(((\+|00)?971[\s.-]?(\(0\)[\s.-]?)?|0)(\(5(0|2|5|6)\)|5(0|2|5|6)|2|3|4|6|7|9)|60)([\s.-]?[0-9]){7}$/.test(a);break;case"BG":o=/^(0|359|00)(((700|900)[0-9]{5}|((800)[0-9]{5}|(800)[0-9]{4}))|(87|88|89)([0-9]{7})|((2[0-9]{7})|(([3-9][0-9])(([0-9]{6})|([0-9]{5})))))$/.test(a.replace(/\+|\s|-|\/|\(|\)/gi,""));break;case"BR":o=/^(([\d]{4}[-.\s]{1}[\d]{2,3}[-.\s]{1}[\d]{2}[-.\s]{1}[\d]{2})|([\d]{4}[-.\s]{1}[\d]{3}[-.\s]{1}[\d]{4})|((\(?\+?[0-9]{2}\)?\s?)?(\(?\d{2}\)?\s?)?\d{4,5}[-.\s]?\d{4}))$/.test(a);break;case"CN":o=/^((00|\+)?(86(?:-| )))?((\d{11})|(\d{3}[- ]{1}\d{4}[- ]{1}\d{4})|((\d{2,4}[- ]){1}(\d{7,8}|(\d{3,4}[- ]{1}\d{4}))([- ]{1}\d{1,4})?))$/.test(a);break;case"CZ":o=/^(((00)([- ]?)|\+)(420)([- ]?))?((\d{3})([- ]?)){2}(\d{3})$/.test(a);break;case"DE":o=/^(((((((00|\+)49[ \-/]?)|0)[1-9][0-9]{1,4})[ \-/]?)|((((00|\+)49\()|\(0)[1-9][0-9]{1,4}\)[ \-/]?))[0-9]{1,7}([ \-/]?[0-9]{1,5})?)$/.test(a);break;case"DK":o=/^(\+45|0045|\(45\))?\s?[2-9](\s?\d){7}$/.test(a);break;case"ES":o=/^(?:(?:(?:\+|00)34\D?))?(?:5|6|7|8|9)(?:\d\D?){8}$/.test(a);break;case"FR":o=/^(?:(?:(?:\+|00)33[ ]?(?:\(0\)[ ]?)?)|0){1}[1-9]{1}([ .-]?)(?:\d{2}\1?){3}\d{2}$/.test(a);break;case"GB":o=/^\(?(?:(?:0(?:0|11)\)?[\s-]?\(?|\+)44\)?[\s-]?\(?(?:0\)?[\s-]?\(?)?|0)(?:\d{2}\)?[\s-]?\d{4}[\s-]?\d{4}|\d{3}\)?[\s-]?\d{3}[\s-]?\d{3,4}|\d{4}\)?[\s-]?(?:\d{5}|\d{3}[\s-]?\d{3})|\d{5}\)?[\s-]?\d{4,5}|8(?:00[\s-]?11[\s-]?11|45[\s-]?46[\s-]?4\d))(?:(?:[\s-]?(?:x|ext\.?\s?|#)\d+)?)$/.test(a);break;case"IN":o=/((\+?)((0[ -]+)*|(91 )*)(\d{12}|\d{10}))|\d{5}([- ]*)\d{6}/.test(a);break;case"MA":o=/^(?:(?:(?:\+|00)212[\s]?(?:[\s]?\(0\)[\s]?)?)|0){1}(?:5[\s.-]?[2-3]|6[\s.-]?[13-9]){1}[0-9]{1}(?:[\s.-]?\d{2}){3}$/.test(a);break;case"NL":o=/^((\+|00(\s|\s?-\s?)?)31(\s|\s?-\s?)?(\(0\)[-\s]?)?|0)[1-9]((\s|\s?-\s?)?[0-9])((\s|\s?-\s?)?[0-9])((\s|\s?-\s?)?[0-9])\s?[0-9]\s?[0-9]\s?[0-9]\s?[0-9]\s?[0-9]$/gm.test(a);break;case"PK":o=/^0?3[0-9]{2}[0-9]{7}$/.test(a);break;case"RO":o=/^(\+4|)?(07[0-8]{1}[0-9]{1}|02[0-9]{2}|03[0-9]{2}){1}?(\s|\.|-)?([0-9]{3}(\s|\.|-|)){2}$/g.test(a);break;case"RU":o=/^((8|\+7|007)[-./ ]?)?([(/.]?\d{3}[)/.]?[-./ ]?)?[\d\-./ ]{7,10}$/g.test(a);break;case"SK":o=/^(((00)([- ]?)|\+)(421)([- ]?))?((\d{3})([- ]?)){2}(\d{3})$/.test(a);break;case"TH":o=/^0\(?([6|8-9]{2})*-([0-9]{3})*-([0-9]{4})$/.test(a);break;case"VE":o=/^0(?:2(?:12|4[0-9]|5[1-9]|6[0-9]|7[0-8]|8[1-35-8]|9[1-5]|3[45789])|4(?:1[246]|2[46]))\d{7}$/.test(a);break;default:o=/^(?:(1-?)|(\+1 ?))?\(?\d{3}\)?[-.\s]?\d{3}[-.\s]?\d{4}$/.test(a)}return{message:t(n.l10n&&n.l10n.phone?r.message||n.l10n.phone.country:r.message,n.l10n&&n.l10n.phone&&n.l10n.phone.countries?n.l10n.phone.countries[s]:s),valid:o}}}},hn}();var fn,pn=dn.exports,mn={exports:{}},gn={};mn.exports=(fn||(fn=1,gn.rtn=function(){return{validate:function(e){if(""===e.value)return{valid:!0};if(!/^\d{9}$/.test(e.value))return{valid:!1};for(var t=0,i=0;i<e.value.length;i+=3)t+=3*parseInt(e.value.charAt(i),10)+7*parseInt(e.value.charAt(i+1),10)+parseInt(e.value.charAt(i+2),10);return{valid:0!==t&&t%10==0}}}}),gn);var vn,yn=mn.exports,bn={exports:{}},xn={};bn.exports=(vn||(vn=1,xn.sedol=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var t=e.value.toUpperCase();if(!/^[0-9A-Z]{7}$/.test(t))return{valid:!1};for(var i=[1,3,1,7,3,9,1],n=t.length,r=0,a=0;a<n-1;a++)r+=i[a]*parseInt(t.charAt(a),36);return{valid:"".concat(r=(10-r%10)%10)===t.charAt(n-1)}}}}),xn);var _n,wn=bn.exports,kn={exports:{}},Mn={};kn.exports=function(){if(_n)return Mn;_n=1;var e=a.algorithms.luhn;return Mn.siren=function(){return{validate:function(t){return{valid:""===t.value||/^\d{9}$/.test(t.value)&&e(t.value)}}}},Mn}();var Sn,An=kn.exports,Ln={exports:{}},Tn={};Ln.exports=(Sn||(Sn=1,Tn.siret=function(){return{validate:function(e){if(""===e.value)return{valid:!0};for(var t,i=e.value.length,n=0,r=0;r<i;r++)t=parseInt(e.value.charAt(r),10),r%2==0&&(t*=2)>9&&(t-=9),n+=t;return{valid:n%10==0}}}}),Tn);var Cn,Dn=Ln.exports,En={exports:{}},On={};En.exports=function(){if(Cn)return On;Cn=1;var e=a.utils.format;return On.step=function(){return{validate:function(t){if(""===t.value)return{valid:!0};var i=parseFloat(t.value);if(isNaN(i)||!isFinite(i))return{valid:!1};var n=Object.assign({},{baseValue:0,message:"",step:1},t.options),r=function(e,t){if(0===t)return 1;var i="".concat(e).split("."),n="".concat(t).split("."),r=(1===i.length?0:i[1].length)+(1===n.length?0:n[1].length);return function(e,t){var i,n=Math.pow(10,t),r=e*n;switch(!0){case 0===r:i=0;break;case r>0:i=1;break;case r<0:i=-1}return r%1==.5*i?(Math.floor(r)+(i>0?1:0))/n:Math.round(r)/n}(e-t*Math.floor(e/t),r)}(i-n.baseValue,n.step);return{message:e(t.l10n?n.message||t.l10n.step.default:n.message,"".concat(n.step)),valid:0===r||r===n.step}}}},On}();var Pn,Yn=En.exports,In={exports:{}},Nn={};In.exports=function(){if(Pn)return Nn;Pn=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return Nn.uuid=function(){return{validate:function(e){if(""===e.value)return{valid:!0};var n=Object.assign({},{message:""},i(e.options)),r={3:/^[0-9A-F]{8}-[0-9A-F]{4}-3[0-9A-F]{3}-[0-9A-F]{4}-[0-9A-F]{12}$/i,4:/^[0-9A-F]{8}-[0-9A-F]{4}-4[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i,5:/^[0-9A-F]{8}-[0-9A-F]{4}-5[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i,all:/^[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}$/i},a=n.version?"".concat(n.version):"all";return{message:n.version?t(e.l10n?n.message||e.l10n.uuid.version:n.message,n.version):e.l10n?e.l10n.uuid.default:n.message,valid:null===r[a]||r[a].test(e.value)}}}},Nn}();var jn,Hn=In.exports,Fn={exports:{}},Rn={};Fn.exports=function(){if(jn)return Rn;jn=1;var e=a,t=e.utils.isValidDate,i=e.utils.isValidDate,n=e.algorithms.mod11And10,r=e.algorithms.luhn,s=e.algorithms.mod11And10,o=e.algorithms.luhn,l=e.utils.isValidDate,c=e.algorithms.mod97And10;function u(e){if(e.length<8)return{meta:{},valid:!1};var t=e;if(8===t.length&&(t="0".concat(t)),!/^[0-9]{4}[.]{0,1}[0-9]{2}[.]{0,1}[0-9]{3}$/.test(t))return{meta:{},valid:!1};if(t=t.replace(/\./g,""),0===parseInt(t,10))return{meta:{},valid:!1};for(var i=0,n=t.length,r=0;r<n-1;r++)i+=(9-r)*parseInt(t.charAt(r),10);return 10==(i%=11)&&(i=0),{meta:{},valid:"".concat(i)===t.charAt(n-1)}}var d=e.algorithms.luhn,h=e.utils.format,f=e.utils.removeUndefined;return Rn.vat=function(){var e=["AR","AT","BE","BG","BR","CH","CY","CZ","DE","DK","EE","EL","ES","FI","FR","GB","GR","HR","HU","IE","IS","IT","LT","LU","LV","MT","NL","NO","PL","PT","RO","RU","RS","SE","SK","SI","VE","ZA"];return{validate:function(a){var p=a.value;if(""===p)return{valid:!0};var m=Object.assign({},{message:""},f(a.options)),g=p.substr(0,2);if(g="function"==typeof m.country?m.country.call(this):m.country,-1===e.indexOf(g))return{valid:!0};var v={meta:{},valid:!0};switch(g.toLowerCase()){case"ar":v=function(e){var t=e.replace("-","");if(/^AR[0-9]{11}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{11}$/.test(t))return{meta:{},valid:!1};for(var i=[5,4,3,2,7,6,5,4,3,2],n=0,r=0;r<10;r++)n+=parseInt(t.charAt(r),10)*i[r];return 11==(n=11-n%11)&&(n=0),{meta:{},valid:"".concat(n)===t.substr(10)}}(p);break;case"at":v=function(e){var t=e;if(/^ATU[0-9]{8}$/.test(t)&&(t=t.substr(2)),!/^U[0-9]{8}$/.test(t))return{meta:{},valid:!1};t=t.substr(1);for(var i=[1,2,1,2,1,2,1],n=0,r=0,a=0;a<7;a++)(r=parseInt(t.charAt(a),10)*i[a])>9&&(r=Math.floor(r/10)+r%10),n+=r;return 10==(n=10-(n+4)%10)&&(n=0),{meta:{},valid:"".concat(n)===t.substr(7,1)}}(p);break;case"be":v=function(e){var t=e;return/^BE[0]?[0-9]{9}$/.test(t)&&(t=t.substr(2)),/^[0]?[0-9]{9}$/.test(t)?(9===t.length&&(t="0".concat(t)),"0"===t.substr(1,1)?{meta:{},valid:!1}:{meta:{},valid:(parseInt(t.substr(0,8),10)+parseInt(t.substr(8,2),10))%97==0}):{meta:{},valid:!1}}(p);break;case"bg":v=function(e){var i=e;if(/^BG[0-9]{9,10}$/.test(i)&&(i=i.substr(2)),!/^[0-9]{9,10}$/.test(i))return{meta:{},valid:!1};var n=0,r=0;if(9===i.length){for(r=0;r<8;r++)n+=parseInt(i.charAt(r),10)*(r+1);if(10==(n%=11)){for(n=0,r=0;r<8;r++)n+=parseInt(i.charAt(r),10)*(r+3);n%=11}return{meta:{},valid:"".concat(n%=10)===i.substr(8)}}return{meta:{},valid:function(e){var i=parseInt(e.substr(0,2),10)+1900,n=parseInt(e.substr(2,2),10),r=parseInt(e.substr(4,2),10);if(n>40?(i+=100,n-=40):n>20&&(i-=100,n-=20),!t(i,n,r))return!1;for(var a=[2,4,8,5,10,9,7,3,6],s=0,o=0;o<9;o++)s+=parseInt(e.charAt(o),10)*a[o];return"".concat(s=s%11%10)===e.substr(9,1)}(i)||function(e){for(var t=[21,19,17,13,11,9,7,3,1],i=0,n=0;n<9;n++)i+=parseInt(e.charAt(n),10)*t[n];return"".concat(i%=10)===e.substr(9,1)}(i)||function(e){for(var t=[4,3,2,7,6,5,4,3,2],i=0,n=0;n<9;n++)i+=parseInt(e.charAt(n),10)*t[n];return 10!=(i=11-i%11)&&(11===i&&(i=0),"".concat(i)===e.substr(9,1))}(i)}}(p);break;case"br":v=function(e){if(""===e)return{meta:{},valid:!0};var t=e.replace(/[^\d]+/g,"");if(""===t||14!==t.length)return{meta:{},valid:!1};if("00000000000000"===t||"11111111111111"===t||"22222222222222"===t||"33333333333333"===t||"44444444444444"===t||"55555555555555"===t||"66666666666666"===t||"77777777777777"===t||"88888888888888"===t||"99999999999999"===t)return{meta:{},valid:!1};var i,n=t.length-2,r=t.substring(0,n),a=t.substring(n),s=0,o=n-7;for(i=n;i>=1;i--)s+=parseInt(r.charAt(n-i),10)*o--,o<2&&(o=9);var l=s%11<2?0:11-s%11;if(l!==parseInt(a.charAt(0),10))return{meta:{},valid:!1};for(n+=1,r=t.substring(0,n),s=0,o=n-7,i=n;i>=1;i--)s+=parseInt(r.charAt(n-i),10)*o--,o<2&&(o=9);return{meta:{},valid:(l=s%11<2?0:11-s%11)===parseInt(a.charAt(1),10)}}(p);break;case"ch":v=function(e){var t=e;if(/^CHE[0-9]{9}(MWST|TVA|IVA|TPV)?$/.test(t)&&(t=t.substr(2)),!/^E[0-9]{9}(MWST|TVA|IVA|TPV)?$/.test(t))return{meta:{},valid:!1};t=t.substr(1);for(var i=[5,4,3,2,7,6,5,4],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];return 10==(n=11-n%11)?{meta:{},valid:!1}:(11===n&&(n=0),{meta:{},valid:"".concat(n)===t.substr(8,1)})}(p);break;case"cy":v=function(e){var t=e;if(/^CY[0-5|9][0-9]{7}[A-Z]$/.test(t)&&(t=t.substr(2)),!/^[0-5|9][0-9]{7}[A-Z]$/.test(t))return{meta:{},valid:!1};if("12"===t.substr(0,2))return{meta:{},valid:!1};for(var i=0,n={0:1,1:0,2:5,3:7,4:9,5:13,6:15,7:17,8:19,9:21},r=0;r<8;r++){var a=parseInt(t.charAt(r),10);r%2==0&&(a=n["".concat(a)]),i+=a}return{meta:{},valid:"".concat("ABCDEFGHIJKLMNOPQRSTUVWXYZ"[i%26])===t.substr(8,1)}}(p);break;case"cz":v=function(e){var t=e;if(/^CZ[0-9]{8,10}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{8,10}$/.test(t))return{meta:{},valid:!1};var n=0,r=0;if(8===t.length){if("9"==="".concat(t.charAt(0)))return{meta:{},valid:!1};for(n=0,r=0;r<7;r++)n+=parseInt(t.charAt(r),10)*(8-r);return 10==(n=11-n%11)&&(n=0),11===n&&(n=1),{meta:{},valid:"".concat(n)===t.substr(7,1)}}if(9===t.length&&"6"==="".concat(t.charAt(0))){for(n=0,r=0;r<7;r++)n+=parseInt(t.charAt(r+1),10)*(8-r);return 10==(n=11-n%11)&&(n=0),11===n&&(n=1),{meta:{},valid:"".concat(n=[8,7,6,5,4,3,2,1,0,9,10][n-1])===t.substr(8,1)}}if(9===t.length||10===t.length){var a=1900+parseInt(t.substr(0,2),10),s=parseInt(t.substr(2,2),10)%50%20,o=parseInt(t.substr(4,2),10);if(9===t.length){if(a>=1980&&(a-=100),a>1953)return{meta:{},valid:!1}}else a<1954&&(a+=100);if(!i(a,s,o))return{meta:{},valid:!1};if(10===t.length){var l=parseInt(t.substr(0,9),10)%11;return a<1985&&(l%=10),{meta:{},valid:"".concat(l)===t.substr(9,1)}}return{meta:{},valid:!0}}return{meta:{},valid:!1}}(p);break;case"de":v=function(e){var t=e;return/^DE[0-9]{9}$/.test(t)&&(t=t.substr(2)),/^[1-9][0-9]{8}$/.test(t)?{meta:{},valid:n(t)}:{meta:{},valid:!1}}(p);break;case"dk":v=function(e){var t=e;if(/^DK[0-9]{8}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{8}$/.test(t))return{meta:{},valid:!1};for(var i=0,n=[2,7,6,5,4,3,2,1],r=0;r<8;r++)i+=parseInt(t.charAt(r),10)*n[r];return{meta:{},valid:i%11==0}}(p);break;case"ee":v=function(e){var t=e;if(/^EE[0-9]{9}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{9}$/.test(t))return{meta:{},valid:!1};for(var i=0,n=[3,7,1,3,7,1,3,7,1],r=0;r<9;r++)i+=parseInt(t.charAt(r),10)*n[r];return{meta:{},valid:i%10==0}}(p);break;case"el":case"gr":v=function(e){var t=e;if(/^(GR|EL)[0-9]{9}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{9}$/.test(t))return{meta:{},valid:!1};8===t.length&&(t="0".concat(t));for(var i=[256,128,64,32,16,8,4,2],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];return{meta:{},valid:"".concat(n=n%11%10)===t.substr(8,1)}}(p);break;case"es":v=function(e){var t=e;if(/^ES[0-9A-Z][0-9]{7}[0-9A-Z]$/.test(t)&&(t=t.substr(2)),!/^[0-9A-Z][0-9]{7}[0-9A-Z]$/.test(t))return{meta:{},valid:!1};var i,n,r=t.charAt(0);return/^[0-9]$/.test(r)?{meta:{type:"DNI"},valid:(i=t,n=parseInt(i.substr(0,8),10),"".concat("TRWAGMYFPDXBNJZSQVHLCKE"[n%23])===i.substr(8,1))}:/^[XYZ]$/.test(r)?{meta:{type:"NIE"},valid:function(e){var t=["XYZ".indexOf(e.charAt(0)),e.substr(1)].join(""),i="TRWAGMYFPDXBNJZSQVHLCKE"[parseInt(t,10)%23];return"".concat(i)===e.substr(8,1)}(t)}:{meta:{type:"CIF"},valid:function(e){var t,i=e.charAt(0);if(-1!=="KLM".indexOf(i))return t=parseInt(e.substr(1,8),10),"".concat(t="TRWAGMYFPDXBNJZSQVHLCKE"[t%23])===e.substr(8,1);if(-1!=="ABCDEFGHJNPQRSUVW".indexOf(i)){for(var n=[2,1,2,1,2,1,2],r=0,a=0,s=0;s<7;s++)(a=parseInt(e.charAt(s+1),10)*n[s])>9&&(a=Math.floor(a/10)+a%10),r+=a;return 10==(r=10-r%10)&&(r=0),"".concat(r)===e.substr(8,1)||"JABCDEFGHI"[r]===e.substr(8,1)}return!1}(t)}}(p);break;case"fi":v=function(e){var t=e;if(/^FI[0-9]{8}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{8}$/.test(t))return{meta:{},valid:!1};for(var i=[7,9,10,5,8,4,2,1],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];return{meta:{},valid:n%11==0}}(p);break;case"fr":v=function(e){var t=e;if(/^FR[0-9A-Z]{2}[0-9]{9}$/.test(t)&&(t=t.substr(2)),!/^[0-9A-Z]{2}[0-9]{9}$/.test(t))return{meta:{},valid:!1};if("000"!==t.substr(2,4))return{meta:{},valid:r(t.substr(2))};if(/^[0-9]{2}$/.test(t.substr(0,2)))return{meta:{},valid:t.substr(0,2)==="".concat(parseInt(t.substr(2)+"12",10)%97)};var i,n="0123456789ABCDEFGHJKLMNPQRSTUVWXYZ";return i=/^[0-9]$/.test(t.charAt(0))?24*n.indexOf(t.charAt(0))+n.indexOf(t.charAt(1))-10:34*n.indexOf(t.charAt(0))+n.indexOf(t.charAt(1))-100,{meta:{},valid:(parseInt(t.substr(2),10)+1+Math.floor(i/11))%11==i%11}}(p);break;case"gb":v=function(e){var t=e;if((/^GB[0-9]{9}$/.test(t)||/^GB[0-9]{12}$/.test(t)||/^GBGD[0-9]{3}$/.test(t)||/^GBHA[0-9]{3}$/.test(t)||/^GB(GD|HA)8888[0-9]{5}$/.test(t))&&(t=t.substr(2)),!(/^[0-9]{9}$/.test(t)||/^[0-9]{12}$/.test(t)||/^GD[0-9]{3}$/.test(t)||/^HA[0-9]{3}$/.test(t)||/^(GD|HA)8888[0-9]{5}$/.test(t)))return{meta:{},valid:!1};var i=t.length;if(5===i){var n=t.substr(0,2),r=parseInt(t.substr(2),10);return{meta:{},valid:"GD"===n&&r<500||"HA"===n&&r>=500}}if(11===i&&("GD8888"===t.substr(0,6)||"HA8888"===t.substr(0,6)))return"GD"===t.substr(0,2)&&parseInt(t.substr(6,3),10)>=500||"HA"===t.substr(0,2)&&parseInt(t.substr(6,3),10)<500?{meta:{},valid:!1}:{meta:{},valid:parseInt(t.substr(6,3),10)%97===parseInt(t.substr(9,2),10)};if(9===i||12===i){for(var a=[8,7,6,5,4,3,2,10,1],s=0,o=0;o<9;o++)s+=parseInt(t.charAt(o),10)*a[o];return s%=97,{meta:{},valid:parseInt(t.substr(0,3),10)>=100?0===s||42===s||55===s:0===s}}return{meta:{},valid:!0}}(p);break;case"hr":v=function(e){var t=e;return/^HR[0-9]{11}$/.test(t)&&(t=t.substr(2)),/^[0-9]{11}$/.test(t)?{meta:{},valid:s(t)}:{meta:{},valid:!1}}(p);break;case"hu":v=function(e){var t=e;if(/^HU[0-9]{8}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{8}$/.test(t))return{meta:{},valid:!1};for(var i=[9,7,3,1,9,7,3,1],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];return{meta:{},valid:n%10==0}}(p);break;case"ie":v=function(e){var t=e;if(/^IE[0-9][0-9A-Z*+][0-9]{5}[A-Z]{1,2}$/.test(t)&&(t=t.substr(2)),!/^[0-9][0-9A-Z*+][0-9]{5}[A-Z]{1,2}$/.test(t))return{meta:{},valid:!1};var i=function(e){for(var t=e;t.length<7;)t="0".concat(t);for(var i="WABCDEFGHIJKLMNOPQRSTUV",n=0,r=0;r<7;r++)n+=parseInt(t.charAt(r),10)*(8-r);return n+=9*i.indexOf(t.substr(7)),i[n%23]};return/^[0-9]+$/.test(t.substr(0,7))?{meta:{},valid:t.charAt(7)===i("".concat(t.substr(0,7)).concat(t.substr(8)))}:-1!=="ABCDEFGHIJKLMNOPQRSTUVWXYZ+*".indexOf(t.charAt(1))?{meta:{},valid:t.charAt(7)===i("".concat(t.substr(2,5)).concat(t.substr(0,1)))}:{meta:{},valid:!0}}(p);break;case"is":v=function(e){var t=e;return/^IS[0-9]{5,6}$/.test(t)&&(t=t.substr(2)),{meta:{},valid:/^[0-9]{5,6}$/.test(t)}}(p);break;case"it":v=function(e){var t=e;if(/^IT[0-9]{11}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{11}$/.test(t))return{meta:{},valid:!1};if(0===parseInt(t.substr(0,7),10))return{meta:{},valid:!1};var i=parseInt(t.substr(7,3),10);return i<1||i>201&&999!==i&&888!==i?{meta:{},valid:!1}:{meta:{},valid:o(t)}}(p);break;case"lt":v=function(e){var t=e;if(/^LT([0-9]{7}1[0-9]|[0-9]{10}1[0-9])$/.test(t)&&(t=t.substr(2)),!/^([0-9]{7}1[0-9]|[0-9]{10}1[0-9])$/.test(t))return{meta:{},valid:!1};var i,n=t.length,r=0;for(i=0;i<n-1;i++)r+=parseInt(t.charAt(i),10)*(1+i%9);var a=r%11;if(10===a)for(r=0,i=0;i<n-1;i++)r+=parseInt(t.charAt(i),10)*(1+(i+2)%9);return{meta:{},valid:"".concat(a=a%11%10)===t.charAt(n-1)}}(p);break;case"lu":v=function(e){var t=e;return/^LU[0-9]{8}$/.test(t)&&(t=t.substring(2)),/^[0-9]{8}$/.test(t)?{meta:{},valid:parseInt(t.substring(0,6),10)%89===parseInt(t.substring(6,8),10)}:{meta:{},valid:!1}}(p);break;case"lv":v=function(e){var t=e;if(/^LV[0-9]{11}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{11}$/.test(t))return{meta:{},valid:!1};var i,n=parseInt(t.charAt(0),10),r=t.length,a=0,s=[];if(n>3){for(a=0,s=[9,1,4,8,3,10,2,5,7,6,1],i=0;i<r;i++)a+=parseInt(t.charAt(i),10)*s[i];return{meta:{},valid:3==(a%=11)}}var o=parseInt(t.substr(0,2),10),c=parseInt(t.substr(2,2),10),u=parseInt(t.substr(4,2),10);if(u=u+1800+100*parseInt(t.charAt(6),10),!l(u,c,o))return{meta:{},valid:!1};for(a=0,s=[10,5,8,4,2,1,6,3,7,9],i=0;i<r-1;i++)a+=parseInt(t.charAt(i),10)*s[i];return{meta:{},valid:"".concat(a=(a+1)%11%10)===t.charAt(r-1)}}(p);break;case"mt":v=function(e){var t=e;if(/^MT[0-9]{8}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{8}$/.test(t))return{meta:{},valid:!1};for(var i=[3,4,6,7,8,9,10,1],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];return{meta:{},valid:n%37==0}}(p);break;case"nl":v=function(e){var t=e;return/^NL[0-9]{9}B[0-9]{2}$/.test(t)&&(t=t.substr(2)),/^[0-9]{9}B[0-9]{2}$/.test(t)?{meta:{},valid:u(t.substr(0,9)).valid||c("NL".concat(t))}:{meta:{},valid:!1}}(p);break;case"no":v=function(e){var t=e;if(/^NO[0-9]{9}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{9}$/.test(t))return{meta:{},valid:!1};for(var i=[3,2,7,6,5,4,3,2],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];return 11==(n=11-n%11)&&(n=0),{meta:{},valid:"".concat(n)===t.substr(8,1)}}(p);break;case"pl":v=function(e){var t=e;if(/^PL[0-9]{10}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{10}$/.test(t))return{meta:{},valid:!1};for(var i=[6,5,7,2,3,4,5,6,7,-1],n=0,r=0;r<10;r++)n+=parseInt(t.charAt(r),10)*i[r];return{meta:{},valid:n%11==0}}(p);break;case"pt":v=function(e){var t=e;if(/^PT[0-9]{9}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{9}$/.test(t))return{meta:{},valid:!1};for(var i=[9,8,7,6,5,4,3,2],n=0,r=0;r<8;r++)n+=parseInt(t.charAt(r),10)*i[r];return(n=11-n%11)>9&&(n=0),{meta:{},valid:"".concat(n)===t.substr(8,1)}}(p);break;case"ro":v=function(e){var t=e;if(/^RO[1-9][0-9]{1,9}$/.test(t)&&(t=t.substr(2)),!/^[1-9][0-9]{1,9}$/.test(t))return{meta:{},valid:!1};for(var i=t.length,n=[7,5,3,2,1,7,5,3,2].slice(10-i),r=0,a=0;a<i-1;a++)r+=parseInt(t.charAt(a),10)*n[a];return{meta:{},valid:"".concat(r=10*r%11%10)===t.substr(i-1,1)}}(p);break;case"rs":v=function(e){var t=e;if(/^RS[0-9]{9}$/.test(t)&&(t=t.substr(2)),!/^[0-9]{9}$/.test(t))return{meta:{},valid:!1};for(var i=10,n=0,r=0;r<8;r++)0==(n=(parseInt(t.charAt(r),10)+i)%10)&&(n=10),i=2*n%11;return{meta:{},valid:(i+parseInt(t.substr(8,1),10))%10==1}}(p);break;case"ru":v=function(e){var t=e;if(/^RU([0-9]{10}|[0-9]{12})$/.test(t)&&(t=t.substr(2)),!/^([0-9]{10}|[0-9]{12})$/.test(t))return{meta:{},valid:!1};var i=0;if(10===t.length){var n=[2,4,10,3,5,9,4,6,8,0],r=0;for(i=0;i<10;i++)r+=parseInt(t.charAt(i),10)*n[i];return(r%=11)>9&&(r%=10),{meta:{},valid:"".concat(r)===t.substr(9,1)}}if(12===t.length){var a=[7,2,4,10,3,5,9,4,6,8,0],s=[3,7,2,4,10,3,5,9,4,6,8,0],o=0,l=0;for(i=0;i<11;i++)o+=parseInt(t.charAt(i),10)*a[i],l+=parseInt(t.charAt(i),10)*s[i];return(o%=11)>9&&(o%=10),(l%=11)>9&&(l%=10),{meta:{},valid:"".concat(o)===t.substr(10,1)&&"".concat(l)===t.substr(11,1)}}return{meta:{},valid:!0}}(p);break;case"se":v=function(e){var t=e;return/^SE[0-9]{10}01$/.test(t)&&(t=t.substr(2)),/^[0-9]{10}01$/.test(t)?(t=t.substr(0,10),{meta:{},valid:d(t)}):{meta:{},valid:!1}}(p);break;case"si":v=function(e){var t=e.match(/^(SI)?([1-9][0-9]{7})$/);if(!t)return{meta:{},valid:!1};for(var i=t[1]?e.substr(2):e,n=[8,7,6,5,4,3,2],r=0,a=0;a<7;a++)r+=parseInt(i.charAt(a),10)*n[a];return 10==(r=11-r%11)&&(r=0),{meta:{},valid:"".concat(r)===i.substr(7,1)}}(p);break;case"sk":v=function(e){var t=e;return/^SK[1-9][0-9][(2-4)|(6-9)][0-9]{7}$/.test(t)&&(t=t.substr(2)),/^[1-9][0-9][(2-4)|(6-9)][0-9]{7}$/.test(t)?{meta:{},valid:parseInt(t,10)%11==0}:{meta:{},valid:!1}}(p);break;case"ve":v=function(e){var t=e;if(/^VE[VEJPG][0-9]{9}$/.test(t)&&(t=t.substr(2)),!/^[VEJPG][0-9]{9}$/.test(t))return{meta:{},valid:!1};for(var i=[3,2,7,6,5,4,3,2],n={E:8,G:20,J:12,P:16,V:4}[t.charAt(0)],r=0;r<8;r++)n+=parseInt(t.charAt(r+1),10)*i[r];return 11!=(n=11-n%11)&&10!==n||(n=0),{meta:{},valid:"".concat(n)===t.substr(9,1)}}(p);break;case"za":v=function(e){var t=e;return/^ZA4[0-9]{9}$/.test(t)&&(t=t.substr(2)),{meta:{},valid:/^4[0-9]{9}$/.test(t)}}(p)}var y=h(a.l10n&&a.l10n.vat?m.message||a.l10n.vat.country:m.message,a.l10n&&a.l10n.vat&&a.l10n.vat.countries?a.l10n.vat.countries[g.toUpperCase()]:g.toUpperCase());return Object.assign({},{message:y},v)}}},Rn}();var zn,Bn=Fn.exports,Vn={exports:{}},Wn={};Vn.exports=(zn||(zn=1,Wn.vin=function(){return{validate:function(e){if(""===e.value)return{valid:!0};if(!/^[a-hj-npr-z0-9]{8}[0-9xX][a-hj-npr-z0-9]{8}$/i.test(e.value))return{valid:!1};for(var t=e.value.toUpperCase(),i={A:1,B:2,C:3,D:4,E:5,F:6,G:7,H:8,J:1,K:2,L:3,M:4,N:5,P:7,R:9,S:2,T:3,U:4,V:5,W:6,X:7,Y:8,Z:9,0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9},n=[8,7,6,5,4,3,2,10,0,9,8,7,6,5,4,3,2],r=t.length,a=0,s=0;s<r;s++)a+=i["".concat(t.charAt(s))]*n[s];var o="".concat(a%11);return"10"===o&&(o="X"),{valid:o===t.charAt(8)}}}}),Wn);var Un,qn=Vn.exports,$n={exports:{}},Xn={};$n.exports=function(){if(Un)return Xn;Un=1;var e=a,t=e.utils.format,i=e.utils.removeUndefined;return Xn.zipCode=function(){var e=["AT","BG","BR","CA","CH","CZ","DE","DK","ES","FR","GB","IE","IN","IT","MA","NL","PL","PT","RO","RU","SE","SG","SK","US"];return{validate:function(n){var r=Object.assign({},{message:""},i(n.options));if(""===n.value||!r.country)return{valid:!0};var a=n.value.substr(0,2);if(!(a="function"==typeof r.country?r.country.call(this):r.country)||-1===e.indexOf(a.toUpperCase()))return{valid:!0};var s=!1;switch(a=a.toUpperCase()){case"AT":case"CH":s=/^([1-9]{1})(\d{3})$/.test(n.value);break;case"BG":s=/^([1-9]{1}[0-9]{3})$/.test(n.value);break;case"BR":s=/^(\d{2})([.]?)(\d{3})([-]?)(\d{3})$/.test(n.value);break;case"CA":s=/^(?:A|B|C|E|G|H|J|K|L|M|N|P|R|S|T|V|X|Y){1}[0-9]{1}(?:A|B|C|E|G|H|J|K|L|M|N|P|R|S|T|V|W|X|Y|Z){1}\s?[0-9]{1}(?:A|B|C|E|G|H|J|K|L|M|N|P|R|S|T|V|W|X|Y|Z){1}[0-9]{1}$/i.test(n.value);break;case"CZ":case"SK":s=/^(\d{3})([ ]?)(\d{2})$/.test(n.value);break;case"DE":s=/^(?!01000|99999)(0[1-9]\d{3}|[1-9]\d{4})$/.test(n.value);break;case"DK":s=/^(DK(-|\s)?)?\d{4}$/i.test(n.value);break;case"ES":s=/^(?:0[1-9]|[1-4][0-9]|5[0-2])\d{3}$/.test(n.value);break;case"FR":s=/^[0-9]{5}$/i.test(n.value);break;case"GB":s=function(e){for(var t="[ABCDEFGHIJKLMNOPRSTUWYZ]",i="[ABCDEFGHKLMNOPQRSTUVWXY]",n="[ABDEFGHJLNPQRSTUWXYZ]",r=0,a=[new RegExp("^(".concat(t,"{1}").concat(i,"?[0-9]{1,2})(\\s*)([0-9]{1}").concat(n,"{2})$"),"i"),new RegExp("^(".concat(t,"{1}[0-9]{1}").concat("[ABCDEFGHJKPMNRSTUVWXY]","{1})(\\s*)([0-9]{1}").concat(n,"{2})$"),"i"),new RegExp("^(".concat(t,"{1}").concat(i,"{1}?[0-9]{1}").concat("[ABEHMNPRVWXY]","{1})(\\s*)([0-9]{1}").concat(n,"{2})$"),"i"),new RegExp("^(BF1)(\\s*)([0-6]{1}[ABDEFGHJLNPQRST]{1}[ABDEFGHJLNPQRSTUWZYZ]{1})$","i"),/^(GIR)(\s*)(0AA)$/i,/^(BFPO)(\s*)([0-9]{1,4})$/i,/^(BFPO)(\s*)(c\/o\s*[0-9]{1,3})$/i,/^([A-Z]{4})(\s*)(1ZZ)$/i,/^(AI-2640)$/i];r<a.length;r++)if(a[r].test(e))return!0;return!1}(n.value);break;case"IN":s=/^\d{3}\s?\d{3}$/.test(n.value);break;case"IE":s=/^(D6W|[ACDEFHKNPRTVWXY]\d{2})\s[0-9ACDEFHKNPRTVWXY]{4}$/.test(n.value);break;case"IT":s=/^(I-|IT-)?\d{5}$/i.test(n.value);break;case"MA":s=/^[1-9][0-9]{4}$/i.test(n.value);break;case"NL":s=/^[1-9][0-9]{3} ?(?!sa|sd|ss)[a-z]{2}$/i.test(n.value);break;case"PL":s=/^[0-9]{2}-[0-9]{3}$/.test(n.value);break;case"PT":s=/^[1-9]\d{3}-\d{3}$/.test(n.value);break;case"RO":s=/^(0[1-8]{1}|[1-9]{1}[0-5]{1})?[0-9]{4}$/i.test(n.value);break;case"RU":s=/^[0-9]{6}$/i.test(n.value);break;case"SE":s=/^(S-)?\d{3}\s?\d{2}$/i.test(n.value);break;case"SG":s=/^([0][1-9]|[1-6][0-9]|[7]([0-3]|[5-9])|[8][0-2])(\d{4})$/i.test(n.value);break;default:s=/^\d{4,5}([-]?\d{4})?$/.test(n.value)}return{message:t(n.l10n&&n.l10n.zipCode?r.message||n.l10n.zipCode.country:r.message,n.l10n&&n.l10n.zipCode&&n.l10n.zipCode.countries?n.l10n.zipCode.countries[a]:a),valid:s}}}},Xn}();var Gn=$n.exports,Zn={Alias:c.Alias,Aria:f.Aria,Declarative:v.Declarative,DefaultSubmit:_.DefaultSubmit,Dependency:S.Dependency,Excluded:C.Excluded,FieldStatus:P.FieldStatus,Framework:z.Framework,Icon:U.Icon,Message:F.Message,Sequence:G.Sequence,SubmitButton:Q.SubmitButton,Tooltip:ne.Tooltip,Trigger:oe.Trigger},Kn={between:de.between,blank:me.blank,callback:be.callback,choice:ke.choice,creditCard:Le.creditCard,date:Ee.date,different:Ie.different,digits:Fe.digits,emailAddress:Ve.emailAddress,file:$e.file,greaterThan:Ke.greaterThan,identical:tt.identical,integer:at.integer,ip:ct.ip,lessThan:ft.lessThan,notEmpty:vt.notEmpty,numeric:_t.numeric,promise:St.promise,regexp:Ct.regexp,remote:Pt.remote,stringCase:jt.stringCase,stringLength:zt.stringLength,uri:Ut.uri,base64:Gt.base64,bic:Qt.bic,color:ni.color,cusip:oi.cusip,ean:di.ean,ein:mi.ein,grid:bi.grid,hex:ki.hex,iban:Li.iban,id:Ei.id,imei:Ii.imei,imo:Fi.imo,isbn:Vi.isbn,isin:$i.isin,ismn:Ki.ismn,issn:tn.issn,mac:sn.mac,meid:un.meid,phone:pn.phone,rtn:yn.rtn,sedol:wn.sedol,siren:An.siren,siret:Dn.siret,step:Yn.step,uuid:Hn.uuid,vat:Bn.vat,vin:qn.vin,zipCode:Gn.zipCode};e.Plugin=a.Plugin,e.algorithms=a.algorithms,e.formValidation=function(e,t){var i=a.formValidation(e,t);return Object.keys(Kn).forEach((function(e){return i.registerValidator(e,Kn[e])})),i},e.plugins=Zn,e.utils=a.utils,e.validators=Kn})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t(require("@form-validation/core"),require("@form-validation/plugin-framework")):"function"==typeof define&&define.amd?define(["@form-validation/core","@form-validation/plugin-framework"],t):((e="undefined"!=typeof globalThis?globalThis:e||self).FormValidation=e.FormValidation||{},e.FormValidation.plugins=e.FormValidation.plugins||{},e.FormValidation.plugins.Bootstrap5=t(e.FormValidation,e.FormValidation.plugins))}(this,(function(e,t){"use strict";var i=function(e,t){return i=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])},i(e,t)},n=e.utils.classSet,r=e.utils.hasClass;return function(e){function t(t){var i=e.call(this,Object.assign({},{eleInvalidClass:"is-invalid",eleValidClass:"is-valid",formClass:"fv-plugins-bootstrap5",rowInvalidClass:"fv-plugins-bootstrap5-row-invalid",rowPattern:/^(.*)(col|offset)(-(sm|md|lg|xl))*-[0-9]+(.*)$/,rowSelector:".row",rowValidClass:"fv-plugins-bootstrap5-row-valid"},t))||this;return i.eleValidatedHandler=i.handleElementValidated.bind(i),i}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function n(){this.constructor=e}i(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}(t,e),t.prototype.install=function(){e.prototype.install.call(this),this.core.on("core.element.validated",this.eleValidatedHandler)},t.prototype.uninstall=function(){e.prototype.uninstall.call(this),this.core.off("core.element.validated",this.eleValidatedHandler)},t.prototype.handleElementValidated=function(e){var t=e.element.getAttribute("type");if(("checkbox"===t||"radio"===t)&&e.elements.length>1&&r(e.element,"form-check-input")){var i=e.element.parentElement;r(i,"form-check")&&r(i,"form-check-inline")&&n(i,{"is-invalid":!e.valid,"is-valid":e.valid})}},t.prototype.onIconPlaced=function(e){n(e.element,{"fv-plugins-icon-input":!0});var t=e.element.parentElement;r(t,"input-group")&&(t.parentElement.insertBefore(e.iconElement,t.nextSibling),e.element.nextElementSibling&&r(e.element.nextElementSibling,"input-group-text")&&n(e.iconElement,{"fv-plugins-icon-input-group":!0}));var i=e.element.getAttribute("type");if("checkbox"===i||"radio"===i){var a=t.parentElement;r(t,"form-check")?(n(e.iconElement,{"fv-plugins-icon-check":!0}),t.parentElement.insertBefore(e.iconElement,t.nextSibling)):r(t.parentElement,"form-check")&&(n(e.iconElement,{"fv-plugins-icon-check":!0}),a.parentElement.insertBefore(e.iconElement,a.nextSibling))}},t.prototype.onMessagePlaced=function(e){e.messageElement.classList.add("invalid-feedback");var t=e.element.parentElement;if(r(t,"input-group"))return t.appendChild(e.messageElement),void n(t,{"has-validation":!0});var i=e.element.getAttribute("type");"checkbox"!==i&&"radio"!==i||!r(e.element,"form-check-input")||r(t,"form-check")||r(t,"form-check-inline")||e.elements[e.elements.length-1].parentElement.appendChild(e.messageElement)},t}(t.Framework)})),function(e){"use strict";e.event.special.destroyed||(e.event.special.destroyed={remove:function(e){e.handler&&e.handler()}}),e.fn.extend({maxlength:function(t,i){var n=e("body");function r(e){var t=e.charCodeAt();return t?t<128?1:t<2048?2:3:0}function a(e){return e.split("").map(r).concat(0).reduce((function(e,t){return e+t}))}function s(e){var i=e.val();i=t.twoCharLinebreak?i.replace(/\r(?!\n)|\n(?!\r)/g,"\r\n"):i.replace(/(?:\r\n|\r|\n)/g,"\n");var n=0;return n=t.utf8?a(i):i.length,"file"===e.prop("type")&&""!==e.val()&&(n-=12),n}function o(e,t){return t-s(e)}function l(e,t){t.css({display:"block"}),e.trigger("maxlength.shown")}function c(e,i,n){var r="";return t.message?r="function"==typeof t.message?t.message(e,i):t.message.replace("%charsTyped%",n).replace("%charsRemaining%",i-n).replace("%charsTotal%",i):(t.preText&&(r+=t.preText),t.showCharsTyped?r+=n:r+=i-n,t.showMaxLength&&(r+=t.separator+i),t.postText&&(r+=t.postText)),r}function u(e,i,n,r){var a,o,u,d;r&&(r.html(c(i.val(),n,n-e)),e>0?(a=i,o=t.threshold,u=n,d=!0,!t.alwaysShow&&u-s(a)>o&&(d=!1),d?l(i,r.removeClass(t.limitReachedClass+" "+t.limitExceededClass).addClass(t.warningClass)):function(e,i){t.alwaysShow||(i.css({display:"none"}),e.trigger("maxlength.hidden"))}(i,r)):t.limitExceededClass?l(i,0===e?r.removeClass(t.warningClass+" "+t.limitExceededClass).addClass(t.limitReachedClass):r.removeClass(t.warningClass+" "+t.limitReachedClass).addClass(t.limitExceededClass)):l(i,r.removeClass(t.warningClass).addClass(t.limitReachedClass))),t.customMaxAttribute&&(e<0?i.addClass(t.customMaxClass):i.removeClass(t.customMaxClass))}function d(i,n){var r=function(t){var i=t[0];return e.extend({},"function"==typeof i.getBoundingClientRect?i.getBoundingClientRect():{width:i.offsetWidth,height:i.offsetHeight},t.offset())}(i);if("function"!==e.type(t.placement))if(e.isPlainObject(t.placement))!function(i,n){if(i&&n){var r={};e.each(["top","bottom","left","right","position"],(function(e,i){var n=t.placement[i];void 0!==n&&(r[i]=n)})),n.css(r)}}(t.placement,n);else{var a=i.outerWidth(),s=n.outerWidth(),o=n.width(),l=n.height();switch(t.appendToParent&&(r.top-=i.parent().offset().top,r.left-=i.parent().offset().left),t.placement){case"bottom":n.css({top:r.top+r.height,left:r.left+r.width/2-o/2});break;case"top":n.css({top:r.top-l,left:r.left+r.width/2-o/2});break;case"left":n.css({top:r.top+r.height/2-l/2,left:r.left-o});break;case"right":n.css({top:r.top+r.height/2-l/2,left:r.left+r.width});break;case"bottom-right":n.css({top:r.top+r.height,left:r.left+r.width});break;case"top-right":n.css({top:r.top-l,left:r.left+a});break;case"top-left":n.css({top:r.top-l,left:r.left-s});break;case"bottom-left":n.css({top:r.top+i.outerHeight(),left:r.left-s});break;case"centered-right":n.css({top:r.top+l/2,left:r.left+a-s-3});break;case"bottom-right-inside":n.css({top:r.top+r.height,left:r.left+r.width-s});break;case"top-right-inside":n.css({top:r.top-l,left:r.left+a-s});break;case"top-left-inside":n.css({top:r.top-l,left:r.left});break;case"bottom-left-inside":n.css({top:r.top+i.outerHeight(),left:r.left})}}else t.placement(i,n,r)}function h(e){var i=e.attr("maxlength")||t.customMaxAttribute;if(t.customMaxAttribute&&!t.allowOverMax){var n=e.attr(t.customMaxAttribute);(!i||n<i)&&(i=n)}return i||(i=e.attr("size")),i}return e.isFunction(t)&&!i&&(i=t,t={}),t=e.extend({showOnReady:!1,alwaysShow:!0,threshold:0,warningClass:"small form-text text-muted",limitReachedClass:"small form-text text-danger",limitExceededClass:"",separator:" / ",preText:"",postText:"",showMaxLength:!0,placement:"bottom-right-inside",message:null,showCharsTyped:!0,validate:!1,utf8:!1,appendToParent:!1,twoCharLinebreak:!0,customMaxAttribute:null,customMaxClass:"overmax",allowOverMax:!1,zIndex:1099},t),this.each((function(){var i,s,l=e(this);function f(){var r=c(l.val(),i,"0");i=h(l),s||(s=e('<span class="bootstrap-maxlength"></span>').css({display:"none",position:"absolute",whiteSpace:"nowrap",zIndex:t.zIndex}).html(r)),l.is("textarea")&&(l.data("maxlenghtsizex",l.outerWidth()),l.data("maxlenghtsizey",l.outerHeight()),l.mouseup((function(){l.outerWidth()===l.data("maxlenghtsizex")&&l.outerHeight()===l.data("maxlenghtsizey")||d(l,s),l.data("maxlenghtsizex",l.outerWidth()),l.data("maxlenghtsizey",l.outerHeight())}))),t.appendToParent?(l.parent().append(s),l.parent().css("position","relative")):n.append(s),u(o(l,h(l)),l,i,s),d(l,s)}e(window).resize((function(){s&&d(l,s)})),t.showOnReady?l.ready((function(){f()})):l.focus((function(){f()})),l.on("maxlength.reposition",(function(){d(l,s)})),l.on("destroyed",(function(){s&&s.remove()})),l.on("blur",(function(){s&&!t.showOnReady&&s.remove()})),l.on("input",(function(){var e=h(l),n=o(l,e),c=!0;return t.validate&&n<0?(!function(e,i){var n=e.val();if(t.twoCharLinebreak&&"\n"===(n=n.replace(/\r(?!\n)|\n(?!\r)/g,"\r\n"))[n.length-1]&&(i-=n.length%2),t.utf8){for(var s=n.split("").map(r),o=0,l=a(n)-i;o<l;o+=s.pop());i-=i-s.length}e.val(n.substr(0,i))}(l,e),c=!1):u(n,l,i,s),c}))}))}})}(jQuery),
/**
* @version: 3.1
* @author: Dan Grossman http://www.dangrossman.info/
* @copyright: Copyright (c) 2012-2019 Dan Grossman. All rights reserved.
* @license: Licensed under the MIT license. See http://www.opensource.org/licenses/mit-license.php
* @website: http://www.daterangepicker.com/
*/
function(e,t){if("function"==typeof define&&define.amd)define(["moment","jquery"],(function(e,i){return i.fn||(i.fn={}),"function"!=typeof e&&e.hasOwnProperty("default")&&(e=e.default),t(e,i)}));else if("object"==typeof module&&module.exports){var i="undefined"!=typeof window?window.jQuery:void 0;i||(i=require("jquery")).fn||(i.fn={});var n="undefined"!=typeof window&&void 0!==window.moment?window.moment:require("moment");module.exports=t(n,i)}else e.daterangepicker=t(e.moment,e.jQuery)}(this,(function(e,t){var i=function(i,n,r){if(this.parentEl="body",this.element=t(i),this.startDate=e().startOf("day"),this.endDate=e().endOf("day"),this.minDate=!1,this.maxDate=!1,this.maxSpan=!1,this.autoApply=!1,this.singleDatePicker=!1,this.showDropdowns=!1,this.minYear=e().subtract(100,"year").format("YYYY"),this.maxYear=e().add(100,"year").format("YYYY"),this.showWeekNumbers=!1,this.showISOWeekNumbers=!1,this.showCustomRangeLabel=!0,this.timePicker=!1,this.timePicker24Hour=!1,this.timePickerIncrement=1,this.timePickerSeconds=!1,this.linkedCalendars=!0,this.autoUpdateInput=!0,this.alwaysShowCalendars=!1,this.ranges={},this.opens="right",this.element.hasClass("pull-right")&&(this.opens="left"),this.drops="down",this.element.hasClass("dropup")&&(this.drops="up"),this.buttonClasses="btn btn-sm",this.applyButtonClasses="btn-primary",this.cancelButtonClasses="btn-default",this.locale={direction:"ltr",format:e.localeData().longDateFormat("L"),separator:" - ",applyLabel:"Apply",cancelLabel:"Cancel",weekLabel:"W",customRangeLabel:"Custom Range",daysOfWeek:e.weekdaysMin(),monthNames:e.monthsShort(),firstDay:e.localeData().firstDayOfWeek()},this.callback=function(){},this.isShowing=!1,this.leftCalendar={},this.rightCalendar={},"object"==typeof n&&null!==n||(n={}),"string"==typeof(n=t.extend(this.element.data(),n)).template||n.template instanceof t||(n.template='<div class="daterangepicker"><div class="ranges"></div><div class="drp-calendar left"><div class="calendar-table"></div><div class="calendar-time"></div></div><div class="drp-calendar right"><div class="calendar-table"></div><div class="calendar-time"></div></div><div class="drp-buttons"><span class="drp-selected"></span><button class="cancelBtn" type="button"></button><button class="applyBtn" disabled="disabled" type="button"></button> </div></div>'),this.parentEl=n.parentEl&&t(n.parentEl).length?t(n.parentEl):t(this.parentEl),this.container=t(n.template).appendTo(this.parentEl),"object"==typeof n.locale&&("string"==typeof n.locale.direction&&(this.locale.direction=n.locale.direction),"string"==typeof n.locale.format&&(this.locale.format=n.locale.format),"string"==typeof n.locale.separator&&(this.locale.separator=n.locale.separator),"object"==typeof n.locale.daysOfWeek&&(this.locale.daysOfWeek=n.locale.daysOfWeek.slice()),"object"==typeof n.locale.monthNames&&(this.locale.monthNames=n.locale.monthNames.slice()),"number"==typeof n.locale.firstDay&&(this.locale.firstDay=n.locale.firstDay),"string"==typeof n.locale.applyLabel&&(this.locale.applyLabel=n.locale.applyLabel),"string"==typeof n.locale.cancelLabel&&(this.locale.cancelLabel=n.locale.cancelLabel),"string"==typeof n.locale.weekLabel&&(this.locale.weekLabel=n.locale.weekLabel),"string"==typeof n.locale.customRangeLabel)){(f=document.createElement("textarea")).innerHTML=n.locale.customRangeLabel;var a=f.value;this.locale.customRangeLabel=a}if(this.container.addClass(this.locale.direction),"string"==typeof n.startDate&&(this.startDate=e(n.startDate,this.locale.format)),"string"==typeof n.endDate&&(this.endDate=e(n.endDate,this.locale.format)),"string"==typeof n.minDate&&(this.minDate=e(n.minDate,this.locale.format)),"string"==typeof n.maxDate&&(this.maxDate=e(n.maxDate,this.locale.format)),"object"==typeof n.startDate&&(this.startDate=e(n.startDate)),"object"==typeof n.endDate&&(this.endDate=e(n.endDate)),"object"==typeof n.minDate&&(this.minDate=e(n.minDate)),"object"==typeof n.maxDate&&(this.maxDate=e(n.maxDate)),this.minDate&&this.startDate.isBefore(this.minDate)&&(this.startDate=this.minDate.clone()),this.maxDate&&this.endDate.isAfter(this.maxDate)&&(this.endDate=this.maxDate.clone()),"string"==typeof n.applyButtonClasses&&(this.applyButtonClasses=n.applyButtonClasses),"string"==typeof n.applyClass&&(this.applyButtonClasses=n.applyClass),"string"==typeof n.cancelButtonClasses&&(this.cancelButtonClasses=n.cancelButtonClasses),"string"==typeof n.cancelClass&&(this.cancelButtonClasses=n.cancelClass),"object"==typeof n.maxSpan&&(this.maxSpan=n.maxSpan),"object"==typeof n.dateLimit&&(this.maxSpan=n.dateLimit),"string"==typeof n.opens&&(this.opens=n.opens),"string"==typeof n.drops&&(this.drops=n.drops),"boolean"==typeof n.showWeekNumbers&&(this.showWeekNumbers=n.showWeekNumbers),"boolean"==typeof n.showISOWeekNumbers&&(this.showISOWeekNumbers=n.showISOWeekNumbers),"string"==typeof n.buttonClasses&&(this.buttonClasses=n.buttonClasses),"object"==typeof n.buttonClasses&&(this.buttonClasses=n.buttonClasses.join(" ")),"boolean"==typeof n.showDropdowns&&(this.showDropdowns=n.showDropdowns),"number"==typeof n.minYear&&(this.minYear=n.minYear),"number"==typeof n.maxYear&&(this.maxYear=n.maxYear),"boolean"==typeof n.showCustomRangeLabel&&(this.showCustomRangeLabel=n.showCustomRangeLabel),"boolean"==typeof n.singleDatePicker&&(this.singleDatePicker=n.singleDatePicker,this.singleDatePicker&&(this.endDate=this.startDate.clone())),"boolean"==typeof n.timePicker&&(this.timePicker=n.timePicker),"boolean"==typeof n.timePickerSeconds&&(this.timePickerSeconds=n.timePickerSeconds),"number"==typeof n.timePickerIncrement&&(this.timePickerIncrement=n.timePickerIncrement),"boolean"==typeof n.timePicker24Hour&&(this.timePicker24Hour=n.timePicker24Hour),"boolean"==typeof n.autoApply&&(this.autoApply=n.autoApply),"boolean"==typeof n.autoUpdateInput&&(this.autoUpdateInput=n.autoUpdateInput),"boolean"==typeof n.linkedCalendars&&(this.linkedCalendars=n.linkedCalendars),"function"==typeof n.isInvalidDate&&(this.isInvalidDate=n.isInvalidDate),"function"==typeof n.isCustomDate&&(this.isCustomDate=n.isCustomDate),"boolean"==typeof n.alwaysShowCalendars&&(this.alwaysShowCalendars=n.alwaysShowCalendars),0!=this.locale.firstDay)for(var s=this.locale.firstDay;s>0;)this.locale.daysOfWeek.push(this.locale.daysOfWeek.shift()),s--;var o,l,c;if(void 0===n.startDate&&void 0===n.endDate&&t(this.element).is(":text")){var u=t(this.element).val(),d=u.split(this.locale.separator);o=l=null,2==d.length?(o=e(d[0],this.locale.format),l=e(d[1],this.locale.format)):this.singleDatePicker&&""!==u&&(o=e(u,this.locale.format),l=e(u,this.locale.format)),null!==o&&null!==l&&(this.setStartDate(o),this.setEndDate(l))}if("object"==typeof n.ranges){for(c in n.ranges){o="string"==typeof n.ranges[c][0]?e(n.ranges[c][0],this.locale.format):e(n.ranges[c][0]),l="string"==typeof n.ranges[c][1]?e(n.ranges[c][1],this.locale.format):e(n.ranges[c][1]),this.minDate&&o.isBefore(this.minDate)&&(o=this.minDate.clone());var h=this.maxDate;if(this.maxSpan&&h&&o.clone().add(this.maxSpan).isAfter(h)&&(h=o.clone().add(this.maxSpan)),h&&l.isAfter(h)&&(l=h.clone()),!(this.minDate&&l.isBefore(this.minDate,this.timepicker?"minute":"day")||h&&o.isAfter(h,this.timepicker?"minute":"day"))){var f;(f=document.createElement("textarea")).innerHTML=c;a=f.value;this.ranges[a]=[o,l]}}var p="<ul>";for(c in this.ranges)p+='<li data-range-key="'+c+'">'+c+"</li>";this.showCustomRangeLabel&&(p+='<li data-range-key="'+this.locale.customRangeLabel+'">'+this.locale.customRangeLabel+"</li>"),p+="</ul>",this.container.find(".ranges").prepend(p)}"function"==typeof r&&(this.callback=r),this.timePicker||(this.startDate=this.startDate.startOf("day"),this.endDate=this.endDate.endOf("day"),this.container.find(".calendar-time").hide()),this.timePicker&&this.autoApply&&(this.autoApply=!1),this.autoApply&&this.container.addClass("auto-apply"),"object"==typeof n.ranges&&this.container.addClass("show-ranges"),this.singleDatePicker&&(this.container.addClass("single"),this.container.find(".drp-calendar.left").addClass("single"),this.container.find(".drp-calendar.left").show(),this.container.find(".drp-calendar.right").hide(),!this.timePicker&&this.autoApply&&this.container.addClass("auto-apply")),(void 0===n.ranges&&!this.singleDatePicker||this.alwaysShowCalendars)&&this.container.addClass("show-calendar"),this.container.addClass("opens"+this.opens),this.container.find(".applyBtn, .cancelBtn").addClass(this.buttonClasses),this.applyButtonClasses.length&&this.container.find(".applyBtn").addClass(this.applyButtonClasses),this.cancelButtonClasses.length&&this.container.find(".cancelBtn").addClass(this.cancelButtonClasses),this.container.find(".applyBtn").html(this.locale.applyLabel),this.container.find(".cancelBtn").html(this.locale.cancelLabel),this.container.find(".drp-calendar").on("click.daterangepicker",".prev",t.proxy(this.clickPrev,this)).on("click.daterangepicker",".next",t.proxy(this.clickNext,this)).on("mousedown.daterangepicker","td.available",t.proxy(this.clickDate,this)).on("mouseenter.daterangepicker","td.available",t.proxy(this.hoverDate,this)).on("change.daterangepicker","select.yearselect",t.proxy(this.monthOrYearChanged,this)).on("change.daterangepicker","select.monthselect",t.proxy(this.monthOrYearChanged,this)).on("change.daterangepicker","select.hourselect,select.minuteselect,select.secondselect,select.ampmselect",t.proxy(this.timeChanged,this)),this.container.find(".ranges").on("click.daterangepicker","li",t.proxy(this.clickRange,this)),this.container.find(".drp-buttons").on("click.daterangepicker","button.applyBtn",t.proxy(this.clickApply,this)).on("click.daterangepicker","button.cancelBtn",t.proxy(this.clickCancel,this)),this.element.is("input")||this.element.is("button")?this.element.on({"click.daterangepicker":t.proxy(this.show,this),"focus.daterangepicker":t.proxy(this.show,this),"keyup.daterangepicker":t.proxy(this.elementChanged,this),"keydown.daterangepicker":t.proxy(this.keydown,this)}):(this.element.on("click.daterangepicker",t.proxy(this.toggle,this)),this.element.on("keydown.daterangepicker",t.proxy(this.toggle,this))),this.updateElement()};return i.prototype={constructor:i,setStartDate:function(t){"string"==typeof t&&(this.startDate=e(t,this.locale.format)),"object"==typeof t&&(this.startDate=e(t)),this.timePicker||(this.startDate=this.startDate.startOf("day")),this.timePicker&&this.timePickerIncrement&&this.startDate.minute(Math.round(this.startDate.minute()/this.timePickerIncrement)*this.timePickerIncrement),this.minDate&&this.startDate.isBefore(this.minDate)&&(this.startDate=this.minDate.clone(),this.timePicker&&this.timePickerIncrement&&this.startDate.minute(Math.round(this.startDate.minute()/this.timePickerIncrement)*this.timePickerIncrement)),this.maxDate&&this.startDate.isAfter(this.maxDate)&&(this.startDate=this.maxDate.clone(),this.timePicker&&this.timePickerIncrement&&this.startDate.minute(Math.floor(this.startDate.minute()/this.timePickerIncrement)*this.timePickerIncrement)),this.isShowing||this.updateElement(),this.updateMonthsInView()},setEndDate:function(t){"string"==typeof t&&(this.endDate=e(t,this.locale.format)),"object"==typeof t&&(this.endDate=e(t)),this.timePicker||(this.endDate=this.endDate.endOf("day")),this.timePicker&&this.timePickerIncrement&&this.endDate.minute(Math.round(this.endDate.minute()/this.timePickerIncrement)*this.timePickerIncrement),this.endDate.isBefore(this.startDate)&&(this.endDate=this.startDate.clone()),this.maxDate&&this.endDate.isAfter(this.maxDate)&&(this.endDate=this.maxDate.clone()),this.maxSpan&&this.startDate.clone().add(this.maxSpan).isBefore(this.endDate)&&(this.endDate=this.startDate.clone().add(this.maxSpan)),this.previousRightTime=this.endDate.clone(),this.container.find(".drp-selected").html(this.startDate.format(this.locale.format)+this.locale.separator+this.endDate.format(this.locale.format)),this.isShowing||this.updateElement(),this.updateMonthsInView()},isInvalidDate:function(){return!1},isCustomDate:function(){return!1},updateView:function(){this.timePicker&&(this.renderTimePicker("left"),this.renderTimePicker("right"),this.endDate?this.container.find(".right .calendar-time select").prop("disabled",!1).removeClass("disabled"):this.container.find(".right .calendar-time select").prop("disabled",!0).addClass("disabled")),this.endDate&&this.container.find(".drp-selected").html(this.startDate.format(this.locale.format)+this.locale.separator+this.endDate.format(this.locale.format)),this.updateMonthsInView(),this.updateCalendars(),this.updateFormInputs()},updateMonthsInView:function(){if(this.endDate){if(!this.singleDatePicker&&this.leftCalendar.month&&this.rightCalendar.month&&(this.startDate.format("YYYY-MM")==this.leftCalendar.month.format("YYYY-MM")||this.startDate.format("YYYY-MM")==this.rightCalendar.month.format("YYYY-MM"))&&(this.endDate.format("YYYY-MM")==this.leftCalendar.month.format("YYYY-MM")||this.endDate.format("YYYY-MM")==this.rightCalendar.month.format("YYYY-MM")))return;this.leftCalendar.month=this.startDate.clone().date(2),this.linkedCalendars||this.endDate.month()==this.startDate.month()&&this.endDate.year()==this.startDate.year()?this.rightCalendar.month=this.startDate.clone().date(2).add(1,"month"):this.rightCalendar.month=this.endDate.clone().date(2)}else this.leftCalendar.month.format("YYYY-MM")!=this.startDate.format("YYYY-MM")&&this.rightCalendar.month.format("YYYY-MM")!=this.startDate.format("YYYY-MM")&&(this.leftCalendar.month=this.startDate.clone().date(2),this.rightCalendar.month=this.startDate.clone().date(2).add(1,"month"));this.maxDate&&this.linkedCalendars&&!this.singleDatePicker&&this.rightCalendar.month>this.maxDate&&(this.rightCalendar.month=this.maxDate.clone().date(2),this.leftCalendar.month=this.maxDate.clone().date(2).subtract(1,"month"))},updateCalendars:function(){if(this.timePicker){var e,t,i,n;if(this.endDate){if(e=parseInt(this.container.find(".left .hourselect").val(),10),t=parseInt(this.container.find(".left .minuteselect").val(),10),isNaN(t)&&(t=parseInt(this.container.find(".left .minuteselect option:last").val(),10)),i=this.timePickerSeconds?parseInt(this.container.find(".left .secondselect").val(),10):0,!this.timePicker24Hour)"PM"===(n=this.container.find(".left .ampmselect").val())&&e<12&&(e+=12),"AM"===n&&12===e&&(e=0)}else if(e=parseInt(this.container.find(".right .hourselect").val(),10),t=parseInt(this.container.find(".right .minuteselect").val(),10),isNaN(t)&&(t=parseInt(this.container.find(".right .minuteselect option:last").val(),10)),i=this.timePickerSeconds?parseInt(this.container.find(".right .secondselect").val(),10):0,!this.timePicker24Hour)"PM"===(n=this.container.find(".right .ampmselect").val())&&e<12&&(e+=12),"AM"===n&&12===e&&(e=0);this.leftCalendar.month.hour(e).minute(t).second(i),this.rightCalendar.month.hour(e).minute(t).second(i)}this.renderCalendar("left"),this.renderCalendar("right"),this.container.find(".ranges li").removeClass("active"),null!=this.endDate&&this.calculateChosenLabel()},renderCalendar:function(i){var n,r=(n="left"==i?this.leftCalendar:this.rightCalendar).month.month(),a=n.month.year(),s=n.month.hour(),o=n.month.minute(),l=n.month.second(),c=e([a,r]).daysInMonth(),u=e([a,r,1]),d=e([a,r,c]),h=e(u).subtract(1,"month").month(),f=e(u).subtract(1,"month").year(),p=e([f,h]).daysInMonth(),m=u.day();(n=[]).firstDay=u,n.lastDay=d;for(var g=0;g<6;g++)n[g]=[];var v=p-m+this.locale.firstDay+1;v>p&&(v-=7),m==this.locale.firstDay&&(v=p-6);for(var y=e([f,h,v,12,o,l]),b=(g=0,0),x=0;g<42;g++,b++,y=e(y).add(24,"hour"))g>0&&b%7==0&&(b=0,x++),n[x][b]=y.clone().hour(s).minute(o).second(l),y.hour(12),this.minDate&&n[x][b].format("YYYY-MM-DD")==this.minDate.format("YYYY-MM-DD")&&n[x][b].isBefore(this.minDate)&&"left"==i&&(n[x][b]=this.minDate.clone()),this.maxDate&&n[x][b].format("YYYY-MM-DD")==this.maxDate.format("YYYY-MM-DD")&&n[x][b].isAfter(this.maxDate)&&"right"==i&&(n[x][b]=this.maxDate.clone());"left"==i?this.leftCalendar.calendar=n:this.rightCalendar.calendar=n;var _="left"==i?this.minDate:this.startDate,w=this.maxDate,k=("left"==i?this.startDate:this.endDate,this.locale.direction,'<table class="table-condensed">');k+="<thead>",k+="<tr>",(this.showWeekNumbers||this.showISOWeekNumbers)&&(k+="<th></th>"),_&&!_.isBefore(n.firstDay)||this.linkedCalendars&&"left"!=i?k+="<th></th>":k+='<th class="prev available"><span></span></th>';var M=this.locale.monthNames[n[1][1].month()]+n[1][1].format(" YYYY");if(this.showDropdowns){for(var S=n[1][1].month(),A=n[1][1].year(),L=w&&w.year()||this.maxYear,T=_&&_.year()||this.minYear,C=A==T,D=A==L,E='<select class="monthselect">',O=0;O<12;O++)(!C||_&&O>=_.month())&&(!D||w&&O<=w.month())?E+="<option value='"+O+"'"+(O===S?" selected='selected'":"")+">"+this.locale.monthNames[O]+"</option>":E+="<option value='"+O+"'"+(O===S?" selected='selected'":"")+" disabled='disabled'>"+this.locale.monthNames[O]+"</option>";E+="</select>";for(var P='<select class="yearselect">',Y=T;Y<=L;Y++)P+='<option value="'+Y+'"'+(Y===A?' selected="selected"':"")+">"+Y+"</option>";M=E+(P+="</select>")}if(k+='<th colspan="5" class="month">'+M+"</th>",w&&!w.isAfter(n.lastDay)||this.linkedCalendars&&"right"!=i&&!this.singleDatePicker?k+="<th></th>":k+='<th class="next available"><span></span></th>',k+="</tr>",k+="<tr>",(this.showWeekNumbers||this.showISOWeekNumbers)&&(k+='<th class="week">'+this.locale.weekLabel+"</th>"),t.each(this.locale.daysOfWeek,(function(e,t){k+="<th>"+t+"</th>"})),k+="</tr>",k+="</thead>",k+="<tbody>",null==this.endDate&&this.maxSpan){var I=this.startDate.clone().add(this.maxSpan).endOf("day");w&&!I.isBefore(w)||(w=I)}for(x=0;x<6;x++){k+="<tr>",this.showWeekNumbers?k+='<td class="week">'+n[x][0].week()+"</td>":this.showISOWeekNumbers&&(k+='<td class="week">'+n[x][0].isoWeek()+"</td>");for(b=0;b<7;b++){var N=[];n[x][b].isSame(new Date,"day")&&N.push("today"),n[x][b].isoWeekday()>5&&N.push("weekend"),n[x][b].month()!=n[1][1].month()&&N.push("off","ends"),this.minDate&&n[x][b].isBefore(this.minDate,"day")&&N.push("off","disabled"),w&&n[x][b].isAfter(w,"day")&&N.push("off","disabled"),this.isInvalidDate(n[x][b])&&N.push("off","disabled"),n[x][b].format("YYYY-MM-DD")==this.startDate.format("YYYY-MM-DD")&&N.push("active","start-date"),null!=this.endDate&&n[x][b].format("YYYY-MM-DD")==this.endDate.format("YYYY-MM-DD")&&N.push("active","end-date"),null!=this.endDate&&n[x][b]>this.startDate&&n[x][b]<this.endDate&&N.push("in-range");var j=this.isCustomDate(n[x][b]);!1!==j&&("string"==typeof j?N.push(j):Array.prototype.push.apply(N,j));var H="",F=!1;for(g=0;g<N.length;g++)H+=N[g]+" ","disabled"==N[g]&&(F=!0);F||(H+="available"),k+='<td class="'+H.replace(/^\s+|\s+$/g,"")+'" data-title="r'+x+"c"+b+'">'+n[x][b].date()+"</td>"}k+="</tr>"}k+="</tbody>",k+="</table>",this.container.find(".drp-calendar."+i+" .calendar-table").html(k)},renderTimePicker:function(e){if("right"!=e||this.endDate){var t,i,n,r=this.maxDate;if(!this.maxSpan||this.maxDate&&!this.startDate.clone().add(this.maxSpan).isBefore(this.maxDate)||(r=this.startDate.clone().add(this.maxSpan)),"left"==e)i=this.startDate.clone(),n=this.minDate;else if("right"==e){i=this.endDate.clone(),n=this.startDate;var a=this.container.find(".drp-calendar.right .calendar-time");if(""!=a.html()&&(i.hour(isNaN(i.hour())?a.find(".hourselect option:selected").val():i.hour()),i.minute(isNaN(i.minute())?a.find(".minuteselect option:selected").val():i.minute()),i.second(isNaN(i.second())?a.find(".secondselect option:selected").val():i.second()),!this.timePicker24Hour)){var s=a.find(".ampmselect option:selected").val();"PM"===s&&i.hour()<12&&i.hour(i.hour()+12),"AM"===s&&12===i.hour()&&i.hour(0)}i.isBefore(this.startDate)&&(i=this.startDate.clone()),r&&i.isAfter(r)&&(i=r.clone())}t='<select class="hourselect">';for(var o=this.timePicker24Hour?0:1,l=this.timePicker24Hour?23:12,c=o;c<=l;c++){var u=c;this.timePicker24Hour||(u=i.hour()>=12?12==c?12:c+12:12==c?0:c);var d=i.clone().hour(u),h=!1;n&&d.minute(59).isBefore(n)&&(h=!0),r&&d.minute(0).isAfter(r)&&(h=!0),u!=i.hour()||h?t+=h?'<option value="'+c+'" disabled="disabled" class="disabled">'+c+"</option>":'<option value="'+c+'">'+c+"</option>":t+='<option value="'+c+'" selected="selected">'+c+"</option>"}t+="</select> ",t+=': <select class="minuteselect">';for(c=0;c<60;c+=this.timePickerIncrement){var f=c<10?"0"+c:c;d=i.clone().minute(c),h=!1;n&&d.second(59).isBefore(n)&&(h=!0),r&&d.second(0).isAfter(r)&&(h=!0),i.minute()!=c||h?t+=h?'<option value="'+c+'" disabled="disabled" class="disabled">'+f+"</option>":'<option value="'+c+'">'+f+"</option>":t+='<option value="'+c+'" selected="selected">'+f+"</option>"}if(t+="</select> ",this.timePickerSeconds){t+=': <select class="secondselect">';for(c=0;c<60;c++){f=c<10?"0"+c:c,d=i.clone().second(c),h=!1;n&&d.isBefore(n)&&(h=!0),r&&d.isAfter(r)&&(h=!0),i.second()!=c||h?t+=h?'<option value="'+c+'" disabled="disabled" class="disabled">'+f+"</option>":'<option value="'+c+'">'+f+"</option>":t+='<option value="'+c+'" selected="selected">'+f+"</option>"}t+="</select> "}if(!this.timePicker24Hour){t+='<select class="ampmselect">';var p="",m="";n&&i.clone().hour(12).minute(0).second(0).isBefore(n)&&(p=' disabled="disabled" class="disabled"'),r&&i.clone().hour(0).minute(0).second(0).isAfter(r)&&(m=' disabled="disabled" class="disabled"'),i.hour()>=12?t+='<option value="AM"'+p+'>AM</option><option value="PM" selected="selected"'+m+">PM</option>":t+='<option value="AM" selected="selected"'+p+'>AM</option><option value="PM"'+m+">PM</option>",t+="</select>"}this.container.find(".drp-calendar."+e+" .calendar-time").html(t)}},updateFormInputs:function(){this.singleDatePicker||this.endDate&&(this.startDate.isBefore(this.endDate)||this.startDate.isSame(this.endDate))?this.container.find("button.applyBtn").prop("disabled",!1):this.container.find("button.applyBtn").prop("disabled",!0)},move:function(){var e,i={top:0,left:0},n=this.drops,r=t(window).width();switch(this.parentEl.is("body")||(i={top:this.parentEl.offset().top-this.parentEl.scrollTop(),left:this.parentEl.offset().left-this.parentEl.scrollLeft()},r=this.parentEl[0].clientWidth+this.parentEl.offset().left),n){case"auto":(e=this.element.offset().top+this.element.outerHeight()-i.top)+this.container.outerHeight()>=this.parentEl[0].scrollHeight&&(e=this.element.offset().top-this.container.outerHeight()-i.top,n="up");break;case"up":e=this.element.offset().top-this.container.outerHeight()-i.top;break;default:e=this.element.offset().top+this.element.outerHeight()-i.top}this.container.css({top:0,left:0,right:"auto"});var a=this.container.outerWidth();if(this.container.toggleClass("drop-up","up"==n),"left"==this.opens){var s=r-this.element.offset().left-this.element.outerWidth();a+s>t(window).width()?this.container.css({top:e,right:"auto",left:9}):this.container.css({top:e,right:s,left:"auto"})}else if("center"==this.opens){(o=this.element.offset().left-i.left+this.element.outerWidth()/2-a/2)<0?this.container.css({top:e,right:"auto",left:9}):o+a>t(window).width()?this.container.css({top:e,left:"auto",right:0}):this.container.css({top:e,left:o,right:"auto"})}else{var o;(o=this.element.offset().left-i.left)+a>t(window).width()?this.container.css({top:e,left:"auto",right:0}):this.container.css({top:e,left:o,right:"auto"})}},show:function(e){this.isShowing||(this._outsideClickProxy=t.proxy((function(e){this.outsideClick(e)}),this),t(document).on("mousedown.daterangepicker",this._outsideClickProxy).on("touchend.daterangepicker",this._outsideClickProxy).on("click.daterangepicker","[data-toggle=dropdown]",this._outsideClickProxy).on("focusin.daterangepicker",this._outsideClickProxy),t(window).on("resize.daterangepicker",t.proxy((function(e){this.move(e)}),this)),this.oldStartDate=this.startDate.clone(),this.oldEndDate=this.endDate.clone(),this.previousRightTime=this.endDate.clone(),this.updateView(),this.container.show(),this.move(),this.element.trigger("show.daterangepicker",this),this.isShowing=!0)},hide:function(e){this.isShowing&&(this.endDate||(this.startDate=this.oldStartDate.clone(),this.endDate=this.oldEndDate.clone()),this.startDate.isSame(this.oldStartDate)&&this.endDate.isSame(this.oldEndDate)||this.callback(this.startDate.clone(),this.endDate.clone(),this.chosenLabel),this.updateElement(),t(document).off(".daterangepicker"),t(window).off(".daterangepicker"),this.container.hide(),this.element.trigger("hide.daterangepicker",this),this.isShowing=!1)},toggle:function(e){this.isShowing?this.hide():this.show()},outsideClick:function(e){var i=t(e.target);"focusin"==e.type||i.closest(this.element).length||i.closest(this.container).length||i.closest(".calendar-table").length||(this.hide(),this.element.trigger("outsideClick.daterangepicker",this))},showCalendars:function(){this.container.addClass("show-calendar"),this.move(),this.element.trigger("showCalendar.daterangepicker",this)},hideCalendars:function(){this.container.removeClass("show-calendar"),this.element.trigger("hideCalendar.daterangepicker",this)},clickRange:function(e){var t=e.target.getAttribute("data-range-key");if(this.chosenLabel=t,t==this.locale.customRangeLabel)this.showCalendars();else{var i=this.ranges[t];this.startDate=i[0],this.endDate=i[1],this.timePicker||(this.startDate.startOf("day"),this.endDate.endOf("day")),this.alwaysShowCalendars||this.hideCalendars(),this.clickApply()}},clickPrev:function(e){t(e.target).parents(".drp-calendar").hasClass("left")?(this.leftCalendar.month.subtract(1,"month"),this.linkedCalendars&&this.rightCalendar.month.subtract(1,"month")):this.rightCalendar.month.subtract(1,"month"),this.updateCalendars()},clickNext:function(e){t(e.target).parents(".drp-calendar").hasClass("left")?this.leftCalendar.month.add(1,"month"):(this.rightCalendar.month.add(1,"month"),this.linkedCalendars&&this.leftCalendar.month.add(1,"month")),this.updateCalendars()},hoverDate:function(e){if(t(e.target).hasClass("available")){var i=t(e.target).attr("data-title"),n=i.substr(1,1),r=i.substr(3,1),a=t(e.target).parents(".drp-calendar").hasClass("left")?this.leftCalendar.calendar[n][r]:this.rightCalendar.calendar[n][r],s=this.leftCalendar,o=this.rightCalendar,l=this.startDate;this.endDate||this.container.find(".drp-calendar tbody td").each((function(e,i){if(!t(i).hasClass("week")){var n=t(i).attr("data-title"),r=n.substr(1,1),c=n.substr(3,1),u=t(i).parents(".drp-calendar").hasClass("left")?s.calendar[r][c]:o.calendar[r][c];u.isAfter(l)&&u.isBefore(a)||u.isSame(a,"day")?t(i).addClass("in-range"):t(i).removeClass("in-range")}}))}},clickDate:function(e){if(t(e.target).hasClass("available")){var i=t(e.target).attr("data-title"),n=i.substr(1,1),r=i.substr(3,1),a=t(e.target).parents(".drp-calendar").hasClass("left")?this.leftCalendar.calendar[n][r]:this.rightCalendar.calendar[n][r];if(this.endDate||a.isBefore(this.startDate,"day")){if(this.timePicker){var s=parseInt(this.container.find(".left .hourselect").val(),10);if(!this.timePicker24Hour)"PM"===(c=this.container.find(".left .ampmselect").val())&&s<12&&(s+=12),"AM"===c&&12===s&&(s=0);var o=parseInt(this.container.find(".left .minuteselect").val(),10);isNaN(o)&&(o=parseInt(this.container.find(".left .minuteselect option:last").val(),10));var l=this.timePickerSeconds?parseInt(this.container.find(".left .secondselect").val(),10):0;a=a.clone().hour(s).minute(o).second(l)}this.endDate=null,this.setStartDate(a.clone())}else if(!this.endDate&&a.isBefore(this.startDate))this.setEndDate(this.startDate.clone());else{if(this.timePicker){var c;s=parseInt(this.container.find(".right .hourselect").val(),10);if(!this.timePicker24Hour)"PM"===(c=this.container.find(".right .ampmselect").val())&&s<12&&(s+=12),"AM"===c&&12===s&&(s=0);o=parseInt(this.container.find(".right .minuteselect").val(),10);isNaN(o)&&(o=parseInt(this.container.find(".right .minuteselect option:last").val(),10));l=this.timePickerSeconds?parseInt(this.container.find(".right .secondselect").val(),10):0;a=a.clone().hour(s).minute(o).second(l)}this.setEndDate(a.clone()),this.autoApply&&(this.calculateChosenLabel(),this.clickApply())}this.singleDatePicker&&(this.setEndDate(this.startDate),!this.timePicker&&this.autoApply&&this.clickApply()),this.updateView(),e.stopPropagation()}},calculateChosenLabel:function(){var e=!0,t=0;for(var i in this.ranges){if(this.timePicker){var n=this.timePickerSeconds?"YYYY-MM-DD HH:mm:ss":"YYYY-MM-DD HH:mm";if(this.startDate.format(n)==this.ranges[i][0].format(n)&&this.endDate.format(n)==this.ranges[i][1].format(n)){e=!1,this.chosenLabel=this.container.find(".ranges li:eq("+t+")").addClass("active").attr("data-range-key");break}}else if(this.startDate.format("YYYY-MM-DD")==this.ranges[i][0].format("YYYY-MM-DD")&&this.endDate.format("YYYY-MM-DD")==this.ranges[i][1].format("YYYY-MM-DD")){e=!1,this.chosenLabel=this.container.find(".ranges li:eq("+t+")").addClass("active").attr("data-range-key");break}t++}e&&(this.showCustomRangeLabel?this.chosenLabel=this.container.find(".ranges li:last").addClass("active").attr("data-range-key"):this.chosenLabel=null,this.showCalendars())},clickApply:function(e){this.hide(),this.element.trigger("apply.daterangepicker",this)},clickCancel:function(e){this.startDate=this.oldStartDate,this.endDate=this.oldEndDate,this.hide(),this.element.trigger("cancel.daterangepicker",this)},monthOrYearChanged:function(e){var i=t(e.target).closest(".drp-calendar").hasClass("left"),n=i?"left":"right",r=this.container.find(".drp-calendar."+n),a=parseInt(r.find(".monthselect").val(),10),s=r.find(".yearselect").val();i||(s<this.startDate.year()||s==this.startDate.year()&&a<this.startDate.month())&&(a=this.startDate.month(),s=this.startDate.year()),this.minDate&&(s<this.minDate.year()||s==this.minDate.year()&&a<this.minDate.month())&&(a=this.minDate.month(),s=this.minDate.year()),this.maxDate&&(s>this.maxDate.year()||s==this.maxDate.year()&&a>this.maxDate.month())&&(a=this.maxDate.month(),s=this.maxDate.year()),i?(this.leftCalendar.month.month(a).year(s),this.linkedCalendars&&(this.rightCalendar.month=this.leftCalendar.month.clone().add(1,"month"))):(this.rightCalendar.month.month(a).year(s),this.linkedCalendars&&(this.leftCalendar.month=this.rightCalendar.month.clone().subtract(1,"month"))),this.updateCalendars()},timeChanged:function(e){var i=t(e.target).closest(".drp-calendar"),n=i.hasClass("left"),r=parseInt(i.find(".hourselect").val(),10),a=parseInt(i.find(".minuteselect").val(),10);isNaN(a)&&(a=parseInt(i.find(".minuteselect option:last").val(),10));var s=this.timePickerSeconds?parseInt(i.find(".secondselect").val(),10):0;if(!this.timePicker24Hour){var o=i.find(".ampmselect").val();"PM"===o&&r<12&&(r+=12),"AM"===o&&12===r&&(r=0)}if(n){var l=this.startDate.clone();l.hour(r),l.minute(a),l.second(s),this.setStartDate(l),this.singleDatePicker?this.endDate=this.startDate.clone():this.endDate&&this.endDate.format("YYYY-MM-DD")==l.format("YYYY-MM-DD")&&this.endDate.isBefore(l)&&this.setEndDate(l.clone())}else if(this.endDate){var c=this.endDate.clone();c.hour(r),c.minute(a),c.second(s),this.setEndDate(c)}this.updateCalendars(),this.updateFormInputs(),this.renderTimePicker("left"),this.renderTimePicker("right")},elementChanged:function(){if(this.element.is("input")&&this.element.val().length){var t=this.element.val().split(this.locale.separator),i=null,n=null;2===t.length&&(i=e(t[0],this.locale.format),n=e(t[1],this.locale.format)),(this.singleDatePicker||null===i||null===n)&&(n=i=e(this.element.val(),this.locale.format)),i.isValid()&&n.isValid()&&(this.setStartDate(i),this.setEndDate(n),this.updateView())}},keydown:function(e){9!==e.keyCode&&13!==e.keyCode||this.hide(),27===e.keyCode&&(e.preventDefault(),e.stopPropagation(),this.hide())},updateElement:function(){if(this.element.is("input")&&this.autoUpdateInput){var e=this.startDate.format(this.locale.format);this.singleDatePicker||(e+=this.locale.separator+this.endDate.format(this.locale.format)),e!==this.element.val()&&this.element.val(e).trigger("change")}},remove:function(){this.container.remove(),this.element.off(".daterangepicker"),this.element.removeData()}},t.fn.daterangepicker=function(e,n){var r=t.extend(!0,{},t.fn.daterangepicker.defaultOptions,e);return this.each((function(){var e=t(this);e.data("daterangepicker")&&e.data("daterangepicker").remove(),e.data("daterangepicker",new i(e,r,n))})),this},i})),function(e,t){if("object"==typeof exports&&"object"==typeof module)module.exports=t();else if("function"==typeof define&&define.amd)define([],t);else{var i=t();for(var n in i)("object"==typeof exports?exports:e)[n]=i[n]}}("undefined"!=typeof self?self:this,(function(){return function(){"use strict";var e={3976:function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0,t.default={_maxTestPos:500,placeholder:"_",optionalmarker:["[","]"],quantifiermarker:["{","}"],groupmarker:["(",")"],alternatormarker:"|",escapeChar:"\\",mask:null,regex:null,oncomplete:function(){},onincomplete:function(){},oncleared:function(){},repeat:0,greedy:!1,autoUnmask:!1,removeMaskOnSubmit:!1,clearMaskOnLostFocus:!0,insertMode:!0,insertModeVisual:!0,clearIncomplete:!1,alias:null,onKeyDown:function(){},onBeforeMask:null,onBeforePaste:function(e,t){return"function"==typeof t.onBeforeMask?t.onBeforeMask.call(this,e,t):e},onBeforeWrite:null,onUnMask:null,showMaskOnFocus:!0,showMaskOnHover:!0,onKeyValidation:function(){},skipOptionalPartCharacter:" ",numericInput:!1,rightAlign:!1,undoOnEscape:!0,radixPoint:"",_radixDance:!1,groupSeparator:"",keepStatic:null,positionCaretOnTab:!0,tabThrough:!1,supportsInputType:["text","tel","url","password","search"],isComplete:null,preValidation:null,postValidation:null,staticDefinitionSymbol:void 0,jitMasking:!1,nullable:!0,inputEventOnly:!1,noValuePatching:!1,positionCaretOnClick:"lvp",casing:null,inputmode:"text",importDataAttributes:!0,shiftPositions:!0,usePrototypeDefinitions:!0,validationEventTimeOut:3e3,substitutes:{}}},7392:function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0,t.default={9:{validator:"[0-9０-９]",definitionSymbol:"*"},a:{validator:"[A-Za-zА-яЁёÀ-ÿµ]",definitionSymbol:"*"},"*":{validator:"[0-9０-９A-Za-zА-яЁёÀ-ÿµ]"}}},253:function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,i){if(void 0===i)return e.__data?e.__data[t]:null;e.__data=e.__data||{},e.__data[t]=i}},3776:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.Event=void 0,t.off=function(e,t){var i,n;return u(this[0])&&e&&(i=this[0].eventRegistry,n=this[0],e.split(" ").forEach((function(e){var r=s(e.split("."),2);(function(e,n){var r,a,s=[];if(e.length>0)if(void 0===t)for(r=0,a=i[e][n].length;r<a;r++)s.push({ev:e,namespace:n&&n.length>0?n:"global",handler:i[e][n][r]});else s.push({ev:e,namespace:n&&n.length>0?n:"global",handler:t});else if(n.length>0)for(var o in i)for(var l in i[o])if(l===n)if(void 0===t)for(r=0,a=i[o][l].length;r<a;r++)s.push({ev:o,namespace:l,handler:i[o][l][r]});else s.push({ev:o,namespace:l,handler:t});return s})(r[0],r[1]).forEach((function(e){var t=e.ev,r=e.handler;!function(e,t,r){if(e in i==1)if(n.removeEventListener?n.removeEventListener(e,r,!1):n.detachEvent&&n.detachEvent("on".concat(e),r),"global"===t)for(var a in i[e])i[e][a].splice(i[e][a].indexOf(r),1);else i[e][t].splice(i[e][t].indexOf(r),1)}(t,e.namespace,r)}))}))),this},t.on=function(e,t){if(u(this[0])){var i=this[0].eventRegistry,n=this[0];e.split(" ").forEach((function(e){var r=s(e.split("."),2),a=r[0],o=r[1];!function(e,r){n.addEventListener?n.addEventListener(e,t,!1):n.attachEvent&&n.attachEvent("on".concat(e),t),i[e]=i[e]||{},i[e][r]=i[e][r]||[],i[e][r].push(t)}(a,void 0===o?"global":o)}))}return this},t.trigger=function(e){var t=arguments;if(u(this[0]))for(var i=this[0].eventRegistry,n=this[0],s="string"==typeof e?e.split(" "):[e.type],o=0;o<s.length;o++){var l=s[o].split("."),d=l[0],h=l[1]||"global";if(void 0!==c&&"global"===h){var f,p={bubbles:!0,cancelable:!0,composed:!0,detail:arguments[1]};if(c.createEvent){try{"input"===d?(p.inputType="insertText",f=new InputEvent(d,p)):f=new CustomEvent(d,p)}catch(e){(f=c.createEvent("CustomEvent")).initCustomEvent(d,p.bubbles,p.cancelable,p.detail)}e.type&&(0,r.default)(f,e),n.dispatchEvent(f)}else(f=c.createEventObject()).eventType=d,f.detail=arguments[1],e.type&&(0,r.default)(f,e),n.fireEvent("on"+f.eventType,f)}else if(void 0!==i[d]){arguments[0]=arguments[0].type?arguments[0]:a.default.Event(arguments[0]),arguments[0].detail=arguments.slice(1);var m=i[d];("global"===h?Object.values(m).flat():m[h]).forEach((function(e){return e.apply(n,t)}))}}return this};var n=l(i(9380)),r=l(i(600)),a=l(i(4963));function s(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var i=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=i){var n,r,a,s,o=[],l=!0,c=!1;try{if(a=(i=i.call(e)).next,0===t){if(Object(i)!==i)return;l=!1}else for(;!(l=(n=a.call(i)).done)&&(o.push(n.value),o.length!==t);l=!0);}catch(e){c=!0,r=e}finally{try{if(!l&&null!=i.return&&(s=i.return(),Object(s)!==s))return}finally{if(c)throw r}}return o}}(e,t)||function(e,t){if(e){if("string"==typeof e)return o(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?o(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function o(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function l(e){return e&&e.__esModule?e:{default:e}}var c=n.default.document;function u(e){return e instanceof Element}var d=t.Event=void 0;"function"==typeof n.default.CustomEvent?t.Event=d=n.default.CustomEvent:n.default.Event&&c&&c.createEvent?(t.Event=d=function(e,t){t=t||{bubbles:!1,cancelable:!1,composed:!0,detail:void 0};var i=c.createEvent("CustomEvent");return i.initCustomEvent(e,t.bubbles,t.cancelable,t.detail),i},d.prototype=n.default.Event.prototype):"undefined"!=typeof Event&&(t.Event=d=Event)},600:function(e,t){function i(e){return i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},i(e)}Object.defineProperty(t,"__esModule",{value:!0}),t.default=function e(){var t,n,r,a,s,o,l=arguments[0]||{},c=1,u=arguments.length,d=!1;for("boolean"==typeof l&&(d=l,l=arguments[c]||{},c++),"object"!==i(l)&&"function"!=typeof l&&(l={});c<u;c++)if(null!=(t=arguments[c]))for(n in t)r=l[n],l!==(a=t[n])&&(d&&a&&("[object Object]"===Object.prototype.toString.call(a)||(s=Array.isArray(a)))?(s?(s=!1,o=r&&Array.isArray(r)?r:[]):o=r&&"[object Object]"===Object.prototype.toString.call(r)?r:{},l[n]=e(d,o,a)):void 0!==a&&(l[n]=a));return l}},4963:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n=o(i(9380)),r=o(i(253)),a=i(3776),s=o(i(600));function o(e){return e&&e.__esModule?e:{default:e}}var l=n.default.document;function c(e){return e instanceof c?e:this instanceof c?void(null!=e&&e!==n.default&&(this[0]=e.nodeName?e:void 0!==e[0]&&e[0].nodeName?e[0]:l.querySelector(e),void 0!==this[0]&&null!==this[0]&&(this[0].eventRegistry=this[0].eventRegistry||{}))):new c(e)}c.prototype={on:a.on,off:a.off,trigger:a.trigger},c.extend=s.default,c.data=r.default,c.Event=a.Event,t.default=c},9845:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.mobile=t.iphone=t.ie=void 0;var n,r=(n=i(9380))&&n.__esModule?n:{default:n},a=r.default.navigator&&r.default.navigator.userAgent||"";t.ie=a.indexOf("MSIE ")>0||a.indexOf("Trident/")>0,t.mobile=r.default.navigator&&r.default.navigator.userAgentData&&r.default.navigator.userAgentData.mobile||r.default.navigator&&r.default.navigator.maxTouchPoints||"ontouchstart"in r.default,t.iphone=/iphone/i.test(a)},7184:function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e){return e.replace(i,"\\$1")};var i=new RegExp("(\\"+["/",".","*","+","?","|","(",")","[","]","{","}","\\","$","^"].join("|\\")+")","gim")},6030:function(e,t,i){function n(e){return n="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},n(e)}Object.defineProperty(t,"__esModule",{value:!0}),t.EventHandlers=void 0;var r,a=i(9845),s=(r=i(9380))&&r.__esModule?r:{default:r},o=i(7760),l=i(2839),c=i(8711),u=i(7215),d=i(4713);function h(){
/*! regenerator-runtime -- Copyright (c) 2014-present, Facebook, Inc. -- license (MIT): https://github.com/facebook/regenerator/blob/main/LICENSE */h=function(){return t};var e,t={},i=Object.prototype,r=i.hasOwnProperty,a=Object.defineProperty||function(e,t,i){e[t]=i.value},s="function"==typeof Symbol?Symbol:{},o=s.iterator||"@@iterator",l=s.asyncIterator||"@@asyncIterator",c=s.toStringTag||"@@toStringTag";function u(e,t,i){return Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}),e[t]}try{u({},"")}catch(e){u=function(e,t,i){return e[t]=i}}function d(e,t,i,n){var r=t&&t.prototype instanceof b?t:b,s=Object.create(r.prototype),o=new O(n||[]);return a(s,"_invoke",{value:T(e,i,o)}),s}function f(e,t,i){try{return{type:"normal",arg:e.call(t,i)}}catch(e){return{type:"throw",arg:e}}}t.wrap=d;var p="suspendedStart",m="suspendedYield",g="executing",v="completed",y={};function b(){}function x(){}function _(){}var w={};u(w,o,(function(){return this}));var k=Object.getPrototypeOf,M=k&&k(k(P([])));M&&M!==i&&r.call(M,o)&&(w=M);var S=_.prototype=b.prototype=Object.create(w);function A(e){["next","throw","return"].forEach((function(t){u(e,t,(function(e){return this._invoke(t,e)}))}))}function L(e,t){function i(a,s,o,l){var c=f(e[a],e,s);if("throw"!==c.type){var u=c.arg,d=u.value;return d&&"object"==n(d)&&r.call(d,"__await")?t.resolve(d.__await).then((function(e){i("next",e,o,l)}),(function(e){i("throw",e,o,l)})):t.resolve(d).then((function(e){u.value=e,o(u)}),(function(e){return i("throw",e,o,l)}))}l(c.arg)}var s;a(this,"_invoke",{value:function(e,n){function r(){return new t((function(t,r){i(e,n,t,r)}))}return s=s?s.then(r,r):r()}})}function T(t,i,n){var r=p;return function(a,s){if(r===g)throw new Error("Generator is already running");if(r===v){if("throw"===a)throw s;return{value:e,done:!0}}for(n.method=a,n.arg=s;;){var o=n.delegate;if(o){var l=C(o,n);if(l){if(l===y)continue;return l}}if("next"===n.method)n.sent=n._sent=n.arg;else if("throw"===n.method){if(r===p)throw r=v,n.arg;n.dispatchException(n.arg)}else"return"===n.method&&n.abrupt("return",n.arg);r=g;var c=f(t,i,n);if("normal"===c.type){if(r=n.done?v:m,c.arg===y)continue;return{value:c.arg,done:n.done}}"throw"===c.type&&(r=v,n.method="throw",n.arg=c.arg)}}}function C(t,i){var n=i.method,r=t.iterator[n];if(r===e)return i.delegate=null,"throw"===n&&t.iterator.return&&(i.method="return",i.arg=e,C(t,i),"throw"===i.method)||"return"!==n&&(i.method="throw",i.arg=new TypeError("The iterator does not provide a '"+n+"' method")),y;var a=f(r,t.iterator,i.arg);if("throw"===a.type)return i.method="throw",i.arg=a.arg,i.delegate=null,y;var s=a.arg;return s?s.done?(i[t.resultName]=s.value,i.next=t.nextLoc,"return"!==i.method&&(i.method="next",i.arg=e),i.delegate=null,y):s:(i.method="throw",i.arg=new TypeError("iterator result is not an object"),i.delegate=null,y)}function D(e){var t={tryLoc:e[0]};1 in e&&(t.catchLoc=e[1]),2 in e&&(t.finallyLoc=e[2],t.afterLoc=e[3]),this.tryEntries.push(t)}function E(e){var t=e.completion||{};t.type="normal",delete t.arg,e.completion=t}function O(e){this.tryEntries=[{tryLoc:"root"}],e.forEach(D,this),this.reset(!0)}function P(t){if(t||""===t){var i=t[o];if(i)return i.call(t);if("function"==typeof t.next)return t;if(!isNaN(t.length)){var a=-1,s=function i(){for(;++a<t.length;)if(r.call(t,a))return i.value=t[a],i.done=!1,i;return i.value=e,i.done=!0,i};return s.next=s}}throw new TypeError(n(t)+" is not iterable")}return x.prototype=_,a(S,"constructor",{value:_,configurable:!0}),a(_,"constructor",{value:x,configurable:!0}),x.displayName=u(_,c,"GeneratorFunction"),t.isGeneratorFunction=function(e){var t="function"==typeof e&&e.constructor;return!!t&&(t===x||"GeneratorFunction"===(t.displayName||t.name))},t.mark=function(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,_):(e.__proto__=_,u(e,c,"GeneratorFunction")),e.prototype=Object.create(S),e},t.awrap=function(e){return{__await:e}},A(L.prototype),u(L.prototype,l,(function(){return this})),t.AsyncIterator=L,t.async=function(e,i,n,r,a){void 0===a&&(a=Promise);var s=new L(d(e,i,n,r),a);return t.isGeneratorFunction(i)?s:s.next().then((function(e){return e.done?e.value:s.next()}))},A(S),u(S,c,"Generator"),u(S,o,(function(){return this})),u(S,"toString",(function(){return"[object Generator]"})),t.keys=function(e){var t=Object(e),i=[];for(var n in t)i.push(n);return i.reverse(),function e(){for(;i.length;){var n=i.pop();if(n in t)return e.value=n,e.done=!1,e}return e.done=!0,e}},t.values=P,O.prototype={constructor:O,reset:function(t){if(this.prev=0,this.next=0,this.sent=this._sent=e,this.done=!1,this.delegate=null,this.method="next",this.arg=e,this.tryEntries.forEach(E),!t)for(var i in this)"t"===i.charAt(0)&&r.call(this,i)&&!isNaN(+i.slice(1))&&(this[i]=e)},stop:function(){this.done=!0;var e=this.tryEntries[0].completion;if("throw"===e.type)throw e.arg;return this.rval},dispatchException:function(t){if(this.done)throw t;var i=this;function n(n,r){return o.type="throw",o.arg=t,i.next=n,r&&(i.method="next",i.arg=e),!!r}for(var a=this.tryEntries.length-1;a>=0;--a){var s=this.tryEntries[a],o=s.completion;if("root"===s.tryLoc)return n("end");if(s.tryLoc<=this.prev){var l=r.call(s,"catchLoc"),c=r.call(s,"finallyLoc");if(l&&c){if(this.prev<s.catchLoc)return n(s.catchLoc,!0);if(this.prev<s.finallyLoc)return n(s.finallyLoc)}else if(l){if(this.prev<s.catchLoc)return n(s.catchLoc,!0)}else{if(!c)throw new Error("try statement without catch or finally");if(this.prev<s.finallyLoc)return n(s.finallyLoc)}}}},abrupt:function(e,t){for(var i=this.tryEntries.length-1;i>=0;--i){var n=this.tryEntries[i];if(n.tryLoc<=this.prev&&r.call(n,"finallyLoc")&&this.prev<n.finallyLoc){var a=n;break}}a&&("break"===e||"continue"===e)&&a.tryLoc<=t&&t<=a.finallyLoc&&(a=null);var s=a?a.completion:{};return s.type=e,s.arg=t,a?(this.method="next",this.next=a.finallyLoc,y):this.complete(s)},complete:function(e,t){if("throw"===e.type)throw e.arg;return"break"===e.type||"continue"===e.type?this.next=e.arg:"return"===e.type?(this.rval=this.arg=e.arg,this.method="return",this.next="end"):"normal"===e.type&&t&&(this.next=t),y},finish:function(e){for(var t=this.tryEntries.length-1;t>=0;--t){var i=this.tryEntries[t];if(i.finallyLoc===e)return this.complete(i.completion,i.afterLoc),E(i),y}},catch:function(e){for(var t=this.tryEntries.length-1;t>=0;--t){var i=this.tryEntries[t];if(i.tryLoc===e){var n=i.completion;if("throw"===n.type){var r=n.arg;E(i)}return r}}throw new Error("illegal catch attempt")},delegateYield:function(t,i,n){return this.delegate={iterator:P(t),resultName:i,nextLoc:n},"next"===this.method&&(this.arg=e),y}},t}function f(e,t){var i="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!i){if(Array.isArray(e)||(i=function(e,t){if(e){if("string"==typeof e)return p(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?p(e,t):void 0}}(e))||t&&e&&"number"==typeof e.length){i&&(e=i);var n=0,r=function(){};return{s:r,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,s=!0,o=!1;return{s:function(){i=i.call(e)},n:function(){var e=i.next();return s=e.done,e},e:function(e){o=!0,a=e},f:function(){try{s||null==i.return||i.return()}finally{if(o)throw a}}}}function p(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function m(e,t,i,n,r,a,s){try{var o=e[a](s),l=o.value}catch(e){return void i(e)}o.done?t(l):Promise.resolve(l).then(n,r)}var g,v,y=t.EventHandlers={keyEvent:function(e,t,i,n,r){var s=this.inputmask,h=s.opts,f=s.dependencyLib,p=s.maskset,m=this,g=f(m),v=e.key,b=c.caret.call(s,m),x=h.onKeyDown.call(this,e,c.getBuffer.call(s),b,h);if(void 0!==x)return x;if(v===l.keys.Backspace||v===l.keys.Delete||a.iphone&&v===l.keys.BACKSPACE_SAFARI||e.ctrlKey&&v===l.keys.x&&!("oncut"in m))e.preventDefault(),u.handleRemove.call(s,m,v,b),(0,o.writeBuffer)(m,c.getBuffer.call(s,!0),p.p,e,m.inputmask._valueGet()!==c.getBuffer.call(s).join(""));else if(v===l.keys.End||v===l.keys.PageDown){e.preventDefault();var _=c.seekNext.call(s,c.getLastValidPosition.call(s));c.caret.call(s,m,e.shiftKey?b.begin:_,_,!0)}else v===l.keys.Home&&!e.shiftKey||v===l.keys.PageUp?(e.preventDefault(),c.caret.call(s,m,0,e.shiftKey?b.begin:0,!0)):h.undoOnEscape&&v===l.keys.Escape&&!0!==e.altKey?((0,o.checkVal)(m,!0,!1,s.undoValue.split("")),g.trigger("click")):v!==l.keys.Insert||e.shiftKey||e.ctrlKey||void 0!==s.userOptions.insertMode?!0===h.tabThrough&&v===l.keys.Tab?!0===e.shiftKey?(b.end=c.seekPrevious.call(s,b.end,!0),!0===d.getTest.call(s,b.end-1).match.static&&b.end--,b.begin=c.seekPrevious.call(s,b.end,!0),b.begin>=0&&b.end>0&&(e.preventDefault(),c.caret.call(s,m,b.begin,b.end))):(b.begin=c.seekNext.call(s,b.begin,!0),b.end=c.seekNext.call(s,b.begin,!0),b.end<p.maskLength&&b.end--,b.begin<=p.maskLength&&(e.preventDefault(),c.caret.call(s,m,b.begin,b.end))):e.shiftKey||(h.insertModeVisual&&!1===h.insertMode?v===l.keys.ArrowRight?setTimeout((function(){var e=c.caret.call(s,m);c.caret.call(s,m,e.begin)}),0):v===l.keys.ArrowLeft&&setTimeout((function(){var e=c.translatePosition.call(s,m.inputmask.caretPos.begin);c.translatePosition.call(s,m.inputmask.caretPos.end),s.isRTL?c.caret.call(s,m,e+(e===p.maskLength?0:1)):c.caret.call(s,m,e-(0===e?0:1))}),0):void 0===s.keyEventHook||s.keyEventHook(e)):u.isSelection.call(s,b)?h.insertMode=!h.insertMode:(h.insertMode=!h.insertMode,c.caret.call(s,m,b.begin,b.begin));return s.isComposing=v==l.keys.Process||v==l.keys.Unidentified,s.ignorable=v.length>1&&!("textarea"===m.tagName.toLowerCase()&&v==l.keys.Enter),y.keypressEvent.call(this,e,t,i,n,r)},keypressEvent:function(e,t,i,n,r){var a=this.inputmask||this,s=a.opts,d=a.dependencyLib,h=a.maskset,f=a.el,p=d(f),m=e.key;if(!0===t||e.ctrlKey&&e.altKey&&!a.ignorable||!(e.ctrlKey||e.metaKey||a.ignorable)){if(m){var g,v=t?{begin:r,end:r}:c.caret.call(a,f);t||(m=s.substitutes[m]||m),h.writeOutBuffer=!0;var y=u.isValid.call(a,v,m,n,void 0,void 0,void 0,t);if(!1!==y&&(c.resetMaskSet.call(a,!0),g=void 0!==y.caret?y.caret:c.seekNext.call(a,y.pos.begin?y.pos.begin:y.pos),h.p=g),g=s.numericInput&&void 0===y.caret?c.seekPrevious.call(a,g):g,!1!==i&&(setTimeout((function(){s.onKeyValidation.call(f,m,y)}),0),h.writeOutBuffer&&!1!==y)){var b=c.getBuffer.call(a);(0,o.writeBuffer)(f,b,g,e,!0!==t)}if(e.preventDefault(),t)return!1!==y&&(y.forwardPosition=g),y}}else m===l.keys.Enter&&a.undoValue!==a._valueGet(!0)&&(a.undoValue=a._valueGet(!0),setTimeout((function(){p.trigger("change")}),0))},pasteEvent:(g=h().mark((function e(t){var i,n,r,a,l,u;return h().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:i=function(e,i,n,r,s){var l=c.caret.call(e,i,void 0,void 0,!0),u=n.substr(0,l.begin),d=n.substr(l.end,n.length);if(u==(e.isRTL?c.getBufferTemplate.call(e).slice().reverse():c.getBufferTemplate.call(e)).slice(0,l.begin).join("")&&(u=""),d==(e.isRTL?c.getBufferTemplate.call(e).slice().reverse():c.getBufferTemplate.call(e)).slice(l.end).join("")&&(d=""),r=u+r+d,e.isRTL&&!0!==a.numericInput){r=r.split("");var h,p=f(c.getBufferTemplate.call(e));try{for(p.s();!(h=p.n()).done;){var m=h.value;r[0]===m&&r.shift()}}catch(e){p.e(e)}finally{p.f()}r=r.reverse().join("")}var g=r;if("function"==typeof s){if(!1===(g=s.call(e,g,a)))return!1;g||(g=n)}(0,o.checkVal)(i,!0,!1,g.toString().split(""),t)},n=this,r=this.inputmask,a=r.opts,l=r._valueGet(!0),r.skipInputEvent=!0,t.clipboardData&&t.clipboardData.getData?u=t.clipboardData.getData("text/plain"):s.default.clipboardData&&s.default.clipboardData.getData&&(u=s.default.clipboardData.getData("Text")),i(r,n,l,u,a.onBeforePaste),t.preventDefault();case 7:case"end":return e.stop()}}),e,this)})),v=function(){var e=this,t=arguments;return new Promise((function(i,n){var r=g.apply(e,t);function a(e){m(r,i,n,a,s,"next",e)}function s(e){m(r,i,n,a,s,"throw",e)}a(void 0)}))},function(e){return v.apply(this,arguments)}),inputFallBackEvent:function(e){var t,i=this.inputmask,n=i.opts,r=i.dependencyLib,s=this,u=s.inputmask._valueGet(!0),h=(i.isRTL?c.getBuffer.call(i).slice().reverse():c.getBuffer.call(i)).join(""),f=c.caret.call(i,s,void 0,void 0,!0);if(h!==u){if(t=function(e,t,r){for(var a,s,o,l=e.substr(0,r.begin).split(""),u=e.substr(r.begin).split(""),h=t.substr(0,r.begin).split(""),f=t.substr(r.begin).split(""),p=l.length>=h.length?l.length:h.length,m=u.length>=f.length?u.length:f.length,g="",v=[],y="~";l.length<p;)l.push(y);for(;h.length<p;)h.push(y);for(;u.length<m;)u.unshift(y);for(;f.length<m;)f.unshift(y);var b=l.concat(u),x=h.concat(f);for(s=0,a=b.length;s<a;s++)switch(o=d.getPlaceholder.call(i,c.translatePosition.call(i,s)),g){case"insertText":x[s-1]===b[s]&&r.begin==b.length-1&&v.push(b[s]),s=a;break;case"insertReplacementText":case"deleteContentBackward":b[s]===y?r.end++:s=a;break;default:b[s]!==x[s]&&(b[s+1]!==y&&b[s+1]!==o&&void 0!==b[s+1]||(x[s]!==o||x[s+1]!==y)&&x[s]!==y?x[s+1]===y&&x[s]===b[s+1]?(g="insertText",v.push(b[s]),r.begin--,r.end--):b[s]!==o&&b[s]!==y&&(b[s+1]===y||x[s]!==b[s]&&x[s+1]===b[s+1])?(g="insertReplacementText",v.push(b[s]),r.begin--):b[s]===y?(g="deleteContentBackward",(c.isMask.call(i,c.translatePosition.call(i,s),!0)||x[s]===n.radixPoint)&&r.end++):s=a:(g="insertText",v.push(b[s]),r.begin--,r.end--))}return{action:g,data:v,caret:r}}(u,h,f),(s.inputmask.shadowRoot||s.ownerDocument).activeElement!==s&&s.focus(),(0,o.writeBuffer)(s,c.getBuffer.call(i)),c.caret.call(i,s,f.begin,f.end,!0),!a.mobile&&i.skipNextInsert&&"insertText"===e.inputType&&"insertText"===t.action&&i.isComposing)return!1;switch("insertCompositionText"===e.inputType&&"insertText"===t.action&&i.isComposing?i.skipNextInsert=!0:i.skipNextInsert=!1,t.action){case"insertText":case"insertReplacementText":t.data.forEach((function(e,t){var n=new r.Event("keypress");n.key=e,i.ignorable=!1,y.keypressEvent.call(s,n)})),setTimeout((function(){i.$el.trigger("keyup")}),0);break;case"deleteContentBackward":var p=new r.Event("keydown");p.key=l.keys.Backspace,y.keyEvent.call(s,p);break;default:(0,o.applyInputValue)(s,u),c.caret.call(i,s,f.begin,f.end,!0)}e.preventDefault()}},setValueEvent:function(e){var t=this.inputmask,i=t.dependencyLib,n=this,r=e&&e.detail?e.detail[0]:arguments[1];void 0===r&&(r=n.inputmask._valueGet(!0)),(0,o.applyInputValue)(n,r,new i.Event("input")),(e.detail&&void 0!==e.detail[1]||void 0!==arguments[2])&&c.caret.call(t,n,e.detail?e.detail[1]:arguments[2])},focusEvent:function(e){var t=this.inputmask,i=t.opts,n=t&&t._valueGet();i.showMaskOnFocus&&n!==c.getBuffer.call(t).join("")&&(0,o.writeBuffer)(this,c.getBuffer.call(t),c.seekNext.call(t,c.getLastValidPosition.call(t))),!0!==i.positionCaretOnTab||!1!==t.mouseEnter||u.isComplete.call(t,c.getBuffer.call(t))&&-1!==c.getLastValidPosition.call(t)||y.clickEvent.apply(this,[e,!0]),t.undoValue=t&&t._valueGet(!0)},invalidEvent:function(e){this.inputmask.validationEvent=!0},mouseleaveEvent:function(){var e=this.inputmask,t=e.opts,i=this;e.mouseEnter=!1,t.clearMaskOnLostFocus&&(i.inputmask.shadowRoot||i.ownerDocument).activeElement!==i&&(0,o.HandleNativePlaceholder)(i,e.originalPlaceholder)},clickEvent:function(e,t){var i=this.inputmask;i.clicked++;var n=this;if((n.inputmask.shadowRoot||n.ownerDocument).activeElement===n){var r=c.determineNewCaretPosition.call(i,c.caret.call(i,n),t);void 0!==r&&c.caret.call(i,n,r)}},cutEvent:function(e){var t=this.inputmask,i=t.maskset,n=this,r=c.caret.call(t,n),a=t.isRTL?c.getBuffer.call(t).slice(r.end,r.begin):c.getBuffer.call(t).slice(r.begin,r.end),d=t.isRTL?a.reverse().join(""):a.join("");s.default.navigator&&s.default.navigator.clipboard?s.default.navigator.clipboard.writeText(d):s.default.clipboardData&&s.default.clipboardData.getData&&s.default.clipboardData.setData("Text",d),u.handleRemove.call(t,n,l.keys.Delete,r),(0,o.writeBuffer)(n,c.getBuffer.call(t),i.p,e,t.undoValue!==t._valueGet(!0))},blurEvent:function(e){var t=this.inputmask,i=t.opts,n=t.dependencyLib;t.clicked=0;var r=n(this),a=this;if(a.inputmask){(0,o.HandleNativePlaceholder)(a,t.originalPlaceholder);var s=a.inputmask._valueGet(),l=c.getBuffer.call(t).slice();""!==s&&(i.clearMaskOnLostFocus&&(-1===c.getLastValidPosition.call(t)&&s===c.getBufferTemplate.call(t).join("")?l=[]:o.clearOptionalTail.call(t,l)),!1===u.isComplete.call(t,l)&&(setTimeout((function(){r.trigger("incomplete")}),0),i.clearIncomplete&&(c.resetMaskSet.call(t,!1),l=i.clearMaskOnLostFocus?[]:c.getBufferTemplate.call(t).slice())),(0,o.writeBuffer)(a,l,void 0,e)),s=t._valueGet(!0),t.undoValue!==s&&(""!=s||t.undoValue!=c.getBufferTemplate.call(t).join("")||t.undoValue==c.getBufferTemplate.call(t).join("")&&t.maskset.validPositions.length>0)&&(t.undoValue=s,r.trigger("change"))}},mouseenterEvent:function(){var e=this.inputmask,t=e.opts.showMaskOnHover,i=this;if(e.mouseEnter=!0,(i.inputmask.shadowRoot||i.ownerDocument).activeElement!==i){var n=(e.isRTL?c.getBufferTemplate.call(e).slice().reverse():c.getBufferTemplate.call(e)).join("");t&&(0,o.HandleNativePlaceholder)(i,n)}},submitEvent:function(){var e=this.inputmask,t=e.opts;e.undoValue!==e._valueGet(!0)&&e.$el.trigger("change"),-1===c.getLastValidPosition.call(e)&&e._valueGet&&e._valueGet()===c.getBufferTemplate.call(e).join("")&&e._valueSet(""),t.clearIncomplete&&!1===u.isComplete.call(e,c.getBuffer.call(e))&&e._valueSet(""),t.removeMaskOnSubmit&&(e._valueSet(e.unmaskedvalue(),!0),setTimeout((function(){(0,o.writeBuffer)(e.el,c.getBuffer.call(e))}),0))},resetEvent:function(){var e=this.inputmask;e.refreshValue=!0,setTimeout((function(){(0,o.applyInputValue)(e.el,e._valueGet(!0))}),0)}}},9716:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.EventRuler=void 0;var n,r=i(7760),a=(n=i(2394))&&n.__esModule?n:{default:n},s=i(2839),o=i(8711);t.EventRuler={on:function(e,t,i){var n=e.inputmask.dependencyLib,l=function(t){t.originalEvent&&(t=t.originalEvent||t,arguments[0]=t);var l,c=this,u=c.inputmask,d=u?u.opts:void 0;if(void 0===u&&"FORM"!==this.nodeName){var h=n.data(c,"_inputmask_opts");n(c).off(),h&&new a.default(h).mask(c)}else{if(["submit","reset","setvalue"].includes(t.type)||"FORM"===this.nodeName||!(c.disabled||c.readOnly&&!("keydown"===t.type&&t.ctrlKey&&t.key===s.keys.c||!1===d.tabThrough&&t.key===s.keys.Tab))){switch(t.type){case"input":if(!0===u.skipInputEvent)return u.skipInputEvent=!1,t.preventDefault();break;case"click":case"focus":return u.validationEvent?(u.validationEvent=!1,e.blur(),(0,r.HandleNativePlaceholder)(e,(u.isRTL?o.getBufferTemplate.call(u).slice().reverse():o.getBufferTemplate.call(u)).join("")),setTimeout((function(){e.focus()}),d.validationEventTimeOut),!1):(l=arguments,void setTimeout((function(){e.inputmask&&i.apply(c,l)}),0))}var f=i.apply(c,arguments);return!1===f&&(t.preventDefault(),t.stopPropagation()),f}t.preventDefault()}};["submit","reset"].includes(t)?(l=l.bind(e),null!==e.form&&n(e.form).on(t,l)):n(e).on(t,l),e.inputmask.events[t]=e.inputmask.events[t]||[],e.inputmask.events[t].push(l)},off:function(e,t){if(e.inputmask&&e.inputmask.events){var i=e.inputmask.dependencyLib,n=e.inputmask.events;for(var r in t&&((n=[])[t]=e.inputmask.events[t]),n){for(var a=n[r];a.length>0;){var s=a.pop();["submit","reset"].includes(r)?null!==e.form&&i(e.form).off(r,s):i(e).off(r,s)}delete e.inputmask.events[r]}}}}},219:function(e,t,i){var n=d(i(7184)),r=d(i(2394)),a=i(2839),s=i(8711),o=i(4713);function l(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function c(e){return c="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},c(e)}function u(e,t){for(var i=0;i<t.length;i++){var n=t[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,(void 0,r=function(e,t){if("object"!==c(e)||null===e)return e;var i=e[Symbol.toPrimitive];if(void 0!==i){var n=i.call(e,"string");if("object"!==c(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(n.key),"symbol"===c(r)?r:String(r)),n)}var r}function d(e){return e&&e.__esModule?e:{default:e}}i(1313);var h=r.default.dependencyLib,f=function(){function e(t,i,n,r){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.mask=t,this.format=i,this.opts=n,this.inputmask=r,this._date=new Date(1,0,1),this.initDateObject(t,this.opts,this.inputmask)}var t,i;return t=e,(i=[{key:"date",get:function(){return void 0===this._date&&(this._date=new Date(1,0,1),this.initDateObject(void 0,this.opts,this.inputmask)),this._date}},{key:"initDateObject",value:function(e,t,i){var n;for(w(t).lastIndex=0;n=w(t).exec(this.format);){var r=/\d+$/.exec(n[0]),a=r?n[0][0]+"x":n[0],s=void 0;if(void 0!==e){if(r){var l=w(t).lastIndex,c=T.call(i,n.index,t,i&&i.maskset);w(t).lastIndex=l,s=e.slice(0,e.indexOf(c.nextMatch[0]))}else{for(var u=n[0][0],d=n.index;i&&(t.placeholder[o.getTest.call(i,d).match.placeholder]||o.getTest.call(i,d).match.placeholder)===u;)d++;var h=d-n.index;s=e.slice(0,h||v[a]&&v[a][4]||a.length)}e=e.slice(s.length)}Object.prototype.hasOwnProperty.call(v,a)&&this.setValue(this,s,a,v[a][2],v[a][1])}}},{key:"setValue",value:function(e,t,i,n,r){if(void 0!==t)switch(n){case"ampm":e[n]=t,e["raw"+n]=t.replace(/\s/g,"_");break;case"month":if("mmm"===i||"mmmm"===i){e[n]=S("mmm"===i?m.monthNames.slice(0,12).findIndex((function(e){return t.toLowerCase()===e.toLowerCase()}))+1:m.monthNames.slice(12,24).findIndex((function(e){return t.toLowerCase()===e.toLowerCase()}))+1,2),e[n]="00"===e[n]?"":e[n].toString(),e["raw"+n]=e[n];break}default:e[n]=t.replace(/[^0-9]/g,"0"),e["raw"+n]=t.replace(/\s/g,"_")}if(void 0!==r){var a=e[n];("day"===n&&29===parseInt(a)||"month"===n&&2===parseInt(a))&&(29!==parseInt(e.day)||2!==parseInt(e.month)||""!==e.year&&void 0!==e.year||e._date.setFullYear(2012,1,29)),"day"===n&&(g=!0,0===parseInt(a)&&(a=1)),"month"===n&&(g=!0),"year"===n&&(g=!0,a.length<v[i][4]&&(a=S(a,v[i][4],!0))),(""!==a&&!isNaN(a)||"ampm"===n)&&r.call(e._date,a)}}},{key:"reset",value:function(){this._date=new Date(1,0,1)}},{key:"reInit",value:function(){this._date=void 0,this.date}}])&&u(t.prototype,i),Object.defineProperty(t,"prototype",{writable:!1}),e}(),p=(new Date).getFullYear(),m=r.default.prototype.i18n,g=!1,v={d:["[1-9]|[12][0-9]|3[01]",Date.prototype.setDate,"day",Date.prototype.getDate],dd:["0[1-9]|[12][0-9]|3[01]",Date.prototype.setDate,"day",function(){return S(Date.prototype.getDate.call(this),2)}],ddd:[""],dddd:[""],m:["[1-9]|1[012]",function(e){var t=e?parseInt(e):0;return t>0&&t--,Date.prototype.setMonth.call(this,t)},"month",function(){return Date.prototype.getMonth.call(this)+1}],mm:["0[1-9]|1[012]",function(e){var t=e?parseInt(e):0;return t>0&&t--,Date.prototype.setMonth.call(this,t)},"month",function(){return S(Date.prototype.getMonth.call(this)+1,2)}],mmm:[m.monthNames.slice(0,12).join("|"),function(e){var t=m.monthNames.slice(0,12).findIndex((function(t){return e.toLowerCase()===t.toLowerCase()}));return-1!==t&&Date.prototype.setMonth.call(this,t)},"month",function(){return m.monthNames.slice(0,12)[Date.prototype.getMonth.call(this)]}],mmmm:[m.monthNames.slice(12,24).join("|"),function(e){var t=m.monthNames.slice(12,24).findIndex((function(t){return e.toLowerCase()===t.toLowerCase()}));return-1!==t&&Date.prototype.setMonth.call(this,t)},"month",function(){return m.monthNames.slice(12,24)[Date.prototype.getMonth.call(this)]}],yy:["[0-9]{2}",function(e){var t=(new Date).getFullYear().toString().slice(0,2);Date.prototype.setFullYear.call(this,"".concat(t).concat(e))},"year",function(){return S(Date.prototype.getFullYear.call(this),2)},2],yyyy:["[0-9]{4}",Date.prototype.setFullYear,"year",function(){return S(Date.prototype.getFullYear.call(this),4)},4],h:["[1-9]|1[0-2]",Date.prototype.setHours,"hours",Date.prototype.getHours],hh:["0[1-9]|1[0-2]",Date.prototype.setHours,"hours",function(){return S(Date.prototype.getHours.call(this),2)}],hx:[function(e){return"[0-9]{".concat(e,"}")},Date.prototype.setHours,"hours",function(e){return Date.prototype.getHours}],H:["1?[0-9]|2[0-3]",Date.prototype.setHours,"hours",Date.prototype.getHours],HH:["0[0-9]|1[0-9]|2[0-3]",Date.prototype.setHours,"hours",function(){return S(Date.prototype.getHours.call(this),2)}],Hx:[function(e){return"[0-9]{".concat(e,"}")},Date.prototype.setHours,"hours",function(e){return function(){return S(Date.prototype.getHours.call(this),e)}}],M:["[1-5]?[0-9]",Date.prototype.setMinutes,"minutes",Date.prototype.getMinutes],MM:["0[0-9]|1[0-9]|2[0-9]|3[0-9]|4[0-9]|5[0-9]",Date.prototype.setMinutes,"minutes",function(){return S(Date.prototype.getMinutes.call(this),2)}],s:["[1-5]?[0-9]",Date.prototype.setSeconds,"seconds",Date.prototype.getSeconds],ss:["0[0-9]|1[0-9]|2[0-9]|3[0-9]|4[0-9]|5[0-9]",Date.prototype.setSeconds,"seconds",function(){return S(Date.prototype.getSeconds.call(this),2)}],l:["[0-9]{3}",Date.prototype.setMilliseconds,"milliseconds",function(){return S(Date.prototype.getMilliseconds.call(this),3)},3],L:["[0-9]{2}",Date.prototype.setMilliseconds,"milliseconds",function(){return S(Date.prototype.getMilliseconds.call(this),2)},2],t:["[ap]",b,"ampm",x,1],tt:["[ap]m",b,"ampm",x,2],T:["[AP]",b,"ampm",x,1],TT:["[AP]M",b,"ampm",x,2],Z:[".*",void 0,"Z",function(){var e=this.toString().match(/\((.+)\)/)[1];return e.includes(" ")&&(e=(e=e.replace("-"," ").toUpperCase()).split(" ").map((function(e){return function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var i=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=i){var n,r,a,s,o=[],l=!0,c=!1;try{if(a=(i=i.call(e)).next,0===t){if(Object(i)!==i)return;l=!1}else for(;!(l=(n=a.call(i)).done)&&(o.push(n.value),o.length!==t);l=!0);}catch(e){c=!0,r=e}finally{try{if(!l&&null!=i.return&&(s=i.return(),Object(s)!==s))return}finally{if(c)throw r}}return o}}(e,t)||function(e,t){if(e){if("string"==typeof e)return l(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?l(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(e,1)[0]})).join("")),e}],o:[""],S:[""]},y={isoDate:"yyyy-mm-dd",isoTime:"HH:MM:ss",isoDateTime:"yyyy-mm-dd'T'HH:MM:ss",isoUtcDateTime:"UTC:yyyy-mm-dd'T'HH:MM:ss'Z'"};function b(e){var t=this.getHours();e.toLowerCase().includes("p")?this.setHours(t+12):e.toLowerCase().includes("a")&&t>=12&&this.setHours(t-12)}function x(){var e=this.getHours();return(e=e||12)>=12?"PM":"AM"}function _(e){var t=/\d+$/.exec(e[0]);if(t&&void 0!==t[0]){var i=v[e[0][0]+"x"].slice("");return i[0]=i[0](t[0]),i[3]=i[3](t[0]),i}if(v[e[0]])return v[e[0]]}function w(e){if(!e.tokenizer){var t=[],i=[];for(var n in v)if(/\.*x$/.test(n)){var r=n[0]+"\\d+";-1===i.indexOf(r)&&i.push(r)}else-1===t.indexOf(n[0])&&t.push(n[0]);e.tokenizer="("+(i.length>0?i.join("|")+"|":"")+t.join("+|")+")+?|.",e.tokenizer=new RegExp(e.tokenizer,"g")}return e.tokenizer}function k(e,t,i){if(!g)return!0;if(void 0===e.rawday||!isFinite(e.rawday)&&new Date(e.date.getFullYear(),isFinite(e.rawmonth)?e.month:e.date.getMonth()+1,0).getDate()>=e.day||"29"==e.day&&(!isFinite(e.rawyear)||void 0===e.rawyear||""===e.rawyear)||new Date(e.date.getFullYear(),isFinite(e.rawmonth)?e.month:e.date.getMonth()+1,0).getDate()>=e.day)return t;if("29"==e.day){var n=T.call(this,t.pos,i,this.maskset);if(n.targetMatch&&"yyyy"===n.targetMatch[0]&&t.pos-n.targetMatchIndex==2)return t.remove=t.pos+1,t}else if(2==e.date.getMonth()&&"30"==e.day&&void 0!==t.c)return e.day="03",e.date.setDate(3),e.date.setMonth(1),t.insert=[{pos:t.pos,c:"0"},{pos:t.pos+1,c:t.c}],t.caret=s.seekNext.call(this,t.pos+1),t;return!1}function M(e,t,i,r){var a,s,o="",l=0,c={};for(w(i).lastIndex=0;a=w(i).exec(e);){if(void 0===t)if(s=_(a))o+="("+s[0]+")",i.placeholder&&""!==i.placeholder?(c[l]=i.placeholder[a.index%i.placeholder.length],c[i.placeholder[a.index%i.placeholder.length]]=a[0].charAt(0)):c[l]=a[0].charAt(0);else switch(a[0]){case"[":o+="(";break;case"]":o+=")?";break;default:o+=(0,n.default)(a[0]),c[l]=a[0].charAt(0)}else(s=_(a))?!0!==r&&s[3]?o+=s[3].call(t.date):s[2]?o+=t["raw"+s[2]]:o+=a[0]:o+=a[0];l++}return void 0===t&&(i.placeholder=c),o}function S(e,t,i){for(e=String(e),t=t||2;e.length<t;)e=i?e+"0":"0"+e;return e}function A(e,t,i){return"string"==typeof e?new f(e,t,i,this):e&&"object"===c(e)&&Object.prototype.hasOwnProperty.call(e,"date")?e:void 0}function L(e,t){return M(t.inputFormat,{date:e},t)}function T(e,t,i){var n,r,a=this,s=i&&i.tests[e]?t.placeholder[i.tests[e][0].match.placeholder]||i.tests[e][0].match.placeholder:"",l=0,c=0;for(w(t).lastIndex=0;r=w(t).exec(t.inputFormat);){var u=/\d+$/.exec(r[0]);if(u)c=parseInt(u[0]);else{for(var d=r[0][0],h=l;a&&(t.placeholder[o.getTest.call(a,h).match.placeholder]||o.getTest.call(a,h).match.placeholder)===d;)h++;0==(c=h-l)&&(c=r[0].length)}if(l+=c,-1!=r[0].indexOf(s)||l>=e+1){n=r,r=w(t).exec(t.inputFormat);break}}return{targetMatchIndex:l-c,nextMatch:r,targetMatch:n}}r.default.extendAliases({datetime:{mask:function(e){return e.numericInput=!1,v.S=m.ordinalSuffix.join("|"),e.inputFormat=y[e.inputFormat]||e.inputFormat,e.displayFormat=y[e.displayFormat]||e.displayFormat||e.inputFormat,e.outputFormat=y[e.outputFormat]||e.outputFormat||e.inputFormat,e.regex=M(e.inputFormat,void 0,e),e.min=A(e.min,e.inputFormat,e),e.max=A(e.max,e.inputFormat,e),null},placeholder:"",inputFormat:"isoDateTime",displayFormat:null,outputFormat:null,min:null,max:null,skipOptionalPartCharacter:"",preValidation:function(e,t,i,n,r,a,s,o){if(o)return!0;if(isNaN(i)&&e[t]!==i){var l=T.call(this,t,r,a);if(l.nextMatch&&l.nextMatch[0]===i&&l.targetMatch[0].length>1){var c=_(l.targetMatch)[0];if(new RegExp(c).test("0"+e[t-1]))return e[t]=e[t-1],e[t-1]="0",{fuzzy:!0,buffer:e,refreshFromBuffer:{start:t-1,end:t+1},pos:t+1}}}return!0},postValidation:function(e,t,i,n,r,a,s,l){var c,u,d=this;if(s)return!0;if(!1===n&&(((c=T.call(d,t+1,r,a)).targetMatch&&c.targetMatchIndex===t&&c.targetMatch[0].length>1&&void 0!==v[c.targetMatch[0]]||(c=T.call(d,t+2,r,a)).targetMatch&&c.targetMatchIndex===t+1&&c.targetMatch[0].length>1&&void 0!==v[c.targetMatch[0]])&&(u=_(c.targetMatch)[0]),void 0!==u&&(void 0!==a.validPositions[t+1]&&new RegExp(u).test(i+"0")?(e[t]=i,e[t+1]="0",n={pos:t+2,caret:t}):new RegExp(u).test("0"+i)&&(e[t]="0",e[t+1]=i,n={pos:t+2})),!1===n))return n;if(n.fuzzy&&(e=n.buffer,t=n.pos),(c=T.call(d,t,r,a)).targetMatch&&c.targetMatch[0]&&void 0!==v[c.targetMatch[0]]){var h=_(c.targetMatch);u=h[0];var f=e.slice(c.targetMatchIndex,c.targetMatchIndex+c.targetMatch[0].length);if(!1===new RegExp(u).test(f.join(""))&&2===c.targetMatch[0].length&&a.validPositions[c.targetMatchIndex]&&a.validPositions[c.targetMatchIndex+1]&&(a.validPositions[c.targetMatchIndex+1].input="0"),"year"==h[2])for(var m=o.getMaskTemplate.call(d,!1,1,void 0,!0),g=t+1;g<e.length;g++)e[g]=m[g],a.validPositions.splice(t+1,1)}var y=n,b=A.call(d,e.join(""),r.inputFormat,r);return y&&!isNaN(b.date.getTime())&&(r.prefillYear&&(y=function(e,t,i){if(e.year!==e.rawyear){var n=p.toString(),r=e.rawyear.replace(/[^0-9]/g,""),a=n.slice(0,r.length),s=n.slice(r.length);if(2===r.length&&r===a){var o=new Date(p,e.month-1,e.day);e.day==o.getDate()&&(!i.max||i.max.date.getTime()>=o.getTime())&&(e.date.setFullYear(p),e.year=n,t.insert=[{pos:t.pos+1,c:s[0]},{pos:t.pos+2,c:s[1]}])}}return t}(b,y,r)),y=function(e,t,i,n,r){if(!t)return t;if(t&&i.min&&!isNaN(i.min.date.getTime())){var a;for(e.reset(),w(i).lastIndex=0;a=w(i).exec(i.inputFormat);){var s;if((s=_(a))&&s[3]){for(var o=s[1],l=e[s[2]],c=i.min[s[2]],u=i.max?i.max[s[2]]:c+1,d=[],h=!1,f=0;f<c.length;f++)void 0!==n.validPositions[f+a.index]||h?(d[f]=l[f],h=h||l[f]>c[f]):(f+a.index==0&&l[f]<c[f]?(d[f]=l[f],h=!0):d[f]=c[f],"year"===s[2]&&l.length-1==f&&c!=u&&(d=(parseInt(d.join(""))+1).toString().split("")),"ampm"===s[2]&&c!=u&&i.min.date.getTime()>e.date.getTime()&&(d[f]=u[f]));o.call(e._date,d.join(""))}}t=i.min.date.getTime()<=e.date.getTime(),e.reInit()}return t&&i.max&&(isNaN(i.max.date.getTime())||(t=i.max.date.getTime()>=e.date.getTime())),t}(b,y=k.call(d,b,y,r),r,a)),void 0!==t&&y&&n.pos!==t?{buffer:M(r.inputFormat,b,r).split(""),refreshFromBuffer:{start:t,end:n.pos},pos:n.caret||n.pos}:y},onKeyDown:function(e,t,i,n){e.ctrlKey&&e.key===a.keys.ArrowRight&&(this.inputmask._valueSet(L(new Date,n)),h(this).trigger("setvalue"))},onUnMask:function(e,t,i){return t?M(i.outputFormat,A.call(this,e,i.inputFormat,i),i,!0):t},casing:function(e,t,i,n){if(0==t.nativeDef.indexOf("[ap]"))return e.toLowerCase();if(0==t.nativeDef.indexOf("[AP]"))return e.toUpperCase();var r=o.getTest.call(this,[i-1]);return 0==r.match.def.indexOf("[AP]")||0===i||r&&r.input===String.fromCharCode(a.keyCode.Space)||r&&r.match.def===String.fromCharCode(a.keyCode.Space)?e.toUpperCase():e.toLowerCase()},onBeforeMask:function(e,t){return"[object Date]"===Object.prototype.toString.call(e)&&(e=L(e,t)),e},insertMode:!1,insertModeVisual:!1,shiftPositions:!1,keepStatic:!1,inputmode:"numeric",prefillYear:!0}})},1313:function(e,t,i){var n,r=(n=i(2394))&&n.__esModule?n:{default:n};r.default.dependencyLib.extend(!0,r.default.prototype.i18n,{dayNames:["Mon","Tue","Wed","Thu","Fri","Sat","Sun","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"],monthNames:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec","January","February","March","April","May","June","July","August","September","October","November","December"],ordinalSuffix:["st","nd","rd","th"]})},3851:function(e,t,i){var n,r=(n=i(2394))&&n.__esModule?n:{default:n},a=i(8711),s=i(4713);function o(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}r.default.extendDefinitions({A:{validator:"[A-Za-zА-яЁёÀ-ÿµ]",casing:"upper"},"&":{validator:"[0-9A-Za-zА-яЁёÀ-ÿµ]",casing:"upper"},"#":{validator:"[0-9A-Fa-f]",casing:"upper"}});var l=/25[0-5]|2[0-4][0-9]|[01][0-9][0-9]/;function c(e,t,i,n,r){if(i-1>-1&&"."!==t.buffer[i-1]?(e=t.buffer[i-1]+e,e=i-2>-1&&"."!==t.buffer[i-2]?t.buffer[i-2]+e:"0"+e):e="00"+e,r.greedy&&parseInt(e)>255&&l.test("00"+e.charAt(2))){var a=[].concat(function(e){return function(e){if(Array.isArray(e))return o(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return o(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?o(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(t.buffer.slice(0,i)),[".",e.charAt(2)]);if(a.join("").match(/\./g).length<4)return{refreshFromBuffer:!0,buffer:a,caret:i+2}}return l.test(e)}r.default.extendAliases({cssunit:{regex:"[+-]?[0-9]+\\.?([0-9]+)?(px|em|rem|ex|%|in|cm|mm|pt|pc)"},url:{regex:"(https?|ftp)://.*",autoUnmask:!1,keepStatic:!1,tabThrough:!0},ip:{mask:"i{1,3}.j{1,3}.k{1,3}.l{1,3}",definitions:{i:{validator:c},j:{validator:c},k:{validator:c},l:{validator:c}},onUnMask:function(e,t,i){return e},inputmode:"decimal",substitutes:{",":"."}},email:{mask:function(e){var t=e.separator,i=e.quantifier,n="*{1,64}[.*{1,64}][.*{1,64}][.*{1,63}]@-{1,63}.-{1,63}[.-{1,63}][.-{1,63}]",r=n;if(t)for(var a=0;a<i;a++)r+="[".concat(t).concat(n,"]");return r},greedy:!1,casing:"lower",separator:null,quantifier:5,skipOptionalPartCharacter:"",onBeforePaste:function(e,t){return(e=e.toLowerCase()).replace("mailto:","")},definitions:{"*":{validator:"[0-9１-９A-Za-zА-яЁёÀ-ÿµ!#$%&'*+/=?^_`{|}~-]"},"-":{validator:"[0-9A-Za-z-]"}},onUnMask:function(e,t,i){return e},inputmode:"email"},mac:{mask:"##:##:##:##:##:##"},vin:{mask:"V{13}9{4}",definitions:{V:{validator:"[A-HJ-NPR-Za-hj-npr-z\\d]",casing:"upper"}},clearIncomplete:!0,autoUnmask:!0},ssn:{mask:"999-99-9999",postValidation:function(e,t,i,n,r,o,l){var c=s.getMaskTemplate.call(this,!0,a.getLastValidPosition.call(this),!0,!0);return/^(?!219-09-9999|078-05-1120)(?!666|000|9.{2}).{3}-(?!00).{2}-(?!0{4}).{4}$/.test(c.join(""))}}})},207:function(e,t,i){var n=o(i(7184)),r=o(i(2394)),a=i(2839),s=i(8711);function o(e){return e&&e.__esModule?e:{default:e}}var l=r.default.dependencyLib;function c(e,t){for(var i="",n=0;n<e.length;n++)r.default.prototype.definitions[e.charAt(n)]||t.definitions[e.charAt(n)]||t.optionalmarker[0]===e.charAt(n)||t.optionalmarker[1]===e.charAt(n)||t.quantifiermarker[0]===e.charAt(n)||t.quantifiermarker[1]===e.charAt(n)||t.groupmarker[0]===e.charAt(n)||t.groupmarker[1]===e.charAt(n)||t.alternatormarker===e.charAt(n)?i+="\\"+e.charAt(n):i+=e.charAt(n);return i}function u(e,t,i,n){if(e.length>0&&t>0&&(!i.digitsOptional||n)){var r=e.indexOf(i.radixPoint),a=!1;i.negationSymbol.back===e[e.length-1]&&(a=!0,e.length--),-1===r&&(e.push(i.radixPoint),r=e.length-1);for(var s=1;s<=t;s++)isFinite(e[r+s])||(e[r+s]="0")}return a&&e.push(i.negationSymbol.back),e}function d(e,t){var i=0;for(var n in"+"===e&&(i=s.seekNext.call(this,t.validPositions.length-1)),t.tests)if((n=parseInt(n))>=i)for(var r=0,a=t.tests[n].length;r<a;r++)if((void 0===t.validPositions[n]||"-"===e)&&t.tests[n][r].match.def===e)return n+(void 0!==t.validPositions[n]&&"-"!==e?1:0);return i}function h(e,t){for(var i=-1,n=0,r=t.validPositions.length;n<r;n++){var a=t.validPositions[n];if(a&&a.match.def===e){i=n;break}}return i}function f(e,t,i,n,r){var a=t.buffer?t.buffer.indexOf(r.radixPoint):-1,s=(-1!==a||n&&r.jitMasking)&&new RegExp(r.definitions[9].validator).test(e);return!n&&r._radixDance&&-1!==a&&s&&null==t.validPositions[a]?{insert:{pos:a===i?a+1:a,c:r.radixPoint},pos:i}:s}r.default.extendAliases({numeric:{mask:function(e){e.repeat=0,e.groupSeparator===e.radixPoint&&e.digits&&"0"!==e.digits&&("."===e.radixPoint?e.groupSeparator=",":","===e.radixPoint?e.groupSeparator=".":e.groupSeparator="")," "===e.groupSeparator&&(e.skipOptionalPartCharacter=void 0),e.placeholder.length>1&&(e.placeholder=e.placeholder.charAt(0)),"radixFocus"===e.positionCaretOnClick&&""===e.placeholder&&(e.positionCaretOnClick="lvp");var t="0",i=e.radixPoint;!0===e.numericInput&&void 0===e.__financeInput?(t="1",e.positionCaretOnClick="radixFocus"===e.positionCaretOnClick?"lvp":e.positionCaretOnClick,e.digitsOptional=!1,isNaN(e.digits)&&(e.digits=2),e._radixDance=!1,i=","===e.radixPoint?"?":"!",""!==e.radixPoint&&void 0===e.definitions[i]&&(e.definitions[i]={},e.definitions[i].validator="["+e.radixPoint+"]",e.definitions[i].placeholder=e.radixPoint,e.definitions[i].static=!0,e.definitions[i].generated=!0)):(e.__financeInput=!1,e.numericInput=!0);var r,a="[+]";if(a+=c(e.prefix,e),""!==e.groupSeparator?(void 0===e.definitions[e.groupSeparator]&&(e.definitions[e.groupSeparator]={},e.definitions[e.groupSeparator].validator="["+e.groupSeparator+"]",e.definitions[e.groupSeparator].placeholder=e.groupSeparator,e.definitions[e.groupSeparator].static=!0,e.definitions[e.groupSeparator].generated=!0),a+=e._mask(e)):a+="9{+}",void 0!==e.digits&&0!==e.digits){var s=e.digits.toString().split(",");isFinite(s[0])&&s[1]&&isFinite(s[1])?a+=i+t+"{"+e.digits+"}":(isNaN(e.digits)||parseInt(e.digits)>0)&&(e.digitsOptional||e.jitMasking?(r=a+i+t+"{0,"+e.digits+"}",e.keepStatic=!0):a+=i+t+"{"+e.digits+"}")}else e.inputmode="numeric";return a+=c(e.suffix,e),a+="[-]",r&&(a=[r+c(e.suffix,e)+"[-]",a]),e.greedy=!1,function(e){void 0===e.parseMinMaxOptions&&(null!==e.min&&(e.min=e.min.toString().replace(new RegExp((0,n.default)(e.groupSeparator),"g"),""),","===e.radixPoint&&(e.min=e.min.replace(e.radixPoint,".")),e.min=isFinite(e.min)?parseFloat(e.min):NaN,isNaN(e.min)&&(e.min=Number.MIN_VALUE)),null!==e.max&&(e.max=e.max.toString().replace(new RegExp((0,n.default)(e.groupSeparator),"g"),""),","===e.radixPoint&&(e.max=e.max.replace(e.radixPoint,".")),e.max=isFinite(e.max)?parseFloat(e.max):NaN,isNaN(e.max)&&(e.max=Number.MAX_VALUE)),e.parseMinMaxOptions="done")}(e),""!==e.radixPoint&&e.substituteRadixPoint&&(e.substitutes["."==e.radixPoint?",":"."]=e.radixPoint),a},_mask:function(e){return"("+e.groupSeparator+"999){+|1}"},digits:"*",digitsOptional:!0,enforceDigitsOnBlur:!1,radixPoint:".",positionCaretOnClick:"radixFocus",_radixDance:!0,groupSeparator:"",allowMinus:!0,negationSymbol:{front:"-",back:""},prefix:"",suffix:"",min:null,max:null,SetMaxOnOverflow:!1,step:1,inputType:"text",unmaskAsNumber:!1,roundingFN:Math.round,inputmode:"decimal",shortcuts:{k:"1000",m:"1000000"},placeholder:"0",greedy:!1,rightAlign:!0,insertMode:!0,autoUnmask:!1,skipOptionalPartCharacter:"",usePrototypeDefinitions:!1,stripLeadingZeroes:!0,substituteRadixPoint:!0,definitions:{0:{validator:f},1:{validator:f,definitionSymbol:"9"},9:{validator:"[0-9０-９٠-٩۰-۹]",definitionSymbol:"*"},"+":{validator:function(e,t,i,n,r){return r.allowMinus&&("-"===e||e===r.negationSymbol.front)}},"-":{validator:function(e,t,i,n,r){return r.allowMinus&&e===r.negationSymbol.back}}},preValidation:function(e,t,i,n,r,a,s,o){var l=this;if(!1!==r.__financeInput&&i===r.radixPoint)return!1;var c=e.indexOf(r.radixPoint),u=t;if(t=function(e,t,i,n,r){return r._radixDance&&r.numericInput&&t!==r.negationSymbol.back&&e<=i&&(i>0||t==r.radixPoint)&&(void 0===n.validPositions[e-1]||n.validPositions[e-1].input!==r.negationSymbol.back)&&(e-=1),e}(t,i,c,a,r),"-"===i||i===r.negationSymbol.front){if(!0!==r.allowMinus)return!1;var f=!1,p=h("+",a),m=h("-",a);return-1!==p&&(f=[p],-1!==m&&f.push(m)),!1!==f?{remove:f,caret:u-r.negationSymbol.back.length}:{insert:[{pos:d.call(l,"+",a),c:r.negationSymbol.front,fromIsValid:!0},{pos:d.call(l,"-",a),c:r.negationSymbol.back,fromIsValid:void 0}],caret:u+r.negationSymbol.back.length}}if(i===r.groupSeparator)return{caret:u};if(o)return!0;if(-1!==c&&!0===r._radixDance&&!1===n&&i===r.radixPoint&&void 0!==r.digits&&(isNaN(r.digits)||parseInt(r.digits)>0)&&c!==t){var g=d.call(l,r.radixPoint,a);return a.validPositions[g]&&(a.validPositions[g].generatedInput=a.validPositions[g].generated||!1),{caret:r._radixDance&&t===c-1?c+1:c}}if(!1===r.__financeInput)if(n){if(r.digitsOptional)return{rewritePosition:s.end};if(!r.digitsOptional){if(s.begin>c&&s.end<=c)return i===r.radixPoint?{insert:{pos:c+1,c:"0",fromIsValid:!0},rewritePosition:c}:{rewritePosition:c+1};if(s.begin<c)return{rewritePosition:s.begin-1}}}else if(!r.showMaskOnHover&&!r.showMaskOnFocus&&!r.digitsOptional&&r.digits>0&&""===this.__valueGet.call(this.el))return{rewritePosition:c};return{rewritePosition:t}},postValidation:function(e,t,i,n,r,a,s){if(!1===n)return n;if(s)return!0;if(null!==r.min||null!==r.max){var o=r.onUnMask(e.slice().reverse().join(""),void 0,l.extend({},r,{unmaskAsNumber:!0}));if(null!==r.min&&o<r.min&&(o.toString().length>r.min.toString().length||o<0))return!1;if(null!==r.max&&o>r.max)return!!r.SetMaxOnOverflow&&{refreshFromBuffer:!0,buffer:u(r.max.toString().replace(".",r.radixPoint).split(""),r.digits,r).reverse()}}return n},onUnMask:function(e,t,i){if(""===t&&!0===i.nullable)return t;var r=e.replace(i.prefix,"");return r=(r=r.replace(i.suffix,"")).replace(new RegExp((0,n.default)(i.groupSeparator),"g"),""),""!==i.placeholder.charAt(0)&&(r=r.replace(new RegExp(i.placeholder.charAt(0),"g"),"0")),i.unmaskAsNumber?(""!==i.radixPoint&&-1!==r.indexOf(i.radixPoint)&&(r=r.replace(n.default.call(this,i.radixPoint),".")),r=(r=r.replace(new RegExp("^"+(0,n.default)(i.negationSymbol.front)),"-")).replace(new RegExp((0,n.default)(i.negationSymbol.back)+"$"),""),Number(r)):r},isComplete:function(e,t){var i=(t.numericInput?e.slice().reverse():e).join("");return i=(i=(i=(i=(i=i.replace(new RegExp("^"+(0,n.default)(t.negationSymbol.front)),"-")).replace(new RegExp((0,n.default)(t.negationSymbol.back)+"$"),"")).replace(t.prefix,"")).replace(t.suffix,"")).replace(new RegExp((0,n.default)(t.groupSeparator)+"([0-9]{3})","g"),"$1"),","===t.radixPoint&&(i=i.replace((0,n.default)(t.radixPoint),".")),isFinite(i)},onBeforeMask:function(e,t){var i;e=null!==(i=e)&&void 0!==i?i:"";var r=t.radixPoint||",";isFinite(t.digits)&&(t.digits=parseInt(t.digits)),"number"!=typeof e&&"number"!==t.inputType||""===r||(e=e.toString().replace(".",r));var a="-"===e.charAt(0)||e.charAt(0)===t.negationSymbol.front,s=e.split(r),o=s[0].replace(/[^\-0-9]/g,""),l=s.length>1?s[1].replace(/[^0-9]/g,""):"",c=s.length>1;e=o+(""!==l?r+l:l);var d=0;if(""!==r&&(d=t.digitsOptional?t.digits<l.length?t.digits:l.length:t.digits,""!==l||!t.digitsOptional)){var h=Math.pow(10,d||1);e=e.replace((0,n.default)(r),"."),isNaN(parseFloat(e))||(e=(t.roundingFN(parseFloat(e)*h)/h).toFixed(d)),e=e.toString().replace(".",r)}if(0===t.digits&&-1!==e.indexOf(r)&&(e=e.substring(0,e.indexOf(r))),null!==t.min||null!==t.max){var f=e.toString().replace(r,".");null!==t.min&&f<t.min?e=t.min.toString().replace(".",r):null!==t.max&&f>t.max&&(e=t.max.toString().replace(".",r))}return a&&"-"!==e.charAt(0)&&(e="-"+e),u(e.toString().split(""),d,t,c).join("")},onBeforeWrite:function(e,t,i,r){function a(e,t){if(!1!==r.__financeInput||t){var i=e.indexOf(r.radixPoint);-1!==i&&e.splice(i,1)}if(""!==r.groupSeparator)for(;-1!==(i=e.indexOf(r.groupSeparator));)e.splice(i,1);return e}var s,o;if(r.stripLeadingZeroes&&(o=function(e,t){var i=new RegExp("(^"+(""!==t.negationSymbol.front?(0,n.default)(t.negationSymbol.front)+"?":"")+(0,n.default)(t.prefix)+")(.*)("+(0,n.default)(t.suffix)+(""!=t.negationSymbol.back?(0,n.default)(t.negationSymbol.back)+"?":"")+"$)").exec(e.slice().reverse().join("")),r=i?i[2]:"",a=!1;return r&&(r=r.split(t.radixPoint.charAt(0))[0],a=new RegExp("^[0"+t.groupSeparator+"]*").exec(r)),!(!a||!(a[0].length>1||a[0].length>0&&a[0].length<r.length))&&a}(t,r)))for(var c=t.join("").lastIndexOf(o[0].split("").reverse().join(""))-(o[0]==o.input?0:1),d=o[0]==o.input?1:0,h=o[0].length-d;h>0;h--)this.maskset.validPositions.splice(c+h,1),delete t[c+h];if(e)switch(e.type){case"blur":case"checkval":if(null!==r.min){var f=r.onUnMask(t.slice().reverse().join(""),void 0,l.extend({},r,{unmaskAsNumber:!0}));if(null!==r.min&&f<r.min)return{refreshFromBuffer:!0,buffer:u(r.min.toString().replace(".",r.radixPoint).split(""),r.digits,r).reverse()}}if(t[t.length-1]===r.negationSymbol.front){var p=new RegExp("(^"+(""!=r.negationSymbol.front?(0,n.default)(r.negationSymbol.front)+"?":"")+(0,n.default)(r.prefix)+")(.*)("+(0,n.default)(r.suffix)+(""!=r.negationSymbol.back?(0,n.default)(r.negationSymbol.back)+"?":"")+"$)").exec(a(t.slice(),!0).reverse().join(""));0==(p?p[2]:"")&&(s={refreshFromBuffer:!0,buffer:[0]})}else""!==r.radixPoint&&t.indexOf(r.radixPoint)===r.suffix.length&&(s&&s.buffer?s.buffer.splice(0,1+r.suffix.length):(t.splice(0,1+r.suffix.length),s={refreshFromBuffer:!0,buffer:a(t)}));if(r.enforceDigitsOnBlur){var m=(s=s||{})&&s.buffer||t.slice().reverse();s.refreshFromBuffer=!0,s.buffer=u(m,r.digits,r,!0).reverse()}}return s},onKeyDown:function(e,t,i,n){var r,s=l(this);if(3!=e.location){var o,c=e.key;if((o=n.shortcuts&&n.shortcuts[c])&&o.length>1)return this.inputmask.__valueSet.call(this,parseFloat(this.inputmask.unmaskedvalue())*parseInt(o)),s.trigger("setvalue"),!1}if(e.ctrlKey)switch(e.key){case a.keys.ArrowUp:return this.inputmask.__valueSet.call(this,parseFloat(this.inputmask.unmaskedvalue())+parseInt(n.step)),s.trigger("setvalue"),!1;case a.keys.ArrowDown:return this.inputmask.__valueSet.call(this,parseFloat(this.inputmask.unmaskedvalue())-parseInt(n.step)),s.trigger("setvalue"),!1}if(!e.shiftKey&&(e.key===a.keys.Delete||e.key===a.keys.Backspace||e.key===a.keys.BACKSPACE_SAFARI)&&i.begin!==t.length){if(t[e.key===a.keys.Delete?i.begin-1:i.end]===n.negationSymbol.front)return r=t.slice().reverse(),""!==n.negationSymbol.front&&r.shift(),""!==n.negationSymbol.back&&r.pop(),s.trigger("setvalue",[r.join(""),i.begin]),!1;if(!0===n._radixDance){var d,h=t.indexOf(n.radixPoint);if(n.digitsOptional){if(0===h)return(r=t.slice().reverse()).pop(),s.trigger("setvalue",[r.join(""),i.begin>=r.length?r.length:i.begin]),!1}else if(-1!==h&&(i.begin<h||i.end<h||e.key===a.keys.Delete&&(i.begin===h||i.begin-1===h)))return i.begin===i.end&&(e.key===a.keys.Backspace||e.key===a.keys.BACKSPACE_SAFARI?i.begin++:e.key===a.keys.Delete&&i.begin-1===h&&(d=l.extend({},i),i.begin--,i.end--)),(r=t.slice().reverse()).splice(r.length-i.begin,i.begin-i.end+1),r=u(r,n.digits,n).join(""),d&&(i=d),s.trigger("setvalue",[r,i.begin>=r.length?h+1:i.begin]),!1}}}},currency:{prefix:"",groupSeparator:",",alias:"numeric",digits:2,digitsOptional:!1},decimal:{alias:"numeric"},integer:{alias:"numeric",inputmode:"numeric",digits:0},percentage:{alias:"numeric",min:0,max:100,suffix:" %",digits:0,allowMinus:!1},indianns:{alias:"numeric",_mask:function(e){return"("+e.groupSeparator+"99){*|1}("+e.groupSeparator+"999){1|1}"},groupSeparator:",",radixPoint:".",placeholder:"0",digits:2,digitsOptional:!1}})},9380:function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var i=!("undefined"==typeof window||!window.document||!window.document.createElement);t.default=i?window:{}},7760:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.HandleNativePlaceholder=function(e,t){var i=e?e.inputmask:this;if(n.ie){if(e.inputmask._valueGet()!==t&&(e.placeholder!==t||""===e.placeholder)){var r=s.getBuffer.call(i).slice(),a=e.inputmask._valueGet();if(a!==t){var o=s.getLastValidPosition.call(i);-1===o&&a===s.getBufferTemplate.call(i).join("")?r=[]:-1!==o&&u.call(i,r),h(e,r)}}}else e.placeholder!==t&&(e.placeholder=t,""===e.placeholder&&e.removeAttribute("placeholder"))},t.applyInputValue=c,t.checkVal=d,t.clearOptionalTail=u,t.unmaskedvalue=function(e){var t=e?e.inputmask:this,i=t.opts,n=t.maskset;if(e){if(void 0===e.inputmask)return e.value;e.inputmask&&e.inputmask.refreshValue&&c(e,e.inputmask._valueGet(!0))}for(var r=[],a=n.validPositions,o=0,l=a.length;o<l;o++)a[o]&&a[o].match&&(1!=a[o].match.static||Array.isArray(n.metadata)&&!0!==a[o].generatedInput)&&r.push(a[o].input);var u=0===r.length?"":(t.isRTL?r.reverse():r).join("");if("function"==typeof i.onUnMask){var d=(t.isRTL?s.getBuffer.call(t).slice().reverse():s.getBuffer.call(t)).join("");u=i.onUnMask.call(t,d,u,i)}return u},t.writeBuffer=h;var n=i(9845),r=i(6030),a=i(2839),s=i(8711),o=i(7215),l=i(4713);function c(e,t,i){var n=e?e.inputmask:this,r=n.opts;e.inputmask.refreshValue=!1,"function"==typeof r.onBeforeMask&&(t=r.onBeforeMask.call(n,t,r)||t),d(e,!0,!1,t=(t||"").toString().split(""),i),n.undoValue=n._valueGet(!0),(r.clearMaskOnLostFocus||r.clearIncomplete)&&e.inputmask._valueGet()===s.getBufferTemplate.call(n).join("")&&-1===s.getLastValidPosition.call(n)&&e.inputmask._valueSet("")}function u(e){e.length=0;for(var t,i=l.getMaskTemplate.call(this,!0,0,!0,void 0,!0);void 0!==(t=i.shift());)e.push(t);return e}function d(e,t,i,n,a){var c,u=e?e.inputmask:this,d=u.maskset,f=u.opts,p=u.dependencyLib,m=n.slice(),g="",v=-1,y=f.skipOptionalPartCharacter;f.skipOptionalPartCharacter="",s.resetMaskSet.call(u,!1),u.clicked=0,v=f.radixPoint?s.determineNewCaretPosition.call(u,{begin:0,end:0},!1,!1===f.__financeInput?"radixFocus":void 0).begin:0,d.p=v,u.caretPos={begin:v};var b=[],x=u.caretPos;if(m.forEach((function(e,t){if(void 0!==e){var n=new p.Event("_checkval");n.key=e,g+=e;var a=s.getLastValidPosition.call(u,void 0,!0);!function(e,t){for(var i=l.getMaskTemplate.call(u,!0,0).slice(e,s.seekNext.call(u,e,!1,!1)).join("").replace(/'/g,""),n=i.indexOf(t);n>0&&" "===i[n-1];)n--;var r=0===n&&!s.isMask.call(u,e)&&(l.getTest.call(u,e).match.nativeDef===t.charAt(0)||!0===l.getTest.call(u,e).match.static&&l.getTest.call(u,e).match.nativeDef==="'"+t.charAt(0)||" "===l.getTest.call(u,e).match.nativeDef&&(l.getTest.call(u,e+1).match.nativeDef===t.charAt(0)||!0===l.getTest.call(u,e+1).match.static&&l.getTest.call(u,e+1).match.nativeDef==="'"+t.charAt(0)));if(!r&&n>0&&!s.isMask.call(u,e,!1,!0)){var a=s.seekNext.call(u,e);u.caretPos.begin<a&&(u.caretPos={begin:a})}return r}(v,g)?(c=r.EventHandlers.keypressEvent.call(u,n,!0,!1,i,u.caretPos.begin))&&(v=u.caretPos.begin+1,g=""):c=r.EventHandlers.keypressEvent.call(u,n,!0,!1,i,a+1),c?(void 0!==c.pos&&d.validPositions[c.pos]&&!0===d.validPositions[c.pos].match.static&&void 0===d.validPositions[c.pos].alternation&&(b.push(c.pos),u.isRTL||(c.forwardPosition=c.pos+1)),h.call(u,void 0,s.getBuffer.call(u),c.forwardPosition,n,!1),u.caretPos={begin:c.forwardPosition,end:c.forwardPosition},x=u.caretPos):void 0===d.validPositions[t]&&m[t]===l.getPlaceholder.call(u,t)&&s.isMask.call(u,t,!0)?u.caretPos.begin++:u.caretPos=x}})),b.length>0){var _,w,k=s.seekNext.call(u,-1,void 0,!1);if(!o.isComplete.call(u,s.getBuffer.call(u))&&b.length<=k||o.isComplete.call(u,s.getBuffer.call(u))&&b.length>0&&b.length!==k&&0===b[0])for(var M=k;void 0!==(_=b.shift());)if(_<M){var S=new p.Event("_checkval");if((w=d.validPositions[_]).generatedInput=!0,S.key=w.input,(c=r.EventHandlers.keypressEvent.call(u,S,!0,!1,i,M))&&void 0!==c.pos&&c.pos!==_&&d.validPositions[c.pos]&&!0===d.validPositions[c.pos].match.static)b.push(c.pos);else if(!c)break;M++}}t&&h.call(u,e,s.getBuffer.call(u),c?c.forwardPosition:u.caretPos.begin,a||new p.Event("checkval"),a&&("input"===a.type&&u.undoValue!==s.getBuffer.call(u).join("")||"paste"===a.type)),f.skipOptionalPartCharacter=y}function h(e,t,i,n,r){var l=e?e.inputmask:this,c=l.opts,u=l.dependencyLib;if(n&&"function"==typeof c.onBeforeWrite){var d=c.onBeforeWrite.call(l,n,t,i,c);if(d){if(d.refreshFromBuffer){var h=d.refreshFromBuffer;o.refreshFromBuffer.call(l,!0===h?h:h.start,h.end,d.buffer||t),t=s.getBuffer.call(l,!0)}void 0!==i&&(i=void 0!==d.caret?d.caret:i)}}if(void 0!==e&&(e.inputmask._valueSet(t.join("")),void 0===i||void 0!==n&&"blur"===n.type||s.caret.call(l,e,i,void 0,void 0,void 0!==n&&"keydown"===n.type&&(n.key===a.keys.Delete||n.key===a.keys.Backspace)),void 0===e.inputmask.writeBufferHook||e.inputmask.writeBufferHook(i),!0===r)){var f=u(e),p=e.inputmask._valueGet();e.inputmask.skipInputEvent=!0,f.trigger("input"),setTimeout((function(){p===s.getBufferTemplate.call(l).join("")?f.trigger("cleared"):!0===o.isComplete.call(l,t)&&f.trigger("complete")}),0)}}},2394:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n=m(i(3976)),r=m(i(7392)),a=m(i(4963)),s=i(9716),o=m(i(9380)),l=i(7760),c=i(157),u=i(2391),d=i(8711),h=i(7215),f=i(4713);function p(e){return p="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},p(e)}function m(e){return e&&e.__esModule?e:{default:e}}var g=o.default.document,v="_inputmask_opts";function y(e,t,i){if(!(this instanceof y))return new y(e,t,i);this.dependencyLib=a.default,this.el=void 0,this.events={},this.maskset=void 0,!0!==i&&("[object Object]"===Object.prototype.toString.call(e)?t=e:(t=t||{},e&&(t.alias=e)),this.opts=a.default.extend(!0,{},this.defaults,t),this.noMasksCache=t&&void 0!==t.definitions,this.userOptions=t||{},b(this.opts.alias,t,this.opts)),this.refreshValue=!1,this.undoValue=void 0,this.$el=void 0,this.skipInputEvent=!1,this.validationEvent=!1,this.ignorable=!1,this.maxLength,this.mouseEnter=!1,this.clicked=0,this.originalPlaceholder=void 0,this.isComposing=!1,this.hasAlternator=!1}function b(e,t,i){var n=y.prototype.aliases[e];return n?(n.alias&&b(n.alias,void 0,i),a.default.extend(!0,i,n),a.default.extend(!0,i,t),!0):(null===i.mask&&(i.mask=e),!1)}y.prototype={dataAttribute:"data-inputmask",defaults:n.default,definitions:r.default,aliases:{},masksCache:{},i18n:{},get isRTL(){return this.opts.isRTL||this.opts.numericInput},mask:function(e){var t=this;return"string"==typeof e&&(e=g.getElementById(e)||g.querySelectorAll(e)),(e=e.nodeName?[e]:Array.isArray(e)?e:[].slice.call(e)).forEach((function(e,i){var n=a.default.extend(!0,{},t.opts);if(function(e,t,i,n){function r(t,r){var a=""===n?t:n+"-"+t;null!==(r=void 0!==r?r:e.getAttribute(a))&&("string"==typeof r&&(0===t.indexOf("on")?r=o.default[r]:"false"===r?r=!1:"true"===r&&(r=!0)),i[t]=r)}if(!0===t.importDataAttributes){var s,l,c,u,d=e.getAttribute(n);if(d&&""!==d&&(d=d.replace(/'/g,'"'),l=JSON.parse("{"+d+"}")),l)for(u in c=void 0,l)if("alias"===u.toLowerCase()){c=l[u];break}for(s in r("alias",c),i.alias&&b(i.alias,i,t),t){if(l)for(u in c=void 0,l)if(u.toLowerCase()===s.toLowerCase()){c=l[u];break}r(s,c)}}return a.default.extend(!0,t,i),("rtl"===e.dir||t.rightAlign)&&(e.style.textAlign="right"),("rtl"===e.dir||t.numericInput)&&(e.dir="ltr",e.removeAttribute("dir"),t.isRTL=!0),Object.keys(i).length}(e,n,a.default.extend(!0,{},t.userOptions),t.dataAttribute)){var r=(0,u.generateMaskSet)(n,t.noMasksCache);void 0!==r&&(void 0!==e.inputmask&&(e.inputmask.opts.autoUnmask=!0,e.inputmask.remove()),e.inputmask=new y(void 0,void 0,!0),e.inputmask.opts=n,e.inputmask.noMasksCache=t.noMasksCache,e.inputmask.userOptions=a.default.extend(!0,{},t.userOptions),e.inputmask.el=e,e.inputmask.$el=(0,a.default)(e),e.inputmask.maskset=r,a.default.data(e,v,t.userOptions),c.mask.call(e.inputmask))}})),e&&e[0]&&e[0].inputmask||this},option:function(e,t){return"string"==typeof e?this.opts[e]:"object"===p(e)?(a.default.extend(this.userOptions,e),this.el&&!0!==t&&this.mask(this.el),this):void 0},unmaskedvalue:function(e){if(this.maskset=this.maskset||(0,u.generateMaskSet)(this.opts,this.noMasksCache),void 0===this.el||void 0!==e){var t=("function"==typeof this.opts.onBeforeMask&&this.opts.onBeforeMask.call(this,e,this.opts)||e).split("");l.checkVal.call(this,void 0,!1,!1,t),"function"==typeof this.opts.onBeforeWrite&&this.opts.onBeforeWrite.call(this,void 0,d.getBuffer.call(this),0,this.opts)}return l.unmaskedvalue.call(this,this.el)},remove:function(){if(this.el){a.default.data(this.el,v,null);var e=this.opts.autoUnmask?(0,l.unmaskedvalue)(this.el):this._valueGet(this.opts.autoUnmask);e!==d.getBufferTemplate.call(this).join("")?this._valueSet(e,this.opts.autoUnmask):this._valueSet(""),s.EventRuler.off(this.el),Object.getOwnPropertyDescriptor&&Object.getPrototypeOf?Object.getOwnPropertyDescriptor(Object.getPrototypeOf(this.el),"value")&&this.__valueGet&&Object.defineProperty(this.el,"value",{get:this.__valueGet,set:this.__valueSet,configurable:!0}):g.__lookupGetter__&&this.el.__lookupGetter__("value")&&this.__valueGet&&(this.el.__defineGetter__("value",this.__valueGet),this.el.__defineSetter__("value",this.__valueSet)),this.el.inputmask=void 0}return this.el},getemptymask:function(){return this.maskset=this.maskset||(0,u.generateMaskSet)(this.opts,this.noMasksCache),(this.isRTL?d.getBufferTemplate.call(this).reverse():d.getBufferTemplate.call(this)).join("")},hasMaskedValue:function(){return!this.opts.autoUnmask},isComplete:function(){return this.maskset=this.maskset||(0,u.generateMaskSet)(this.opts,this.noMasksCache),h.isComplete.call(this,d.getBuffer.call(this))},getmetadata:function(){if(this.maskset=this.maskset||(0,u.generateMaskSet)(this.opts,this.noMasksCache),Array.isArray(this.maskset.metadata)){var e=f.getMaskTemplate.call(this,!0,0,!1).join("");return this.maskset.metadata.forEach((function(t){return t.mask!==e||(e=t,!1)})),e}return this.maskset.metadata},isValid:function(e){if(this.maskset=this.maskset||(0,u.generateMaskSet)(this.opts,this.noMasksCache),e){var t=("function"==typeof this.opts.onBeforeMask&&this.opts.onBeforeMask.call(this,e,this.opts)||e).split("");l.checkVal.call(this,void 0,!0,!1,t)}else e=this.isRTL?d.getBuffer.call(this).slice().reverse().join(""):d.getBuffer.call(this).join("");for(var i=d.getBuffer.call(this),n=d.determineLastRequiredPosition.call(this),r=i.length-1;r>n&&!d.isMask.call(this,r);r--);return i.splice(n,r+1-n),h.isComplete.call(this,i)&&e===(this.isRTL?d.getBuffer.call(this).slice().reverse().join(""):d.getBuffer.call(this).join(""))},format:function(e,t){this.maskset=this.maskset||(0,u.generateMaskSet)(this.opts,this.noMasksCache);var i=("function"==typeof this.opts.onBeforeMask&&this.opts.onBeforeMask.call(this,e,this.opts)||e).split("");l.checkVal.call(this,void 0,!0,!1,i);var n=this.isRTL?d.getBuffer.call(this).slice().reverse().join(""):d.getBuffer.call(this).join("");return t?{value:n,metadata:this.getmetadata()}:n},setValue:function(e){this.el&&(0,a.default)(this.el).trigger("setvalue",[e])},analyseMask:u.analyseMask},y.extendDefaults=function(e){a.default.extend(!0,y.prototype.defaults,e)},y.extendDefinitions=function(e){a.default.extend(!0,y.prototype.definitions,e)},y.extendAliases=function(e){a.default.extend(!0,y.prototype.aliases,e)},y.format=function(e,t,i){return y(t).format(e,i)},y.unmask=function(e,t){return y(t).unmaskedvalue(e)},y.isValid=function(e,t){return y(t).isValid(e)},y.remove=function(e){"string"==typeof e&&(e=g.getElementById(e)||g.querySelectorAll(e)),(e=e.nodeName?[e]:e).forEach((function(e){e.inputmask&&e.inputmask.remove()}))},y.setValue=function(e,t){"string"==typeof e&&(e=g.getElementById(e)||g.querySelectorAll(e)),(e=e.nodeName?[e]:e).forEach((function(e){e.inputmask?e.inputmask.setValue(t):(0,a.default)(e).trigger("setvalue",[t])}))},y.dependencyLib=a.default,o.default.Inputmask=y,t.default=y},5296:function(e,t,i){function n(e){return n="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},n(e)}var r=f(i(9380)),a=f(i(2394));function s(e,t){for(var i=0;i<t.length;i++){var r=t[i];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,(void 0,a=function(e,t){if("object"!==n(e)||null===e)return e;var i=e[Symbol.toPrimitive];if(void 0!==i){var r=i.call(e,"string");if("object"!==n(r))return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(r.key),"symbol"===n(a)?a:String(a)),r)}var a}function o(e){var t=u();return function(){var i,r=h(e);if(t){var a=h(this).constructor;i=Reflect.construct(r,arguments,a)}else i=r.apply(this,arguments);return function(e,t){if(t&&("object"===n(t)||"function"==typeof t))return t;if(void 0!==t)throw new TypeError("Derived constructors may only return object or undefined");return function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}(e)}(this,i)}}function l(e){var t="function"==typeof Map?new Map:void 0;return l=function(e){if(null===e||!function(e){try{return-1!==Function.toString.call(e).indexOf("[native code]")}catch(t){return"function"==typeof e}}(e))return e;if("function"!=typeof e)throw new TypeError("Super expression must either be null or a function");if(void 0!==t){if(t.has(e))return t.get(e);t.set(e,i)}function i(){return c(e,arguments,h(this).constructor)}return i.prototype=Object.create(e.prototype,{constructor:{value:i,enumerable:!1,writable:!0,configurable:!0}}),d(i,e)},l(e)}function c(e,t,i){return c=u()?Reflect.construct.bind():function(e,t,i){var n=[null];n.push.apply(n,t);var r=new(Function.bind.apply(e,n));return i&&d(r,i.prototype),r},c.apply(null,arguments)}function u(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}function d(e,t){return d=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(e,t){return e.__proto__=t,e},d(e,t)}function h(e){return h=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(e){return e.__proto__||Object.getPrototypeOf(e)},h(e)}function f(e){return e&&e.__esModule?e:{default:e}}var p=r.default.document;if(p&&p.head&&p.head.attachShadow&&r.default.customElements&&void 0===r.default.customElements.get("input-mask")){var m=function(e){!function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&d(e,t)}(r,e);var t,i,n=o(r);function r(){var e;!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,r);var t=(e=n.call(this)).getAttributeNames(),i=e.attachShadow({mode:"closed"});for(var s in e.input=p.createElement("input"),e.input.type="text",i.appendChild(e.input),t)Object.prototype.hasOwnProperty.call(t,s)&&e.input.setAttribute(t[s],e.getAttribute(t[s]));var o=new a.default;return o.dataAttribute="",o.mask(e.input),e.input.inputmask.shadowRoot=i,e}return t=r,(i=[{key:"attributeChangedCallback",value:function(e,t,i){this.input.setAttribute(e,i)}},{key:"value",get:function(){return this.input.value},set:function(e){this.input.value=e}}])&&s(t.prototype,i),Object.defineProperty(t,"prototype",{writable:!1}),r}(l(HTMLElement));r.default.customElements.define("input-mask",m)}},2839:function(e,t){function i(e){return i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},i(e)}function n(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var i=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=i){var n,r,a,s,o=[],l=!0,c=!1;try{if(a=(i=i.call(e)).next,0===t){if(Object(i)!==i)return;l=!1}else for(;!(l=(n=a.call(i)).done)&&(o.push(n.value),o.length!==t);l=!0);}catch(e){c=!0,r=e}finally{try{if(!l&&null!=i.return&&(s=i.return(),Object(s)!==s))return}finally{if(c)throw r}}return o}}(e,t)||function(e,t){if(e){if("string"==typeof e)return r(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?r(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function r(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function a(e,t){var i=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),i.push.apply(i,n)}return i}function s(e,t,n){return(t=function(e){var t=function(e,t){if("object"!==i(e)||null===e)return e;var n=e[Symbol.toPrimitive];if(void 0!==n){var r=n.call(e,"string");if("object"!==i(r))return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"===i(t)?t:String(t)}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}Object.defineProperty(t,"__esModule",{value:!0}),t.keys=t.keyCode=void 0,t.toKey=function(e,t){return l[e]||(t?String.fromCharCode(e):String.fromCharCode(e).toLowerCase())},t.toKeyCode=function(e){return o[e]};var o=t.keyCode=function(e){for(var t=1;t<arguments.length;t++){var i=null!=arguments[t]?arguments[t]:{};t%2?a(Object(i),!0).forEach((function(t){s(e,t,i[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(i)):a(Object(i)).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(i,t))}))}return e}({c:67,x:88,z:90,BACKSPACE_SAFARI:127,Enter:13,Meta_LEFT:91,Meta_RIGHT:92,Space:32},{Alt:18,AltGraph:18,ArrowDown:40,ArrowLeft:37,ArrowRight:39,ArrowUp:38,Backspace:8,CapsLock:20,Control:17,ContextMenu:93,Dead:221,Delete:46,End:35,Escape:27,F1:112,F2:113,F3:114,F4:115,F5:116,F6:117,F7:118,F8:119,F9:120,F10:121,F11:122,F12:123,Home:36,Insert:45,NumLock:144,PageDown:34,PageUp:33,Pause:19,PrintScreen:44,Process:229,Shift:16,ScrollLock:145,Tab:9,Unidentified:229}),l=Object.entries(o).reduce((function(e,t){var i=n(t,2),r=i[0],a=i[1];return e[a]=void 0===e[a]?r:e[a],e}),{});t.keys=Object.entries(o).reduce((function(e,t){var i=n(t,2),r=i[0];return i[1],e[r]="Space"===r?" ":r,e}),{})},2391:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.analyseMask=function(e,t,i){var n,r,l,c,u,d,h=/(?:[?*+]|\{[0-9+*]+(?:,[0-9+*]*)?(?:\|[0-9+*]*)?\})|[^.?*+^${[]()|\\]+|./g,f=/\[\^?]?(?:[^\\\]]+|\\[\S\s]?)*]?|\\(?:0(?:[0-3][0-7]{0,2}|[4-7][0-7]?)?|[1-9][0-9]*|x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4}|c[A-Za-z]|[\S\s]?)|\((?:\?[:=!]?)?|(?:[?*+]|\{[0-9]+(?:,[0-9]*)?\})\??|[^.?*+^${[()|\\]+|./g,p=!1,m=new s.default,g=[],v=[],y=!1;function b(e,n,r){r=void 0!==r?r:e.matches.length;var s=e.matches[r-1];if(t){if(0===n.indexOf("[")||p&&/\\d|\\s|\\w|\\p/i.test(n)||"."===n){var l=i.casing?"i":"";/\\p\{.*}/i.test(n)&&(l+="u"),e.matches.splice(r++,0,{fn:new RegExp(n,l),static:!1,optionality:!1,newBlockMarker:void 0===s?"master":s.def!==n,casing:null,def:n,placeholder:"object"===o(i.placeholder)?i.placeholder[m.matches.length]:void 0,nativeDef:n})}else p&&(n=n[n.length-1]),n.split("").forEach((function(t,n){s=e.matches[r-1],e.matches.splice(r++,0,{fn:/[a-z]/i.test(i.staticDefinitionSymbol||t)?new RegExp("["+(i.staticDefinitionSymbol||t)+"]",i.casing?"i":""):null,static:!0,optionality:!1,newBlockMarker:void 0===s?"master":s.def!==t&&!0!==s.static,casing:null,def:i.staticDefinitionSymbol||t,placeholder:void 0!==i.staticDefinitionSymbol?t:"object"===o(i.placeholder)?i.placeholder[m.matches.length]:void 0,nativeDef:(p?"'":"")+t})}));p=!1}else{var c=i.definitions&&i.definitions[n]||i.usePrototypeDefinitions&&a.default.prototype.definitions[n];c&&!p?e.matches.splice(r++,0,{fn:c.validator?"string"==typeof c.validator?new RegExp(c.validator,i.casing?"i":""):new function(){this.test=c.validator}:/./,static:c.static||!1,optionality:c.optional||!1,defOptionality:c.optional||!1,newBlockMarker:void 0===s||c.optional?"master":s.def!==(c.definitionSymbol||n),casing:c.casing,def:c.definitionSymbol||n,placeholder:c.placeholder,nativeDef:n,generated:c.generated}):(e.matches.splice(r++,0,{fn:/[a-z]/i.test(i.staticDefinitionSymbol||n)?new RegExp("["+(i.staticDefinitionSymbol||n)+"]",i.casing?"i":""):null,static:!0,optionality:!1,newBlockMarker:void 0===s?"master":s.def!==n&&!0!==s.static,casing:null,def:i.staticDefinitionSymbol||n,placeholder:void 0!==i.staticDefinitionSymbol?n:void 0,nativeDef:(p?"'":"")+n}),p=!1)}}function x(){if(g.length>0){if(b(c=g[g.length-1],r),c.isAlternator){u=g.pop();for(var e=0;e<u.matches.length;e++)u.matches[e].isGroup&&(u.matches[e].isGroup=!1);g.length>0?(c=g[g.length-1]).matches.push(u):m.matches.push(u)}}else b(m,r)}function _(e){var t=new s.default(!0);return t.openGroup=!1,t.matches=e,t}function w(){if((l=g.pop()).openGroup=!1,void 0!==l)if(g.length>0){if((c=g[g.length-1]).matches.push(l),c.isAlternator){u=g.pop();for(var e=0;e<u.matches.length;e++)u.matches[e].isGroup=!1,u.matches[e].alternatorGroup=!1;g.length>0?(c=g[g.length-1]).matches.push(u):m.matches.push(u)}}else m.matches.push(l);else x()}function k(e){var t=e.pop();return t.isQuantifier&&(t=_([e.pop(),t])),t}for(t&&(i.optionalmarker[0]=void 0,i.optionalmarker[1]=void 0);n=t?f.exec(e):h.exec(e);){if(r=n[0],t){switch(r.charAt(0)){case"?":r="{0,1}";break;case"+":case"*":r="{"+r+"}";break;case"|":if(0===g.length){var M=_(m.matches);M.openGroup=!0,g.push(M),m.matches=[],y=!0}}switch(r){case"\\d":r="[0-9]";break;case"\\p":r+=f.exec(e)[0],r+=f.exec(e)[0]}}if(p)x();else switch(r.charAt(0)){case"$":case"^":t||x();break;case i.escapeChar:p=!0,t&&x();break;case i.optionalmarker[1]:case i.groupmarker[1]:w();break;case i.optionalmarker[0]:g.push(new s.default(!1,!0));break;case i.groupmarker[0]:g.push(new s.default(!0));break;case i.quantifiermarker[0]:var S=new s.default(!1,!1,!0),A=(r=r.replace(/[{}?]/g,"")).split("|"),L=A[0].split(","),T=isNaN(L[0])?L[0]:parseInt(L[0]),C=1===L.length?T:isNaN(L[1])?L[1]:parseInt(L[1]),D=isNaN(A[1])?A[1]:parseInt(A[1]);"*"!==T&&"+"!==T||(T="*"===C?0:1),S.quantifier={min:T,max:C,jit:D};var E=g.length>0?g[g.length-1].matches:m.matches;(n=E.pop()).isGroup||(n=_([n])),E.push(n),E.push(S);break;case i.alternatormarker:if(g.length>0){var O=(c=g[g.length-1]).matches[c.matches.length-1];d=c.openGroup&&(void 0===O.matches||!1===O.isGroup&&!1===O.isAlternator)?g.pop():k(c.matches)}else d=k(m.matches);if(d.isAlternator)g.push(d);else if(d.alternatorGroup?(u=g.pop(),d.alternatorGroup=!1):u=new s.default(!1,!1,!1,!0),u.matches.push(d),g.push(u),d.openGroup){d.openGroup=!1;var P=new s.default(!0);P.alternatorGroup=!0,g.push(P)}break;default:x()}}for(y&&w();g.length>0;)l=g.pop(),m.matches.push(l);return m.matches.length>0&&(function e(n){n&&n.matches&&n.matches.forEach((function(r,a){var s=n.matches[a+1];(void 0===s||void 0===s.matches||!1===s.isQuantifier)&&r&&r.isGroup&&(r.isGroup=!1,t||(b(r,i.groupmarker[0],0),!0!==r.openGroup&&b(r,i.groupmarker[1]))),e(r)}))}(m),v.push(m)),(i.numericInput||i.isRTL)&&function e(t){for(var n in t.matches=t.matches.reverse(),t.matches)if(Object.prototype.hasOwnProperty.call(t.matches,n)){var r=parseInt(n);if(t.matches[n].isQuantifier&&t.matches[r+1]&&t.matches[r+1].isGroup){var a=t.matches[n];t.matches.splice(n,1),t.matches.splice(r+1,0,a)}void 0!==t.matches[n].matches?t.matches[n]=e(t.matches[n]):t.matches[n]=((s=t.matches[n])===i.optionalmarker[0]?s=i.optionalmarker[1]:s===i.optionalmarker[1]?s=i.optionalmarker[0]:s===i.groupmarker[0]?s=i.groupmarker[1]:s===i.groupmarker[1]&&(s=i.groupmarker[0]),s)}var s;return t}(v[0]),v},t.generateMaskSet=function(e,t){var i;function s(e,t){var i=t.repeat,n=t.groupmarker,a=t.quantifiermarker,s=t.keepStatic;if(i>0||"*"===i||"+"===i){var o="*"===i?0:"+"===i?1:i;if(o!=i)e=n[0]+e+n[1]+a[0]+o+","+i+a[1];else for(var c=e,u=1;u<o;u++)e+=c}if(!0===s){var d=e.match(new RegExp("(.)\\[([^\\]]*)\\]","g"));d&&d.forEach((function(t,i){var n=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var i=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=i){var n,r,a,s,o=[],l=!0,c=!1;try{for(a=(i=i.call(e)).next,!2;!(l=(n=a.call(i)).done)&&(o.push(n.value),2!==o.length);l=!0);}catch(e){c=!0,r=e}finally{try{if(!l&&null!=i.return&&(s=i.return(),Object(s)!==s))return}finally{if(c)throw r}}return o}}(e)||function(e,t){if(e){if("string"==typeof e)return l(e,2);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?l(e,2):void 0}}(e)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(t.split("[")),a=n[0],s=n[1];s=s.replace("]",""),e=e.replace(new RegExp("".concat((0,r.default)(a),"\\[").concat((0,r.default)(s),"\\]")),a.charAt(0)===s.charAt(0)?"(".concat(a,"|").concat(a).concat(s,")"):"".concat(a,"[").concat(s,"]"))}))}return e}function c(e,i,r){var l,c,u=!1;return null!==e&&""!==e||((u=null!==r.regex)?e=(e=r.regex).replace(/^(\^)(.*)(\$)$/,"$2"):(u=!0,e=".*")),1===e.length&&!1===r.greedy&&0!==r.repeat&&(r.placeholder=""),e=s(e,r),c=u?"regex_"+r.regex:r.numericInput?e.split("").reverse().join(""):e,null!==r.keepStatic&&(c="ks_"+r.keepStatic+c),"object"===o(r.placeholder)&&(c="ph_"+JSON.stringify(r.placeholder)+c),void 0===a.default.prototype.masksCache[c]||!0===t?(l={mask:e,maskToken:a.default.prototype.analyseMask(e,u,r),validPositions:[],_buffer:void 0,buffer:void 0,tests:{},excludes:{},metadata:i,maskLength:void 0,jitOffset:{}},!0!==t&&(a.default.prototype.masksCache[c]=l,l=n.default.extend(!0,{},a.default.prototype.masksCache[c]))):l=n.default.extend(!0,{},a.default.prototype.masksCache[c]),l}if("function"==typeof e.mask&&(e.mask=e.mask(e)),Array.isArray(e.mask)){if(e.mask.length>1){null===e.keepStatic&&(e.keepStatic=!0);var u=e.groupmarker[0];return(e.isRTL?e.mask.reverse():e.mask).forEach((function(t){u.length>1&&(u+=e.alternatormarker),void 0!==t.mask&&"function"!=typeof t.mask?u+=t.mask:u+=t})),c(u+=e.groupmarker[1],e.mask,e)}e.mask=e.mask.pop()}return i=e.mask&&void 0!==e.mask.mask&&"function"!=typeof e.mask.mask?c(e.mask.mask,e.mask,e):c(e.mask,e.mask,e),null===e.keepStatic&&(e.keepStatic=!1),i};var n=c(i(4963)),r=c(i(7184)),a=c(i(2394)),s=c(i(9695));function o(e){return o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},o(e)}function l(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function c(e){return e&&e.__esModule?e:{default:e}}},157:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.mask=function(){var e=this,t=this.opts,i=this.el,c=this.dependencyLib;a.EventRuler.off(i);var u=function(t,i){var n=t.getAttribute("type"),r="input"===t.tagName.toLowerCase()&&i.supportsInputType.includes(n)||t.isContentEditable||"textarea"===t.tagName.toLowerCase();if(!r)if("input"===t.tagName.toLowerCase()){var l=document.createElement("input");l.setAttribute("type",n),r="text"===l.type,l=null}else r="partial";return!1!==r?function(t){var n,r;function l(){return this.inputmask?this.inputmask.opts.autoUnmask?this.inputmask.unmaskedvalue():-1!==o.getLastValidPosition.call(e)||!0!==i.nullable?(this.inputmask.shadowRoot||this.ownerDocument).activeElement===this&&i.clearMaskOnLostFocus?(e.isRTL?s.clearOptionalTail.call(e,o.getBuffer.call(e).slice()).reverse():s.clearOptionalTail.call(e,o.getBuffer.call(e).slice())).join(""):n.call(this):"":n.call(this)}function u(e){r.call(this,e),this.inputmask&&(0,s.applyInputValue)(this,e)}if(!t.inputmask.__valueGet){if(!0!==i.noValuePatching){if(Object.getOwnPropertyDescriptor){var d=Object.getPrototypeOf?Object.getOwnPropertyDescriptor(Object.getPrototypeOf(t),"value"):void 0;d&&d.get&&d.set?(n=d.get,r=d.set,Object.defineProperty(t,"value",{get:l,set:u,configurable:!0})):"input"!==t.tagName.toLowerCase()&&(n=function(){return this.textContent},r=function(e){this.textContent=e},Object.defineProperty(t,"value",{get:l,set:u,configurable:!0}))}else document.__lookupGetter__&&t.__lookupGetter__("value")&&(n=t.__lookupGetter__("value"),r=t.__lookupSetter__("value"),t.__defineGetter__("value",l),t.__defineSetter__("value",u));t.inputmask.__valueGet=n,t.inputmask.__valueSet=r}t.inputmask._valueGet=function(t){return e.isRTL&&!0!==t?n.call(this.el).split("").reverse().join(""):n.call(this.el)},t.inputmask._valueSet=function(t,i){r.call(this.el,null==t?"":!0!==i&&e.isRTL?t.split("").reverse().join(""):t)},void 0===n&&(n=function(){return this.value},r=function(e){this.value=e},function(t){if(c.valHooks&&(void 0===c.valHooks[t]||!0!==c.valHooks[t].inputmaskpatch)){var n=c.valHooks[t]&&c.valHooks[t].get?c.valHooks[t].get:function(e){return e.value},r=c.valHooks[t]&&c.valHooks[t].set?c.valHooks[t].set:function(e,t){return e.value=t,e};c.valHooks[t]={get:function(t){if(t.inputmask){if(t.inputmask.opts.autoUnmask)return t.inputmask.unmaskedvalue();var r=n(t);return-1!==o.getLastValidPosition.call(e,void 0,void 0,t.inputmask.maskset.validPositions)||!0!==i.nullable?r:""}return n(t)},set:function(e,t){var i=r(e,t);return e.inputmask&&(0,s.applyInputValue)(e,t),i},inputmaskpatch:!0}}}(t.type),function(e){a.EventRuler.on(e,"mouseenter",(function(){var e=this,t=e.inputmask._valueGet(!0);t!=(e.inputmask.isRTL?o.getBuffer.call(e.inputmask).slice().reverse():o.getBuffer.call(e.inputmask)).join("")&&(0,s.applyInputValue)(e,t)}))}(t))}}(t):t.inputmask=void 0,r}(i,t);if(!1!==u){e.originalPlaceholder=i.placeholder,e.maxLength=void 0!==i?i.maxLength:void 0,-1===e.maxLength&&(e.maxLength=void 0),"inputMode"in i&&null===i.getAttribute("inputmode")&&(i.inputMode=t.inputmode,i.setAttribute("inputmode",t.inputmode)),!0===u&&(t.showMaskOnFocus=t.showMaskOnFocus&&-1===["cc-number","cc-exp"].indexOf(i.autocomplete),n.iphone&&(t.insertModeVisual=!1,i.setAttribute("autocorrect","off")),a.EventRuler.on(i,"submit",r.EventHandlers.submitEvent),a.EventRuler.on(i,"reset",r.EventHandlers.resetEvent),a.EventRuler.on(i,"blur",r.EventHandlers.blurEvent),a.EventRuler.on(i,"focus",r.EventHandlers.focusEvent),a.EventRuler.on(i,"invalid",r.EventHandlers.invalidEvent),a.EventRuler.on(i,"click",r.EventHandlers.clickEvent),a.EventRuler.on(i,"mouseleave",r.EventHandlers.mouseleaveEvent),a.EventRuler.on(i,"mouseenter",r.EventHandlers.mouseenterEvent),a.EventRuler.on(i,"paste",r.EventHandlers.pasteEvent),a.EventRuler.on(i,"cut",r.EventHandlers.cutEvent),a.EventRuler.on(i,"complete",t.oncomplete),a.EventRuler.on(i,"incomplete",t.onincomplete),a.EventRuler.on(i,"cleared",t.oncleared),!0!==t.inputEventOnly&&a.EventRuler.on(i,"keydown",r.EventHandlers.keyEvent),(n.mobile||t.inputEventOnly)&&i.removeAttribute("maxLength"),a.EventRuler.on(i,"input",r.EventHandlers.inputFallBackEvent)),a.EventRuler.on(i,"setvalue",r.EventHandlers.setValueEvent),void 0===e.applyMaskHook||e.applyMaskHook(),o.getBufferTemplate.call(e).join(""),e.undoValue=e._valueGet(!0);var d=(i.inputmask.shadowRoot||i.ownerDocument).activeElement;if(""!==i.inputmask._valueGet(!0)||!1===t.clearMaskOnLostFocus||d===i){(0,s.applyInputValue)(i,i.inputmask._valueGet(!0),t);var h=o.getBuffer.call(e).slice();!1===l.isComplete.call(e,h)&&t.clearIncomplete&&o.resetMaskSet.call(e,!1),t.clearMaskOnLostFocus&&d!==i&&(-1===o.getLastValidPosition.call(e)?h=[]:s.clearOptionalTail.call(e,h)),(!1===t.clearMaskOnLostFocus||t.showMaskOnFocus&&d===i||""!==i.inputmask._valueGet(!0))&&(0,s.writeBuffer)(i,h),d===i&&o.caret.call(e,i,o.seekNext.call(e,o.getLastValidPosition.call(e)))}}};var n=i(9845),r=i(6030),a=i(9716),s=i(7760),o=i(8711),l=i(7215)},9695:function(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,i,n){this.matches=[],this.openGroup=e||!1,this.alternatorGroup=!1,this.isGroup=e||!1,this.isOptional=t||!1,this.isQuantifier=i||!1,this.isAlternator=n||!1,this.quantifier={min:1,max:1}}},3194:function(){Array.prototype.includes||Object.defineProperty(Array.prototype,"includes",{value:function(e,t){if(null==this)throw new TypeError('"this" is null or not defined');var i=Object(this),n=i.length>>>0;if(0===n)return!1;for(var r=0|t,a=Math.max(r>=0?r:n-Math.abs(r),0);a<n;){if(i[a]===e)return!0;a++}return!1}})},9302:function(){var e=Function.bind.call(Function.call,Array.prototype.reduce),t=Function.bind.call(Function.call,Object.prototype.propertyIsEnumerable),i=Function.bind.call(Function.call,Array.prototype.concat),n=Object.keys;Object.entries||(Object.entries=function(r){return e(n(r),(function(e,n){return i(e,"string"==typeof n&&t(r,n)?[[n,r[n]]]:[])}),[])})},7149:function(){function e(t){return(e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(t)}"function"!=typeof Object.getPrototypeOf&&(Object.getPrototypeOf="object"===e("test".__proto__)?function(e){return e.__proto__}:function(e){return e.constructor.prototype})},4013:function(){String.prototype.includes||(String.prototype.includes=function(e,t){return"number"!=typeof t&&(t=0),!(t+e.length>this.length)&&-1!==this.indexOf(e,t)})},8711:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.caret=function(e,t,i,n,a){var s,o=this,l=this.opts;if(void 0===t)return"selectionStart"in e&&"selectionEnd"in e?(t=e.selectionStart,i=e.selectionEnd):r.default.getSelection?(s=r.default.getSelection().getRangeAt(0)).commonAncestorContainer.parentNode!==e&&s.commonAncestorContainer!==e||(t=s.startOffset,i=s.endOffset):document.selection&&document.selection.createRange&&(i=(t=0-(s=document.selection.createRange()).duplicate().moveStart("character",-e.inputmask._valueGet().length))+s.text.length),{begin:n?t:d.call(o,t),end:n?i:d.call(o,i)};if(Array.isArray(t)&&(i=o.isRTL?t[0]:t[1],t=o.isRTL?t[1]:t[0]),void 0!==t.begin&&(i=o.isRTL?t.begin:t.end,t=o.isRTL?t.end:t.begin),"number"==typeof t){t=n?t:d.call(o,t),i="number"==typeof(i=n?i:d.call(o,i))?i:t;var c=parseInt(((e.ownerDocument.defaultView||r.default).getComputedStyle?(e.ownerDocument.defaultView||r.default).getComputedStyle(e,null):e.currentStyle).fontSize)*i;if(e.scrollLeft=c>e.scrollWidth?c:0,e.inputmask.caretPos={begin:t,end:i},l.insertModeVisual&&!1===l.insertMode&&t===i&&(a||i++),e===(e.inputmask.shadowRoot||e.ownerDocument).activeElement){if("setSelectionRange"in e)e.setSelectionRange(t,i);else if(r.default.getSelection){if(s=document.createRange(),void 0===e.firstChild||null===e.firstChild){var u=document.createTextNode("");e.appendChild(u)}s.setStart(e.firstChild,t<e.inputmask._valueGet().length?t:e.inputmask._valueGet().length),s.setEnd(e.firstChild,i<e.inputmask._valueGet().length?i:e.inputmask._valueGet().length),s.collapse(!0);var h=r.default.getSelection();h.removeAllRanges(),h.addRange(s)}else e.createTextRange&&((s=e.createTextRange()).collapse(!0),s.moveEnd("character",i),s.moveStart("character",t),s.select());void 0===e.inputmask.caretHook||e.inputmask.caretHook.call(o,{begin:t,end:i})}}},t.determineLastRequiredPosition=function(e){var t,i,n=this,r=n.maskset,o=n.dependencyLib,c=l.call(n),u={},d=r.validPositions[c],h=s.getMaskTemplate.call(n,!0,l.call(n),!0,!0),f=h.length,p=void 0!==d?d.locator.slice():void 0;for(t=c+1;t<h.length;t++)p=(i=s.getTestTemplate.call(n,t,p,t-1)).locator.slice(),u[t]=o.extend(!0,{},i);var m=d&&void 0!==d.alternation?d.locator[d.alternation]:void 0;for(t=f-1;t>c&&((i=u[t]).match.optionality||i.match.optionalQuantifier&&i.match.newBlockMarker||m&&(m!==u[t].locator[d.alternation]&&!0!==i.match.static||!0===i.match.static&&i.locator[d.alternation]&&a.checkAlternationMatch.call(n,i.locator[d.alternation].toString().split(","),m.toString().split(","))&&""!==s.getTests.call(n,t)[0].def))&&h[t]===s.getPlaceholder.call(n,t,i.match);t--)f--;return e?{l:f,def:u[f]?u[f].match:void 0}:f},t.determineNewCaretPosition=function(e,t,i){var n,r,a,d=this,h=d.maskset,f=d.opts;if(t&&(d.isRTL?e.end=e.begin:e.begin=e.end),e.begin===e.end){switch(i=i||f.positionCaretOnClick){case"none":break;case"select":e={begin:0,end:o.call(d).length};break;case"ignore":e.end=e.begin=u.call(d,l.call(d));break;case"radixFocus":if(d.clicked>1&&0===h.validPositions.length)break;if(function(e){if(""!==f.radixPoint&&0!==f.digits){var t=h.validPositions;if(void 0===t[e]||void 0===t[e].input){if(e<u.call(d,-1))return!0;var i=o.call(d).indexOf(f.radixPoint);if(-1!==i){for(var n=0,r=t.length;n<r;n++)if(t[n]&&i<n&&t[n].input!==s.getPlaceholder.call(d,n))return!1;return!0}}}return!1}(e.begin)){var p=o.call(d).join("").indexOf(f.radixPoint);e.end=e.begin=f.numericInput?u.call(d,p):p;break}default:if(n=e.begin,r=l.call(d,n,!0),n<=(a=u.call(d,-1!==r||c.call(d,0)?r:-1)))e.end=e.begin=c.call(d,n,!1,!0)?n:u.call(d,n);else{var m=h.validPositions[r],g=s.getTestTemplate.call(d,a,m?m.match.locator:void 0,m),v=s.getPlaceholder.call(d,a,g.match);if(""!==v&&o.call(d)[a]!==v&&!0!==g.match.optionalQuantifier&&!0!==g.match.newBlockMarker||!c.call(d,a,f.keepStatic,!0)&&g.match.def===v){var y=u.call(d,a);(n>=y||n===a)&&(a=y)}e.end=e.begin=a}}return e}},t.getBuffer=o,t.getBufferTemplate=function(){var e=this.maskset;return void 0===e._buffer&&(e._buffer=s.getMaskTemplate.call(this,!1,1),void 0===e.buffer&&(e.buffer=e._buffer.slice())),e._buffer},t.getLastValidPosition=l,t.isMask=c,t.resetMaskSet=function(e){var t=this.maskset;t.buffer=void 0,!0!==e&&(t.validPositions=[],t.p=0),!1===e&&(t.tests={},t.jitOffset={})},t.seekNext=u,t.seekPrevious=function(e,t){var i=this,n=e-1;if(e<=0)return 0;for(;n>0&&(!0===t&&(!0!==s.getTest.call(i,n).match.newBlockMarker||!c.call(i,n,void 0,!0))||!0!==t&&!c.call(i,n,void 0,!0));)n--;return n},t.translatePosition=d;var n,r=(n=i(9380))&&n.__esModule?n:{default:n},a=i(7215),s=i(4713);function o(e){var t=this,i=t.maskset;return void 0!==i.buffer&&!0!==e||(i.buffer=s.getMaskTemplate.call(t,!0,l.call(t),!0),void 0===i._buffer&&(i._buffer=i.buffer.slice())),i.buffer}function l(e,t,i){var n=this.maskset,r=-1,a=-1,s=i||n.validPositions;void 0===e&&(e=-1);for(var o=0,l=s.length;o<l;o++)s[o]&&(t||!0!==s[o].generatedInput)&&(o<=e&&(r=o),o>=e&&(a=o));return-1===r||r===e?a:-1===a||e-r<a-e?r:a}function c(e,t,i){var n=this,r=this.maskset,a=s.getTestTemplate.call(n,e).match;if(""===a.def&&(a=s.getTest.call(n,e).match),!0!==a.static)return a.fn;if(!0===i&&void 0!==r.validPositions[e]&&!0!==r.validPositions[e].generatedInput)return!0;if(!0!==t&&e>-1){if(i){var o=s.getTests.call(n,e);return o.length>1+(""===o[o.length-1].match.def?1:0)}var l=s.determineTestTemplate.call(n,e,s.getTests.call(n,e)),c=s.getPlaceholder.call(n,e,l.match);return l.match.def!==c}return!1}function u(e,t,i){var n=this;void 0===i&&(i=!0);for(var r=e+1;""!==s.getTest.call(n,r).match.def&&(!0===t&&(!0!==s.getTest.call(n,r).match.newBlockMarker||!c.call(n,r,void 0,!0))||!0!==t&&!c.call(n,r,void 0,i));)r++;return r}function d(e){var t=this.opts,i=this.el;return!this.isRTL||"number"!=typeof e||t.greedy&&""===t.placeholder||!i||(e=this._valueGet().length-e)<0&&(e=0),e}},4713:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.determineTestTemplate=d,t.getDecisionTaker=l,t.getMaskTemplate=function(e,t,i,n,r){var a=this,s=this.opts,o=this.maskset,l=s.greedy;r&&s.greedy&&(s.greedy=!1,a.maskset.tests={}),t=t||0;var h,f,m,g,v=[],y=0;do{if(!0===e&&o.validPositions[y])f=(m=r&&o.validPositions[y].match.optionality&&void 0===o.validPositions[y+1]&&(!0===o.validPositions[y].generatedInput||o.validPositions[y].input==s.skipOptionalPartCharacter&&y>0)?d.call(a,y,p.call(a,y,h,y-1)):o.validPositions[y]).match,h=m.locator.slice(),v.push(!0===i?m.input:!1===i?f.nativeDef:c.call(a,y,f));else{f=(m=u.call(a,y,h,y-1)).match,h=m.locator.slice();var b=!0!==n&&(!1!==s.jitMasking?s.jitMasking:f.jit);(g=(g||o.validPositions[y-1])&&f.static&&f.def!==s.groupSeparator&&null===f.fn)||!1===b||void 0===b||"number"==typeof b&&isFinite(b)&&b>y?v.push(!1===i?f.nativeDef:c.call(a,v.length,f)):g=!1}y++}while(!0!==f.static||""!==f.def||t>y);return""===v[v.length-1]&&v.pop(),!1===i&&void 0!==o.maskLength||(o.maskLength=y-1),s.greedy=l,v},t.getPlaceholder=c,t.getTest=h,t.getTestTemplate=u,t.getTests=p,t.isSubsetOf=f;var n,r=(n=i(2394))&&n.__esModule?n:{default:n},a=i(8711);function s(e){return s="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},s(e)}function o(e,t){var i=(null!=e.alternation?e.mloc[l(e)]:e.locator).join("");if(""!==i)for(i=i.split(":")[0];i.length<t;)i+="0";return i}function l(e){var t=e.locator[e.alternation];return"string"==typeof t&&t.length>0&&(t=t.split(",")[0]),void 0!==t?t.toString():""}function c(e,t,i){var n=this,r=this.opts,o=this.maskset;if(void 0!==(t=t||h.call(n,e).match).placeholder||!0===i){if(""!==t.placeholder&&!0===t.static&&!0!==t.generated){var l=a.getLastValidPosition.call(n,e),c=a.seekNext.call(n,l);return(i?e<=c:e<c)?r.staticDefinitionSymbol&&t.static?t.nativeDef:t.def:"function"==typeof t.placeholder?t.placeholder(r):t.placeholder}return"function"==typeof t.placeholder?t.placeholder(r):t.placeholder}if(!0===t.static){if(e>-1&&void 0===o.validPositions[e]){var u,d=p.call(n,e),f=[];if("string"==typeof r.placeholder&&d.length>1+(""===d[d.length-1].match.def?1:0))for(var m=0;m<d.length;m++)if(""!==d[m].match.def&&!0!==d[m].match.optionality&&!0!==d[m].match.optionalQuantifier&&(!0===d[m].match.static||void 0===u||!1!==d[m].match.fn.test(u.match.def,o,e,!0,r))&&(f.push(d[m]),!0===d[m].match.static&&(u=d[m]),f.length>1&&/[0-9a-bA-Z]/.test(f[0].match.def)))return r.placeholder.charAt(e%r.placeholder.length)}return t.def}return"object"===s(r.placeholder)?t.def:r.placeholder.charAt(e%r.placeholder.length)}function u(e,t,i){return this.maskset.validPositions[e]||d.call(this,e,p.call(this,e,t?t.slice():t,i))}function d(e,t){var i=this.opts,n=0,r=function(e,t){var i=0,n=!1;return t.forEach((function(e){e.match.optionality&&(0!==i&&i!==e.match.optionality&&(n=!0),(0===i||i>e.match.optionality)&&(i=e.match.optionality))})),i&&(0==e||1==t.length?i=0:n||(i=0)),i}(e,t);e=e>0?e-1:0;var a,s,l,c=o(h.call(this,e));i.greedy&&t.length>1&&""===t[t.length-1].match.def&&(n=1);for(var u=0;u<t.length-n;u++){var d=t[u];a=o(d,c.length);var f=Math.abs(a-c);(!0!==d.unMatchedAlternationStopped||t.filter((function(e){return!0!==e.unMatchedAlternationStopped})).length<=1)&&(void 0===s||""!==a&&f<s||l&&!i.greedy&&l.match.optionality&&l.match.optionality-r>0&&"master"===l.match.newBlockMarker&&(!d.match.optionality||d.match.optionality-r<1||!d.match.newBlockMarker)||l&&!i.greedy&&l.match.optionalQuantifier&&!d.match.optionalQuantifier)&&(s=f,l=d)}return l}function h(e,t){var i=this.maskset;return i.validPositions[e]?i.validPositions[e]:(t||p.call(this,e))[0]}function f(e,t,i){function n(e){for(var t,i=[],n=-1,r=0,a=e.length;r<a;r++)if("-"===e.charAt(r))for(t=e.charCodeAt(r+1);++n<t;)i.push(String.fromCharCode(n));else n=e.charCodeAt(r),i.push(e.charAt(r));return i.join("")}return e.match.def===t.match.nativeDef||!(!(i.regex||e.match.fn instanceof RegExp&&t.match.fn instanceof RegExp)||!0===e.match.static||!0===t.match.static)&&("."===t.match.fn.source||-1!==n(t.match.fn.source.replace(/[[\]/]/g,"")).indexOf(n(e.match.fn.source.replace(/[[\]/]/g,""))))}function p(e,t,i){var n,a,s=this,o=this.dependencyLib,l=this.maskset,c=this.opts,u=this.el,h=l.maskToken,p=t?i:0,m=t?t.slice():[0],g=[],v=!1,y=t?t.join(""):"",b=!1;function x(t,i,a,o){function d(a,o,h){function m(e,t){var i=0===t.matches.indexOf(e);return i||t.matches.every((function(n,r){return!0===n.isQuantifier?i=m(e,t.matches[r-1]):Object.prototype.hasOwnProperty.call(n,"matches")&&(i=m(e,n)),!i})),i}function w(e,t,i){var n,r;if((l.tests[e]||l.validPositions[e])&&(l.validPositions[e]?[l.validPositions[e]]:l.tests[e]).every((function(e,a){if(e.mloc[t])return n=e,!1;var s=void 0!==i?i:e.alternation,o=void 0!==e.locator[s]?e.locator[s].toString().indexOf(t):-1;return(void 0===r||o<r)&&-1!==o&&(n=e,r=o),!0})),n){var a=n.locator[n.alternation],s=n.mloc[t]||n.mloc[a]||n.locator;return-1!==s[s.length-1].toString().indexOf(":")&&s.pop(),s.slice((void 0!==i?i:n.alternation)+1)}return void 0!==i?w(e,t):void 0}function k(t,i){return!0===t.match.static&&!0!==i.match.static&&i.match.fn.test(t.match.def,l,e,!1,c,!1)}function M(e,t){var i=e.alternation,n=void 0===t||i<=t.alternation&&-1===e.locator[i].toString().indexOf(t.locator[i]);if(!n&&i>t.alternation)for(var r=0;r<i;r++)if(e.locator[r]!==t.locator[r]){i=r,n=!0;break}return!!n&&function(i){e.mloc=e.mloc||{};var n=e.locator[i];if(void 0!==n){if("string"==typeof n&&(n=n.split(",")[0]),void 0===e.mloc[n]&&(e.mloc[n]=e.locator.slice(),e.mloc[n].push(":".concat(e.alternation))),void 0!==t){for(var r in t.mloc)"string"==typeof r&&(r=parseInt(r.split(",")[0])),e.mloc[r+0]=t.mloc[r];e.locator[i]=Object.keys(e.mloc).join(",")}return e.alternation>i&&(e.alternation=i),!0}return e.alternation=void 0,!1}(i)}function S(e,t){if(e.locator.length!==t.locator.length)return!1;for(var i=e.alternation+1;i<e.locator.length;i++)if(e.locator[i]!==t.locator[i])return!1;return!0}if(p>e+c._maxTestPos)throw new Error("Inputmask: There is probably an error in your mask definition or in the code. Create an issue on github with an example of the mask you are using. ".concat(l.mask));if(p===e&&void 0===a.matches){if(g.push({match:a,locator:o.reverse(),cd:y,mloc:{}}),!a.optionality||void 0!==h||!(c.definitions&&c.definitions[a.nativeDef]&&c.definitions[a.nativeDef].optional||r.default.prototype.definitions[a.nativeDef]&&r.default.prototype.definitions[a.nativeDef].optional))return!0;v=!0,p=e}else if(void 0!==a.matches){if(a.isGroup&&h!==a)return function(){if(a=d(t.matches[t.matches.indexOf(a)+1],o,h))return!0}();if(a.isOptional)return function(){var t=a,r=g.length;if(a=x(a,i,o,h),g.length>0){if(g.forEach((function(e,t){t>=r&&(e.match.optionality=e.match.optionality?e.match.optionality+1:1)})),n=g[g.length-1].match,void 0!==h||!m(n,t))return a;v=!0,p=e}}();if(a.isAlternator)return function(){function n(e){for(var t,i=e.matches[0].matches?e.matches[0].matches.length:1,n=0;n<e.matches.length&&i===(t=e.matches[n].matches?e.matches[n].matches.length:1);n++);return i!==t}s.hasAlternator=!0;var r,m=a,y=[],x=g.slice(),_=o.length,A=i.length>0?i.shift():-1;if(-1===A||"string"==typeof A){var L,T=p,C=i.slice(),D=[];if("string"==typeof A)D=A.split(",");else for(L=0;L<m.matches.length;L++)D.push(L.toString());if(void 0!==l.excludes[e]){for(var E=D.slice(),O=0,P=l.excludes[e].length;O<P;O++){var Y=l.excludes[e][O].toString().split(":");o.length==Y[1]&&D.splice(D.indexOf(Y[0]),1)}0===D.length&&(delete l.excludes[e],D=E)}(!0===c.keepStatic||isFinite(parseInt(c.keepStatic))&&T>=c.keepStatic)&&(D=D.slice(0,1));for(var I=0;I<D.length;I++){L=parseInt(D[I]),g=[],i="string"==typeof A&&w(p,L,_)||C.slice();var N=m.matches[L];if(N&&d(N,[L].concat(o),h))a=!0;else if(0===I&&(b=n(m)),N&&N.matches&&N.matches.length>m.matches[0].matches.length)break;r=g.slice(),p=T,g=[];for(var j=0;j<r.length;j++){var H=r[j],F=!1;H.alternation=H.alternation||_,M(H);for(var R=0;R<y.length;R++){var z=y[R];if("string"!=typeof A||void 0!==H.alternation&&D.includes(H.locator[H.alternation].toString())){if(H.match.nativeDef===z.match.nativeDef){F=!0,M(z,H);break}if(f(H,z,c)){M(H,z)&&(F=!0,y.splice(y.indexOf(z),0,H));break}if(f(z,H,c)){M(z,H);break}if(k(H,z)){S(H,z)||void 0!==u.inputmask.userOptions.keepStatic?M(H,z)&&(F=!0,y.splice(y.indexOf(z),0,H)):c.keepStatic=!0;break}if(k(z,H)){M(z,H);break}}}F||y.push(H)}}g=x.concat(y),p=e,v=g.length>0&&b,a=y.length>0&&!b,b&&v&&!a&&g.forEach((function(e,t){e.unMatchedAlternationStopped=!0})),i=C.slice()}else a=d(m.matches[A]||t.matches[A],[A].concat(o),h);if(a)return!0}();if(a.isQuantifier&&h!==t.matches[t.matches.indexOf(a)-1])return function(){for(var r=a,s=!1,u=i.length>0?i.shift():0;u<(isNaN(r.quantifier.max)?u+1:r.quantifier.max)&&p<=e;u++){var h=t.matches[t.matches.indexOf(r)-1];if(a=d(h,[u].concat(o),h)){if(g.forEach((function(t,i){(n=_(h,t.match)?t.match:g[g.length-1].match).optionalQuantifier=u>=r.quantifier.min,n.jit=(u+1)*(h.matches.indexOf(n)+1)>r.quantifier.jit,n.optionalQuantifier&&m(n,h)&&(v=!0,p=e,c.greedy&&null==l.validPositions[e-1]&&u>r.quantifier.min&&-1!=["*","+"].indexOf(r.quantifier.max)&&(g.pop(),y=void 0),s=!0,a=!1),!s&&n.jit&&(l.jitOffset[e]=h.matches.length-h.matches.indexOf(n))})),s)break;return!0}}}();if(a=x(a,i,o,h))return!0}else p++}for(var h=i.length>0?i.shift():0;h<t.matches.length;h++)if(!0!==t.matches[h].isQuantifier){var m=d(t.matches[h],[h].concat(a),o);if(m&&p===e)return m;if(p>e)break}}function _(e,t){var i=-1!=e.matches.indexOf(t);return i||e.matches.forEach((function(e,n){void 0===e.matches||i||(i=_(e,t))})),i}if(e>-1){if(void 0===t){for(var w,k=e-1;void 0===(w=l.validPositions[k]||l.tests[k])&&k>-1;)k--;void 0!==w&&k>-1&&(m=function(e,t){var i,n=[];return Array.isArray(t)||(t=[t]),t.length>0&&(void 0===t[0].alternation||!0===c.keepStatic?0===(n=d.call(s,e,t.slice()).locator.slice()).length&&(n=t[0].locator.slice()):t.forEach((function(e){""!==e.def&&(0===n.length?(i=e.alternation,n=e.locator.slice()):e.locator[i]&&-1===n[i].toString().indexOf(e.locator[i])&&(n[i]+=","+e.locator[i]))}))),n}(k,w),y=m.join(""),p=k)}if(l.tests[e]&&l.tests[e][0].cd===y)return l.tests[e];for(var M=m.shift();M<h.length&&!(x(h[M],m,[M])&&p===e||p>e);M++);}return(0===g.length||v)&&g.push({match:{fn:null,static:!0,optionality:!1,casing:null,def:"",placeholder:""},locator:b&&0===g.filter((function(e){return!0!==e.unMatchedAlternationStopped})).length?[0]:[],mloc:{},cd:y}),void 0!==t&&l.tests[e]?a=o.extend(!0,[],g):(l.tests[e]=o.extend(!0,[],g),a=l.tests[e]),g.forEach((function(e){e.match.optionality=e.match.defOptionality||!1})),a}},7215:function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.alternate=o,t.checkAlternationMatch=function(e,t,i){for(var n,r=this.opts.greedy?t:t.slice(0,1),a=!1,s=void 0!==i?i.split(","):[],o=0;o<s.length;o++)-1!==(n=e.indexOf(s[o]))&&e.splice(n,1);for(var l=0;l<e.length;l++)if(r.includes(e[l])){a=!0;break}return a},t.handleRemove=function(e,t,i,n,l){var c=this,u=this.maskset,d=this.opts;if((d.numericInput||c.isRTL)&&(t===r.keys.Backspace?t=r.keys.Delete:t===r.keys.Delete&&(t=r.keys.Backspace),c.isRTL)){var h=i.end;i.end=i.begin,i.begin=h}var f,p=a.getLastValidPosition.call(c,void 0,!0);i.end>=a.getBuffer.call(c).length&&p>=i.end&&(i.end=p+1),t===r.keys.Backspace?i.end-i.begin<1&&(i.begin=a.seekPrevious.call(c,i.begin)):t===r.keys.Delete&&i.begin===i.end&&(i.end=a.isMask.call(c,i.end,!0,!0)?i.end+1:a.seekNext.call(c,i.end)+1),!1!==(f=m.call(c,i))&&((!0!==n&&!1!==d.keepStatic||null!==d.regex&&-1!==s.getTest.call(c,i.begin).match.def.indexOf("|"))&&o.call(c,!0),!0!==n&&(u.p=t===r.keys.Delete?i.begin+f:i.begin,u.p=a.determineNewCaretPosition.call(c,{begin:u.p,end:u.p},!1,!1===d.insertMode&&t===r.keys.Backspace?"none":void 0).begin))},t.isComplete=c,t.isSelection=u,t.isValid=d,t.refreshFromBuffer=f,t.revalidateMask=m;var n=i(6030),r=i(2839),a=i(8711),s=i(4713);function o(e,t,i,n,r,l){var c=this,u=this.dependencyLib,h=this.opts,f=c.maskset;if(!c.hasAlternator)return!1;var p,m,g,v,y,b,x,_,w,k,M,S=u.extend(!0,[],f.validPositions),A=u.extend(!0,{},f.tests),L=!1,T=!1,C=void 0!==r?r:a.getLastValidPosition.call(c);if(l&&(k=l.begin,M=l.end,l.begin>l.end&&(k=l.end,M=l.begin)),-1===C&&void 0===r)p=0,m=(v=s.getTest.call(c,p)).alternation;else for(;C>=0;C--)if((g=f.validPositions[C])&&void 0!==g.alternation){if(C<=(e||0)&&v&&v.locator[g.alternation]!==g.locator[g.alternation])break;p=C,m=f.validPositions[p].alternation,v=g}if(void 0!==m){x=parseInt(p),f.excludes[x]=f.excludes[x]||[],!0!==e&&f.excludes[x].push((0,s.getDecisionTaker)(v)+":"+v.alternation);var D=[],E=-1;for(y=x;x<a.getLastValidPosition.call(c,void 0,!0)+1;y++)-1===E&&e<=y&&void 0!==t&&(D.push(t),E=D.length-1),(b=f.validPositions[x])&&!0!==b.generatedInput&&(void 0===l||y<k||y>=M)&&D.push(b.input),f.validPositions.splice(x,1);for(-1===E&&void 0!==t&&(D.push(t),E=D.length-1);void 0!==f.excludes[x]&&f.excludes[x].length<10;){for(f.tests={},a.resetMaskSet.call(c,!0),L=!0,y=0;y<D.length&&(_=L.caret||0==h.insertMode&&null!=_?a.seekNext.call(c,_):a.getLastValidPosition.call(c,void 0,!0)+1,w=D[y],L=d.call(c,_,w,!1,n,!0));y++)y===E&&(T=L),1==e&&L&&(T={caretPos:y});if(L)break;if(a.resetMaskSet.call(c),v=s.getTest.call(c,x),f.validPositions=u.extend(!0,[],S),f.tests=u.extend(!0,{},A),!f.excludes[x]){T=o.call(c,e,t,i,n,x-1,l);break}if(null!=v.alternation){var O=(0,s.getDecisionTaker)(v);if(-1!==f.excludes[x].indexOf(O+":"+v.alternation)){T=o.call(c,e,t,i,n,x-1,l);break}for(f.excludes[x].push(O+":"+v.alternation),y=x;y<a.getLastValidPosition.call(c,void 0,!0)+1;y++)f.validPositions.splice(x)}else delete f.excludes[x]}}return T&&!1===h.keepStatic||delete f.excludes[x],T}function l(e,t,i){var n=this.opts,a=this.maskset;switch(n.casing||t.casing){case"upper":e=e.toUpperCase();break;case"lower":e=e.toLowerCase();break;case"title":var s=a.validPositions[i-1];e=0===i||s&&s.input===String.fromCharCode(r.keyCode.Space)?e.toUpperCase():e.toLowerCase();break;default:if("function"==typeof n.casing){var o=Array.prototype.slice.call(arguments);o.push(a.validPositions),e=n.casing.apply(this,o)}}return e}function c(e){var t=this,i=this.opts,n=this.maskset;if("function"==typeof i.isComplete)return i.isComplete(e,i);if("*"!==i.repeat){var r=!1,o=a.determineLastRequiredPosition.call(t,!0),l=o.l;if(void 0===o.def||o.def.newBlockMarker||o.def.optionality||o.def.optionalQuantifier){r=!0;for(var c=0;c<=l;c++){var u=s.getTestTemplate.call(t,c).match;if(!0!==u.static&&void 0===n.validPositions[c]&&(!1===u.optionality||void 0===u.optionality||u.optionality&&0==u.newBlockMarker)&&(!1===u.optionalQuantifier||void 0===u.optionalQuantifier)||!0===u.static&&""!=u.def&&e[c]!==s.getPlaceholder.call(t,c,u)){r=!1;break}}}return r}}function u(e){var t=this.opts.insertMode?0:1;return this.isRTL?e.begin-e.end>t:e.end-e.begin>t}function d(e,t,i,n,r,h,g){var v=this,y=this.dependencyLib,b=this.opts,x=v.maskset;i=!0===i;var _=e;function w(e){if(void 0!==e){if(void 0!==e.remove&&(Array.isArray(e.remove)||(e.remove=[e.remove]),e.remove.sort((function(e,t){return v.isRTL?e.pos-t.pos:t.pos-e.pos})).forEach((function(e){m.call(v,{begin:e,end:e+1})})),e.remove=void 0),void 0!==e.insert&&(Array.isArray(e.insert)||(e.insert=[e.insert]),e.insert.sort((function(e,t){return v.isRTL?t.pos-e.pos:e.pos-t.pos})).forEach((function(e){""!==e.c&&d.call(v,e.pos,e.c,void 0===e.strict||e.strict,void 0!==e.fromIsValid?e.fromIsValid:n)})),e.insert=void 0),e.refreshFromBuffer&&e.buffer){var t=e.refreshFromBuffer;f.call(v,!0===t?t:t.start,t.end,e.buffer),e.refreshFromBuffer=void 0}void 0!==e.rewritePosition&&(_=e.rewritePosition,e=!0)}return e}function k(t,i,r){var o=!1;return s.getTests.call(v,t).every((function(c,d){var h=c.match;if(a.getBuffer.call(v,!0),!1!==(o=(!h.jit||void 0!==x.validPositions[a.seekPrevious.call(v,t)])&&(null!=h.fn?h.fn.test(i,x,t,r,b,u.call(v,e)):(i===h.def||i===b.skipOptionalPartCharacter)&&""!==h.def&&{c:s.getPlaceholder.call(v,t,h,!0)||h.def,pos:t}))){var f=void 0!==o.c?o.c:i,p=t;return f=f===b.skipOptionalPartCharacter&&!0===h.static?s.getPlaceholder.call(v,t,h,!0)||h.def:f,!0!==(o=w(o))&&void 0!==o.pos&&o.pos!==t&&(p=o.pos),!0!==o&&void 0===o.pos&&void 0===o.c||!1===m.call(v,e,y.extend({},c,{input:l.call(v,f,h,p)}),n,p)&&(o=!1),!1}return!0})),o}void 0!==e.begin&&(_=v.isRTL?e.end:e.begin);var M=!0,S=y.extend(!0,[],x.validPositions);if(!1===b.keepStatic&&void 0!==x.excludes[_]&&!0!==r&&!0!==n)for(var A=_;A<(v.isRTL?e.begin:e.end);A++)void 0!==x.excludes[A]&&(x.excludes[A]=void 0,delete x.tests[A]);if("function"==typeof b.preValidation&&!0!==n&&!0!==h&&(M=w(M=b.preValidation.call(v,a.getBuffer.call(v),_,t,u.call(v,e),b,x,e,i||r))),!0===M){if(M=k(_,t,i),(!i||!0===n)&&!1===M&&!0!==h){var L=x.validPositions[_];if(!L||!0!==L.match.static||L.match.def!==t&&t!==b.skipOptionalPartCharacter){if(b.insertMode||void 0===x.validPositions[a.seekNext.call(v,_)]||e.end>_){var T=!1;if(x.jitOffset[_]&&void 0===x.validPositions[a.seekNext.call(v,_)]&&!1!==(M=d.call(v,_+x.jitOffset[_],t,!0,!0))&&(!0!==r&&(M.caret=_),T=!0),e.end>_&&(x.validPositions[_]=void 0),!T&&!a.isMask.call(v,_,b.keepStatic&&0===_))for(var C=_+1,D=a.seekNext.call(v,_,!1,0!==_);C<=D;C++)if(!1!==(M=k(C,t,i))){M=p.call(v,_,void 0!==M.pos?M.pos:C)||M,_=C;break}}}else M={caret:a.seekNext.call(v,_)}}v.hasAlternator&&!0!==r&&!i&&(r=!0,!1===M&&b.keepStatic&&(c.call(v,a.getBuffer.call(v))||0===_)?M=o.call(v,_,t,i,n,void 0,e):(u.call(v,e)&&x.tests[_]&&x.tests[_].length>1&&b.keepStatic||1==M&&!0!==b.numericInput&&x.tests[_]&&x.tests[_].length>1&&a.getLastValidPosition.call(v,void 0,!0)>_)&&(M=o.call(v,!0))),!0===M&&(M={pos:_})}if("function"==typeof b.postValidation&&!0!==n&&!0!==h){var E=b.postValidation.call(v,a.getBuffer.call(v,!0),void 0!==e.begin?v.isRTL?e.end:e.begin:e,t,M,b,x,i,g);void 0!==E&&(M=!0===E?M:E)}M&&void 0===M.pos&&(M.pos=_),!1===M||!0===h?(a.resetMaskSet.call(v,!0),x.validPositions=y.extend(!0,[],S)):p.call(v,void 0,_,!0);var O=w(M);return void 0!==v.maxLength&&a.getBuffer.call(v).length>v.maxLength&&!n&&(a.resetMaskSet.call(v,!0),x.validPositions=y.extend(!0,[],S),O=!1),O}function h(e,t,i){for(var n=this.maskset,r=!1,a=s.getTests.call(this,e),o=0;o<a.length;o++){if(a[o].match&&(a[o].match.nativeDef===t.match[i.shiftPositions?"def":"nativeDef"]&&(!i.shiftPositions||!t.match.static)||a[o].match.nativeDef===t.match.nativeDef||i.regex&&!a[o].match.static&&a[o].match.fn.test(t.input,n,e,!1,i))){r=!0;break}if(a[o].match&&a[o].match.def===t.match.nativeDef){r=void 0;break}}return!1===r&&void 0!==n.jitOffset[e]&&(r=h.call(this,e+n.jitOffset[e],t,i)),r}function f(e,t,i){var r,s,o=this,l=this.maskset,c=this.opts,u=this.dependencyLib,d=c.skipOptionalPartCharacter,h=o.isRTL?i.slice().reverse():i;if(c.skipOptionalPartCharacter="",!0===e)a.resetMaskSet.call(o,!1),e=0,t=i.length,s=a.determineNewCaretPosition.call(o,{begin:0,end:0},!1).begin;else{for(r=e;r<t;r++)l.validPositions.splice(e,0);s=e}var f=new u.Event("keypress");for(r=e;r<t;r++){f.key=h[r].toString(),o.ignorable=!1;var p=n.EventHandlers.keypressEvent.call(o,f,!0,!1,!1,s);!1!==p&&void 0!==p&&(s=p.forwardPosition)}c.skipOptionalPartCharacter=d}function p(e,t,i){var n=this,r=this.maskset,o=this.dependencyLib;if(void 0===e)for(e=t-1;e>0&&!r.validPositions[e];e--);for(var l=e;l<t;l++)if(void 0===r.validPositions[l]&&!a.isMask.call(n,l,!1)&&(0==l?s.getTest.call(n,l):r.validPositions[l-1])){var c=s.getTests.call(n,l).slice();""===c[c.length-1].match.def&&c.pop();var u,h=s.determineTestTemplate.call(n,l,c);if(h&&(!0!==h.match.jit||"master"===h.match.newBlockMarker&&(u=r.validPositions[l+1])&&!0===u.match.optionalQuantifier)&&((h=o.extend({},h,{input:s.getPlaceholder.call(n,l,h.match,!0)||h.match.def})).generatedInput=!0,m.call(n,l,h,!0),!0!==i)){var f=r.validPositions[t].input;return r.validPositions[t]=void 0,d.call(n,t,f,!0,!0)}}}function m(e,t,i,n){var r=this,o=this.maskset,l=this.opts,c=this.dependencyLib;function f(e,t,i){var n=t[e];if(void 0!==n&&!0===n.match.static&&!0!==n.match.optionality&&(void 0===t[0]||void 0===t[0].alternation)){var r=i.begin<=e-1?t[e-1]&&!0===t[e-1].match.static&&t[e-1]:t[e-1],a=i.end>e+1?t[e+1]&&!0===t[e+1].match.static&&t[e+1]:t[e+1];return r&&a}return!1}var p=0,m=void 0!==e.begin?e.begin:e,g=void 0!==e.end?e.end:e,v=!0;if(e.begin>e.end&&(m=e.end,g=e.begin),n=void 0!==n?n:m,void 0===i&&(m!==g||l.insertMode&&void 0!==o.validPositions[n]||void 0===t||t.match.optionalQuantifier||t.match.optionality)){var y,b=c.extend(!0,[],o.validPositions),x=a.getLastValidPosition.call(r,void 0,!0);o.p=m;var _=u.call(r,e)?m:n;for(y=x;y>=_;y--)o.validPositions.splice(y,1),void 0===t&&delete o.tests[y+1];var w,k,M=n,S=M;for(t&&(o.validPositions[n]=c.extend(!0,{},t),S++,M++),null==b[g]&&o.jitOffset[g]&&(g+=o.jitOffset[g]+1),y=t?g:g-1;y<=x;y++){if(void 0!==(w=b[y])&&!0!==w.generatedInput&&(y>=g||y>=m&&f(y,b,{begin:m,end:g}))){for(;""!==s.getTest.call(r,S).match.def;){if(!1!==(k=h.call(r,S,w,l))||"+"===w.match.def){"+"===w.match.def&&a.getBuffer.call(r,!0);var A=d.call(r,S,w.input,"+"!==w.match.def,!0);if(v=!1!==A,M=(A.pos||S)+1,!v&&k)break}else v=!1;if(v){void 0===t&&w.match.static&&y===e.begin&&p++;break}if(!v&&a.getBuffer.call(r),S>o.maskLength)break;S++}""==s.getTest.call(r,S).match.def&&(v=!1),S=M}if(!v)break}if(!v)return o.validPositions=c.extend(!0,[],b),a.resetMaskSet.call(r,!0),!1}else t&&s.getTest.call(r,n).match.cd===t.match.cd&&(o.validPositions[n]=c.extend(!0,{},t));return a.resetMaskSet.call(r,!0),p}}},t={};function i(n){var r=t[n];if(void 0!==r)return r.exports;var a=t[n]={exports:{}};return e[n](a,a.exports,i),a.exports}var n={};return function(){var e=n;Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,i(7149),i(3194),i(9302),i(4013),i(3851),i(219),i(207),i(5296);var t,r=(t=i(2394))&&t.__esModule?t:{default:t};e.default=r.default}(),n}()})),function(e,t,i){e(i.document).ajaxComplete((function(i,n,r){-1!==e.inArray("html",r.dataTypes)&&e(".inputmask, [data-inputmask], [data-inputmask-mask], [data-inputmask-alias], [data-inputmask-regex]").each((function(e,i){void 0===i.inputmask&&t().mask(i)}))})).ready((function(){e(".inputmask, [data-inputmask], [data-inputmask-mask], [data-inputmask-alias],[data-inputmask-regex]").each((function(e,i){void 0===i.inputmask&&t().mask(i)}))}))}(jQuery,window.Inputmask,window);var tns=function(){var e=window,t=e.requestAnimationFrame||e.webkitRequestAnimationFrame||e.mozRequestAnimationFrame||e.msRequestAnimationFrame||function(e){return setTimeout(e,16)},i=window,n=i.cancelAnimationFrame||i.mozCancelAnimationFrame||function(e){clearTimeout(e)};function r(){for(var e,t,i,n=arguments[0]||{},r=1,a=arguments.length;r<a;r++)if(null!==(e=arguments[r]))for(t in e)n!==(i=e[t])&&void 0!==i&&(n[t]=i);return n}function a(e){return 0<=["true","false"].indexOf(e)?JSON.parse(e):e}function s(e,t,i,n){if(n)try{e.setItem(t,i)}catch(e){}return i}function o(){var e=document,t=e.body;return t||((t=e.createElement("body")).fake=!0),t}var l=document.documentElement;function c(e){var t="";return e.fake&&(t=l.style.overflow,e.style.background="",e.style.overflow=l.style.overflow="hidden",l.appendChild(e)),t}function u(e,t){e.fake&&(e.remove(),l.style.overflow=t,l.offsetHeight)}function d(e,t,i,n){"insertRule"in e?e.insertRule(t+"{"+i+"}",n):e.addRule(t,i,n)}function h(e){return("insertRule"in e?e.cssRules:e.rules).length}function f(e,t,i){for(var n=0,r=e.length;n<r;n++)t.call(i,e[n],n)}var p="classList"in document.createElement("_"),m=p?function(e,t){return e.classList.contains(t)}:function(e,t){return 0<=e.className.indexOf(t)},g=p?function(e,t){m(e,t)||e.classList.add(t)}:function(e,t){m(e,t)||(e.className+=" "+t)},v=p?function(e,t){m(e,t)&&e.classList.remove(t)}:function(e,t){m(e,t)&&(e.className=e.className.replace(t,""))};function y(e,t){return e.hasAttribute(t)}function b(e,t){return e.getAttribute(t)}function x(e){return void 0!==e.item}function _(e,t){if(e=x(e)||e instanceof Array?e:[e],"[object Object]"===Object.prototype.toString.call(t))for(var i=e.length;i--;)for(var n in t)e[i].setAttribute(n,t[n])}function w(e,t){e=x(e)||e instanceof Array?e:[e];for(var i=(t=t instanceof Array?t:[t]).length,n=e.length;n--;)for(var r=i;r--;)e[n].removeAttribute(t[r])}function k(e){for(var t=[],i=0,n=e.length;i<n;i++)t.push(e[i]);return t}function M(e,t){"none"!==e.style.display&&(e.style.display="none")}function S(e,t){"none"===e.style.display&&(e.style.display="")}function A(e){return"none"!==window.getComputedStyle(e).display}function L(e){if("string"==typeof e){var t=[e],i=e.charAt(0).toUpperCase()+e.substr(1);["Webkit","Moz","ms","O"].forEach((function(n){"ms"===n&&"transform"!==e||t.push(n+i)})),e=t}for(var n=document.createElement("fakeelement"),r=(e.length,0);r<e.length;r++){var a=e[r];if(void 0!==n.style[a])return a}return!1}function T(e,t){var i=!1;return/^Webkit/.test(e)?i="webkit"+t+"End":/^O/.test(e)?i="o"+t+"End":e&&(i=t.toLowerCase()+"end"),i}var C=!1;try{var D=Object.defineProperty({},"passive",{get:function(){C=!0}});window.addEventListener("test",null,D)}catch(e){}var E=!!C&&{passive:!0};function O(e,t,i){for(var n in t){var r=0<=["touchstart","touchmove"].indexOf(n)&&!i&&E;e.addEventListener(n,t[n],r)}}function P(e,t){for(var i in t){var n=0<=["touchstart","touchmove"].indexOf(i)&&E;e.removeEventListener(i,t[i],n)}}function Y(){return{topics:{},on:function(e,t){this.topics[e]=this.topics[e]||[],this.topics[e].push(t)},off:function(e,t){if(this.topics[e])for(var i=0;i<this.topics[e].length;i++)if(this.topics[e][i]===t){this.topics[e].splice(i,1);break}},emit:function(e,t){t.type=e,this.topics[e]&&this.topics[e].forEach((function(i){i(t,e)}))}}}Object.keys||(Object.keys=function(e){var t=[];for(var i in e)Object.prototype.hasOwnProperty.call(e,i)&&t.push(i);return t}),"remove"in Element.prototype||(Element.prototype.remove=function(){this.parentNode&&this.parentNode.removeChild(this)});var I=function(e){e=r({container:".slider",mode:"carousel",axis:"horizontal",items:1,gutter:0,edgePadding:0,fixedWidth:!1,autoWidth:!1,viewportMax:!1,slideBy:1,center:!1,controls:!0,controlsPosition:"top",controlsText:["prev","next"],controlsContainer:!1,prevButton:!1,nextButton:!1,nav:!0,navPosition:"top",navContainer:!1,navAsThumbnails:!1,arrowKeys:!1,speed:300,autoplay:!1,autoplayPosition:"top",autoplayTimeout:5e3,autoplayDirection:"forward",autoplayText:["start","stop"],autoplayHoverPause:!1,autoplayButton:!1,autoplayButtonOutput:!0,autoplayResetOnVisibility:!0,animateIn:"tns-fadeIn",animateOut:"tns-fadeOut",animateNormal:"tns-normal",animateDelay:!1,loop:!0,rewind:!1,autoHeight:!1,responsive:!1,lazyload:!1,lazyloadSelector:".tns-lazy-img",touch:!0,mouseDrag:!1,swipeAngle:15,nested:!1,preventActionWhenRunning:!1,preventScrollOnTouch:!1,freezable:!0,onInit:!1,useLocalStorage:!0,nonce:!1},e||{});var i=document,l=window,p={ENTER:13,SPACE:32,LEFT:37,RIGHT:39},x={},C=e.useLocalStorage;if(C){var D=navigator.userAgent,E=new Date;try{(x=l.localStorage)?(x.setItem(E,E),C=x.getItem(E)==E,x.removeItem(E)):C=!1,C||(x={})}catch(D){C=!1}C&&(x.tnsApp&&x.tnsApp!==D&&["tC","tPL","tMQ","tTf","t3D","tTDu","tTDe","tADu","tADe","tTE","tAE"].forEach((function(e){x.removeItem(e)})),localStorage.tnsApp=D)}var N=x.tC?a(x.tC):s(x,"tC",function(){var e=document,t=o(),i=c(t),n=e.createElement("div"),r=!1;t.appendChild(n);try{for(var a,s="(10px * 10)",l=["calc"+s,"-moz-calc"+s,"-webkit-calc"+s],d=0;d<3;d++)if(a=l[d],n.style.width=a,100===n.offsetWidth){r=a.replace(s,"");break}}catch(e){}return t.fake?u(t,i):n.remove(),r}(),C),j=x.tPL?a(x.tPL):s(x,"tPL",function(){var e,t=document,i=o(),n=c(i),r=t.createElement("div"),a=t.createElement("div"),s="";r.className="tns-t-subp2",a.className="tns-t-ct";for(var l=0;l<70;l++)s+="<div></div>";return a.innerHTML=s,r.appendChild(a),i.appendChild(r),e=Math.abs(r.getBoundingClientRect().left-a.children[67].getBoundingClientRect().left)<2,i.fake?u(i,n):r.remove(),e}(),C),H=x.tMQ?a(x.tMQ):s(x,"tMQ",function(){if(window.matchMedia||window.msMatchMedia)return!0;var e,t=document,i=o(),n=c(i),r=t.createElement("div"),a=t.createElement("style"),s="@media all and (min-width:1px){.tns-mq-test{position:absolute}}";return a.type="text/css",r.className="tns-mq-test",i.appendChild(a),i.appendChild(r),a.styleSheet?a.styleSheet.cssText=s:a.appendChild(t.createTextNode(s)),e=window.getComputedStyle?window.getComputedStyle(r).position:r.currentStyle.position,i.fake?u(i,n):r.remove(),"absolute"===e}(),C),F=x.tTf?a(x.tTf):s(x,"tTf",L("transform"),C),R=x.t3D?a(x.t3D):s(x,"t3D",function(e){if(!e)return!1;if(!window.getComputedStyle)return!1;var t,i=document,n=o(),r=c(n),a=i.createElement("p"),s=9<e.length?"-"+e.slice(0,-9).toLowerCase()+"-":"";return s+="transform",n.insertBefore(a,null),a.style[e]="translate3d(1px,1px,1px)",t=window.getComputedStyle(a).getPropertyValue(s),n.fake?u(n,r):a.remove(),void 0!==t&&0<t.length&&"none"!==t}(F),C),z=x.tTDu?a(x.tTDu):s(x,"tTDu",L("transitionDuration"),C),B=x.tTDe?a(x.tTDe):s(x,"tTDe",L("transitionDelay"),C),V=x.tADu?a(x.tADu):s(x,"tADu",L("animationDuration"),C),W=x.tADe?a(x.tADe):s(x,"tADe",L("animationDelay"),C),U=x.tTE?a(x.tTE):s(x,"tTE",T(z,"Transition"),C),q=x.tAE?a(x.tAE):s(x,"tAE",T(V,"Animation"),C),$=l.console&&"function"==typeof l.console.warn,X=["container","controlsContainer","prevButton","nextButton","navContainer","autoplayButton"],G={};if(X.forEach((function(t){if("string"==typeof e[t]){var n=e[t],r=i.querySelector(n);if(G[t]=n,!r||!r.nodeName)return void($&&console.warn("Can't find",e[t]));e[t]=r}})),!(e.container.children.length<1)){var Z=e.responsive,K=e.nested,J="carousel"===e.mode;if(Z){0 in Z&&(e=r(e,Z[0]),delete Z[0]);var Q={};for(var ee in Z){var te=Z[ee];te="number"==typeof te?{items:te}:te,Q[ee]=te}Z=Q,Q=null}if(J||function e(t){for(var i in t)J||("slideBy"===i&&(t[i]="page"),"edgePadding"===i&&(t[i]=!1),"autoHeight"===i&&(t[i]=!1)),"responsive"===i&&e(t[i])}(e),!J){e.axis="horizontal",e.slideBy="page",e.edgePadding=!1;var ie=e.animateIn,ne=e.animateOut,re=e.animateDelay,ae=e.animateNormal}var se,oe,le="horizontal"===e.axis,ce=i.createElement("div"),ue=i.createElement("div"),de=e.container,he=de.parentNode,fe=de.outerHTML,pe=de.children,me=pe.length,ge=Ei(),ve=!1;Z&&Ki(),J&&(de.className+=" tns-vpfix");var ye,be,xe,_e,we,ke,Me,Se,Ae=e.autoWidth,Le=Ii("fixedWidth"),Te=Ii("edgePadding"),Ce=Ii("gutter"),De=Pi(),Ee=Ii("center"),Oe=Ae?1:Math.floor(Ii("items")),Pe=Ii("slideBy"),Ye=e.viewportMax||e.fixedWidthViewportWidth,Ie=Ii("arrowKeys"),Ne=Ii("speed"),je=e.rewind,He=!je&&e.loop,Fe=Ii("autoHeight"),Re=Ii("controls"),ze=Ii("controlsText"),Be=Ii("nav"),Ve=Ii("touch"),We=Ii("mouseDrag"),Ue=Ii("autoplay"),qe=Ii("autoplayTimeout"),$e=Ii("autoplayText"),Xe=Ii("autoplayHoverPause"),Ge=Ii("autoplayResetOnVisibility"),Ze=(Me=Ii("nonce"),Se=document.createElement("style"),Me&&Se.setAttribute("nonce",Me),document.querySelector("head").appendChild(Se),Se.sheet?Se.sheet:Se.styleSheet),Ke=e.lazyload,Je=e.lazyloadSelector,Qe=[],et=He?(we=function(){if(Ae||Le&&!Ye)return me-1;var t=Le?"fixedWidth":"items",i=[];if((Le||e[t]<me)&&i.push(e[t]),Z)for(var n in Z){var r=Z[n][t];r&&(Le||r<me)&&i.push(r)}return i.length||i.push(0),Math.ceil(Le?Ye/Math.min.apply(null,i):Math.max.apply(null,i))}(),ke=J?Math.ceil((5*we-me)/2):4*we-me,ke=Math.max(we,ke),Yi("edgePadding")?ke+1:ke):0,tt=J?me+2*et:me+et,it=!(!Le&&!Ae||He),nt=Le?Mn():null,rt=!J||!He,at=le?"left":"top",st="",ot="",lt=Le?function(){return Ee&&!He?me-1:Math.ceil(-nt/(Le+Ce))}:Ae?function(){for(var e=0;e<tt;e++)if(ye[e]>=-nt)return e}:function(){return Ee&&J&&!He?me-1:He||J?Math.max(0,tt-Math.ceil(Oe)):tt-1},ct=Ti(Ii("startIndex")),ut=ct,dt=(Li(),0),ht=Ae?null:lt(),ft=e.preventActionWhenRunning,pt=e.swipeAngle,mt=!pt||"?",gt=!1,vt=e.onInit,yt=new Y,bt=" tns-slider tns-"+e.mode,xt=de.id||(_e=window.tnsId,window.tnsId=_e?_e+1:1,"tns"+window.tnsId),_t=Ii("disable"),wt=!1,kt=e.freezable,Mt=!(!kt||Ae)&&Zi(),St=!1,At={click:Pn,keydown:function(e){e=zn(e);var t=[p.LEFT,p.RIGHT].indexOf(e.keyCode);0<=t&&(0===t?Xt.disabled||Pn(e,-1):Gt.disabled||Pn(e,1))}},Lt={click:function(e){if(gt){if(ft)return;En()}for(var t=Bn(e=zn(e));t!==Qt&&!y(t,"data-nav");)t=t.parentNode;if(y(t,"data-nav")){var i=ni=Number(b(t,"data-nav")),n=Le||Ae?i*me/ti:i*Oe;On(It?i:Math.min(Math.ceil(n),me-1),e),ri===i&&(ui&&Hn(),ni=-1)}},keydown:function(e){e=zn(e);var t=i.activeElement;if(y(t,"data-nav")){var n=[p.LEFT,p.RIGHT,p.ENTER,p.SPACE].indexOf(e.keyCode),r=Number(b(t,"data-nav"));0<=n&&(0===n?0<r&&Rn(Jt[r-1]):1===n?r<ti-1&&Rn(Jt[r+1]):On(ni=r,e))}}},Tt={mouseover:function(){ui&&(In(),di=!0)},mouseout:function(){di&&(Yn(),di=!1)}},Ct={visibilitychange:function(){i.hidden?ui&&(In(),fi=!0):fi&&(Yn(),fi=!1)}},Dt={keydown:function(e){e=zn(e);var t=[p.LEFT,p.RIGHT].indexOf(e.keyCode);0<=t&&Pn(e,0===t?-1:1)}},Et={touchstart:qn,touchmove:$n,touchend:Xn,touchcancel:Xn},Ot={mousedown:qn,mousemove:$n,mouseup:Xn,mouseleave:Xn},Pt=Yi("controls"),Yt=Yi("nav"),It=!!Ae||e.navAsThumbnails,Nt=Yi("autoplay"),jt=Yi("touch"),Ht=Yi("mouseDrag"),Ft="tns-slide-active",Rt="tns-slide-cloned",zt="tns-complete",Bt={load:function(e){on(Bn(e))},error:function(e){var t;t=Bn(e),g(t,"failed"),ln(t)}},Vt="force"===e.preventScrollOnTouch;if(Pt)var Wt,Ut,qt=e.controlsContainer,$t=e.controlsContainer?e.controlsContainer.outerHTML:"",Xt=e.prevButton,Gt=e.nextButton,Zt=e.prevButton?e.prevButton.outerHTML:"",Kt=e.nextButton?e.nextButton.outerHTML:"";if(Yt)var Jt,Qt=e.navContainer,ei=e.navContainer?e.navContainer.outerHTML:"",ti=Ae?me:Zn(),ii=0,ni=-1,ri=Di(),ai=ri,si="tns-nav-active",oi="Carousel Page ",li=" (Current Slide)";if(Nt)var ci,ui,di,hi,fi,pi="forward"===e.autoplayDirection?1:-1,mi=e.autoplayButton,gi=e.autoplayButton?e.autoplayButton.outerHTML:"",vi=["<span class='tns-visually-hidden'>"," animation</span>"];if(jt||Ht)var yi,bi,xi={},_i={},wi=!1,ki=le?function(e,t){return e.x-t.x}:function(e,t){return e.y-t.y};Ae||Ai(_t||Mt),F&&(at=F,st="translate",R?(st+=le?"3d(":"3d(0px, ",ot=le?", 0px, 0px)":", 0px)"):(st+=le?"X(":"Y(",ot=")")),J&&(de.className=de.className.replace("tns-vpfix","")),function(){(Yi("gutter"),ce.className="tns-outer",ue.className="tns-inner",ce.id=xt+"-ow",ue.id=xt+"-iw",""===de.id&&(de.id=xt),bt+=j||Ae?" tns-subpixel":" tns-no-subpixel",bt+=N?" tns-calc":" tns-no-calc",Ae&&(bt+=" tns-autowidth"),bt+=" tns-"+e.axis,de.className+=bt,J?((se=i.createElement("div")).id=xt+"-mw",se.className="tns-ovh",ce.appendChild(se),se.appendChild(ue)):ce.appendChild(ue),Fe)&&((se||ue).className+=" tns-ah");if(he.insertBefore(ce,de),ue.appendChild(de),f(pe,(function(e,t){g(e,"tns-item"),e.id||(e.id=xt+"-item"+t),!J&&ae&&g(e,ae),_(e,{"aria-hidden":"true",tabindex:"-1"})})),et){for(var t=i.createDocumentFragment(),n=i.createDocumentFragment(),r=et;r--;){var a=r%me,s=pe[a].cloneNode(!0);if(g(s,Rt),w(s,"id"),n.insertBefore(s,n.firstChild),J){var o=pe[me-1-a].cloneNode(!0);g(o,Rt),w(o,"id"),t.appendChild(o)}}de.insertBefore(t,de.firstChild),de.appendChild(n),pe=de.children}}(),function(){if(!J)for(var t=ct,i=ct+Math.min(me,Oe);t<i;t++){var n=pe[t];n.style.left=100*(t-ct)/Oe+"%",g(n,ie),v(n,ae)}if(le&&(j||Ae?(d(Ze,"#"+xt+" > .tns-item","font-size:"+l.getComputedStyle(pe[0]).fontSize+";",h(Ze)),d(Ze,"#"+xt,"font-size:0;",h(Ze))):J&&f(pe,(function(e,t){var i;e.style.marginLeft=(i=t,N?N+"("+100*i+"% / "+tt+")":100*i/tt+"%")}))),H){if(z){var r=se&&e.autoHeight?zi(e.speed):"";d(Ze,"#"+xt+"-mw",r,h(Ze))}r=Ni(e.edgePadding,e.gutter,e.fixedWidth,e.speed,e.autoHeight),d(Ze,"#"+xt+"-iw",r,h(Ze)),J&&(r=le&&!Ae?"width:"+ji(e.fixedWidth,e.gutter,e.items)+";":"",z&&(r+=zi(Ne)),d(Ze,"#"+xt,r,h(Ze))),r=le&&!Ae?Hi(e.fixedWidth,e.gutter,e.items):"",e.gutter&&(r+=Fi(e.gutter)),J||(z&&(r+=zi(Ne)),V&&(r+=Bi(Ne))),r&&d(Ze,"#"+xt+" > .tns-item",r,h(Ze))}else{J&&Fe&&(se.style[z]=Ne/1e3+"s"),ue.style.cssText=Ni(Te,Ce,Le,Fe),J&&le&&!Ae&&(de.style.width=ji(Le,Ce,Oe));r=le&&!Ae?Hi(Le,Ce,Oe):"";Ce&&(r+=Fi(Ce)),r&&d(Ze,"#"+xt+" > .tns-item",r,h(Ze))}if(Z&&H)for(var a in Z){a=parseInt(a);var s=Z[a],o=(r="",""),c="",u="",p="",m=Ae?null:Ii("items",a),y=Ii("fixedWidth",a),b=Ii("speed",a),x=Ii("edgePadding",a),_=Ii("autoHeight",a),w=Ii("gutter",a);z&&se&&Ii("autoHeight",a)&&"speed"in s&&(o="#"+xt+"-mw{"+zi(b)+"}"),("edgePadding"in s||"gutter"in s)&&(c="#"+xt+"-iw{"+Ni(x,w,y,b,_)+"}"),J&&le&&!Ae&&("fixedWidth"in s||"items"in s||Le&&"gutter"in s)&&(u="width:"+ji(y,w,m)+";"),z&&"speed"in s&&(u+=zi(b)),u&&(u="#"+xt+"{"+u+"}"),("fixedWidth"in s||Le&&"gutter"in s||!J&&"items"in s)&&(p+=Hi(y,w,m)),"gutter"in s&&(p+=Fi(w)),!J&&"speed"in s&&(z&&(p+=zi(b)),V&&(p+=Bi(b))),p&&(p="#"+xt+" > .tns-item{"+p+"}"),(r=o+c+u+p)&&Ze.insertRule("@media (min-width: "+a/16+"em) {"+r+"}",Ze.cssRules.length)}}(),Vi();var Mi=He?J?function(){var e=dt,t=ht;e+=Pe,t-=Pe,Te?(e+=1,t-=1):Le&&(De+Ce)%(Le+Ce)&&(t-=1),et&&(t<ct?ct-=me:ct<e&&(ct+=me))}:function(){if(ht<ct)for(;dt+me<=ct;)ct-=me;else if(ct<dt)for(;ct<=ht-me;)ct+=me}:function(){ct=Math.max(dt,Math.min(ht,ct))},Si=J?function(){var e,t,i,n,r,a,s,o,l,c,u;wn(de,""),z||!Ne?(Ln(),Ne&&A(de)||En()):(e=de,t=at,i=st,n=ot,r=Sn(),a=Ne,s=En,o=Math.min(a,10),l=0<=r.indexOf("%")?"%":"px",r=r.replace(l,""),c=Number(e.style[t].replace(i,"").replace(n,"").replace(l,"")),u=(r-c)/a*o,setTimeout((function r(){a-=o,c+=u,e.style[t]=i+c+l+n,0<a?setTimeout(r,o):s()}),o)),le||Gn()}:function(){Qe=[];var e={};e[U]=e[q]=En,P(pe[ut],e),O(pe[ct],e),Tn(ut,ie,ne,!0),Tn(ct,ae,ie),U&&q&&Ne&&A(de)||En()};return{version:"2.9.4",getInfo:Jn,events:yt,goTo:On,play:function(){Ue&&!ui&&(jn(),hi=!1)},pause:function(){ui&&(Hn(),hi=!0)},isOn:ve,updateSliderHeight:pn,refresh:Vi,destroy:function(){if(Ze.disabled=!0,Ze.ownerNode&&Ze.ownerNode.remove(),P(l,{resize:Xi}),Ie&&P(i,Dt),qt&&P(qt,At),Qt&&P(Qt,Lt),P(de,Tt),P(de,Ct),mi&&P(mi,{click:Fn}),Ue&&clearInterval(ci),J&&U){var t={};t[U]=En,P(de,t)}Ve&&P(de,Et),We&&P(de,Ot);var n=[fe,$t,Zt,Kt,ei,gi];for(var r in X.forEach((function(t,i){var r="container"===t?ce:e[t];if("object"==typeof r&&r){var a=!!r.previousElementSibling&&r.previousElementSibling,s=r.parentNode;r.outerHTML=n[i],e[t]=a?a.nextElementSibling:s.firstElementChild}})),X=ie=ne=re=ae=le=ce=ue=de=he=fe=pe=me=oe=ge=Ae=Le=Te=Ce=De=Oe=Pe=Ye=Ie=Ne=je=He=Fe=Ze=Ke=ye=Qe=et=tt=it=nt=rt=at=st=ot=lt=ct=ut=dt=ht=pt=mt=gt=vt=yt=bt=xt=_t=wt=kt=Mt=St=At=Lt=Tt=Ct=Dt=Et=Ot=Pt=Yt=It=Nt=jt=Ht=Ft=zt=Bt=be=Re=ze=qt=$t=Xt=Gt=Wt=Ut=Be=Qt=ei=Jt=ti=ii=ni=ri=ai=si=oi=li=Ue=qe=pi=$e=Xe=mi=gi=Ge=vi=ci=ui=di=hi=fi=xi=_i=yi=wi=bi=ki=Ve=We=null,this)"rebuild"!==r&&(this[r]=null);ve=!1},rebuild:function(){return I(r(e,G))}}}function Ai(e){e&&(Re=Be=Ve=We=Ie=Ue=Xe=Ge=!1)}function Li(){for(var e=J?ct-et:ct;e<0;)e+=me;return e%me+1}function Ti(e){return e=e?Math.max(0,Math.min(He?me-1:me-Oe,e)):0,J?e+et:e}function Ci(e){for(null==e&&(e=ct),J&&(e-=et);e<0;)e+=me;return Math.floor(e%me)}function Di(){var e,t=Ci();return e=It?t:Le||Ae?Math.ceil((t+1)*ti/me-1):Math.floor(t/Oe),!He&&J&&ct===ht&&(e=ti-1),e}function Ei(){return l.innerWidth||i.documentElement.clientWidth||i.body.clientWidth}function Oi(e){return"top"===e?"afterbegin":"beforeend"}function Pi(){var e=Te?2*Te-Ce:0;return function e(t){if(null!=t){var n,r,a=i.createElement("div");return t.appendChild(a),r=(n=a.getBoundingClientRect()).right-n.left,a.remove(),r||e(t.parentNode)}}(he)-e}function Yi(t){if(e[t])return!0;if(Z)for(var i in Z)if(Z[i][t])return!0;return!1}function Ii(t,i){if(null==i&&(i=ge),"items"===t&&Le)return Math.floor((De+Ce)/(Le+Ce))||1;var n=e[t];if(Z)for(var r in Z)i>=parseInt(r)&&t in Z[r]&&(n=Z[r][t]);return"slideBy"===t&&"page"===n&&(n=Ii("items")),J||"slideBy"!==t&&"items"!==t||(n=Math.floor(n)),n}function Ni(e,t,i,n,r){var a="";if(void 0!==e){var s=e;t&&(s-=t),a=le?"margin: 0 "+s+"px 0 "+e+"px;":"margin: "+e+"px 0 "+s+"px 0;"}else if(t&&!i){var o="-"+t+"px";a="margin: 0 "+(le?o+" 0 0":"0 "+o+" 0")+";"}return!J&&r&&z&&n&&(a+=zi(n)),a}function ji(e,t,i){return e?(e+t)*tt+"px":N?N+"("+100*tt+"% / "+i+")":100*tt/i+"%"}function Hi(e,t,i){var n;if(e)n=e+t+"px";else{J||(i=Math.floor(i));var r=J?tt:i;n=N?N+"(100% / "+r+")":100/r+"%"}return n="width:"+n,"inner"!==K?n+";":n+" !important;"}function Fi(e){var t="";return!1!==e&&(t=(le?"padding-":"margin-")+(le?"right":"bottom")+": "+e+"px;"),t}function Ri(e,t){var i=e.substring(0,e.length-t).toLowerCase();return i&&(i="-"+i+"-"),i}function zi(e){return Ri(z,18)+"transition-duration:"+e/1e3+"s;"}function Bi(e){return Ri(V,17)+"animation-duration:"+e/1e3+"s;"}function Vi(){if(Yi("autoHeight")||Ae||!le){var e=de.querySelectorAll("img");f(e,(function(e){var t=e.src;Ke||(t&&t.indexOf("data:image")<0?(e.src="",O(e,Bt),g(e,"loading"),e.src=t):on(e))})),t((function(){dn(k(e),(function(){be=!0}))})),Yi("autoHeight")&&(e=cn(ct,Math.min(ct+Oe-1,tt-1))),Ke?Wi():t((function(){dn(k(e),Wi)}))}else J&&An(),qi(),$i()}function Wi(){if(Ae&&1<me){var e=He?ct:me-1;!function t(){var i=pe[e].getBoundingClientRect().left,n=pe[e-1].getBoundingClientRect().right;Math.abs(i-n)<=1?Ui():setTimeout((function(){t()}),16)}()}else Ui()}function Ui(){le&&!Ae||(mn(),Ae?(nt=Mn(),kt&&(Mt=Zi()),ht=lt(),Ai(_t||Mt)):Gn()),J&&An(),qi(),$i()}function qi(){if(gn(),ce.insertAdjacentHTML("afterbegin",'<div class="tns-liveregion tns-visually-hidden" aria-live="polite" aria-atomic="true">slide <span class="current">'+rn()+"</span>  of "+me+"</div>"),xe=ce.querySelector(".tns-liveregion .current"),Nt){var t=Ue?"stop":"start";mi?_(mi,{"data-action":t}):e.autoplayButtonOutput&&(ce.insertAdjacentHTML(Oi(e.autoplayPosition),'<button type="button" data-action="'+t+'">'+vi[0]+t+vi[1]+$e[0]+"</button>"),mi=ce.querySelector("[data-action]")),mi&&O(mi,{click:Fn}),Ue&&(jn(),Xe&&O(de,Tt),Ge&&O(de,Ct))}if(Yt){if(Qt)_(Qt,{"aria-label":"Carousel Pagination"}),f(Jt=Qt.children,(function(e,t){_(e,{"data-nav":t,tabindex:"-1","aria-label":oi+(t+1),"aria-controls":xt})}));else{for(var i="",n=It?"":'style="display:none"',r=0;r<me;r++)i+='<button type="button" data-nav="'+r+'" tabindex="-1" aria-controls="'+xt+'" '+n+' aria-label="'+oi+(r+1)+'"></button>';i='<div class="tns-nav" aria-label="Carousel Pagination">'+i+"</div>",ce.insertAdjacentHTML(Oi(e.navPosition),i),Qt=ce.querySelector(".tns-nav"),Jt=Qt.children}if(Kn(),z){var a=z.substring(0,z.length-18).toLowerCase(),s="transition: all "+Ne/1e3+"s";a&&(s="-"+a+"-"+s),d(Ze,"[aria-controls^="+xt+"-item]",s,h(Ze))}_(Jt[ri],{"aria-label":oi+(ri+1)+li}),w(Jt[ri],"tabindex"),g(Jt[ri],si),O(Qt,Lt)}Pt&&(qt||Xt&&Gt||(ce.insertAdjacentHTML(Oi(e.controlsPosition),'<div class="tns-controls" aria-label="Carousel Navigation" tabindex="0"><button type="button" data-controls="prev" tabindex="-1" aria-controls="'+xt+'">'+ze[0]+'</button><button type="button" data-controls="next" tabindex="-1" aria-controls="'+xt+'">'+ze[1]+"</button></div>"),qt=ce.querySelector(".tns-controls")),Xt&&Gt||(Xt=qt.children[0],Gt=qt.children[1]),e.controlsContainer&&_(qt,{"aria-label":"Carousel Navigation",tabindex:"0"}),(e.controlsContainer||e.prevButton&&e.nextButton)&&_([Xt,Gt],{"aria-controls":xt,tabindex:"-1"}),(e.controlsContainer||e.prevButton&&e.nextButton)&&(_(Xt,{"data-controls":"prev"}),_(Gt,{"data-controls":"next"})),Wt=yn(Xt),Ut=yn(Gt),_n(),qt?O(qt,At):(O(Xt,At),O(Gt,At))),Ji()}function $i(){if(J&&U){var t={};t[U]=En,O(de,t)}Ve&&O(de,Et,e.preventScrollOnTouch),We&&O(de,Ot),Ie&&O(i,Dt),"inner"===K?yt.on("outerResized",(function(){Gi(),yt.emit("innerLoaded",Jn())})):(Z||Le||Ae||Fe||!le)&&O(l,{resize:Xi}),Fe&&("outer"===K?yt.on("innerLoaded",un):_t||un()),sn(),_t?tn():Mt&&en(),yt.on("indexChanged",hn),"inner"===K&&yt.emit("innerLoaded",Jn()),"function"==typeof vt&&vt(Jn()),ve=!0}function Xi(e){t((function(){Gi(zn(e))}))}function Gi(t){if(ve){"outer"===K&&yt.emit("outerResized",Jn(t)),ge=Ei();var n,r=oe,a=!1;Z&&(Ki(),(n=r!==oe)&&yt.emit("newBreakpointStart",Jn(t)));var s,o,l,c,u=Oe,p=_t,m=Mt,y=Ie,b=Re,x=Be,_=Ve,w=We,k=Ue,A=Xe,L=Ge,T=ct;if(n){var C=Le,D=Fe,E=ze,Y=Ee,I=$e;if(!H)var N=Ce,j=Te}if(Ie=Ii("arrowKeys"),Re=Ii("controls"),Be=Ii("nav"),Ve=Ii("touch"),Ee=Ii("center"),We=Ii("mouseDrag"),Ue=Ii("autoplay"),Xe=Ii("autoplayHoverPause"),Ge=Ii("autoplayResetOnVisibility"),n&&(_t=Ii("disable"),Le=Ii("fixedWidth"),Ne=Ii("speed"),Fe=Ii("autoHeight"),ze=Ii("controlsText"),$e=Ii("autoplayText"),qe=Ii("autoplayTimeout"),H||(Te=Ii("edgePadding"),Ce=Ii("gutter"))),Ai(_t),De=Pi(),le&&!Ae||_t||(mn(),le||(Gn(),a=!0)),(Le||Ae)&&(nt=Mn(),ht=lt()),(n||Le)&&(Oe=Ii("items"),Pe=Ii("slideBy"),(o=Oe!==u)&&(Le||Ae||(ht=lt()),Mi())),n&&_t!==p&&(_t?tn():function(){if(wt){if(Ze.disabled=!1,de.className+=bt,An(),He)for(var e=et;e--;)J&&S(pe[e]),S(pe[tt-e-1]);if(!J)for(var t=ct,i=ct+me;t<i;t++){var n=pe[t],r=t<ct+Oe?ie:ae;n.style.left=100*(t-ct)/Oe+"%",g(n,r)}Qi(),wt=!1}}()),kt&&(n||Le||Ae)&&(Mt=Zi())!==m&&(Mt?(Ln(Sn(Ti(0))),en()):(function(){if(St){if(Te&&H&&(ue.style.margin=""),et)for(var e="tns-transparent",t=et;t--;)J&&v(pe[t],e),v(pe[tt-t-1],e);Qi(),St=!1}}(),a=!0)),Ai(_t||Mt),Ue||(Xe=Ge=!1),Ie!==y&&(Ie?O(i,Dt):P(i,Dt)),Re!==b&&(Re?qt?S(qt):(Xt&&S(Xt),Gt&&S(Gt)):qt?M(qt):(Xt&&M(Xt),Gt&&M(Gt))),Be!==x&&(Be?(S(Qt),Kn()):M(Qt)),Ve!==_&&(Ve?O(de,Et,e.preventScrollOnTouch):P(de,Et)),We!==w&&(We?O(de,Ot):P(de,Ot)),Ue!==k&&(Ue?(mi&&S(mi),ui||hi||jn()):(mi&&M(mi),ui&&Hn())),Xe!==A&&(Xe?O(de,Tt):P(de,Tt)),Ge!==L&&(Ge?O(i,Ct):P(i,Ct)),n){if(Le===C&&Ee===Y||(a=!0),Fe!==D&&(Fe||(ue.style.height="")),Re&&ze!==E&&(Xt.innerHTML=ze[0],Gt.innerHTML=ze[1]),mi&&$e!==I){var F=Ue?1:0,R=mi.innerHTML,z=R.length-I[F].length;R.substring(z)===I[F]&&(mi.innerHTML=R.substring(0,z)+$e[F])}}else Ee&&(Le||Ae)&&(a=!0);if((o||Le&&!Ae)&&(ti=Zn(),Kn()),(s=ct!==T)?(yt.emit("indexChanged",Jn()),a=!0):o?s||hn():(Le||Ae)&&(sn(),gn(),nn()),o&&!J&&function(){for(var e=ct+Math.min(me,Oe),t=tt;t--;){var i=pe[t];ct<=t&&t<e?(g(i,"tns-moving"),i.style.left=100*(t-ct)/Oe+"%",g(i,ie),v(i,ae)):i.style.left&&(i.style.left="",g(i,ae),v(i,ie)),v(i,ne)}setTimeout((function(){f(pe,(function(e){v(e,"tns-moving")}))}),300)}(),!_t&&!Mt){if(n&&!H&&(Te===j&&Ce===N||(ue.style.cssText=Ni(Te,Ce,Le,Ne,Fe)),le)){J&&(de.style.width=ji(Le,Ce,Oe));var B=Hi(Le,Ce,Oe)+Fi(Ce);c=h(l=Ze)-1,"deleteRule"in l?l.deleteRule(c):l.removeRule(c),d(Ze,"#"+xt+" > .tns-item",B,h(Ze))}Fe&&un(),a&&(An(),ut=ct)}n&&yt.emit("newBreakpointEnd",Jn(t))}}function Zi(){if(!Le&&!Ae)return me<=(Ee?Oe-(Oe-1)/2:Oe);var e=Le?(Le+Ce)*me:ye[me],t=Te?De+2*Te:De+Ce;return Ee&&(t-=Le?(De-Le)/2:(De-(ye[ct+1]-ye[ct]-Ce))/2),e<=t}function Ki(){for(var e in oe=0,Z)(e=parseInt(e))<=ge&&(oe=e)}function Ji(){!Ue&&mi&&M(mi),!Be&&Qt&&M(Qt),Re||(qt?M(qt):(Xt&&M(Xt),Gt&&M(Gt)))}function Qi(){Ue&&mi&&S(mi),Be&&Qt&&S(Qt),Re&&(qt?S(qt):(Xt&&S(Xt),Gt&&S(Gt)))}function en(){if(!St){if(Te&&(ue.style.margin="0px"),et)for(var e="tns-transparent",t=et;t--;)J&&g(pe[t],e),g(pe[tt-t-1],e);Ji(),St=!0}}function tn(){if(!wt){if(Ze.disabled=!0,de.className=de.className.replace(bt.substring(1),""),w(de,["style"]),He)for(var e=et;e--;)J&&M(pe[e]),M(pe[tt-e-1]);if(le&&J||w(ue,["style"]),!J)for(var t=ct,i=ct+me;t<i;t++){var n=pe[t];w(n,["style"]),v(n,ie),v(n,ae)}Ji(),wt=!0}}function nn(){var e=rn();xe.innerHTML!==e&&(xe.innerHTML=e)}function rn(){var e=an(),t=e[0]+1,i=e[1]+1;return t===i?t+"":t+" to "+i}function an(e){null==e&&(e=Sn());var t,i,n,r=ct;if(Ee||Te?(Ae||Le)&&(i=-(parseFloat(e)+Te),n=i+De+2*Te):Ae&&(i=ye[ct],n=i+De),Ae)ye.forEach((function(e,a){a<tt&&((Ee||Te)&&e<=i+.5&&(r=a),.5<=n-e&&(t=a))}));else{if(Le){var a=Le+Ce;Ee||Te?(r=Math.floor(i/a),t=Math.ceil(n/a-1)):t=r+Math.ceil(De/a)-1}else if(Ee||Te){var s=Oe-1;if(Ee?(r-=s/2,t=ct+s/2):t=ct+s,Te){var o=Te*Oe/De;r-=o,t+=o}r=Math.floor(r),t=Math.ceil(t)}else t=r+Oe-1;r=Math.max(r,0),t=Math.min(t,tt-1)}return[r,t]}function sn(){if(Ke&&!_t){var e=an();e.push(Je),cn.apply(null,e).forEach((function(e){if(!m(e,zt)){var t={};t[U]=function(e){e.stopPropagation()},O(e,t),O(e,Bt),e.src=b(e,"data-src");var i=b(e,"data-srcset");i&&(e.srcset=i),g(e,"loading")}}))}}function on(e){g(e,"loaded"),ln(e)}function ln(e){g(e,zt),v(e,"loading"),P(e,Bt)}function cn(e,t,i){var n=[];for(i||(i="img");e<=t;)f(pe[e].querySelectorAll(i),(function(e){n.push(e)})),e++;return n}function un(){var e=cn.apply(null,an());t((function(){dn(e,pn)}))}function dn(e,i){return be?i():(e.forEach((function(t,i){!Ke&&t.complete&&ln(t),m(t,zt)&&e.splice(i,1)})),e.length?void t((function(){dn(e,i)})):i())}function hn(){sn(),gn(),nn(),_n(),function(){if(Be&&(ri=0<=ni?ni:Di(),ni=-1,ri!==ai)){var e=Jt[ai],t=Jt[ri];_(e,{tabindex:"-1","aria-label":oi+(ai+1)}),v(e,si),_(t,{"aria-label":oi+(ri+1)+li}),w(t,"tabindex"),g(t,si),ai=ri}}()}function fn(e,t){for(var i=[],n=e,r=Math.min(e+t,tt);n<r;n++)i.push(pe[n].offsetHeight);return Math.max.apply(null,i)}function pn(){var e=Fe?fn(ct,Oe):fn(et,me),t=se||ue;t.style.height!==e&&(t.style.height=e+"px")}function mn(){ye=[0];var e=le?"left":"top",t=le?"right":"bottom",i=pe[0].getBoundingClientRect()[e];f(pe,(function(n,r){r&&ye.push(n.getBoundingClientRect()[e]-i),r===tt-1&&ye.push(n.getBoundingClientRect()[t]-i)}))}function gn(){var e=an(),t=e[0],i=e[1];f(pe,(function(e,n){t<=n&&n<=i?y(e,"aria-hidden")&&(w(e,["aria-hidden","tabindex"]),g(e,Ft)):y(e,"aria-hidden")||(_(e,{"aria-hidden":"true",tabindex:"-1"}),v(e,Ft))}))}function vn(e){return e.nodeName.toLowerCase()}function yn(e){return"button"===vn(e)}function bn(e){return"true"===e.getAttribute("aria-disabled")}function xn(e,t,i){e?t.disabled=i:t.setAttribute("aria-disabled",i.toString())}function _n(){if(Re&&!je&&!He){var e=Wt?Xt.disabled:bn(Xt),t=Ut?Gt.disabled:bn(Gt),i=ct<=dt,n=!je&&ht<=ct;i&&!e&&xn(Wt,Xt,!0),!i&&e&&xn(Wt,Xt,!1),n&&!t&&xn(Ut,Gt,!0),!n&&t&&xn(Ut,Gt,!1)}}function wn(e,t){z&&(e.style[z]=t)}function kn(e){return null==e&&(e=ct),Ae?(De-(Te?Ce:0)-(ye[e+1]-ye[e]-Ce))/2:Le?(De-Le)/2:(Oe-1)/2}function Mn(){var e=De+(Te?Ce:0)-(Le?(Le+Ce)*tt:ye[tt]);return Ee&&!He&&(e=Le?-(Le+Ce)*(tt-1)-kn():kn(tt-1)-ye[tt-1]),0<e&&(e=0),e}function Sn(e){var t;if(null==e&&(e=ct),le&&!Ae)if(Le)t=-(Le+Ce)*e,Ee&&(t+=kn());else{var i=F?tt:Oe;Ee&&(e-=kn()),t=100*-e/i}else t=-ye[e],Ee&&Ae&&(t+=kn());return it&&(t=Math.max(t,nt)),t+(!le||Ae||Le?"px":"%")}function An(e){wn(de,"0s"),Ln(e)}function Ln(e){null==e&&(e=Sn()),de.style[at]=st+e+ot}function Tn(e,t,i,n){var r=e+Oe;He||(r=Math.min(r,tt));for(var a=e;a<r;a++){var s=pe[a];n||(s.style.left=100*(a-ct)/Oe+"%"),re&&B&&(s.style[B]=s.style[W]=re*(a-e)/1e3+"s"),v(s,t),g(s,i),n&&Qe.push(s)}}function Cn(e,t){rt&&Mi(),(ct!==ut||t)&&(yt.emit("indexChanged",Jn()),yt.emit("transitionStart",Jn()),Fe&&un(),ui&&e&&0<=["click","keydown"].indexOf(e.type)&&Hn(),gt=!0,Si())}function Dn(e){return e.toLowerCase().replace(/-/g,"")}function En(e){if(J||gt){if(yt.emit("transitionEnd",Jn(e)),!J&&0<Qe.length)for(var t=0;t<Qe.length;t++){var i=Qe[t];i.style.left="",W&&B&&(i.style[W]="",i.style[B]=""),v(i,ne),g(i,ae)}if(!e||!J&&e.target.parentNode===de||e.target===de&&Dn(e.propertyName)===Dn(at)){if(!rt){var n=ct;Mi(),ct!==n&&(yt.emit("indexChanged",Jn()),An())}"inner"===K&&yt.emit("innerLoaded",Jn()),gt=!1,ut=ct}}}function On(e,t){if(!Mt)if("prev"===e)Pn(t,-1);else if("next"===e)Pn(t,1);else{if(gt){if(ft)return;En()}var i=Ci(),n=0;if("first"===e?n=-i:"last"===e?n=J?me-Oe-i:me-1-i:("number"!=typeof e&&(e=parseInt(e)),isNaN(e)||(t||(e=Math.max(0,Math.min(me-1,e))),n=e-i)),!J&&n&&Math.abs(n)<Oe){var r=0<n?1:-1;n+=dt<=ct+n-me?me*r:2*me*r*-1}ct+=n,J&&He&&(ct<dt&&(ct+=me),ht<ct&&(ct-=me)),Ci(ct)!==Ci(ut)&&Cn(t)}}function Pn(e,t){if(gt){if(ft)return;En()}var i;if(!t){for(var n=Bn(e=zn(e));n!==qt&&[Xt,Gt].indexOf(n)<0;)n=n.parentNode;var r=[Xt,Gt].indexOf(n);0<=r&&(i=!0,t=0===r?-1:1)}if(je){if(ct===dt&&-1===t)return void On("last",e);if(ct===ht&&1===t)return void On("first",e)}t&&(ct+=Pe*t,Ae&&(ct=Math.floor(ct)),Cn(i||e&&"keydown"===e.type?e:null))}function Yn(){ci=setInterval((function(){Pn(null,pi)}),qe),ui=!0}function In(){clearInterval(ci),ui=!1}function Nn(e,t){_(mi,{"data-action":e}),mi.innerHTML=vi[0]+e+vi[1]+t}function jn(){Yn(),mi&&Nn("stop",$e[1])}function Hn(){In(),mi&&Nn("start",$e[0])}function Fn(){ui?(Hn(),hi=!0):(jn(),hi=!1)}function Rn(e){e.focus()}function zn(e){return Vn(e=e||l.event)?e.changedTouches[0]:e}function Bn(e){return e.target||l.event.srcElement}function Vn(e){return 0<=e.type.indexOf("touch")}function Wn(e){e.preventDefault?e.preventDefault():e.returnValue=!1}function Un(){return a=_i.y-xi.y,s=_i.x-xi.x,t=Math.atan2(a,s)*(180/Math.PI),n=!1,90-(i=pt)<=(r=Math.abs(90-Math.abs(t)))?n="horizontal":r<=i&&(n="vertical"),n===e.axis;var t,i,n,r,a,s}function qn(e){if(gt){if(ft)return;En()}Ue&&ui&&In(),wi=!0,bi&&(n(bi),bi=null);var t=zn(e);yt.emit(Vn(e)?"touchStart":"dragStart",Jn(e)),!Vn(e)&&0<=["img","a"].indexOf(vn(Bn(e)))&&Wn(e),_i.x=xi.x=t.clientX,_i.y=xi.y=t.clientY,J&&(yi=parseFloat(de.style[at].replace(st,"")),wn(de,"0s"))}function $n(e){if(wi){var i=zn(e);_i.x=i.clientX,_i.y=i.clientY,J?bi||(bi=t((function(){!function e(i){if(mt){if(n(bi),wi&&(bi=t((function(){e(i)}))),"?"===mt&&(mt=Un()),mt){!Vt&&Vn(i)&&(Vt=!0);try{i.type&&yt.emit(Vn(i)?"touchMove":"dragMove",Jn(i))}catch(e){}var r=yi,a=ki(_i,xi);if(!le||Le||Ae)r+=a,r+="px";else r+=F?a*Oe*100/((De+Ce)*tt):100*a/(De+Ce),r+="%";de.style[at]=st+r+ot}}else wi=!1}(e)}))):("?"===mt&&(mt=Un()),mt&&(Vt=!0)),("boolean"!=typeof e.cancelable||e.cancelable)&&Vt&&e.preventDefault()}}function Xn(i){if(wi){bi&&(n(bi),bi=null),J&&wn(de,""),wi=!1;var r=zn(i);_i.x=r.clientX,_i.y=r.clientY;var a=ki(_i,xi);if(Math.abs(a)){if(!Vn(i)){var s=Bn(i);O(s,{click:function e(t){Wn(t),P(s,{click:e})}})}J?bi=t((function(){if(le&&!Ae){var e=-a*Oe/(De+Ce);e=0<a?Math.floor(e):Math.ceil(e),ct+=e}else{var t=-(yi+a);if(t<=0)ct=dt;else if(t>=ye[tt-1])ct=ht;else for(var n=0;n<tt&&t>=ye[n];)t>ye[ct=n]&&a<0&&(ct+=1),n++}Cn(i,a),yt.emit(Vn(i)?"touchEnd":"dragEnd",Jn(i))})):mt&&Pn(i,0<a?-1:1)}}"auto"===e.preventScrollOnTouch&&(Vt=!1),pt&&(mt="?"),Ue&&!ui&&Yn()}function Gn(){(se||ue).style.height=ye[ct+Oe]-ye[ct]+"px"}function Zn(){var e=Le?(Le+Ce)*me/De:me/Oe;return Math.min(Math.ceil(e),me)}function Kn(){if(Be&&!It&&ti!==ii){var e=ii,t=ti,i=S;for(ti<ii&&(e=ti,t=ii,i=M);e<t;)i(Jt[e]),e++;ii=ti}}function Jn(e){return{container:de,slideItems:pe,navContainer:Qt,navItems:Jt,controlsContainer:qt,hasControls:Pt,prevButton:Xt,nextButton:Gt,items:Oe,slideBy:Pe,cloneCount:et,slideCount:me,slideCountNew:tt,index:ct,indexCached:ut,displayIndex:Li(),navCurrentIndex:ri,navCurrentIndexCached:ai,pages:ti,pagesCached:ii,sheet:Ze,isOn:ve,event:e||{}}}$&&console.warn("No slides found in",e.container)};return I}();!function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).noUiSlider={})}(this,(function(e){"use strict";var t,i;function n(e){return"object"==typeof e&&"function"==typeof e.to}function r(e){e.parentElement.removeChild(e)}function a(e){return null!=e}function s(e){e.preventDefault()}function o(e){return"number"==typeof e&&!isNaN(e)&&isFinite(e)}function l(e,t,i){i>0&&(h(e,t),setTimeout((function(){f(e,t)}),i))}function c(e){return Math.max(Math.min(e,100),0)}function u(e){return Array.isArray(e)?e:[e]}function d(e){var t=(e=String(e)).split(".");return t.length>1?t[1].length:0}function h(e,t){e.classList&&!/\s/.test(t)?e.classList.add(t):e.className+=" "+t}function f(e,t){e.classList&&!/\s/.test(t)?e.classList.remove(t):e.className=e.className.replace(new RegExp("(^|\\b)"+t.split(" ").join("|")+"(\\b|$)","gi")," ")}function p(e){var t=void 0!==window.pageXOffset,i="CSS1Compat"===(e.compatMode||"");return{x:t?window.pageXOffset:i?e.documentElement.scrollLeft:e.body.scrollLeft,y:t?window.pageYOffset:i?e.documentElement.scrollTop:e.body.scrollTop}}function m(e,t){return 100/(t-e)}function g(e,t,i){return 100*t/(e[i+1]-e[i])}function v(e,t){for(var i=1;e>=t[i];)i+=1;return i}function y(e,t,i){if(i>=e.slice(-1)[0])return 100;var n=v(i,e),r=e[n-1],a=e[n],s=t[n-1],o=t[n];return s+function(e,t){return g(e,e[0]<0?t+Math.abs(e[0]):t-e[0],0)}([r,a],i)/m(s,o)}function b(e,t,i,n){if(100===n)return n;var r=v(n,e),a=e[r-1],s=e[r];return i?n-a>(s-a)/2?s:a:t[r-1]?e[r-1]+function(e,t){return Math.round(e/t)*t}(n-e[r-1],t[r-1]):n}e.PipsMode=void 0,(t=e.PipsMode||(e.PipsMode={})).Range="range",t.Steps="steps",t.Positions="positions",t.Count="count",t.Values="values",e.PipsType=void 0,(i=e.PipsType||(e.PipsType={}))[i.None=-1]="None",i[i.NoValue=0]="NoValue",i[i.LargeValue=1]="LargeValue",i[i.SmallValue=2]="SmallValue";var x=function(){function e(e,t,i){var n;this.xPct=[],this.xVal=[],this.xSteps=[],this.xNumSteps=[],this.xHighestCompleteStep=[],this.xSteps=[i||!1],this.xNumSteps=[!1],this.snap=t;var r=[];for(Object.keys(e).forEach((function(t){r.push([u(e[t]),t])})),r.sort((function(e,t){return e[0][0]-t[0][0]})),n=0;n<r.length;n++)this.handleEntryPoint(r[n][1],r[n][0]);for(this.xNumSteps=this.xSteps.slice(0),n=0;n<this.xNumSteps.length;n++)this.handleStepPoint(n,this.xNumSteps[n])}return e.prototype.getDistance=function(e){for(var t=[],i=0;i<this.xNumSteps.length-1;i++)t[i]=g(this.xVal,e,i);return t},e.prototype.getAbsoluteDistance=function(e,t,i){var n,r=0;if(e<this.xPct[this.xPct.length-1])for(;e>this.xPct[r+1];)r++;else e===this.xPct[this.xPct.length-1]&&(r=this.xPct.length-2);i||e!==this.xPct[r+1]||r++,null===t&&(t=[]);var a=1,s=t[r],o=0,l=0,c=0,u=0;for(n=i?(e-this.xPct[r])/(this.xPct[r+1]-this.xPct[r]):(this.xPct[r+1]-e)/(this.xPct[r+1]-this.xPct[r]);s>0;)o=this.xPct[r+1+u]-this.xPct[r+u],t[r+u]*a+100-100*n>100?(l=o*n,a=(s-100*n)/t[r+u],n=1):(l=t[r+u]*o/100*a,a=0),i?(c-=l,this.xPct.length+u>=1&&u--):(c+=l,this.xPct.length-u>=1&&u++),s=t[r+u]*a;return e+c},e.prototype.toStepping=function(e){return e=y(this.xVal,this.xPct,e)},e.prototype.fromStepping=function(e){return function(e,t,i){if(i>=100)return e.slice(-1)[0];var n=v(i,t),r=e[n-1],a=e[n],s=t[n-1];return function(e,t){return t*(e[1]-e[0])/100+e[0]}([r,a],(i-s)*m(s,t[n]))}(this.xVal,this.xPct,e)},e.prototype.getStep=function(e){return e=b(this.xPct,this.xSteps,this.snap,e)},e.prototype.getDefaultStep=function(e,t,i){var n=v(e,this.xPct);return(100===e||t&&e===this.xPct[n-1])&&(n=Math.max(n-1,1)),(this.xVal[n]-this.xVal[n-1])/i},e.prototype.getNearbySteps=function(e){var t=v(e,this.xPct);return{stepBefore:{startValue:this.xVal[t-2],step:this.xNumSteps[t-2],highestStep:this.xHighestCompleteStep[t-2]},thisStep:{startValue:this.xVal[t-1],step:this.xNumSteps[t-1],highestStep:this.xHighestCompleteStep[t-1]},stepAfter:{startValue:this.xVal[t],step:this.xNumSteps[t],highestStep:this.xHighestCompleteStep[t]}}},e.prototype.countStepDecimals=function(){var e=this.xNumSteps.map(d);return Math.max.apply(null,e)},e.prototype.hasNoSize=function(){return this.xVal[0]===this.xVal[this.xVal.length-1]},e.prototype.convert=function(e){return this.getStep(this.toStepping(e))},e.prototype.handleEntryPoint=function(e,t){var i;if(!o(i="min"===e?0:"max"===e?100:parseFloat(e))||!o(t[0]))throw new Error("noUiSlider: 'range' value isn't numeric.");this.xPct.push(i),this.xVal.push(t[0]);var n=Number(t[1]);i?this.xSteps.push(!isNaN(n)&&n):isNaN(n)||(this.xSteps[0]=n),this.xHighestCompleteStep.push(0)},e.prototype.handleStepPoint=function(e,t){if(t)if(this.xVal[e]!==this.xVal[e+1]){this.xSteps[e]=g([this.xVal[e],this.xVal[e+1]],t,0)/m(this.xPct[e],this.xPct[e+1]);var i=(this.xVal[e+1]-this.xVal[e])/this.xNumSteps[e],n=Math.ceil(Number(i.toFixed(3))-1),r=this.xVal[e]+this.xNumSteps[e]*n;this.xHighestCompleteStep[e]=r}else this.xSteps[e]=this.xHighestCompleteStep[e]=this.xVal[e]},e}(),_={to:function(e){return void 0===e?"":e.toFixed(2)},from:Number},w={target:"target",base:"base",origin:"origin",handle:"handle",handleLower:"handle-lower",handleUpper:"handle-upper",touchArea:"touch-area",horizontal:"horizontal",vertical:"vertical",background:"background",connect:"connect",connects:"connects",ltr:"ltr",rtl:"rtl",textDirectionLtr:"txt-dir-ltr",textDirectionRtl:"txt-dir-rtl",draggable:"draggable",drag:"state-drag",tap:"state-tap",active:"active",tooltip:"tooltip",pips:"pips",pipsHorizontal:"pips-horizontal",pipsVertical:"pips-vertical",marker:"marker",markerHorizontal:"marker-horizontal",markerVertical:"marker-vertical",markerNormal:"marker-normal",markerLarge:"marker-large",markerSub:"marker-sub",value:"value",valueHorizontal:"value-horizontal",valueVertical:"value-vertical",valueNormal:"value-normal",valueLarge:"value-large",valueSub:"value-sub"},k={tooltips:".__tooltips",aria:".__aria"};function M(e,t){if(!o(t))throw new Error("noUiSlider: 'step' is not numeric.");e.singleStep=t}function S(e,t){if(!o(t))throw new Error("noUiSlider: 'keyboardPageMultiplier' is not numeric.");e.keyboardPageMultiplier=t}function A(e,t){if(!o(t))throw new Error("noUiSlider: 'keyboardMultiplier' is not numeric.");e.keyboardMultiplier=t}function L(e,t){if(!o(t))throw new Error("noUiSlider: 'keyboardDefaultStep' is not numeric.");e.keyboardDefaultStep=t}function T(e,t){if("object"!=typeof t||Array.isArray(t))throw new Error("noUiSlider: 'range' is not an object.");if(void 0===t.min||void 0===t.max)throw new Error("noUiSlider: Missing 'min' or 'max' in 'range'.");e.spectrum=new x(t,e.snap||!1,e.singleStep)}function C(e,t){if(t=u(t),!Array.isArray(t)||!t.length)throw new Error("noUiSlider: 'start' option is incorrect.");e.handles=t.length,e.start=t}function D(e,t){if("boolean"!=typeof t)throw new Error("noUiSlider: 'snap' option must be a boolean.");e.snap=t}function E(e,t){if("boolean"!=typeof t)throw new Error("noUiSlider: 'animate' option must be a boolean.");e.animate=t}function O(e,t){if("number"!=typeof t)throw new Error("noUiSlider: 'animationDuration' option must be a number.");e.animationDuration=t}function P(e,t){var i,n=[!1];if("lower"===t?t=[!0,!1]:"upper"===t&&(t=[!1,!0]),!0===t||!1===t){for(i=1;i<e.handles;i++)n.push(t);n.push(!1)}else{if(!Array.isArray(t)||!t.length||t.length!==e.handles+1)throw new Error("noUiSlider: 'connect' option doesn't match handle count.");n=t}e.connect=n}function Y(e,t){switch(t){case"horizontal":e.ort=0;break;case"vertical":e.ort=1;break;default:throw new Error("noUiSlider: 'orientation' option is invalid.")}}function I(e,t){if(!o(t))throw new Error("noUiSlider: 'margin' option must be numeric.");0!==t&&(e.margin=e.spectrum.getDistance(t))}function N(e,t){if(!o(t))throw new Error("noUiSlider: 'limit' option must be numeric.");if(e.limit=e.spectrum.getDistance(t),!e.limit||e.handles<2)throw new Error("noUiSlider: 'limit' option is only supported on linear sliders with 2 or more handles.")}function j(e,t){var i;if(!o(t)&&!Array.isArray(t))throw new Error("noUiSlider: 'padding' option must be numeric or array of exactly 2 numbers.");if(Array.isArray(t)&&2!==t.length&&!o(t[0])&&!o(t[1]))throw new Error("noUiSlider: 'padding' option must be numeric or array of exactly 2 numbers.");if(0!==t){for(Array.isArray(t)||(t=[t,t]),e.padding=[e.spectrum.getDistance(t[0]),e.spectrum.getDistance(t[1])],i=0;i<e.spectrum.xNumSteps.length-1;i++)if(e.padding[0][i]<0||e.padding[1][i]<0)throw new Error("noUiSlider: 'padding' option must be a positive number(s).");var n=t[0]+t[1],r=e.spectrum.xVal[0];if(n/(e.spectrum.xVal[e.spectrum.xVal.length-1]-r)>1)throw new Error("noUiSlider: 'padding' option must not exceed 100% of the range.")}}function H(e,t){switch(t){case"ltr":e.dir=0;break;case"rtl":e.dir=1;break;default:throw new Error("noUiSlider: 'direction' option was not recognized.")}}function F(e,t){if("string"!=typeof t)throw new Error("noUiSlider: 'behaviour' must be a string containing options.");var i=t.indexOf("tap")>=0,n=t.indexOf("drag")>=0,r=t.indexOf("fixed")>=0,a=t.indexOf("snap")>=0,s=t.indexOf("hover")>=0,o=t.indexOf("unconstrained")>=0,l=t.indexOf("invert-connects")>=0,c=t.indexOf("drag-all")>=0,u=t.indexOf("smooth-steps")>=0;if(r){if(2!==e.handles)throw new Error("noUiSlider: 'fixed' behaviour must be used with 2 handles");I(e,e.start[1]-e.start[0])}if(l&&2!==e.handles)throw new Error("noUiSlider: 'invert-connects' behaviour must be used with 2 handles");if(o&&(e.margin||e.limit))throw new Error("noUiSlider: 'unconstrained' behaviour cannot be used with margin or limit");e.events={tap:i||a,drag:n,dragAll:c,smoothSteps:u,fixed:r,snap:a,hover:s,unconstrained:o,invertConnects:l}}function R(e,t){if(!1!==t)if(!0===t||n(t)){e.tooltips=[];for(var i=0;i<e.handles;i++)e.tooltips.push(t)}else{if((t=u(t)).length!==e.handles)throw new Error("noUiSlider: must pass a formatter for all handles.");t.forEach((function(e){if("boolean"!=typeof e&&!n(e))throw new Error("noUiSlider: 'tooltips' must be passed a formatter or 'false'.")})),e.tooltips=t}}function z(e,t){if(t.length!==e.handles)throw new Error("noUiSlider: must pass a attributes for all handles.");e.handleAttributes=t}function B(e,t){if(!n(t))throw new Error("noUiSlider: 'ariaFormat' requires 'to' method.");e.ariaFormat=t}function V(e,t){if(!function(e){return n(e)&&"function"==typeof e.from}(t))throw new Error("noUiSlider: 'format' requires 'to' and 'from' methods.");e.format=t}function W(e,t){if("boolean"!=typeof t)throw new Error("noUiSlider: 'keyboardSupport' option must be a boolean.");e.keyboardSupport=t}function U(e,t){e.documentElement=t}function q(e,t){if("string"!=typeof t&&!1!==t)throw new Error("noUiSlider: 'cssPrefix' must be a string or `false`.");e.cssPrefix=t}function $(e,t){if("object"!=typeof t)throw new Error("noUiSlider: 'cssClasses' must be an object.");"string"==typeof e.cssPrefix?(e.cssClasses={},Object.keys(t).forEach((function(i){e.cssClasses[i]=e.cssPrefix+t[i]}))):e.cssClasses=t}function X(e){var t={margin:null,limit:null,padding:null,animate:!0,animationDuration:300,ariaFormat:_,format:_},i={step:{r:!1,t:M},keyboardPageMultiplier:{r:!1,t:S},keyboardMultiplier:{r:!1,t:A},keyboardDefaultStep:{r:!1,t:L},start:{r:!0,t:C},connect:{r:!0,t:P},direction:{r:!0,t:H},snap:{r:!1,t:D},animate:{r:!1,t:E},animationDuration:{r:!1,t:O},range:{r:!0,t:T},orientation:{r:!1,t:Y},margin:{r:!1,t:I},limit:{r:!1,t:N},padding:{r:!1,t:j},behaviour:{r:!0,t:F},ariaFormat:{r:!1,t:B},format:{r:!1,t:V},tooltips:{r:!1,t:R},keyboardSupport:{r:!0,t:W},documentElement:{r:!1,t:U},cssPrefix:{r:!0,t:q},cssClasses:{r:!0,t:$},handleAttributes:{r:!1,t:z}},n={connect:!1,direction:"ltr",behaviour:"tap",orientation:"horizontal",keyboardSupport:!0,cssPrefix:"noUi-",cssClasses:w,keyboardPageMultiplier:5,keyboardMultiplier:1,keyboardDefaultStep:10};e.format&&!e.ariaFormat&&(e.ariaFormat=e.format),Object.keys(i).forEach((function(r){if(a(e[r])||void 0!==n[r])i[r].t(t,a(e[r])?e[r]:n[r]);else if(i[r].r)throw new Error("noUiSlider: '"+r+"' is required.")})),t.pips=e.pips;var r=document.createElement("div"),s=void 0!==r.style.msTransform,o=void 0!==r.style.transform;t.transformRule=o?"transform":s?"msTransform":"webkitTransform";return t.style=[["left","top"],["right","bottom"]][t.dir][t.ort],t}function G(t,i,n){var o,d,m,g,v,y,b,x=window.navigator.pointerEnabled?{start:"pointerdown",move:"pointermove",end:"pointerup"}:window.navigator.msPointerEnabled?{start:"MSPointerDown",move:"MSPointerMove",end:"MSPointerUp"}:{start:"mousedown touchstart",move:"mousemove touchmove",end:"mouseup touchend"},_=window.CSS&&CSS.supports&&CSS.supports("touch-action","none")&&function(){var e=!1;try{var t=Object.defineProperty({},"passive",{get:function(){e=!0}});window.addEventListener("test",null,t)}catch(e){}return e}(),w=t,M=i.spectrum,S=[],A=[],L=[],T=0,C={},D=!1,E=t.ownerDocument,O=i.documentElement||E.documentElement,Y=E.body,I="rtl"===E.dir||1===i.ort?0:100;function N(e,t){var i=E.createElement("div");return t&&h(i,t),e.appendChild(i),i}function j(e,t){var n=N(e,i.cssClasses.origin),r=N(n,i.cssClasses.handle);if(N(r,i.cssClasses.touchArea),r.setAttribute("data-handle",String(t)),i.keyboardSupport&&(r.setAttribute("tabindex","0"),r.addEventListener("keydown",(function(e){return function(e,t){if(R()||z(t))return!1;var n=["Left","Right"],r=["Down","Up"],a=["PageDown","PageUp"],s=["Home","End"];i.dir&&!i.ort?n.reverse():i.ort&&!i.dir&&(r.reverse(),a.reverse());var o,l=e.key.replace("Arrow",""),c=l===a[0],u=l===a[1],d=l===r[0]||l===n[0]||c,h=l===r[1]||l===n[1]||u,f=l===s[0],p=l===s[1];if(!(d||h||f||p))return!0;if(e.preventDefault(),h||d){var m=d?0:1,g=xe(t)[m];if(null===g)return!1;!1===g&&(g=M.getDefaultStep(A[t],d,i.keyboardDefaultStep)),g*=u||c?i.keyboardPageMultiplier:i.keyboardMultiplier,g=Math.max(g,1e-7),g*=d?-1:1,o=S[t]+g}else o=p?i.spectrum.xVal[i.spectrum.xVal.length-1]:i.spectrum.xVal[0];return me(t,M.toStepping(o),!0,!0),le("slide",t),le("update",t),le("change",t),le("set",t),!1}(e,t)}))),void 0!==i.handleAttributes){var a=i.handleAttributes[t];Object.keys(a).forEach((function(e){r.setAttribute(e,a[e])}))}return r.setAttribute("role","slider"),r.setAttribute("aria-orientation",i.ort?"vertical":"horizontal"),0===t?h(r,i.cssClasses.handleLower):t===i.handles-1&&h(r,i.cssClasses.handleUpper),n.handle=r,n}function H(e,t){return!!t&&N(e,i.cssClasses.connect)}function F(e,t){return!(!i.tooltips||!i.tooltips[t])&&N(e.firstChild,i.cssClasses.tooltip)}function R(){return w.hasAttribute("disabled")}function z(e){return m[e].hasAttribute("disabled")}function B(){y&&(oe("update"+k.tooltips),y.forEach((function(e){e&&r(e)})),y=null)}function V(){B(),y=m.map(F),se("update"+k.tooltips,(function(e,t,n){if(y&&i.tooltips&&!1!==y[t]){var r=e[t];!0!==i.tooltips[t]&&(r=i.tooltips[t].to(n[t])),y[t].innerHTML=r}}))}function W(e,t){return e.map((function(e){return M.fromStepping(t?M.getStep(e):e)}))}function U(t){var i,n=function(t){if(t.mode===e.PipsMode.Range||t.mode===e.PipsMode.Steps)return M.xVal;if(t.mode===e.PipsMode.Count){if(t.values<2)throw new Error("noUiSlider: 'values' (>= 2) required for mode 'count'.");for(var i=t.values-1,n=100/i,r=[];i--;)r[i]=i*n;return r.push(100),W(r,t.stepped)}return t.mode===e.PipsMode.Positions?W(t.values,t.stepped):t.mode===e.PipsMode.Values?t.stepped?t.values.map((function(e){return M.fromStepping(M.getStep(M.toStepping(e)))})):t.values:[]}(t),r={},a=M.xVal[0],s=M.xVal[M.xVal.length-1],o=!1,l=!1,c=0;return i=n.slice().sort((function(e,t){return e-t})),(n=i.filter((function(e){return!this[e]&&(this[e]=!0)}),{}))[0]!==a&&(n.unshift(a),o=!0),n[n.length-1]!==s&&(n.push(s),l=!0),n.forEach((function(i,a){var s,u,d,h,f,p,m,g,v,y,b=i,x=n[a+1],_=t.mode===e.PipsMode.Steps;for(_&&(s=M.xNumSteps[a]),s||(s=x-b),void 0===x&&(x=b),s=Math.max(s,1e-7),u=b;u<=x;u=Number((u+s).toFixed(7))){for(g=(f=(h=M.toStepping(u))-c)/(t.density||1),y=f/(v=Math.round(g)),d=1;d<=v;d+=1)r[(p=c+d*y).toFixed(5)]=[M.fromStepping(p),0];m=n.indexOf(u)>-1?e.PipsType.LargeValue:_?e.PipsType.SmallValue:e.PipsType.NoValue,!a&&o&&u!==x&&(m=0),u===x&&l||(r[h.toFixed(5)]=[u,m]),c=h}})),r}function q(t,n,r){var a,s,o=E.createElement("div"),l=((a={})[e.PipsType.None]="",a[e.PipsType.NoValue]=i.cssClasses.valueNormal,a[e.PipsType.LargeValue]=i.cssClasses.valueLarge,a[e.PipsType.SmallValue]=i.cssClasses.valueSub,a),c=((s={})[e.PipsType.None]="",s[e.PipsType.NoValue]=i.cssClasses.markerNormal,s[e.PipsType.LargeValue]=i.cssClasses.markerLarge,s[e.PipsType.SmallValue]=i.cssClasses.markerSub,s),u=[i.cssClasses.valueHorizontal,i.cssClasses.valueVertical],d=[i.cssClasses.markerHorizontal,i.cssClasses.markerVertical];function f(e,t){var n=t===i.cssClasses.value,r=n?l:c;return t+" "+(n?u:d)[i.ort]+" "+r[e]}return h(o,i.cssClasses.pips),h(o,0===i.ort?i.cssClasses.pipsHorizontal:i.cssClasses.pipsVertical),Object.keys(t).forEach((function(a){!function(t,a,s){if((s=n?n(a,s):s)!==e.PipsType.None){var l=N(o,!1);l.className=f(s,i.cssClasses.marker),l.style[i.style]=t+"%",s>e.PipsType.NoValue&&((l=N(o,!1)).className=f(s,i.cssClasses.value),l.setAttribute("data-value",String(a)),l.style[i.style]=t+"%",l.innerHTML=String(r.to(a)))}}(a,t[a][0],t[a][1])})),o}function $(){v&&(r(v),v=null)}function G(e){$();var t=U(e),i=e.filter,n=e.format||{to:function(e){return String(Math.round(e))}};return v=w.appendChild(q(t,i,n))}function Z(){var e=o.getBoundingClientRect(),t="offset"+["Width","Height"][i.ort];return 0===i.ort?e.width||o[t]:e.height||o[t]}function K(e,t,n,r){var a=function(a){var s,o,l=function(e,t,i){var n=0===e.type.indexOf("touch"),r=0===e.type.indexOf("mouse"),a=0===e.type.indexOf("pointer"),s=0,o=0;0===e.type.indexOf("MSPointer")&&(a=!0);if("mousedown"===e.type&&!e.buttons&&!e.touches)return!1;if(n){var l=function(t){var n=t.target;return n===i||i.contains(n)||e.composed&&e.composedPath().shift()===i};if("touchstart"===e.type){var c=Array.prototype.filter.call(e.touches,l);if(c.length>1)return!1;s=c[0].pageX,o=c[0].pageY}else{var u=Array.prototype.find.call(e.changedTouches,l);if(!u)return!1;s=u.pageX,o=u.pageY}}t=t||p(E),(r||a)&&(s=e.clientX+t.x,o=e.clientY+t.y);return e.pageOffset=t,e.points=[s,o],e.cursor=r||a,e}(a,r.pageOffset,r.target||t);return!!l&&(!(R()&&!r.doNotReject)&&(s=w,o=i.cssClasses.tap,!((s.classList?s.classList.contains(o):new RegExp("\\b"+o+"\\b").test(s.className))&&!r.doNotReject)&&(!(e===x.start&&void 0!==l.buttons&&l.buttons>1)&&((!r.hover||!l.buttons)&&(_||l.preventDefault(),l.calcPoint=l.points[i.ort],void n(l,r))))))},s=[];return e.split(" ").forEach((function(e){t.addEventListener(e,a,!!_&&{passive:!0}),s.push([e,a])})),s}function J(e){var t,n,r,a,s,l,u=100*(e-(t=o,n=i.ort,r=t.getBoundingClientRect(),a=t.ownerDocument,s=a.documentElement,l=p(a),/webkit.*Chrome.*Mobile/i.test(navigator.userAgent)&&(l.x=0),n?r.top+l.y-s.clientTop:r.left+l.x-s.clientLeft))/Z();return u=c(u),i.dir?100-u:u}function Q(e,t){"mouseout"===e.type&&"HTML"===e.target.nodeName&&null===e.relatedTarget&&te(e,t)}function ee(e,t){if(-1===navigator.appVersion.indexOf("MSIE 9")&&0===e.buttons&&0!==t.buttonsProperty)return te(e,t);var n=(i.dir?-1:1)*(e.calcPoint-t.startCalcPoint);de(n>0,100*n/t.baseSize,t.locations,t.handleNumbers,t.connect)}function te(e,t){t.handle&&(f(t.handle,i.cssClasses.active),T-=1),t.listeners.forEach((function(e){O.removeEventListener(e[0],e[1])})),0===T&&(f(w,i.cssClasses.drag),pe(),e.cursor&&(Y.style.cursor="",Y.removeEventListener("selectstart",s))),i.events.smoothSteps&&(t.handleNumbers.forEach((function(e){me(e,A[e],!0,!0,!1,!1)})),t.handleNumbers.forEach((function(e){le("update",e)}))),t.handleNumbers.forEach((function(e){le("change",e),le("set",e),le("end",e)}))}function ie(e,t){if(!t.handleNumbers.some(z)){var n;if(1===t.handleNumbers.length)n=m[t.handleNumbers[0]].children[0],T+=1,h(n,i.cssClasses.active);e.stopPropagation();var r=[],a=K(x.move,O,ee,{target:e.target,handle:n,connect:t.connect,listeners:r,startCalcPoint:e.calcPoint,baseSize:Z(),pageOffset:e.pageOffset,handleNumbers:t.handleNumbers,buttonsProperty:e.buttons,locations:A.slice()}),o=K(x.end,O,te,{target:e.target,handle:n,listeners:r,doNotReject:!0,handleNumbers:t.handleNumbers}),l=K("mouseout",O,Q,{target:e.target,handle:n,listeners:r,doNotReject:!0,handleNumbers:t.handleNumbers});r.push.apply(r,a.concat(o,l)),e.cursor&&(Y.style.cursor=getComputedStyle(e.target).cursor,m.length>1&&h(w,i.cssClasses.drag),Y.addEventListener("selectstart",s,!1)),t.handleNumbers.forEach((function(e){le("start",e)}))}}function ne(e){e.stopPropagation();var t=J(e.calcPoint),n=function(e){var t=100,i=!1;return m.forEach((function(n,r){if(!z(r)){var a=A[r],s=Math.abs(a-e);(s<t||s<=t&&e>a||100===s&&100===t)&&(i=r,t=s)}})),i}(t);!1!==n&&(i.events.snap||l(w,i.cssClasses.tap,i.animationDuration),me(n,t,!0,!0),pe(),le("slide",n,!0),le("update",n,!0),i.events.snap?ie(e,{handleNumbers:[n]}):(le("change",n,!0),le("set",n,!0)))}function re(e){var t=J(e.calcPoint),i=M.getStep(t),n=M.fromStepping(i);Object.keys(C).forEach((function(e){"hover"===e.split(".")[0]&&C[e].forEach((function(e){e.call(we,n)}))}))}function ae(e){e.fixed||m.forEach((function(e,t){K(x.start,e.children[0],ie,{handleNumbers:[t]})})),e.tap&&K(x.start,o,ne,{}),e.hover&&K(x.move,o,re,{hover:!0}),e.drag&&g.forEach((function(t,n){if(!1!==t&&0!==n&&n!==g.length-1){var r=m[n-1],a=m[n],s=[t],o=[r,a],l=[n-1,n];h(t,i.cssClasses.draggable),e.fixed&&(s.push(r.children[0]),s.push(a.children[0])),e.dragAll&&(o=m,l=L),s.forEach((function(e){K(x.start,e,ie,{handles:o,handleNumbers:l,connect:t})}))}}))}function se(e,t){C[e]=C[e]||[],C[e].push(t),"update"===e.split(".")[0]&&m.forEach((function(e,t){le("update",t)}))}function oe(e){var t=e&&e.split(".")[0],i=t?e.substring(t.length):e;Object.keys(C).forEach((function(e){var n=e.split(".")[0],r=e.substring(n.length);t&&t!==n||i&&i!==r||function(e){return e===k.aria||e===k.tooltips}(r)&&i!==r||delete C[e]}))}function le(e,t,n){Object.keys(C).forEach((function(r){var a=r.split(".")[0];e===a&&C[r].forEach((function(e){e.call(we,S.map(i.format.to),t,S.slice(),n||!1,A.slice(),we)}))}))}function ce(e,t,n,r,a,s,o){var l;return m.length>1&&!i.events.unconstrained&&(r&&t>0&&(l=M.getAbsoluteDistance(e[t-1],i.margin,!1),n=Math.max(n,l)),a&&t<m.length-1&&(l=M.getAbsoluteDistance(e[t+1],i.margin,!0),n=Math.min(n,l))),m.length>1&&i.limit&&(r&&t>0&&(l=M.getAbsoluteDistance(e[t-1],i.limit,!1),n=Math.min(n,l)),a&&t<m.length-1&&(l=M.getAbsoluteDistance(e[t+1],i.limit,!0),n=Math.max(n,l))),i.padding&&(0===t&&(l=M.getAbsoluteDistance(0,i.padding[0],!1),n=Math.max(n,l)),t===m.length-1&&(l=M.getAbsoluteDistance(100,i.padding[1],!0),n=Math.min(n,l))),o||(n=M.getStep(n)),!((n=c(n))===e[t]&&!s)&&n}function ue(e,t){var n=i.ort;return(n?t:e)+", "+(n?e:t)}function de(e,t,n,r,a){var s=n.slice(),o=r[0],l=i.events.smoothSteps,c=[!e,e],u=[e,!e];r=r.slice(),e&&r.reverse(),r.length>1?r.forEach((function(e,i){var n=ce(s,e,s[e]+t,c[i],u[i],!1,l);!1===n?t=0:(t=n-s[e],s[e]=n)})):c=u=[!0];var d=!1;r.forEach((function(e,i){d=me(e,n[e]+t,c[i],u[i],!1,l)||d})),d&&(r.forEach((function(e){le("update",e),le("slide",e)})),null!=a&&le("drag",o))}function he(e,t){return i.dir?100-e-t:e}function fe(e,t){A[e]=t,S[e]=M.fromStepping(t);var n="translate("+ue(he(t,0)-I+"%","0")+")";if(m[e].style[i.transformRule]=n,i.events.invertConnects&&A.length>1){var r=A.every((function(e,t,i){return 0===t||e>=i[t-1]}));if(D!==!r)return D=!D,P(i,i.connect.map((function(e){return!e}))),void _e()}ge(e),ge(e+1),D&&(ge(e-1),ge(e+2))}function pe(){L.forEach((function(e){var t=A[e]>50?-1:1,i=3+(m.length+t*e);m[e].style.zIndex=String(i)}))}function me(e,t,i,n,r,a){return r||(t=ce(A,e,t,i,n,!1,a)),!1!==t&&(fe(e,t),!0)}function ge(e){if(g[e]){var t=A.slice();D&&t.sort((function(e,t){return e-t}));var n=0,r=100;0!==e&&(n=t[e-1]),e!==g.length-1&&(r=t[e]);var a=r-n,s="translate("+ue(he(n,a)+"%","0")+")",o="scale("+ue(a/100,"1")+")";g[e].style[i.transformRule]=s+" "+o}}function ve(e,t){return null===e||!1===e||void 0===e?A[t]:("number"==typeof e&&(e=String(e)),!1!==(e=i.format.from(e))&&(e=M.toStepping(e)),!1===e||isNaN(e)?A[t]:e)}function ye(e,t,n){var r=u(e),a=void 0===A[0];t=void 0===t||t,i.animate&&!a&&l(w,i.cssClasses.tap,i.animationDuration),L.forEach((function(e){me(e,ve(r[e],e),!0,!1,n)}));var s=1===L.length?0:1;if(a&&M.hasNoSize()&&(n=!0,A[0]=0,L.length>1)){var o=100/(L.length-1);L.forEach((function(e){A[e]=e*o}))}for(;s<L.length;++s)L.forEach((function(e){me(e,A[e],!0,!0,n)}));pe(),L.forEach((function(e){le("update",e),null!==r[e]&&t&&le("set",e)}))}function be(e){if(void 0===e&&(e=!1),e)return 1===S.length?S[0]:S.slice(0);var t=S.map(i.format.to);return 1===t.length?t[0]:t}function xe(e){var t=A[e],n=M.getNearbySteps(t),r=S[e],a=n.thisStep.step,s=null;if(i.snap)return[r-n.stepBefore.startValue||null,n.stepAfter.startValue-r||null];!1!==a&&r+a>n.stepAfter.startValue&&(a=n.stepAfter.startValue-r),s=r>n.thisStep.startValue?n.thisStep.step:!1!==n.stepBefore.step&&r-n.stepBefore.highestStep,100===t?a=null:0===t&&(s=null);var o=M.countStepDecimals();return null!==a&&!1!==a&&(a=Number(a.toFixed(o))),null!==s&&!1!==s&&(s=Number(s.toFixed(o))),[s,a]}function _e(){for(;d.firstChild;)d.removeChild(d.firstChild);for(var e=0;e<=i.handles;e++)g[e]=H(d,i.connect[e]),ge(e);ae({drag:i.events.drag,fixed:!0})}h(b=w,i.cssClasses.target),0===i.dir?h(b,i.cssClasses.ltr):h(b,i.cssClasses.rtl),0===i.ort?h(b,i.cssClasses.horizontal):h(b,i.cssClasses.vertical),h(b,"rtl"===getComputedStyle(b).direction?i.cssClasses.textDirectionRtl:i.cssClasses.textDirectionLtr),o=N(b,i.cssClasses.base),function(e,t){d=N(t,i.cssClasses.connects),m=[],(g=[]).push(H(d,e[0]));for(var n=0;n<i.handles;n++)m.push(j(t,n)),L[n]=n,g.push(H(d,e[n+1]))}(i.connect,o),ae(i.events),ye(i.start),i.pips&&G(i.pips),i.tooltips&&V(),oe("update"+k.aria),se("update"+k.aria,(function(e,t,n,r,a){L.forEach((function(e){var t=m[e],r=ce(A,e,0,!0,!0,!0),s=ce(A,e,100,!0,!0,!0),o=a[e],l=String(i.ariaFormat.to(n[e]));r=M.fromStepping(r).toFixed(1),s=M.fromStepping(s).toFixed(1),o=M.fromStepping(o).toFixed(1),t.children[0].setAttribute("aria-valuemin",r),t.children[0].setAttribute("aria-valuemax",s),t.children[0].setAttribute("aria-valuenow",o),t.children[0].setAttribute("aria-valuetext",l)}))}));var we={destroy:function(){for(oe(k.aria),oe(k.tooltips),Object.keys(i.cssClasses).forEach((function(e){f(w,i.cssClasses[e])}));w.firstChild;)w.removeChild(w.firstChild);delete w.noUiSlider},steps:function(){return L.map(xe)},on:se,off:oe,get:be,set:ye,setHandle:function(e,t,i,n){if(!((e=Number(e))>=0&&e<L.length))throw new Error("noUiSlider: invalid handle number, got: "+e);me(e,ve(t,e),!0,!0,n),le("update",e),i&&le("set",e)},reset:function(e){ye(i.start,e)},disable:function(e){null!=e?(m[e].setAttribute("disabled",""),m[e].handle.removeAttribute("tabindex")):(w.setAttribute("disabled",""),m.forEach((function(e){e.handle.removeAttribute("tabindex")})))},enable:function(e){null!=e?(m[e].removeAttribute("disabled"),m[e].handle.setAttribute("tabindex","0")):(w.removeAttribute("disabled"),m.forEach((function(e){e.removeAttribute("disabled"),e.handle.setAttribute("tabindex","0")})))},__moveHandles:function(e,t,i){de(e,t,A,i)},options:n,updateOptions:function(e,t){var r=be(),s=["margin","limit","padding","range","animate","snap","step","format","pips","tooltips","connect"];s.forEach((function(t){void 0!==e[t]&&(n[t]=e[t])}));var o=X(n);s.forEach((function(t){void 0!==e[t]&&(i[t]=o[t])})),M=o.spectrum,i.margin=o.margin,i.limit=o.limit,i.padding=o.padding,i.pips?G(i.pips):$(),i.tooltips?V():B(),A=[],ye(a(e.start)?e.start:r,t),e.connect&&_e()},target:w,removePips:$,removeTooltips:B,getPositions:function(){return A.slice()},getTooltips:function(){return y},getOrigins:function(){return m},pips:G};return we}function Z(e,t){if(!e||!e.nodeName)throw new Error("noUiSlider: create requires a single element, got: "+e);if(e.noUiSlider)throw new Error("noUiSlider: Slider was already initialized.");var i=G(e,X(t),t);return e.noUiSlider=i,i}var K={__spectrum:x,cssClasses:w,create:Z};e.create=Z,e.cssClasses=w,e.default=K,Object.defineProperty(e,"__esModule",{value:!0})})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(e=e||self).autosize=t()}(this,(function(){var e=new Map;function t(t){if(t&&t.nodeName&&"TEXTAREA"===t.nodeName&&!e.has(t)){var i,n=null,r=window.getComputedStyle(t),a=(i=t.value,function(){o({testForHeightReduction:""===i||!t.value.startsWith(i),restoreTextAlign:null}),i=t.value}),s=function(i){t.removeEventListener("autosize:destroy",s),t.removeEventListener("autosize:update",l),t.removeEventListener("input",a),window.removeEventListener("resize",l),Object.keys(i).forEach((function(e){return t.style[e]=i[e]})),e.delete(t)}.bind(t,{height:t.style.height,resize:t.style.resize,textAlign:t.style.textAlign,overflowY:t.style.overflowY,overflowX:t.style.overflowX,wordWrap:t.style.wordWrap});t.addEventListener("autosize:destroy",s),t.addEventListener("autosize:update",l),t.addEventListener("input",a),window.addEventListener("resize",l),t.style.overflowX="hidden",t.style.wordWrap="break-word",e.set(t,{destroy:s,update:l}),l()}function o(e){var i,a,s=e.restoreTextAlign,l=void 0===s?null:s,c=e.testForHeightReduction,u=void 0===c||c,d=r.overflowY;if(0!==t.scrollHeight&&("vertical"===r.resize?t.style.resize="none":"both"===r.resize&&(t.style.resize="horizontal"),u&&(i=function(e){for(var t=[];e&&e.parentNode&&e.parentNode instanceof Element;)e.parentNode.scrollTop&&t.push([e.parentNode,e.parentNode.scrollTop]),e=e.parentNode;return function(){return t.forEach((function(e){var t=e[0],i=e[1];t.style.scrollBehavior="auto",t.scrollTop=i,t.style.scrollBehavior=null}))}}(t),t.style.height=""),a="content-box"===r.boxSizing?t.scrollHeight-(parseFloat(r.paddingTop)+parseFloat(r.paddingBottom)):t.scrollHeight+parseFloat(r.borderTopWidth)+parseFloat(r.borderBottomWidth),"none"!==r.maxHeight&&a>parseFloat(r.maxHeight)?("hidden"===r.overflowY&&(t.style.overflow="scroll"),a=parseFloat(r.maxHeight)):"hidden"!==r.overflowY&&(t.style.overflow="hidden"),t.style.height=a+"px",l&&(t.style.textAlign=l),i&&i(),n!==a&&(t.dispatchEvent(new Event("autosize:resized",{bubbles:!0})),n=a),d!==r.overflow&&!l)){var h=r.textAlign;"hidden"===r.overflow&&(t.style.textAlign="start"===h?"end":"start"),o({restoreTextAlign:h,testForHeightReduction:!0})}}function l(){o({testForHeightReduction:!0,restoreTextAlign:null})}}function i(t){var i=e.get(t);i&&i.destroy()}function n(t){var i=e.get(t);i&&i.update()}var r=null;return"undefined"==typeof window?((r=function(e){return e}).destroy=function(e){return e},r.update=function(e){return e}):((r=function(e,i){return e&&Array.prototype.forEach.call(e.length?e:[e],(function(e){return t(e)})),e}).destroy=function(e){return e&&Array.prototype.forEach.call(e.length?e:[e],i),e},r.update=function(e){return e&&Array.prototype.forEach.call(e.length?e:[e],n),e}),r})),function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define([],t):"object"==typeof exports?exports.ClipboardJS=t():e.ClipboardJS=t()}(this,(function(){return t={686:function(e,t,i){"use strict";i.d(t,{default:function(){return g}});t=i(279);var n=i.n(t),r=(t=i(370),i.n(t)),a=(t=i(817),i.n(t));function s(e){try{return document.execCommand(e)}catch(e){return}}var o=function(e){return e=a()(e),s("cut"),e};function l(e,t){var i,n;i=e,n="rtl"===document.documentElement.getAttribute("dir"),(e=document.createElement("textarea")).style.fontSize="12pt",e.style.border="0",e.style.padding="0",e.style.margin="0",e.style.position="absolute",e.style[n?"right":"left"]="-9999px",n=window.pageYOffset||document.documentElement.scrollTop,e.style.top="".concat(n,"px"),e.setAttribute("readonly",""),e.value=i;return t.container.appendChild(e),t=a()(e),s("copy"),e.remove(),t}var c=function(e){var t=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{container:document.body},i="";return"string"==typeof e?i=l(e,t):e instanceof HTMLInputElement&&!["text","search","url","tel","password"].includes(null==e?void 0:e.type)?i=l(e.value,t):(i=a()(e),s("copy")),i};function u(e){return(u="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function d(e){return(d="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function h(e,t){for(var i=0;i<t.length;i++){var n=t[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}function f(e,t){return(f=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e})(e,t)}function p(e){return(p=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}function m(e,t){if(e="data-clipboard-".concat(e),t.hasAttribute(e))return t.getAttribute(e)}var g=function(){!function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&f(e,t)}(s,n());var e,t,i,a=function(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],(function(){}))),!0}catch(e){return!1}}();return function(){var i,n=p(e);return i=t?(i=p(this).constructor,Reflect.construct(n,arguments,i)):n.apply(this,arguments),n=this,!i||"object"!==d(i)&&"function"!=typeof i?function(e){if(void 0!==e)return e;throw new ReferenceError("this hasn't been initialised - super() hasn't been called")}(n):i}}(s);function s(e,t){var i;return function(e){if(!(e instanceof s))throw new TypeError("Cannot call a class as a function")}(this),(i=a.call(this)).resolveOptions(t),i.listenClick(e),i}return e=s,i=[{key:"copy",value:function(e){var t=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{container:document.body};return c(e,t)}},{key:"cut",value:function(e){return o(e)}},{key:"isSupported",value:function(){var e="string"==typeof(e=0<arguments.length&&void 0!==arguments[0]?arguments[0]:["copy","cut"])?[e]:e,t=!!document.queryCommandSupported;return e.forEach((function(e){t=t&&!!document.queryCommandSupported(e)})),t}}],(t=[{key:"resolveOptions",value:function(){var e=0<arguments.length&&void 0!==arguments[0]?arguments[0]:{};this.action="function"==typeof e.action?e.action:this.defaultAction,this.target="function"==typeof e.target?e.target:this.defaultTarget,this.text="function"==typeof e.text?e.text:this.defaultText,this.container="object"===d(e.container)?e.container:document.body}},{key:"listenClick",value:function(e){var t=this;this.listener=r()(e,"click",(function(e){return t.onClick(e)}))}},{key:"onClick",value:function(e){var t=e.delegateTarget||e.currentTarget,i=this.action(t)||"copy";e=function(){var e=void 0===(i=(n=0<arguments.length&&void 0!==arguments[0]?arguments[0]:{}).action)?"copy":i,t=n.container,i=n.target,n=n.text;if("copy"!==e&&"cut"!==e)throw new Error('Invalid "action" value, use either "copy" or "cut"');if(void 0!==i){if(!i||"object"!==u(i)||1!==i.nodeType)throw new Error('Invalid "target" value, use a valid Element');if("copy"===e&&i.hasAttribute("disabled"))throw new Error('Invalid "target" attribute. Please use "readonly" instead of "disabled" attribute');if("cut"===e&&(i.hasAttribute("readonly")||i.hasAttribute("disabled")))throw new Error('Invalid "target" attribute. You can\'t cut text from elements with "readonly" or "disabled" attributes')}return n?c(n,{container:t}):i?"cut"===e?o(i):c(i,{container:t}):void 0}({action:i,container:this.container,target:this.target(t),text:this.text(t)});this.emit(e?"success":"error",{action:i,text:e,trigger:t,clearSelection:function(){t&&t.focus(),window.getSelection().removeAllRanges()}})}},{key:"defaultAction",value:function(e){return m("action",e)}},{key:"defaultTarget",value:function(e){if(e=m("target",e))return document.querySelector(e)}},{key:"defaultText",value:function(e){return m("text",e)}},{key:"destroy",value:function(){this.listener.destroy()}}])&&h(e.prototype,t),i&&h(e,i),s}()},828:function(e){var t;"undefined"==typeof Element||Element.prototype.matches||((t=Element.prototype).matches=t.matchesSelector||t.mozMatchesSelector||t.msMatchesSelector||t.oMatchesSelector||t.webkitMatchesSelector),e.exports=function(e,t){for(;e&&9!==e.nodeType;){if("function"==typeof e.matches&&e.matches(t))return e;e=e.parentNode}}},438:function(e,t,i){var n=i(828);function r(e,t,i,r,a){var s=function(e,t,i,r){return function(i){i.delegateTarget=n(i.target,t),i.delegateTarget&&r.call(e,i)}}.apply(this,arguments);return e.addEventListener(i,s,a),{destroy:function(){e.removeEventListener(i,s,a)}}}e.exports=function(e,t,i,n,a){return"function"==typeof e.addEventListener?r.apply(null,arguments):"function"==typeof i?r.bind(null,document).apply(null,arguments):("string"==typeof e&&(e=document.querySelectorAll(e)),Array.prototype.map.call(e,(function(e){return r(e,t,i,n,a)})))}},879:function(e,t){t.node=function(e){return void 0!==e&&e instanceof HTMLElement&&1===e.nodeType},t.nodeList=function(e){var i=Object.prototype.toString.call(e);return void 0!==e&&("[object NodeList]"===i||"[object HTMLCollection]"===i)&&"length"in e&&(0===e.length||t.node(e[0]))},t.string=function(e){return"string"==typeof e||e instanceof String},t.fn=function(e){return"[object Function]"===Object.prototype.toString.call(e)}},370:function(e,t,i){var n=i(879),r=i(438);e.exports=function(e,t,i){if(!e&&!t&&!i)throw new Error("Missing required arguments");if(!n.string(t))throw new TypeError("Second argument must be a String");if(!n.fn(i))throw new TypeError("Third argument must be a Function");if(n.node(e))return c=t,u=i,(l=e).addEventListener(c,u),{destroy:function(){l.removeEventListener(c,u)}};if(n.nodeList(e))return a=e,s=t,o=i,Array.prototype.forEach.call(a,(function(e){e.addEventListener(s,o)})),{destroy:function(){Array.prototype.forEach.call(a,(function(e){e.removeEventListener(s,o)}))}};if(n.string(e))return r(document.body,e,t,i);throw new TypeError("First argument must be a String, HTMLElement, HTMLCollection, or NodeList");var a,s,o,l,c,u}},817:function(e){e.exports=function(e){var t,i="SELECT"===e.nodeName?(e.focus(),e.value):"INPUT"===e.nodeName||"TEXTAREA"===e.nodeName?((t=e.hasAttribute("readonly"))||e.setAttribute("readonly",""),e.select(),e.setSelectionRange(0,e.value.length),t||e.removeAttribute("readonly"),e.value):(e.hasAttribute("contenteditable")&&e.focus(),i=window.getSelection(),(t=document.createRange()).selectNodeContents(e),i.removeAllRanges(),i.addRange(t),i.toString());return i}},279:function(e){function t(){}t.prototype={on:function(e,t,i){var n=this.e||(this.e={});return(n[e]||(n[e]=[])).push({fn:t,ctx:i}),this},once:function(e,t,i){var n=this;function r(){n.off(e,r),t.apply(i,arguments)}return r._=t,this.on(e,r,i)},emit:function(e){for(var t=[].slice.call(arguments,1),i=((this.e||(this.e={}))[e]||[]).slice(),n=0,r=i.length;n<r;n++)i[n].fn.apply(i[n].ctx,t);return this},off:function(e,t){var i=this.e||(this.e={}),n=i[e],r=[];if(n&&t)for(var a=0,s=n.length;a<s;a++)n[a].fn!==t&&n[a].fn._!==t&&r.push(n[a]);return r.length?i[e]=r:delete i[e],this}},e.exports=t,e.exports.TinyEmitter=t}},i={},e.n=function(t){var i=t&&t.__esModule?function(){return t.default}:function(){return t};return e.d(i,{a:i}),i},e.d=function(t,i){for(var n in i)e.o(i,n)&&!e.o(t,n)&&Object.defineProperty(t,n,{enumerable:!0,get:i[n]})},e.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},e(686).default;function e(n){if(i[n])return i[n].exports;var r=i[n]={exports:{}};return t[n](r,r.exports,e),r.exports}var t,i})),function(e){"use strict";var t=function(e,t){this.init("multiselectsplitter",e,t)};t.DEFAULTS={selectSize:null,maxSelectSize:null,clearOnFirstChange:!1,onlySameGroup:!1,groupCounter:!1,maximumSelected:null,afterInitialize:null,maximumAlert:function(e){alert("Only "+e+" values can be selected")},createFirstSelect:function(e,t){return"<option>"+e+"</option>"},createSecondSelect:function(e,t){return"<option>"+e+"</option>"},template:'<div class="row" data-multiselectsplitter-wrapper-selector><div class="col-xs-6 col-sm-6"><select class="form-control" data-multiselectsplitter-firstselect-selector></select></div> \x3c!-- Add the extra clearfix for only the required viewport --\x3e<div class="col-xs-6 col-sm-6"><select class="form-control" data-multiselectsplitter-secondselect-selector></select></div></div>'},t.prototype.init=function(i,n,r){var a=this;a.type=i,a.last$ElementSelected=[],a.initialized=!1,a.$element=e(n),a.$element.hide(),a.options=e.extend({},t.DEFAULTS,r),a.$element.after(a.options.template),a.$wrapper=a.$element.next("div[data-multiselectsplitter-wrapper-selector]"),a.$firstSelect=e("select[data-multiselectsplitter-firstselect-selector]",a.$wrapper),a.$secondSelect=e("select[data-multiselectsplitter-secondselect-selector]",a.$wrapper);var s=0,o=0;if(0!=a.$element.find("optgroup").length){a.$element.find("optgroup").each((function(){var t=e(this).attr("label"),i=e(a.options.createFirstSelect(t,a.$element));i.val(t),i.attr("data-current-label",i.text()),a.$firstSelect.append(i);var n=e(this).find("option").length;n>o&&(o=n),s++}));var l=Math.max(s,o);l=Math.min(l,10),a.options.selectSize?l=a.options.selectSize:a.options.maxSelectSize&&(l=Math.min(l,a.options.maxSelectSize)),a.$firstSelect.attr("size",l),a.$secondSelect.attr("size",l),a.$element.attr("multiple")&&a.$secondSelect.attr("multiple","multiple"),a.$element.is(":disabled")&&a.disable(),a.$firstSelect.on("change",e.proxy(a.updateParentCategory,a)),a.$secondSelect.on("click change",e.proxy(a.updateChildCategory,a)),a.update=function(){if(!(a.$element.find("option").length<1)){var e,t=a.$element.find("option:selected:first");e=t.length?t.parent().attr("label"):a.$element.find("option:first").parent().attr("label"),a.$firstSelect.find('option[value="'+e+'"]').prop("selected",!0),a.$firstSelect.trigger("change")}},a.update(),a.initialized=!0,a.options.afterInitialize&&a.options.afterInitialize(a.$firstSelect,a.$secondSelect)}},t.prototype.disable=function(){this.$secondSelect.prop("disabled",!0),this.$firstSelect.prop("disabled",!0)},t.prototype.enable=function(){this.$secondSelect.prop("disabled",!1),this.$firstSelect.prop("disabled",!1)},t.prototype.createSecondSelect=function(){var t=this;t.$secondSelect.empty(),e.each(t.$element.find('optgroup[label="'+t.$firstSelect.val()+'"] option'),(function(i,n){var r=e(this).val(),a=e(this).text(),s=e(t.options.createSecondSelect(a,t.$firstSelect));s.val(r),e.each(t.$element.find("option:selected"),(function(t,i){e(i).val()==r&&s.prop("selected",!0)})),t.$secondSelect.append(s)}))},t.prototype.updateParentCategory=function(){var e=this;e.last$ElementSelected=e.$element.find("option:selected"),e.options.clearOnFirstChange&&e.initialized&&e.$element.find("option:selected").prop("selected",!1),e.createSecondSelect(),e.checkSelected(),e.updateCounter()},t.prototype.updateCounter=function(){var t=this;t.$element.attr("multiple")&&t.options.groupCounter&&e.each(t.$firstSelect.find("option"),(function(i,n){var r=e(n).val(),a=e(n).data("currentLabel"),s=t.$element.find('optgroup[label="'+r+'"] option:selected').length;s>0&&(a+=" ("+s+")"),e(n).html(a)}))},t.prototype.checkSelected=function(){var t=this;if(t.$element.attr("multiple")&&t.options.maximumSelected){var i=0;if(!((i="function"==typeof t.options.maximumSelected?t.options.maximumSelected(t.$firstSelect,t.$secondSelect):t.options.maximumSelected)<1))if(t.$element.find("option:selected").length>i){t.$firstSelect.find("option:selected").prop("selected",!1),t.$secondSelect.find("option:selected").prop("selected",!1),t.initialized?(t.$element.find("option:selected").prop("selected",!1),t.last$ElementSelected.prop("selected",!0)):e.each(t.$element.find("option:selected"),(function(t,n){t>i-1&&e(n).prop("selected",!1)}));var n=t.last$ElementSelected.first().parent().attr("label");t.$firstSelect.find('option[value="'+n+'"]').prop("selected",!0),t.createSecondSelect(),t.options.maximumAlert(i)}}},t.prototype.basicUpdateChildCategory=function(t,i){var n=this;n.last$ElementSelected=n.$element.find("option:selected");var r=n.$secondSelect.val();e.isArray(r)||(r=[r]);var a=n.$firstSelect.val(),s=!1;n.$element.attr("multiple")?n.options.onlySameGroup?e.each(n.$element.find("option:selected"),(function(t,i){if(e(i).parent().attr("label")!=a)return s=!0,!1})):i||(s=!0):s=!0,s?n.$element.find("option:selected").prop("selected",!1):e.each(n.$element.find("option:selected"),(function(t,i){a==e(i).parent().attr("label")&&-1==e.inArray(e(i).val(),r)&&e(i).prop("selected",!1)})),e.each(r,(function(e,t){n.$element.find('option[value="'+t+'"]').prop("selected",!0)})),n.checkSelected(),n.updateCounter(),n.$element.trigger("change")},t.prototype.updateChildCategory=function(t){"change"==t.type?this.timeOut=setTimeout(e.proxy((function(){this.basicUpdateChildCategory(t,t.ctrlKey)}),this),10):"click"==t.type&&(clearTimeout(this.timeOut),this.basicUpdateChildCategory(t,t.ctrlKey))},t.prototype.destroy=function(){this.$wrapper.remove(),this.$element.removeData(this.type),this.$element.show()},e.fn.multiselectsplitter=function(i){return this.each((function(){var n=e(this),r=n.data("multiselectsplitter"),a="object"==typeof i&&i;(r||"destroy"!=i)&&(r||n.data("multiselectsplitter",r=new t(this,a)),"string"==typeof i&&r[i]())}))},e.fn.multiselectsplitter.Constructor=t,e.fn.multiselectsplitter.VERSION="1.0.1"}(jQuery),
/*!
 * smooth-scroll v16.1.3
 * Animate scrolling to anchor links
 * (c) 2020 Chris Ferdinandi
 * MIT License
 * http://github.com/cferdinandi/smooth-scroll
 */
function(e,t){"function"==typeof define&&define.amd?define([],(function(){return t(e)})):"object"==typeof exports?module.exports=t(e):e.SmoothScroll=t(e)}("undefined"!=typeof global?global:"undefined"!=typeof window?window:this,(function(e){"use strict";var t={ignore:"[data-scroll-ignore]",header:null,topOnEmptyHash:!0,speed:500,speedAsDuration:!1,durationMax:null,durationMin:null,clip:!0,offset:0,easing:"easeInOutCubic",customEasing:null,updateURL:!0,popstate:!0,emitEvents:!0},i=function(){var e={};return Array.prototype.forEach.call(arguments,(function(t){for(var i in t){if(!t.hasOwnProperty(i))return;e[i]=t[i]}})),e},n=function(e){"#"===e.charAt(0)&&(e=e.substr(1));for(var t,i=String(e),n=i.length,r=-1,a="",s=i.charCodeAt(0);++r<n;){if(0===(t=i.charCodeAt(r)))throw new InvalidCharacterError("Invalid character: the input contains U+0000.");t>=1&&t<=31||127==t||0===r&&t>=48&&t<=57||1===r&&t>=48&&t<=57&&45===s?a+="\\"+t.toString(16)+" ":a+=t>=128||45===t||95===t||t>=48&&t<=57||t>=65&&t<=90||t>=97&&t<=122?i.charAt(r):"\\"+i.charAt(r)}return"#"+a},r=function(){return Math.max(document.body.scrollHeight,document.documentElement.scrollHeight,document.body.offsetHeight,document.documentElement.offsetHeight,document.body.clientHeight,document.documentElement.clientHeight)},a=function(t){return t?(i=t,parseInt(e.getComputedStyle(i).height,10)+t.offsetTop):0;var i},s=function(t,i,n){0===t&&document.body.focus(),n||(t.focus(),document.activeElement!==t&&(t.setAttribute("tabindex","-1"),t.focus(),t.style.outline="none"),e.scrollTo(0,i))},o=function(t,i,n,r){if(i.emitEvents&&"function"==typeof e.CustomEvent){var a=new CustomEvent(t,{bubbles:!0,detail:{anchor:n,toggle:r}});document.dispatchEvent(a)}};return function(l,c){var u,d,h,f,p={};p.cancelScroll=function(e){cancelAnimationFrame(f),f=null,e||o("scrollCancel",u)},p.animateScroll=function(n,l,c){p.cancelScroll();var d=i(u||t,c||{}),m="[object Number]"===Object.prototype.toString.call(n),g=m||!n.tagName?null:n;if(m||g){var v=e.pageYOffset;d.header&&!h&&(h=document.querySelector(d.header));var y,b,x,_=a(h),w=m?n:function(t,i,n,a){var s=0;if(t.offsetParent)do{s+=t.offsetTop,t=t.offsetParent}while(t);return s=Math.max(s-i-n,0),a&&(s=Math.min(s,r()-e.innerHeight)),s}(g,_,parseInt("function"==typeof d.offset?d.offset(n,l):d.offset,10),d.clip),k=w-v,M=r(),S=0,A=function(e,t){var i=t.speedAsDuration?t.speed:Math.abs(e/1e3*t.speed);return t.durationMax&&i>t.durationMax?t.durationMax:t.durationMin&&i<t.durationMin?t.durationMin:parseInt(i,10)}(k,d),L=function(t){y||(y=t),S+=t-y,x=v+k*function(e,t){var i;return"easeInQuad"===e.easing&&(i=t*t),"easeOutQuad"===e.easing&&(i=t*(2-t)),"easeInOutQuad"===e.easing&&(i=t<.5?2*t*t:(4-2*t)*t-1),"easeInCubic"===e.easing&&(i=t*t*t),"easeOutCubic"===e.easing&&(i=--t*t*t+1),"easeInOutCubic"===e.easing&&(i=t<.5?4*t*t*t:(t-1)*(2*t-2)*(2*t-2)+1),"easeInQuart"===e.easing&&(i=t*t*t*t),"easeOutQuart"===e.easing&&(i=1- --t*t*t*t),"easeInOutQuart"===e.easing&&(i=t<.5?8*t*t*t*t:1-8*--t*t*t*t),"easeInQuint"===e.easing&&(i=t*t*t*t*t),"easeOutQuint"===e.easing&&(i=1+--t*t*t*t*t),"easeInOutQuint"===e.easing&&(i=t<.5?16*t*t*t*t*t:1+16*--t*t*t*t*t),e.customEasing&&(i=e.customEasing(t)),i||t}(d,b=(b=0===A?0:S/A)>1?1:b),e.scrollTo(0,Math.floor(x)),function(t,i){var r=e.pageYOffset;if(t==i||r==i||(v<i&&e.innerHeight+r)>=M)return p.cancelScroll(!0),s(n,i,m),o("scrollStop",d,n,l),y=null,f=null,!0}(x,w)||(f=e.requestAnimationFrame(L),y=t)};0===e.pageYOffset&&e.scrollTo(0,0),function(e,t,i){t||history.pushState&&i.updateURL&&history.pushState({smoothScroll:JSON.stringify(i),anchor:e.id},document.title,e===document.documentElement?"#top":"#"+e.id)}(n,m,d),"matchMedia"in e&&e.matchMedia("(prefers-reduced-motion)").matches?s(n,Math.floor(w),!1):(o("scrollStart",d,n,l),p.cancelScroll(!0),e.requestAnimationFrame(L))}};var m=function(t){if(!t.defaultPrevented&&!(0!==t.button||t.metaKey||t.ctrlKey||t.shiftKey)&&"closest"in t.target&&(d=t.target.closest(l))&&"a"===d.tagName.toLowerCase()&&!t.target.closest(u.ignore)&&d.hostname===e.location.hostname&&d.pathname===e.location.pathname&&/#/.test(d.href)){var i,r;try{i=n(decodeURIComponent(d.hash))}catch(e){i=n(d.hash)}if("#"===i){if(!u.topOnEmptyHash)return;r=document.documentElement}else r=document.querySelector(i);(r=r||"#top"!==i?r:document.documentElement)&&(t.preventDefault(),function(t){if(history.replaceState&&t.updateURL&&!history.state){var i=e.location.hash;i=i||"",history.replaceState({smoothScroll:JSON.stringify(t),anchor:i||e.pageYOffset},document.title,i||e.location.href)}}(u),p.animateScroll(r,d))}},g=function(e){if(null!==history.state&&history.state.smoothScroll&&history.state.smoothScroll===JSON.stringify(u)){var t=history.state.anchor;"string"==typeof t&&t&&!(t=document.querySelector(n(history.state.anchor)))||p.animateScroll(t,null,{updateURL:!1})}};p.destroy=function(){u&&(document.removeEventListener("click",m,!1),e.removeEventListener("popstate",g,!1),p.cancelScroll(),u=null,d=null,h=null,f=null)};return function(){if(!("querySelector"in document&&"addEventListener"in e&&"requestAnimationFrame"in e&&"closest"in e.Element.prototype))throw"Smooth Scroll: This browser does not support the required JavaScript methods and browser APIs.";p.destroy(),u=i(t,c||{}),h=u.header?document.querySelector(u.header):null,document.addEventListener("click",m,!1),u.updateURL&&u.popstate&&e.addEventListener("popstate",g,!1)}(),p}})),function(e,t){if("object"==typeof exports&&"object"==typeof module)module.exports=t();else if("function"==typeof define&&define.amd)define([],t);else{var i=t();for(var n in i)("object"==typeof exports?exports:e)[n]=i[n]}}(self,(function(){return function(){var e={3099:function(e){e.exports=function(e){if("function"!=typeof e)throw TypeError(String(e)+" is not a function");return e}},6077:function(e,t,i){var n=i(111);e.exports=function(e){if(!n(e)&&null!==e)throw TypeError("Can't set "+String(e)+" as a prototype");return e}},1223:function(e,t,i){var n=i(5112),r=i(30),a=i(3070),s=n("unscopables"),o=Array.prototype;null==o[s]&&a.f(o,s,{configurable:!0,value:r(null)}),e.exports=function(e){o[s][e]=!0}},1530:function(e,t,i){"use strict";var n=i(8710).charAt;e.exports=function(e,t,i){return t+(i?n(e,t).length:1)}},5787:function(e){e.exports=function(e,t,i){if(!(e instanceof t))throw TypeError("Incorrect "+(i?i+" ":"")+"invocation");return e}},9670:function(e,t,i){var n=i(111);e.exports=function(e){if(!n(e))throw TypeError(String(e)+" is not an object");return e}},4019:function(e){e.exports="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView},260:function(e,t,i){"use strict";var n,r=i(4019),a=i(9781),s=i(7854),o=i(111),l=i(6656),c=i(648),u=i(8880),d=i(1320),h=i(3070).f,f=i(9518),p=i(7674),m=i(5112),g=i(9711),v=s.Int8Array,y=v&&v.prototype,b=s.Uint8ClampedArray,x=b&&b.prototype,_=v&&f(v),w=y&&f(y),k=Object.prototype,M=k.isPrototypeOf,S=m("toStringTag"),A=g("TYPED_ARRAY_TAG"),L=r&&!!p&&"Opera"!==c(s.opera),T=!1,C={Int8Array:1,Uint8Array:1,Uint8ClampedArray:1,Int16Array:2,Uint16Array:2,Int32Array:4,Uint32Array:4,Float32Array:4,Float64Array:8},D={BigInt64Array:8,BigUint64Array:8},E=function(e){if(!o(e))return!1;var t=c(e);return l(C,t)||l(D,t)};for(n in C)s[n]||(L=!1);if((!L||"function"!=typeof _||_===Function.prototype)&&(_=function(){throw TypeError("Incorrect invocation")},L))for(n in C)s[n]&&p(s[n],_);if((!L||!w||w===k)&&(w=_.prototype,L))for(n in C)s[n]&&p(s[n].prototype,w);if(L&&f(x)!==w&&p(x,w),a&&!l(w,S))for(n in T=!0,h(w,S,{get:function(){return o(this)?this[A]:void 0}}),C)s[n]&&u(s[n],A,n);e.exports={NATIVE_ARRAY_BUFFER_VIEWS:L,TYPED_ARRAY_TAG:T&&A,aTypedArray:function(e){if(E(e))return e;throw TypeError("Target is not a typed array")},aTypedArrayConstructor:function(e){if(p){if(M.call(_,e))return e}else for(var t in C)if(l(C,n)){var i=s[t];if(i&&(e===i||M.call(i,e)))return e}throw TypeError("Target is not a typed array constructor")},exportTypedArrayMethod:function(e,t,i){if(a){if(i)for(var n in C){var r=s[n];r&&l(r.prototype,e)&&delete r.prototype[e]}w[e]&&!i||d(w,e,i?t:L&&y[e]||t)}},exportTypedArrayStaticMethod:function(e,t,i){var n,r;if(a){if(p){if(i)for(n in C)(r=s[n])&&l(r,e)&&delete r[e];if(_[e]&&!i)return;try{return d(_,e,i?t:L&&v[e]||t)}catch(e){}}for(n in C)!(r=s[n])||r[e]&&!i||d(r,e,t)}},isView:function(e){if(!o(e))return!1;var t=c(e);return"DataView"===t||l(C,t)||l(D,t)},isTypedArray:E,TypedArray:_,TypedArrayPrototype:w}},3331:function(e,t,i){"use strict";var n=i(7854),r=i(9781),a=i(4019),s=i(8880),o=i(2248),l=i(7293),c=i(5787),u=i(9958),d=i(7466),h=i(7067),f=i(1179),p=i(9518),m=i(7674),g=i(8006).f,v=i(3070).f,y=i(1285),b=i(8003),x=i(9909),_=x.get,w=x.set,k="ArrayBuffer",M="DataView",S="prototype",A="Wrong index",L=n[k],T=L,C=n[M],D=C&&C[S],E=Object.prototype,O=n.RangeError,P=f.pack,Y=f.unpack,I=function(e){return[255&e]},N=function(e){return[255&e,e>>8&255]},j=function(e){return[255&e,e>>8&255,e>>16&255,e>>24&255]},H=function(e){return e[3]<<24|e[2]<<16|e[1]<<8|e[0]},F=function(e){return P(e,23,4)},R=function(e){return P(e,52,8)},z=function(e,t){v(e[S],t,{get:function(){return _(this)[t]}})},B=function(e,t,i,n){var r=h(i),a=_(e);if(r+t>a.byteLength)throw O(A);var s=_(a.buffer).bytes,o=r+a.byteOffset,l=s.slice(o,o+t);return n?l:l.reverse()},V=function(e,t,i,n,r,a){var s=h(i),o=_(e);if(s+t>o.byteLength)throw O(A);for(var l=_(o.buffer).bytes,c=s+o.byteOffset,u=n(+r),d=0;d<t;d++)l[c+d]=u[a?d:t-d-1]};if(a){if(!l((function(){L(1)}))||!l((function(){new L(-1)}))||l((function(){return new L,new L(1.5),new L(NaN),L.name!=k}))){for(var W,U=(T=function(e){return c(this,T),new L(h(e))})[S]=L[S],q=g(L),$=0;q.length>$;)(W=q[$++])in T||s(T,W,L[W]);U.constructor=T}m&&p(D)!==E&&m(D,E);var X=new C(new T(2)),G=D.setInt8;X.setInt8(0,2147483648),X.setInt8(1,2147483649),!X.getInt8(0)&&X.getInt8(1)||o(D,{setInt8:function(e,t){G.call(this,e,t<<24>>24)},setUint8:function(e,t){G.call(this,e,t<<24>>24)}},{unsafe:!0})}else T=function(e){c(this,T,k);var t=h(e);w(this,{bytes:y.call(new Array(t),0),byteLength:t}),r||(this.byteLength=t)},C=function(e,t,i){c(this,C,M),c(e,T,M);var n=_(e).byteLength,a=u(t);if(a<0||a>n)throw O("Wrong offset");if(a+(i=void 0===i?n-a:d(i))>n)throw O("Wrong length");w(this,{buffer:e,byteLength:i,byteOffset:a}),r||(this.buffer=e,this.byteLength=i,this.byteOffset=a)},r&&(z(T,"byteLength"),z(C,"buffer"),z(C,"byteLength"),z(C,"byteOffset")),o(C[S],{getInt8:function(e){return B(this,1,e)[0]<<24>>24},getUint8:function(e){return B(this,1,e)[0]},getInt16:function(e){var t=B(this,2,e,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(e){var t=B(this,2,e,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(e){return H(B(this,4,e,arguments.length>1?arguments[1]:void 0))},getUint32:function(e){return H(B(this,4,e,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(e){return Y(B(this,4,e,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(e){return Y(B(this,8,e,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(e,t){V(this,1,e,I,t)},setUint8:function(e,t){V(this,1,e,I,t)},setInt16:function(e,t){V(this,2,e,N,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(e,t){V(this,2,e,N,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(e,t){V(this,4,e,j,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(e,t){V(this,4,e,j,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(e,t){V(this,4,e,F,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(e,t){V(this,8,e,R,t,arguments.length>2?arguments[2]:void 0)}});b(T,k),b(C,M),e.exports={ArrayBuffer:T,DataView:C}},1048:function(e,t,i){"use strict";var n=i(7908),r=i(1400),a=i(7466),s=Math.min;e.exports=[].copyWithin||function(e,t){var i=n(this),o=a(i.length),l=r(e,o),c=r(t,o),u=arguments.length>2?arguments[2]:void 0,d=s((void 0===u?o:r(u,o))-c,o-l),h=1;for(c<l&&l<c+d&&(h=-1,c+=d-1,l+=d-1);d-- >0;)c in i?i[l]=i[c]:delete i[l],l+=h,c+=h;return i}},1285:function(e,t,i){"use strict";var n=i(7908),r=i(1400),a=i(7466);e.exports=function(e){for(var t=n(this),i=a(t.length),s=arguments.length,o=r(s>1?arguments[1]:void 0,i),l=s>2?arguments[2]:void 0,c=void 0===l?i:r(l,i);c>o;)t[o++]=e;return t}},8533:function(e,t,i){"use strict";var n=i(2092).forEach,r=i(9341)("forEach");e.exports=r?[].forEach:function(e){return n(this,e,arguments.length>1?arguments[1]:void 0)}},8457:function(e,t,i){"use strict";var n=i(9974),r=i(7908),a=i(3411),s=i(7659),o=i(7466),l=i(6135),c=i(1246);e.exports=function(e){var t,i,u,d,h,f,p=r(e),m="function"==typeof this?this:Array,g=arguments.length,v=g>1?arguments[1]:void 0,y=void 0!==v,b=c(p),x=0;if(y&&(v=n(v,g>2?arguments[2]:void 0,2)),null==b||m==Array&&s(b))for(i=new m(t=o(p.length));t>x;x++)f=y?v(p[x],x):p[x],l(i,x,f);else for(h=(d=b.call(p)).next,i=new m;!(u=h.call(d)).done;x++)f=y?a(d,v,[u.value,x],!0):u.value,l(i,x,f);return i.length=x,i}},1318:function(e,t,i){var n=i(5656),r=i(7466),a=i(1400),s=function(e){return function(t,i,s){var o,l=n(t),c=r(l.length),u=a(s,c);if(e&&i!=i){for(;c>u;)if((o=l[u++])!=o)return!0}else for(;c>u;u++)if((e||u in l)&&l[u]===i)return e||u||0;return!e&&-1}};e.exports={includes:s(!0),indexOf:s(!1)}},2092:function(e,t,i){var n=i(9974),r=i(8361),a=i(7908),s=i(7466),o=i(5417),l=[].push,c=function(e){var t=1==e,i=2==e,c=3==e,u=4==e,d=6==e,h=7==e,f=5==e||d;return function(p,m,g,v){for(var y,b,x=a(p),_=r(x),w=n(m,g,3),k=s(_.length),M=0,S=v||o,A=t?S(p,k):i||h?S(p,0):void 0;k>M;M++)if((f||M in _)&&(b=w(y=_[M],M,x),e))if(t)A[M]=b;else if(b)switch(e){case 3:return!0;case 5:return y;case 6:return M;case 2:l.call(A,y)}else switch(e){case 4:return!1;case 7:l.call(A,y)}return d?-1:c||u?u:A}};e.exports={forEach:c(0),map:c(1),filter:c(2),some:c(3),every:c(4),find:c(5),findIndex:c(6),filterOut:c(7)}},6583:function(e,t,i){"use strict";var n=i(5656),r=i(9958),a=i(7466),s=i(9341),o=Math.min,l=[].lastIndexOf,c=!!l&&1/[1].lastIndexOf(1,-0)<0,u=s("lastIndexOf"),d=c||!u;e.exports=d?function(e){if(c)return l.apply(this,arguments)||0;var t=n(this),i=a(t.length),s=i-1;for(arguments.length>1&&(s=o(s,r(arguments[1]))),s<0&&(s=i+s);s>=0;s--)if(s in t&&t[s]===e)return s||0;return-1}:l},1194:function(e,t,i){var n=i(7293),r=i(5112),a=i(7392),s=r("species");e.exports=function(e){return a>=51||!n((function(){var t=[];return(t.constructor={})[s]=function(){return{foo:1}},1!==t[e](Boolean).foo}))}},9341:function(e,t,i){"use strict";var n=i(7293);e.exports=function(e,t){var i=[][e];return!!i&&n((function(){i.call(null,t||function(){throw 1},1)}))}},3671:function(e,t,i){var n=i(3099),r=i(7908),a=i(8361),s=i(7466),o=function(e){return function(t,i,o,l){n(i);var c=r(t),u=a(c),d=s(c.length),h=e?d-1:0,f=e?-1:1;if(o<2)for(;;){if(h in u){l=u[h],h+=f;break}if(h+=f,e?h<0:d<=h)throw TypeError("Reduce of empty array with no initial value")}for(;e?h>=0:d>h;h+=f)h in u&&(l=i(l,u[h],h,c));return l}};e.exports={left:o(!1),right:o(!0)}},5417:function(e,t,i){var n=i(111),r=i(3157),a=i(5112)("species");e.exports=function(e,t){var i;return r(e)&&("function"!=typeof(i=e.constructor)||i!==Array&&!r(i.prototype)?n(i)&&null===(i=i[a])&&(i=void 0):i=void 0),new(void 0===i?Array:i)(0===t?0:t)}},3411:function(e,t,i){var n=i(9670),r=i(9212);e.exports=function(e,t,i,a){try{return a?t(n(i)[0],i[1]):t(i)}catch(t){throw r(e),t}}},7072:function(e,t,i){var n=i(5112)("iterator"),r=!1;try{var a=0,s={next:function(){return{done:!!a++}},return:function(){r=!0}};s[n]=function(){return this},Array.from(s,(function(){throw 2}))}catch(e){}e.exports=function(e,t){if(!t&&!r)return!1;var i=!1;try{var a={};a[n]=function(){return{next:function(){return{done:i=!0}}}},e(a)}catch(e){}return i}},4326:function(e){var t={}.toString;e.exports=function(e){return t.call(e).slice(8,-1)}},648:function(e,t,i){var n=i(1694),r=i(4326),a=i(5112)("toStringTag"),s="Arguments"==r(function(){return arguments}());e.exports=n?r:function(e){var t,i,n;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(i=function(e,t){try{return e[t]}catch(e){}}(t=Object(e),a))?i:s?r(t):"Object"==(n=r(t))&&"function"==typeof t.callee?"Arguments":n}},9920:function(e,t,i){var n=i(6656),r=i(3887),a=i(1236),s=i(3070);e.exports=function(e,t){for(var i=r(t),o=s.f,l=a.f,c=0;c<i.length;c++){var u=i[c];n(e,u)||o(e,u,l(t,u))}}},8544:function(e,t,i){var n=i(7293);e.exports=!n((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype}))},4994:function(e,t,i){"use strict";var n=i(3383).IteratorPrototype,r=i(30),a=i(9114),s=i(8003),o=i(7497),l=function(){return this};e.exports=function(e,t,i){var c=t+" Iterator";return e.prototype=r(n,{next:a(1,i)}),s(e,c,!1,!0),o[c]=l,e}},8880:function(e,t,i){var n=i(9781),r=i(3070),a=i(9114);e.exports=n?function(e,t,i){return r.f(e,t,a(1,i))}:function(e,t,i){return e[t]=i,e}},9114:function(e){e.exports=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}}},6135:function(e,t,i){"use strict";var n=i(7593),r=i(3070),a=i(9114);e.exports=function(e,t,i){var s=n(t);s in e?r.f(e,s,a(0,i)):e[s]=i}},654:function(e,t,i){"use strict";var n=i(2109),r=i(4994),a=i(9518),s=i(7674),o=i(8003),l=i(8880),c=i(1320),u=i(5112),d=i(1913),h=i(7497),f=i(3383),p=f.IteratorPrototype,m=f.BUGGY_SAFARI_ITERATORS,g=u("iterator"),v="keys",y="values",b="entries",x=function(){return this};e.exports=function(e,t,i,u,f,_,w){r(i,t,u);var k,M,S,A=function(e){if(e===f&&E)return E;if(!m&&e in C)return C[e];switch(e){case v:case y:case b:return function(){return new i(this,e)}}return function(){return new i(this)}},L=t+" Iterator",T=!1,C=e.prototype,D=C[g]||C["@@iterator"]||f&&C[f],E=!m&&D||A(f),O="Array"==t&&C.entries||D;if(O&&(k=a(O.call(new e)),p!==Object.prototype&&k.next&&(d||a(k)===p||(s?s(k,p):"function"!=typeof k[g]&&l(k,g,x)),o(k,L,!0,!0),d&&(h[L]=x))),f==y&&D&&D.name!==y&&(T=!0,E=function(){return D.call(this)}),d&&!w||C[g]===E||l(C,g,E),h[t]=E,f)if(M={values:A(y),keys:_?E:A(v),entries:A(b)},w)for(S in M)(m||T||!(S in C))&&c(C,S,M[S]);else n({target:t,proto:!0,forced:m||T},M);return M}},9781:function(e,t,i){var n=i(7293);e.exports=!n((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]}))},317:function(e,t,i){var n=i(7854),r=i(111),a=n.document,s=r(a)&&r(a.createElement);e.exports=function(e){return s?a.createElement(e):{}}},8324:function(e){e.exports={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0}},8113:function(e,t,i){var n=i(5005);e.exports=n("navigator","userAgent")||""},7392:function(e,t,i){var n,r,a=i(7854),s=i(8113),o=a.process,l=o&&o.versions,c=l&&l.v8;c?r=(n=c.split("."))[0]+n[1]:s&&(!(n=s.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=s.match(/Chrome\/(\d+)/))&&(r=n[1]),e.exports=r&&+r},748:function(e){e.exports=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"]},2109:function(e,t,i){var n=i(7854),r=i(1236).f,a=i(8880),s=i(1320),o=i(3505),l=i(9920),c=i(4705);e.exports=function(e,t){var i,u,d,h,f,p=e.target,m=e.global,g=e.stat;if(i=m?n:g?n[p]||o(p,{}):(n[p]||{}).prototype)for(u in t){if(h=t[u],d=e.noTargetGet?(f=r(i,u))&&f.value:i[u],!c(m?u:p+(g?".":"#")+u,e.forced)&&void 0!==d){if(typeof h==typeof d)continue;l(h,d)}(e.sham||d&&d.sham)&&a(h,"sham",!0),s(i,u,h,e)}}},7293:function(e){e.exports=function(e){try{return!!e()}catch(e){return!0}}},7007:function(e,t,i){"use strict";i(4916);var n=i(1320),r=i(7293),a=i(5112),s=i(2261),o=i(8880),l=a("species"),c=!r((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")})),u="$0"==="a".replace(/./,"$0"),d=a("replace"),h=!!/./[d]&&""===/./[d]("a","$0"),f=!r((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var i="ab".split(e);return 2!==i.length||"a"!==i[0]||"b"!==i[1]}));e.exports=function(e,t,i,d){var p=a(e),m=!r((function(){var t={};return t[p]=function(){return 7},7!=""[e](t)})),g=m&&!r((function(){var t=!1,i=/a/;return"split"===e&&((i={}).constructor={},i.constructor[l]=function(){return i},i.flags="",i[p]=/./[p]),i.exec=function(){return t=!0,null},i[p](""),!t}));if(!m||!g||"replace"===e&&(!c||!u||h)||"split"===e&&!f){var v=/./[p],y=i(p,""[e],(function(e,t,i,n,r){return t.exec===s?m&&!r?{done:!0,value:v.call(t,i,n)}:{done:!0,value:e.call(i,t,n)}:{done:!1}}),{REPLACE_KEEPS_$0:u,REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE:h}),b=y[0],x=y[1];n(String.prototype,e,b),n(RegExp.prototype,p,2==t?function(e,t){return x.call(e,this,t)}:function(e){return x.call(e,this)})}d&&o(RegExp.prototype[p],"sham",!0)}},9974:function(e,t,i){var n=i(3099);e.exports=function(e,t,i){if(n(e),void 0===t)return e;switch(i){case 0:return function(){return e.call(t)};case 1:return function(i){return e.call(t,i)};case 2:return function(i,n){return e.call(t,i,n)};case 3:return function(i,n,r){return e.call(t,i,n,r)}}return function(){return e.apply(t,arguments)}}},5005:function(e,t,i){var n=i(857),r=i(7854),a=function(e){return"function"==typeof e?e:void 0};e.exports=function(e,t){return arguments.length<2?a(n[e])||a(r[e]):n[e]&&n[e][t]||r[e]&&r[e][t]}},1246:function(e,t,i){var n=i(648),r=i(7497),a=i(5112)("iterator");e.exports=function(e){if(null!=e)return e[a]||e["@@iterator"]||r[n(e)]}},8554:function(e,t,i){var n=i(9670),r=i(1246);e.exports=function(e){var t=r(e);if("function"!=typeof t)throw TypeError(String(e)+" is not iterable");return n(t.call(e))}},647:function(e,t,i){var n=i(7908),r=Math.floor,a="".replace,s=/\$([$&'`]|\d\d?|<[^>]*>)/g,o=/\$([$&'`]|\d\d?)/g;e.exports=function(e,t,i,l,c,u){var d=i+e.length,h=l.length,f=o;return void 0!==c&&(c=n(c),f=s),a.call(u,f,(function(n,a){var s;switch(a.charAt(0)){case"$":return"$";case"&":return e;case"`":return t.slice(0,i);case"'":return t.slice(d);case"<":s=c[a.slice(1,-1)];break;default:var o=+a;if(0===o)return n;if(o>h){var u=r(o/10);return 0===u?n:u<=h?void 0===l[u-1]?a.charAt(1):l[u-1]+a.charAt(1):n}s=l[o-1]}return void 0===s?"":s}))}},7854:function(e,t,i){var n=function(e){return e&&e.Math==Math&&e};e.exports=n("object"==typeof globalThis&&globalThis)||n("object"==typeof window&&window)||n("object"==typeof self&&self)||n("object"==typeof i.g&&i.g)||function(){return this}()||Function("return this")()},6656:function(e){var t={}.hasOwnProperty;e.exports=function(e,i){return t.call(e,i)}},3501:function(e){e.exports={}},490:function(e,t,i){var n=i(5005);e.exports=n("document","documentElement")},4664:function(e,t,i){var n=i(9781),r=i(7293),a=i(317);e.exports=!n&&!r((function(){return 7!=Object.defineProperty(a("div"),"a",{get:function(){return 7}}).a}))},1179:function(e){var t=Math.abs,i=Math.pow,n=Math.floor,r=Math.log,a=Math.LN2;e.exports={pack:function(e,s,o){var l,c,u,d=new Array(o),h=8*o-s-1,f=(1<<h)-1,p=f>>1,m=23===s?i(2,-24)-i(2,-77):0,g=e<0||0===e&&1/e<0?1:0,v=0;for((e=t(e))!=e||e===1/0?(c=e!=e?1:0,l=f):(l=n(r(e)/a),e*(u=i(2,-l))<1&&(l--,u*=2),(e+=l+p>=1?m/u:m*i(2,1-p))*u>=2&&(l++,u/=2),l+p>=f?(c=0,l=f):l+p>=1?(c=(e*u-1)*i(2,s),l+=p):(c=e*i(2,p-1)*i(2,s),l=0));s>=8;d[v++]=255&c,c/=256,s-=8);for(l=l<<s|c,h+=s;h>0;d[v++]=255&l,l/=256,h-=8);return d[--v]|=128*g,d},unpack:function(e,t){var n,r=e.length,a=8*r-t-1,s=(1<<a)-1,o=s>>1,l=a-7,c=r-1,u=e[c--],d=127&u;for(u>>=7;l>0;d=256*d+e[c],c--,l-=8);for(n=d&(1<<-l)-1,d>>=-l,l+=t;l>0;n=256*n+e[c],c--,l-=8);if(0===d)d=1-o;else{if(d===s)return n?NaN:u?-1/0:1/0;n+=i(2,t),d-=o}return(u?-1:1)*n*i(2,d-t)}}},8361:function(e,t,i){var n=i(7293),r=i(4326),a="".split;e.exports=n((function(){return!Object("z").propertyIsEnumerable(0)}))?function(e){return"String"==r(e)?a.call(e,""):Object(e)}:Object},9587:function(e,t,i){var n=i(111),r=i(7674);e.exports=function(e,t,i){var a,s;return r&&"function"==typeof(a=t.constructor)&&a!==i&&n(s=a.prototype)&&s!==i.prototype&&r(e,s),e}},2788:function(e,t,i){var n=i(5465),r=Function.toString;"function"!=typeof n.inspectSource&&(n.inspectSource=function(e){return r.call(e)}),e.exports=n.inspectSource},9909:function(e,t,i){var n,r,a,s=i(8536),o=i(7854),l=i(111),c=i(8880),u=i(6656),d=i(5465),h=i(6200),f=i(3501),p=o.WeakMap;if(s){var m=d.state||(d.state=new p),g=m.get,v=m.has,y=m.set;n=function(e,t){return t.facade=e,y.call(m,e,t),t},r=function(e){return g.call(m,e)||{}},a=function(e){return v.call(m,e)}}else{var b=h("state");f[b]=!0,n=function(e,t){return t.facade=e,c(e,b,t),t},r=function(e){return u(e,b)?e[b]:{}},a=function(e){return u(e,b)}}e.exports={set:n,get:r,has:a,enforce:function(e){return a(e)?r(e):n(e,{})},getterFor:function(e){return function(t){var i;if(!l(t)||(i=r(t)).type!==e)throw TypeError("Incompatible receiver, "+e+" required");return i}}}},7659:function(e,t,i){var n=i(5112),r=i(7497),a=n("iterator"),s=Array.prototype;e.exports=function(e){return void 0!==e&&(r.Array===e||s[a]===e)}},3157:function(e,t,i){var n=i(4326);e.exports=Array.isArray||function(e){return"Array"==n(e)}},4705:function(e,t,i){var n=i(7293),r=/#|\.prototype\./,a=function(e,t){var i=o[s(e)];return i==c||i!=l&&("function"==typeof t?n(t):!!t)},s=a.normalize=function(e){return String(e).replace(r,".").toLowerCase()},o=a.data={},l=a.NATIVE="N",c=a.POLYFILL="P";e.exports=a},111:function(e){e.exports=function(e){return"object"==typeof e?null!==e:"function"==typeof e}},1913:function(e){e.exports=!1},7850:function(e,t,i){var n=i(111),r=i(4326),a=i(5112)("match");e.exports=function(e){var t;return n(e)&&(void 0!==(t=e[a])?!!t:"RegExp"==r(e))}},9212:function(e,t,i){var n=i(9670);e.exports=function(e){var t=e.return;if(void 0!==t)return n(t.call(e)).value}},3383:function(e,t,i){"use strict";var n,r,a,s=i(7293),o=i(9518),l=i(8880),c=i(6656),u=i(5112),d=i(1913),h=u("iterator"),f=!1;[].keys&&("next"in(a=[].keys())?(r=o(o(a)))!==Object.prototype&&(n=r):f=!0);var p=null==n||s((function(){var e={};return n[h].call(e)!==e}));p&&(n={}),d&&!p||c(n,h)||l(n,h,(function(){return this})),e.exports={IteratorPrototype:n,BUGGY_SAFARI_ITERATORS:f}},7497:function(e){e.exports={}},133:function(e,t,i){var n=i(7293);e.exports=!!Object.getOwnPropertySymbols&&!n((function(){return!String(Symbol())}))},590:function(e,t,i){var n=i(7293),r=i(5112),a=i(1913),s=r("iterator");e.exports=!n((function(){var e=new URL("b?a=1&b=2&c=3","http://a"),t=e.searchParams,i="";return e.pathname="c%20d",t.forEach((function(e,n){t.delete("b"),i+=n+e})),a&&!e.toJSON||!t.sort||"http://a/c%20d?a=1&c=3"!==e.href||"3"!==t.get("c")||"a=1"!==String(new URLSearchParams("?a=1"))||!t[s]||"a"!==new URL("https://a@b").username||"b"!==new URLSearchParams(new URLSearchParams("a=b")).get("a")||"xn--e1aybc"!==new URL("http://тест").host||"#%D0%B1"!==new URL("http://a#б").hash||"a1c3"!==i||"x"!==new URL("http://x",void 0).host}))},8536:function(e,t,i){var n=i(7854),r=i(2788),a=n.WeakMap;e.exports="function"==typeof a&&/native code/.test(r(a))},1574:function(e,t,i){"use strict";var n=i(9781),r=i(7293),a=i(1956),s=i(5181),o=i(5296),l=i(7908),c=i(8361),u=Object.assign,d=Object.defineProperty;e.exports=!u||r((function(){if(n&&1!==u({b:1},u(d({},"a",{enumerable:!0,get:function(){d(this,"b",{value:3,enumerable:!1})}}),{b:2})).b)return!0;var e={},t={},i=Symbol(),r="abcdefghijklmnopqrst";return e[i]=7,r.split("").forEach((function(e){t[e]=e})),7!=u({},e)[i]||a(u({},t)).join("")!=r}))?function(e,t){for(var i=l(e),r=arguments.length,u=1,d=s.f,h=o.f;r>u;)for(var f,p=c(arguments[u++]),m=d?a(p).concat(d(p)):a(p),g=m.length,v=0;g>v;)f=m[v++],n&&!h.call(p,f)||(i[f]=p[f]);return i}:u},30:function(e,t,i){var n,r=i(9670),a=i(6048),s=i(748),o=i(3501),l=i(490),c=i(317),u=i(6200),d="prototype",h="script",f=u("IE_PROTO"),p=function(){},m=function(e){return"<"+h+">"+e+"</"+h+">"},g=function(){try{n=document.domain&&new ActiveXObject("htmlfile")}catch(e){}var e,t,i;g=n?function(e){e.write(m("")),e.close();var t=e.parentWindow.Object;return e=null,t}(n):(t=c("iframe"),i="java"+h+":",t.style.display="none",l.appendChild(t),t.src=String(i),(e=t.contentWindow.document).open(),e.write(m("document.F=Object")),e.close(),e.F);for(var r=s.length;r--;)delete g[d][s[r]];return g()};o[f]=!0,e.exports=Object.create||function(e,t){var i;return null!==e?(p[d]=r(e),i=new p,p[d]=null,i[f]=e):i=g(),void 0===t?i:a(i,t)}},6048:function(e,t,i){var n=i(9781),r=i(3070),a=i(9670),s=i(1956);e.exports=n?Object.defineProperties:function(e,t){a(e);for(var i,n=s(t),o=n.length,l=0;o>l;)r.f(e,i=n[l++],t[i]);return e}},3070:function(e,t,i){var n=i(9781),r=i(4664),a=i(9670),s=i(7593),o=Object.defineProperty;t.f=n?o:function(e,t,i){if(a(e),t=s(t,!0),a(i),r)try{return o(e,t,i)}catch(e){}if("get"in i||"set"in i)throw TypeError("Accessors not supported");return"value"in i&&(e[t]=i.value),e}},1236:function(e,t,i){var n=i(9781),r=i(5296),a=i(9114),s=i(5656),o=i(7593),l=i(6656),c=i(4664),u=Object.getOwnPropertyDescriptor;t.f=n?u:function(e,t){if(e=s(e),t=o(t,!0),c)try{return u(e,t)}catch(e){}if(l(e,t))return a(!r.f.call(e,t),e[t])}},8006:function(e,t,i){var n=i(6324),r=i(748).concat("length","prototype");t.f=Object.getOwnPropertyNames||function(e){return n(e,r)}},5181:function(e,t){t.f=Object.getOwnPropertySymbols},9518:function(e,t,i){var n=i(6656),r=i(7908),a=i(6200),s=i(8544),o=a("IE_PROTO"),l=Object.prototype;e.exports=s?Object.getPrototypeOf:function(e){return e=r(e),n(e,o)?e[o]:"function"==typeof e.constructor&&e instanceof e.constructor?e.constructor.prototype:e instanceof Object?l:null}},6324:function(e,t,i){var n=i(6656),r=i(5656),a=i(1318).indexOf,s=i(3501);e.exports=function(e,t){var i,o=r(e),l=0,c=[];for(i in o)!n(s,i)&&n(o,i)&&c.push(i);for(;t.length>l;)n(o,i=t[l++])&&(~a(c,i)||c.push(i));return c}},1956:function(e,t,i){var n=i(6324),r=i(748);e.exports=Object.keys||function(e){return n(e,r)}},5296:function(e,t){"use strict";var i={}.propertyIsEnumerable,n=Object.getOwnPropertyDescriptor,r=n&&!i.call({1:2},1);t.f=r?function(e){var t=n(this,e);return!!t&&t.enumerable}:i},7674:function(e,t,i){var n=i(9670),r=i(6077);e.exports=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,i={};try{(e=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set).call(i,[]),t=i instanceof Array}catch(e){}return function(i,a){return n(i),r(a),t?e.call(i,a):i.__proto__=a,i}}():void 0)},288:function(e,t,i){"use strict";var n=i(1694),r=i(648);e.exports=n?{}.toString:function(){return"[object "+r(this)+"]"}},3887:function(e,t,i){var n=i(5005),r=i(8006),a=i(5181),s=i(9670);e.exports=n("Reflect","ownKeys")||function(e){var t=r.f(s(e)),i=a.f;return i?t.concat(i(e)):t}},857:function(e,t,i){var n=i(7854);e.exports=n},2248:function(e,t,i){var n=i(1320);e.exports=function(e,t,i){for(var r in t)n(e,r,t[r],i);return e}},1320:function(e,t,i){var n=i(7854),r=i(8880),a=i(6656),s=i(3505),o=i(2788),l=i(9909),c=l.get,u=l.enforce,d=String(String).split("String");(e.exports=function(e,t,i,o){var l,c=!!o&&!!o.unsafe,h=!!o&&!!o.enumerable,f=!!o&&!!o.noTargetGet;"function"==typeof i&&("string"!=typeof t||a(i,"name")||r(i,"name",t),(l=u(i)).source||(l.source=d.join("string"==typeof t?t:""))),e!==n?(c?!f&&e[t]&&(h=!0):delete e[t],h?e[t]=i:r(e,t,i)):h?e[t]=i:s(t,i)})(Function.prototype,"toString",(function(){return"function"==typeof this&&c(this).source||o(this)}))},7651:function(e,t,i){var n=i(4326),r=i(2261);e.exports=function(e,t){var i=e.exec;if("function"==typeof i){var a=i.call(e,t);if("object"!=typeof a)throw TypeError("RegExp exec method returned something other than an Object or null");return a}if("RegExp"!==n(e))throw TypeError("RegExp#exec called on incompatible receiver");return r.call(e,t)}},2261:function(e,t,i){"use strict";var n,r,a=i(7066),s=i(2999),o=RegExp.prototype.exec,l=String.prototype.replace,c=o,u=(n=/a/,r=/b*/g,o.call(n,"a"),o.call(r,"a"),0!==n.lastIndex||0!==r.lastIndex),d=s.UNSUPPORTED_Y||s.BROKEN_CARET,h=void 0!==/()??/.exec("")[1];(u||h||d)&&(c=function(e){var t,i,n,r,s=this,c=d&&s.sticky,f=a.call(s),p=s.source,m=0,g=e;return c&&(-1===(f=f.replace("y","")).indexOf("g")&&(f+="g"),g=String(e).slice(s.lastIndex),s.lastIndex>0&&(!s.multiline||s.multiline&&"\n"!==e[s.lastIndex-1])&&(p="(?: "+p+")",g=" "+g,m++),i=new RegExp("^(?:"+p+")",f)),h&&(i=new RegExp("^"+p+"$(?!\\s)",f)),u&&(t=s.lastIndex),n=o.call(c?i:s,g),c?n?(n.input=n.input.slice(m),n[0]=n[0].slice(m),n.index=s.lastIndex,s.lastIndex+=n[0].length):s.lastIndex=0:u&&n&&(s.lastIndex=s.global?n.index+n[0].length:t),h&&n&&n.length>1&&l.call(n[0],i,(function(){for(r=1;r<arguments.length-2;r++)void 0===arguments[r]&&(n[r]=void 0)})),n}),e.exports=c},7066:function(e,t,i){"use strict";var n=i(9670);e.exports=function(){var e=n(this),t="";return e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.sticky&&(t+="y"),t}},2999:function(e,t,i){"use strict";var n=i(7293);function r(e,t){return RegExp(e,t)}t.UNSUPPORTED_Y=n((function(){var e=r("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),t.BROKEN_CARET=n((function(){var e=r("^r","gy");return e.lastIndex=2,null!=e.exec("str")}))},4488:function(e){e.exports=function(e){if(null==e)throw TypeError("Can't call method on "+e);return e}},3505:function(e,t,i){var n=i(7854),r=i(8880);e.exports=function(e,t){try{r(n,e,t)}catch(i){n[e]=t}return t}},6340:function(e,t,i){"use strict";var n=i(5005),r=i(3070),a=i(5112),s=i(9781),o=a("species");e.exports=function(e){var t=n(e),i=r.f;s&&t&&!t[o]&&i(t,o,{configurable:!0,get:function(){return this}})}},8003:function(e,t,i){var n=i(3070).f,r=i(6656),a=i(5112)("toStringTag");e.exports=function(e,t,i){e&&!r(e=i?e:e.prototype,a)&&n(e,a,{configurable:!0,value:t})}},6200:function(e,t,i){var n=i(2309),r=i(9711),a=n("keys");e.exports=function(e){return a[e]||(a[e]=r(e))}},5465:function(e,t,i){var n=i(7854),r=i(3505),a="__core-js_shared__",s=n[a]||r(a,{});e.exports=s},2309:function(e,t,i){var n=i(1913),r=i(5465);(e.exports=function(e,t){return r[e]||(r[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.9.0",mode:n?"pure":"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})},6707:function(e,t,i){var n=i(9670),r=i(3099),a=i(5112)("species");e.exports=function(e,t){var i,s=n(e).constructor;return void 0===s||null==(i=n(s)[a])?t:r(i)}},8710:function(e,t,i){var n=i(9958),r=i(4488),a=function(e){return function(t,i){var a,s,o=String(r(t)),l=n(i),c=o.length;return l<0||l>=c?e?"":void 0:(a=o.charCodeAt(l))<55296||a>56319||l+1===c||(s=o.charCodeAt(l+1))<56320||s>57343?e?o.charAt(l):a:e?o.slice(l,l+2):s-56320+(a-55296<<10)+65536}};e.exports={codeAt:a(!1),charAt:a(!0)}},3197:function(e){"use strict";var t=2147483647,i=/[^\0-\u007E]/,n=/[.\u3002\uFF0E\uFF61]/g,r="Overflow: input needs wider integers to process",a=Math.floor,s=String.fromCharCode,o=function(e){return e+22+75*(e<26)},l=function(e,t,i){var n=0;for(e=i?a(e/700):e>>1,e+=a(e/t);e>455;n+=36)e=a(e/35);return a(n+36*e/(e+38))},c=function(e){var i=[];e=function(e){for(var t=[],i=0,n=e.length;i<n;){var r=e.charCodeAt(i++);if(r>=55296&&r<=56319&&i<n){var a=e.charCodeAt(i++);56320==(64512&a)?t.push(((1023&r)<<10)+(1023&a)+65536):(t.push(r),i--)}else t.push(r)}return t}(e);var n,c,u=e.length,d=128,h=0,f=72;for(n=0;n<e.length;n++)(c=e[n])<128&&i.push(s(c));var p=i.length,m=p;for(p&&i.push("-");m<u;){var g=t;for(n=0;n<e.length;n++)(c=e[n])>=d&&c<g&&(g=c);var v=m+1;if(g-d>a((t-h)/v))throw RangeError(r);for(h+=(g-d)*v,d=g,n=0;n<e.length;n++){if((c=e[n])<d&&++h>t)throw RangeError(r);if(c==d){for(var y=h,b=36;;b+=36){var x=b<=f?1:b>=f+26?26:b-f;if(y<x)break;var _=y-x,w=36-x;i.push(s(o(x+_%w))),y=a(_/w)}i.push(s(o(y))),f=l(h,v,m==p),h=0,++m}}++h,++d}return i.join("")};e.exports=function(e){var t,r,a=[],s=e.toLowerCase().replace(n,".").split(".");for(t=0;t<s.length;t++)r=s[t],a.push(i.test(r)?"xn--"+c(r):r);return a.join(".")}},6091:function(e,t,i){var n=i(7293),r=i(1361);e.exports=function(e){return n((function(){return!!r[e]()||"​᠎"!="​᠎"[e]()||r[e].name!==e}))}},3111:function(e,t,i){var n=i(4488),r="["+i(1361)+"]",a=RegExp("^"+r+r+"*"),s=RegExp(r+r+"*$"),o=function(e){return function(t){var i=String(n(t));return 1&e&&(i=i.replace(a,"")),2&e&&(i=i.replace(s,"")),i}};e.exports={start:o(1),end:o(2),trim:o(3)}},1400:function(e,t,i){var n=i(9958),r=Math.max,a=Math.min;e.exports=function(e,t){var i=n(e);return i<0?r(i+t,0):a(i,t)}},7067:function(e,t,i){var n=i(9958),r=i(7466);e.exports=function(e){if(void 0===e)return 0;var t=n(e),i=r(t);if(t!==i)throw RangeError("Wrong length or index");return i}},5656:function(e,t,i){var n=i(8361),r=i(4488);e.exports=function(e){return n(r(e))}},9958:function(e){var t=Math.ceil,i=Math.floor;e.exports=function(e){return isNaN(e=+e)?0:(e>0?i:t)(e)}},7466:function(e,t,i){var n=i(9958),r=Math.min;e.exports=function(e){return e>0?r(n(e),9007199254740991):0}},7908:function(e,t,i){var n=i(4488);e.exports=function(e){return Object(n(e))}},4590:function(e,t,i){var n=i(3002);e.exports=function(e,t){var i=n(e);if(i%t)throw RangeError("Wrong offset");return i}},3002:function(e,t,i){var n=i(9958);e.exports=function(e){var t=n(e);if(t<0)throw RangeError("The argument can't be less than 0");return t}},7593:function(e,t,i){var n=i(111);e.exports=function(e,t){if(!n(e))return e;var i,r;if(t&&"function"==typeof(i=e.toString)&&!n(r=i.call(e)))return r;if("function"==typeof(i=e.valueOf)&&!n(r=i.call(e)))return r;if(!t&&"function"==typeof(i=e.toString)&&!n(r=i.call(e)))return r;throw TypeError("Can't convert object to primitive value")}},1694:function(e,t,i){var n={};n[i(5112)("toStringTag")]="z",e.exports="[object z]"===String(n)},9843:function(e,t,i){"use strict";var n=i(2109),r=i(7854),a=i(9781),s=i(3832),o=i(260),l=i(3331),c=i(5787),u=i(9114),d=i(8880),h=i(7466),f=i(7067),p=i(4590),m=i(7593),g=i(6656),v=i(648),y=i(111),b=i(30),x=i(7674),_=i(8006).f,w=i(7321),k=i(2092).forEach,M=i(6340),S=i(3070),A=i(1236),L=i(9909),T=i(9587),C=L.get,D=L.set,E=S.f,O=A.f,P=Math.round,Y=r.RangeError,I=l.ArrayBuffer,N=l.DataView,j=o.NATIVE_ARRAY_BUFFER_VIEWS,H=o.TYPED_ARRAY_TAG,F=o.TypedArray,R=o.TypedArrayPrototype,z=o.aTypedArrayConstructor,B=o.isTypedArray,V="BYTES_PER_ELEMENT",W="Wrong length",U=function(e,t){for(var i=0,n=t.length,r=new(z(e))(n);n>i;)r[i]=t[i++];return r},q=function(e,t){E(e,t,{get:function(){return C(this)[t]}})},$=function(e){var t;return e instanceof I||"ArrayBuffer"==(t=v(e))||"SharedArrayBuffer"==t},X=function(e,t){return B(e)&&"symbol"!=typeof t&&t in e&&String(+t)==String(t)},G=function(e,t){return X(e,t=m(t,!0))?u(2,e[t]):O(e,t)},Z=function(e,t,i){return!(X(e,t=m(t,!0))&&y(i)&&g(i,"value"))||g(i,"get")||g(i,"set")||i.configurable||g(i,"writable")&&!i.writable||g(i,"enumerable")&&!i.enumerable?E(e,t,i):(e[t]=i.value,e)};a?(j||(A.f=G,S.f=Z,q(R,"buffer"),q(R,"byteOffset"),q(R,"byteLength"),q(R,"length")),n({target:"Object",stat:!0,forced:!j},{getOwnPropertyDescriptor:G,defineProperty:Z}),e.exports=function(e,t,i){var a=e.match(/\d+$/)[0]/8,o=e+(i?"Clamped":"")+"Array",l="get"+e,u="set"+e,m=r[o],g=m,v=g&&g.prototype,S={},A=function(e,t){E(e,t,{get:function(){return function(e,t){var i=C(e);return i.view[l](t*a+i.byteOffset,!0)}(this,t)},set:function(e){return function(e,t,n){var r=C(e);i&&(n=(n=P(n))<0?0:n>255?255:255&n),r.view[u](t*a+r.byteOffset,n,!0)}(this,t,e)},enumerable:!0})};j?s&&(g=t((function(e,t,i,n){return c(e,g,o),T(y(t)?$(t)?void 0!==n?new m(t,p(i,a),n):void 0!==i?new m(t,p(i,a)):new m(t):B(t)?U(g,t):w.call(g,t):new m(f(t)),e,g)})),x&&x(g,F),k(_(m),(function(e){e in g||d(g,e,m[e])})),g.prototype=v):(g=t((function(e,t,i,n){c(e,g,o);var r,s,l,u=0,d=0;if(y(t)){if(!$(t))return B(t)?U(g,t):w.call(g,t);r=t,d=p(i,a);var m=t.byteLength;if(void 0===n){if(m%a)throw Y(W);if((s=m-d)<0)throw Y(W)}else if((s=h(n)*a)+d>m)throw Y(W);l=s/a}else l=f(t),r=new I(s=l*a);for(D(e,{buffer:r,byteOffset:d,byteLength:s,length:l,view:new N(r)});u<l;)A(e,u++)})),x&&x(g,F),v=g.prototype=b(R)),v.constructor!==g&&d(v,"constructor",g),H&&d(v,H,o),S[o]=g,n({global:!0,forced:g!=m,sham:!j},S),V in g||d(g,V,a),V in v||d(v,V,a),M(o)}):e.exports=function(){}},3832:function(e,t,i){var n=i(7854),r=i(7293),a=i(7072),s=i(260).NATIVE_ARRAY_BUFFER_VIEWS,o=n.ArrayBuffer,l=n.Int8Array;e.exports=!s||!r((function(){l(1)}))||!r((function(){new l(-1)}))||!a((function(e){new l,new l(null),new l(1.5),new l(e)}),!0)||r((function(){return 1!==new l(new o(2),1,void 0).length}))},3074:function(e,t,i){var n=i(260).aTypedArrayConstructor,r=i(6707);e.exports=function(e,t){for(var i=r(e,e.constructor),a=0,s=t.length,o=new(n(i))(s);s>a;)o[a]=t[a++];return o}},7321:function(e,t,i){var n=i(7908),r=i(7466),a=i(1246),s=i(7659),o=i(9974),l=i(260).aTypedArrayConstructor;e.exports=function(e){var t,i,c,u,d,h,f=n(e),p=arguments.length,m=p>1?arguments[1]:void 0,g=void 0!==m,v=a(f);if(null!=v&&!s(v))for(h=(d=v.call(f)).next,f=[];!(u=h.call(d)).done;)f.push(u.value);for(g&&p>2&&(m=o(m,arguments[2],2)),i=r(f.length),c=new(l(this))(i),t=0;i>t;t++)c[t]=g?m(f[t],t):f[t];return c}},9711:function(e){var t=0,i=Math.random();e.exports=function(e){return"Symbol("+String(void 0===e?"":e)+")_"+(++t+i).toString(36)}},3307:function(e,t,i){var n=i(133);e.exports=n&&!Symbol.sham&&"symbol"==typeof Symbol.iterator},5112:function(e,t,i){var n=i(7854),r=i(2309),a=i(6656),s=i(9711),o=i(133),l=i(3307),c=r("wks"),u=n.Symbol,d=l?u:u&&u.withoutSetter||s;e.exports=function(e){return a(c,e)||(o&&a(u,e)?c[e]=u[e]:c[e]=d("Symbol."+e)),c[e]}},1361:function(e){e.exports="\t\n\v\f\r                　\u2028\u2029\ufeff"},8264:function(e,t,i){"use strict";var n=i(2109),r=i(7854),a=i(3331),s=i(6340),o="ArrayBuffer",l=a[o];n({global:!0,forced:r[o]!==l},{ArrayBuffer:l}),s(o)},2222:function(e,t,i){"use strict";var n=i(2109),r=i(7293),a=i(3157),s=i(111),o=i(7908),l=i(7466),c=i(6135),u=i(5417),d=i(1194),h=i(5112),f=i(7392),p=h("isConcatSpreadable"),m=9007199254740991,g="Maximum allowed index exceeded",v=f>=51||!r((function(){var e=[];return e[p]=!1,e.concat()[0]!==e})),y=d("concat"),b=function(e){if(!s(e))return!1;var t=e[p];return void 0!==t?!!t:a(e)};n({target:"Array",proto:!0,forced:!v||!y},{concat:function(e){var t,i,n,r,a,s=o(this),d=u(s,0),h=0;for(t=-1,n=arguments.length;t<n;t++)if(b(a=-1===t?s:arguments[t])){if(h+(r=l(a.length))>m)throw TypeError(g);for(i=0;i<r;i++,h++)i in a&&c(d,h,a[i])}else{if(h>=m)throw TypeError(g);c(d,h++,a)}return d.length=h,d}})},7327:function(e,t,i){"use strict";var n=i(2109),r=i(2092).filter;n({target:"Array",proto:!0,forced:!i(1194)("filter")},{filter:function(e){return r(this,e,arguments.length>1?arguments[1]:void 0)}})},2772:function(e,t,i){"use strict";var n=i(2109),r=i(1318).indexOf,a=i(9341),s=[].indexOf,o=!!s&&1/[1].indexOf(1,-0)<0,l=a("indexOf");n({target:"Array",proto:!0,forced:o||!l},{indexOf:function(e){return o?s.apply(this,arguments)||0:r(this,e,arguments.length>1?arguments[1]:void 0)}})},6992:function(e,t,i){"use strict";var n=i(5656),r=i(1223),a=i(7497),s=i(9909),o=i(654),l="Array Iterator",c=s.set,u=s.getterFor(l);e.exports=o(Array,"Array",(function(e,t){c(this,{type:l,target:n(e),index:0,kind:t})}),(function(){var e=u(this),t=e.target,i=e.kind,n=e.index++;return!t||n>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==i?{value:n,done:!1}:"values"==i?{value:t[n],done:!1}:{value:[n,t[n]],done:!1}}),"values"),a.Arguments=a.Array,r("keys"),r("values"),r("entries")},1249:function(e,t,i){"use strict";var n=i(2109),r=i(2092).map;n({target:"Array",proto:!0,forced:!i(1194)("map")},{map:function(e){return r(this,e,arguments.length>1?arguments[1]:void 0)}})},7042:function(e,t,i){"use strict";var n=i(2109),r=i(111),a=i(3157),s=i(1400),o=i(7466),l=i(5656),c=i(6135),u=i(5112),d=i(1194)("slice"),h=u("species"),f=[].slice,p=Math.max;n({target:"Array",proto:!0,forced:!d},{slice:function(e,t){var i,n,u,d=l(this),m=o(d.length),g=s(e,m),v=s(void 0===t?m:t,m);if(a(d)&&("function"!=typeof(i=d.constructor)||i!==Array&&!a(i.prototype)?r(i)&&null===(i=i[h])&&(i=void 0):i=void 0,i===Array||void 0===i))return f.call(d,g,v);for(n=new(void 0===i?Array:i)(p(v-g,0)),u=0;g<v;g++,u++)g in d&&c(n,u,d[g]);return n.length=u,n}})},561:function(e,t,i){"use strict";var n=i(2109),r=i(1400),a=i(9958),s=i(7466),o=i(7908),l=i(5417),c=i(6135),u=i(1194)("splice"),d=Math.max,h=Math.min;n({target:"Array",proto:!0,forced:!u},{splice:function(e,t){var i,n,u,f,p,m,g=o(this),v=s(g.length),y=r(e,v),b=arguments.length;if(0===b?i=n=0:1===b?(i=0,n=v-y):(i=b-2,n=h(d(a(t),0),v-y)),v+i-n>9007199254740991)throw TypeError("Maximum allowed length exceeded");for(u=l(g,n),f=0;f<n;f++)(p=y+f)in g&&c(u,f,g[p]);if(u.length=n,i<n){for(f=y;f<v-n;f++)m=f+i,(p=f+n)in g?g[m]=g[p]:delete g[m];for(f=v;f>v-n+i;f--)delete g[f-1]}else if(i>n)for(f=v-n;f>y;f--)m=f+i-1,(p=f+n-1)in g?g[m]=g[p]:delete g[m];for(f=0;f<i;f++)g[f+y]=arguments[f+2];return g.length=v-n+i,u}})},8309:function(e,t,i){var n=i(9781),r=i(3070).f,a=Function.prototype,s=a.toString,o=/^\s*function ([^ (]*)/,l="name";n&&!(l in a)&&r(a,l,{configurable:!0,get:function(){try{return s.call(this).match(o)[1]}catch(e){return""}}})},489:function(e,t,i){var n=i(2109),r=i(7293),a=i(7908),s=i(9518),o=i(8544);n({target:"Object",stat:!0,forced:r((function(){s(1)})),sham:!o},{getPrototypeOf:function(e){return s(a(e))}})},1539:function(e,t,i){var n=i(1694),r=i(1320),a=i(288);n||r(Object.prototype,"toString",a,{unsafe:!0})},4916:function(e,t,i){"use strict";var n=i(2109),r=i(2261);n({target:"RegExp",proto:!0,forced:/./.exec!==r},{exec:r})},9714:function(e,t,i){"use strict";var n=i(1320),r=i(9670),a=i(7293),s=i(7066),o="toString",l=RegExp.prototype,c=l[o],u=a((function(){return"/a/b"!=c.call({source:"a",flags:"b"})})),d=c.name!=o;(u||d)&&n(RegExp.prototype,o,(function(){var e=r(this),t=String(e.source),i=e.flags;return"/"+t+"/"+String(void 0===i&&e instanceof RegExp&&!("flags"in l)?s.call(e):i)}),{unsafe:!0})},8783:function(e,t,i){"use strict";var n=i(8710).charAt,r=i(9909),a=i(654),s="String Iterator",o=r.set,l=r.getterFor(s);a(String,"String",(function(e){o(this,{type:s,string:String(e),index:0})}),(function(){var e,t=l(this),i=t.string,r=t.index;return r>=i.length?{value:void 0,done:!0}:(e=n(i,r),t.index+=e.length,{value:e,done:!1})}))},4723:function(e,t,i){"use strict";var n=i(7007),r=i(9670),a=i(7466),s=i(4488),o=i(1530),l=i(7651);n("match",1,(function(e,t,i){return[function(t){var i=s(this),n=null==t?void 0:t[e];return void 0!==n?n.call(t,i):new RegExp(t)[e](String(i))},function(e){var n=i(t,e,this);if(n.done)return n.value;var s=r(e),c=String(this);if(!s.global)return l(s,c);var u=s.unicode;s.lastIndex=0;for(var d,h=[],f=0;null!==(d=l(s,c));){var p=String(d[0]);h[f]=p,""===p&&(s.lastIndex=o(c,a(s.lastIndex),u)),f++}return 0===f?null:h}]}))},5306:function(e,t,i){"use strict";var n=i(7007),r=i(9670),a=i(7466),s=i(9958),o=i(4488),l=i(1530),c=i(647),u=i(7651),d=Math.max,h=Math.min;n("replace",2,(function(e,t,i,n){var f=n.REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE,p=n.REPLACE_KEEPS_$0,m=f?"$":"$0";return[function(i,n){var r=o(this),a=null==i?void 0:i[e];return void 0!==a?a.call(i,r,n):t.call(String(r),i,n)},function(e,n){if(!f&&p||"string"==typeof n&&-1===n.indexOf(m)){var o=i(t,e,this,n);if(o.done)return o.value}var g=r(e),v=String(this),y="function"==typeof n;y||(n=String(n));var b=g.global;if(b){var x=g.unicode;g.lastIndex=0}for(var _=[];;){var w=u(g,v);if(null===w)break;if(_.push(w),!b)break;""===String(w[0])&&(g.lastIndex=l(v,a(g.lastIndex),x))}for(var k,M="",S=0,A=0;A<_.length;A++){w=_[A];for(var L=String(w[0]),T=d(h(s(w.index),v.length),0),C=[],D=1;D<w.length;D++)C.push(void 0===(k=w[D])?k:String(k));var E=w.groups;if(y){var O=[L].concat(C,T,v);void 0!==E&&O.push(E);var P=String(n.apply(void 0,O))}else P=c(L,v,T,C,E,n);T>=S&&(M+=v.slice(S,T)+P,S=T+L.length)}return M+v.slice(S)}]}))},3123:function(e,t,i){"use strict";var n=i(7007),r=i(7850),a=i(9670),s=i(4488),o=i(6707),l=i(1530),c=i(7466),u=i(7651),d=i(2261),h=i(7293),f=[].push,p=Math.min,m=4294967295,g=!h((function(){return!RegExp(m,"y")}));n("split",2,(function(e,t,i){var n;return n="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,i){var n=String(s(this)),a=void 0===i?m:i>>>0;if(0===a)return[];if(void 0===e)return[n];if(!r(e))return t.call(n,e,a);for(var o,l,c,u=[],h=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),p=0,g=new RegExp(e.source,h+"g");(o=d.call(g,n))&&!((l=g.lastIndex)>p&&(u.push(n.slice(p,o.index)),o.length>1&&o.index<n.length&&f.apply(u,o.slice(1)),c=o[0].length,p=l,u.length>=a));)g.lastIndex===o.index&&g.lastIndex++;return p===n.length?!c&&g.test("")||u.push(""):u.push(n.slice(p)),u.length>a?u.slice(0,a):u}:"0".split(void 0,0).length?function(e,i){return void 0===e&&0===i?[]:t.call(this,e,i)}:t,[function(t,i){var r=s(this),a=null==t?void 0:t[e];return void 0!==a?a.call(t,r,i):n.call(String(r),t,i)},function(e,r){var s=i(n,e,this,r,n!==t);if(s.done)return s.value;var d=a(e),h=String(this),f=o(d,RegExp),v=d.unicode,y=(d.ignoreCase?"i":"")+(d.multiline?"m":"")+(d.unicode?"u":"")+(g?"y":"g"),b=new f(g?d:"^(?:"+d.source+")",y),x=void 0===r?m:r>>>0;if(0===x)return[];if(0===h.length)return null===u(b,h)?[h]:[];for(var _=0,w=0,k=[];w<h.length;){b.lastIndex=g?w:0;var M,S=u(b,g?h:h.slice(w));if(null===S||(M=p(c(b.lastIndex+(g?0:w)),h.length))===_)w=l(h,w,v);else{if(k.push(h.slice(_,w)),k.length===x)return k;for(var A=1;A<=S.length-1;A++)if(k.push(S[A]),k.length===x)return k;w=_=M}}return k.push(h.slice(_)),k}]}),!g)},3210:function(e,t,i){"use strict";var n=i(2109),r=i(3111).trim;n({target:"String",proto:!0,forced:i(6091)("trim")},{trim:function(){return r(this)}})},2990:function(e,t,i){"use strict";var n=i(260),r=i(1048),a=n.aTypedArray;(0,n.exportTypedArrayMethod)("copyWithin",(function(e,t){return r.call(a(this),e,t,arguments.length>2?arguments[2]:void 0)}))},8927:function(e,t,i){"use strict";var n=i(260),r=i(2092).every,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("every",(function(e){return r(a(this),e,arguments.length>1?arguments[1]:void 0)}))},3105:function(e,t,i){"use strict";var n=i(260),r=i(1285),a=n.aTypedArray;(0,n.exportTypedArrayMethod)("fill",(function(e){return r.apply(a(this),arguments)}))},5035:function(e,t,i){"use strict";var n=i(260),r=i(2092).filter,a=i(3074),s=n.aTypedArray;(0,n.exportTypedArrayMethod)("filter",(function(e){var t=r(s(this),e,arguments.length>1?arguments[1]:void 0);return a(this,t)}))},7174:function(e,t,i){"use strict";var n=i(260),r=i(2092).findIndex,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("findIndex",(function(e){return r(a(this),e,arguments.length>1?arguments[1]:void 0)}))},4345:function(e,t,i){"use strict";var n=i(260),r=i(2092).find,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("find",(function(e){return r(a(this),e,arguments.length>1?arguments[1]:void 0)}))},2846:function(e,t,i){"use strict";var n=i(260),r=i(2092).forEach,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("forEach",(function(e){r(a(this),e,arguments.length>1?arguments[1]:void 0)}))},4731:function(e,t,i){"use strict";var n=i(260),r=i(1318).includes,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("includes",(function(e){return r(a(this),e,arguments.length>1?arguments[1]:void 0)}))},7209:function(e,t,i){"use strict";var n=i(260),r=i(1318).indexOf,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("indexOf",(function(e){return r(a(this),e,arguments.length>1?arguments[1]:void 0)}))},6319:function(e,t,i){"use strict";var n=i(7854),r=i(260),a=i(6992),s=i(5112)("iterator"),o=n.Uint8Array,l=a.values,c=a.keys,u=a.entries,d=r.aTypedArray,h=r.exportTypedArrayMethod,f=o&&o.prototype[s],p=!!f&&("values"==f.name||null==f.name),m=function(){return l.call(d(this))};h("entries",(function(){return u.call(d(this))})),h("keys",(function(){return c.call(d(this))})),h("values",m,!p),h(s,m,!p)},8867:function(e,t,i){"use strict";var n=i(260),r=n.aTypedArray,a=n.exportTypedArrayMethod,s=[].join;a("join",(function(e){return s.apply(r(this),arguments)}))},7789:function(e,t,i){"use strict";var n=i(260),r=i(6583),a=n.aTypedArray;(0,n.exportTypedArrayMethod)("lastIndexOf",(function(e){return r.apply(a(this),arguments)}))},3739:function(e,t,i){"use strict";var n=i(260),r=i(2092).map,a=i(6707),s=n.aTypedArray,o=n.aTypedArrayConstructor;(0,n.exportTypedArrayMethod)("map",(function(e){return r(s(this),e,arguments.length>1?arguments[1]:void 0,(function(e,t){return new(o(a(e,e.constructor)))(t)}))}))},4483:function(e,t,i){"use strict";var n=i(260),r=i(3671).right,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("reduceRight",(function(e){return r(a(this),e,arguments.length,arguments.length>1?arguments[1]:void 0)}))},9368:function(e,t,i){"use strict";var n=i(260),r=i(3671).left,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("reduce",(function(e){return r(a(this),e,arguments.length,arguments.length>1?arguments[1]:void 0)}))},2056:function(e,t,i){"use strict";var n=i(260),r=n.aTypedArray,a=n.exportTypedArrayMethod,s=Math.floor;a("reverse",(function(){for(var e,t=this,i=r(t).length,n=s(i/2),a=0;a<n;)e=t[a],t[a++]=t[--i],t[i]=e;return t}))},3462:function(e,t,i){"use strict";var n=i(260),r=i(7466),a=i(4590),s=i(7908),o=i(7293),l=n.aTypedArray;(0,n.exportTypedArrayMethod)("set",(function(e){l(this);var t=a(arguments.length>1?arguments[1]:void 0,1),i=this.length,n=s(e),o=r(n.length),c=0;if(o+t>i)throw RangeError("Wrong length");for(;c<o;)this[t+c]=n[c++]}),o((function(){new Int8Array(1).set({})})))},678:function(e,t,i){"use strict";var n=i(260),r=i(6707),a=i(7293),s=n.aTypedArray,o=n.aTypedArrayConstructor,l=n.exportTypedArrayMethod,c=[].slice;l("slice",(function(e,t){for(var i=c.call(s(this),e,t),n=r(this,this.constructor),a=0,l=i.length,u=new(o(n))(l);l>a;)u[a]=i[a++];return u}),a((function(){new Int8Array(1).slice()})))},7462:function(e,t,i){"use strict";var n=i(260),r=i(2092).some,a=n.aTypedArray;(0,n.exportTypedArrayMethod)("some",(function(e){return r(a(this),e,arguments.length>1?arguments[1]:void 0)}))},3824:function(e,t,i){"use strict";var n=i(260),r=n.aTypedArray,a=n.exportTypedArrayMethod,s=[].sort;a("sort",(function(e){return s.call(r(this),e)}))},5021:function(e,t,i){"use strict";var n=i(260),r=i(7466),a=i(1400),s=i(6707),o=n.aTypedArray;(0,n.exportTypedArrayMethod)("subarray",(function(e,t){var i=o(this),n=i.length,l=a(e,n);return new(s(i,i.constructor))(i.buffer,i.byteOffset+l*i.BYTES_PER_ELEMENT,r((void 0===t?n:a(t,n))-l))}))},2974:function(e,t,i){"use strict";var n=i(7854),r=i(260),a=i(7293),s=n.Int8Array,o=r.aTypedArray,l=r.exportTypedArrayMethod,c=[].toLocaleString,u=[].slice,d=!!s&&a((function(){c.call(new s(1))}));l("toLocaleString",(function(){return c.apply(d?u.call(o(this)):o(this),arguments)}),a((function(){return[1,2].toLocaleString()!=new s([1,2]).toLocaleString()}))||!a((function(){s.prototype.toLocaleString.call([1,2])})))},5016:function(e,t,i){"use strict";var n=i(260).exportTypedArrayMethod,r=i(7293),a=i(7854).Uint8Array,s=a&&a.prototype||{},o=[].toString,l=[].join;r((function(){o.call({})}))&&(o=function(){return l.call(this)});var c=s.toString!=o;n("toString",o,c)},2472:function(e,t,i){i(9843)("Uint8",(function(e){return function(t,i,n){return e(this,t,i,n)}}))},4747:function(e,t,i){var n=i(7854),r=i(8324),a=i(8533),s=i(8880);for(var o in r){var l=n[o],c=l&&l.prototype;if(c&&c.forEach!==a)try{s(c,"forEach",a)}catch(e){c.forEach=a}}},3948:function(e,t,i){var n=i(7854),r=i(8324),a=i(6992),s=i(8880),o=i(5112),l=o("iterator"),c=o("toStringTag"),u=a.values;for(var d in r){var h=n[d],f=h&&h.prototype;if(f){if(f[l]!==u)try{s(f,l,u)}catch(e){f[l]=u}if(f[c]||s(f,c,d),r[d])for(var p in a)if(f[p]!==a[p])try{s(f,p,a[p])}catch(e){f[p]=a[p]}}}},1637:function(e,t,i){"use strict";i(6992);var n=i(2109),r=i(5005),a=i(590),s=i(1320),o=i(2248),l=i(8003),c=i(4994),u=i(9909),d=i(5787),h=i(6656),f=i(9974),p=i(648),m=i(9670),g=i(111),v=i(30),y=i(9114),b=i(8554),x=i(1246),_=i(5112),w=r("fetch"),k=r("Headers"),M=_("iterator"),S="URLSearchParams",A=S+"Iterator",L=u.set,T=u.getterFor(S),C=u.getterFor(A),D=/\+/g,E=Array(4),O=function(e){return E[e-1]||(E[e-1]=RegExp("((?:%[\\da-f]{2}){"+e+"})","gi"))},P=function(e){try{return decodeURIComponent(e)}catch(t){return e}},Y=function(e){var t=e.replace(D," "),i=4;try{return decodeURIComponent(t)}catch(e){for(;i;)t=t.replace(O(i--),P);return t}},I=/[!'()~]|%20/g,N={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+"},j=function(e){return N[e]},H=function(e){return encodeURIComponent(e).replace(I,j)},F=function(e,t){if(t)for(var i,n,r=t.split("&"),a=0;a<r.length;)(i=r[a++]).length&&(n=i.split("="),e.push({key:Y(n.shift()),value:Y(n.join("="))}))},R=function(e){this.entries.length=0,F(this.entries,e)},z=function(e,t){if(e<t)throw TypeError("Not enough arguments")},B=c((function(e,t){L(this,{type:A,iterator:b(T(e).entries),kind:t})}),"Iterator",(function(){var e=C(this),t=e.kind,i=e.iterator.next(),n=i.value;return i.done||(i.value="keys"===t?n.key:"values"===t?n.value:[n.key,n.value]),i})),V=function(){d(this,V,S);var e,t,i,n,r,a,s,o,l,c=arguments.length>0?arguments[0]:void 0,u=[];if(L(this,{type:S,entries:u,updateURL:function(){},updateSearchParams:R}),void 0!==c)if(g(c))if("function"==typeof(e=x(c)))for(i=(t=e.call(c)).next;!(n=i.call(t)).done;){if((s=(a=(r=b(m(n.value))).next).call(r)).done||(o=a.call(r)).done||!a.call(r).done)throw TypeError("Expected sequence with length 2");u.push({key:s.value+"",value:o.value+""})}else for(l in c)h(c,l)&&u.push({key:l,value:c[l]+""});else F(u,"string"==typeof c?"?"===c.charAt(0)?c.slice(1):c:c+"")},W=V.prototype;o(W,{append:function(e,t){z(arguments.length,2);var i=T(this);i.entries.push({key:e+"",value:t+""}),i.updateURL()},delete:function(e){z(arguments.length,1);for(var t=T(this),i=t.entries,n=e+"",r=0;r<i.length;)i[r].key===n?i.splice(r,1):r++;t.updateURL()},get:function(e){z(arguments.length,1);for(var t=T(this).entries,i=e+"",n=0;n<t.length;n++)if(t[n].key===i)return t[n].value;return null},getAll:function(e){z(arguments.length,1);for(var t=T(this).entries,i=e+"",n=[],r=0;r<t.length;r++)t[r].key===i&&n.push(t[r].value);return n},has:function(e){z(arguments.length,1);for(var t=T(this).entries,i=e+"",n=0;n<t.length;)if(t[n++].key===i)return!0;return!1},set:function(e,t){z(arguments.length,1);for(var i,n=T(this),r=n.entries,a=!1,s=e+"",o=t+"",l=0;l<r.length;l++)(i=r[l]).key===s&&(a?r.splice(l--,1):(a=!0,i.value=o));a||r.push({key:s,value:o}),n.updateURL()},sort:function(){var e,t,i,n=T(this),r=n.entries,a=r.slice();for(r.length=0,i=0;i<a.length;i++){for(e=a[i],t=0;t<i;t++)if(r[t].key>e.key){r.splice(t,0,e);break}t===i&&r.push(e)}n.updateURL()},forEach:function(e){for(var t,i=T(this).entries,n=f(e,arguments.length>1?arguments[1]:void 0,3),r=0;r<i.length;)n((t=i[r++]).value,t.key,this)},keys:function(){return new B(this,"keys")},values:function(){return new B(this,"values")},entries:function(){return new B(this,"entries")}},{enumerable:!0}),s(W,M,W.entries),s(W,"toString",(function(){for(var e,t=T(this).entries,i=[],n=0;n<t.length;)e=t[n++],i.push(H(e.key)+"="+H(e.value));return i.join("&")}),{enumerable:!0}),l(V,S),n({global:!0,forced:!a},{URLSearchParams:V}),a||"function"!=typeof w||"function"!=typeof k||n({global:!0,enumerable:!0,forced:!0},{fetch:function(e){var t,i,n,r=[e];return arguments.length>1&&(g(t=arguments[1])&&(i=t.body,p(i)===S&&((n=t.headers?new k(t.headers):new k).has("content-type")||n.set("content-type","application/x-www-form-urlencoded;charset=UTF-8"),t=v(t,{body:y(0,String(i)),headers:y(0,n)}))),r.push(t)),w.apply(this,r)}}),e.exports={URLSearchParams:V,getState:T}},285:function(e,t,i){"use strict";i(8783);var n,r=i(2109),a=i(9781),s=i(590),o=i(7854),l=i(6048),c=i(1320),u=i(5787),d=i(6656),h=i(1574),f=i(8457),p=i(8710).codeAt,m=i(3197),g=i(8003),v=i(1637),y=i(9909),b=o.URL,x=v.URLSearchParams,_=v.getState,w=y.set,k=y.getterFor("URL"),M=Math.floor,S=Math.pow,A="Invalid scheme",L="Invalid host",T="Invalid port",C=/[A-Za-z]/,D=/[\d+-.A-Za-z]/,E=/\d/,O=/^(0x|0X)/,P=/^[0-7]+$/,Y=/^\d+$/,I=/^[\dA-Fa-f]+$/,N=/[\u0000\t\u000A\u000D #%/:?@[\\]]/,j=/[\u0000\t\u000A\u000D #/:?@[\\]]/,H=/^[\u0000-\u001F ]+|[\u0000-\u001F ]+$/g,F=/[\t\u000A\u000D]/g,R=function(e,t){var i,n,r;if("["==t.charAt(0)){if("]"!=t.charAt(t.length-1))return L;if(!(i=B(t.slice(1,-1))))return L;e.host=i}else if(Z(e)){if(t=m(t),N.test(t))return L;if(null===(i=z(t)))return L;e.host=i}else{if(j.test(t))return L;for(i="",n=f(t),r=0;r<n.length;r++)i+=X(n[r],W);e.host=i}},z=function(e){var t,i,n,r,a,s,o,l=e.split(".");if(l.length&&""==l[l.length-1]&&l.pop(),(t=l.length)>4)return e;for(i=[],n=0;n<t;n++){if(""==(r=l[n]))return e;if(a=10,r.length>1&&"0"==r.charAt(0)&&(a=O.test(r)?16:8,r=r.slice(8==a?1:2)),""===r)s=0;else{if(!(10==a?Y:8==a?P:I).test(r))return e;s=parseInt(r,a)}i.push(s)}for(n=0;n<t;n++)if(s=i[n],n==t-1){if(s>=S(256,5-t))return null}else if(s>255)return null;for(o=i.pop(),n=0;n<i.length;n++)o+=i[n]*S(256,3-n);return o},B=function(e){var t,i,n,r,a,s,o,l=[0,0,0,0,0,0,0,0],c=0,u=null,d=0,h=function(){return e.charAt(d)};if(":"==h()){if(":"!=e.charAt(1))return;d+=2,u=++c}for(;h();){if(8==c)return;if(":"!=h()){for(t=i=0;i<4&&I.test(h());)t=16*t+parseInt(h(),16),d++,i++;if("."==h()){if(0==i)return;if(d-=i,c>6)return;for(n=0;h();){if(r=null,n>0){if(!("."==h()&&n<4))return;d++}if(!E.test(h()))return;for(;E.test(h());){if(a=parseInt(h(),10),null===r)r=a;else{if(0==r)return;r=10*r+a}if(r>255)return;d++}l[c]=256*l[c]+r,2!=++n&&4!=n||c++}if(4!=n)return;break}if(":"==h()){if(d++,!h())return}else if(h())return;l[c++]=t}else{if(null!==u)return;d++,u=++c}}if(null!==u)for(s=c-u,c=7;0!=c&&s>0;)o=l[c],l[c--]=l[u+s-1],l[u+--s]=o;else if(8!=c)return;return l},V=function(e){var t,i,n,r;if("number"==typeof e){for(t=[],i=0;i<4;i++)t.unshift(e%256),e=M(e/256);return t.join(".")}if("object"==typeof e){for(t="",n=function(e){for(var t=null,i=1,n=null,r=0,a=0;a<8;a++)0!==e[a]?(r>i&&(t=n,i=r),n=null,r=0):(null===n&&(n=a),++r);return r>i&&(t=n,i=r),t}(e),i=0;i<8;i++)r&&0===e[i]||(r&&(r=!1),n===i?(t+=i?":":"::",r=!0):(t+=e[i].toString(16),i<7&&(t+=":")));return"["+t+"]"}return e},W={},U=h({},W,{" ":1,'"':1,"<":1,">":1,"`":1}),q=h({},U,{"#":1,"?":1,"{":1,"}":1}),$=h({},q,{"/":1,":":1,";":1,"=":1,"@":1,"[":1,"\\":1,"]":1,"^":1,"|":1}),X=function(e,t){var i=p(e,0);return i>32&&i<127&&!d(t,e)?e:encodeURIComponent(e)},G={ftp:21,file:null,http:80,https:443,ws:80,wss:443},Z=function(e){return d(G,e.scheme)},K=function(e){return""!=e.username||""!=e.password},J=function(e){return!e.host||e.cannotBeABaseURL||"file"==e.scheme},Q=function(e,t){var i;return 2==e.length&&C.test(e.charAt(0))&&(":"==(i=e.charAt(1))||!t&&"|"==i)},ee=function(e){var t;return e.length>1&&Q(e.slice(0,2))&&(2==e.length||"/"===(t=e.charAt(2))||"\\"===t||"?"===t||"#"===t)},te=function(e){var t=e.path,i=t.length;!i||"file"==e.scheme&&1==i&&Q(t[0],!0)||t.pop()},ie=function(e){return"."===e||"%2e"===e.toLowerCase()},ne={},re={},ae={},se={},oe={},le={},ce={},ue={},de={},he={},fe={},pe={},me={},ge={},ve={},ye={},be={},xe={},_e={},we={},ke={},Me=function(e,t,i,r){var a,s,o,l,c,u=i||ne,h=0,p="",m=!1,g=!1,v=!1;for(i||(e.scheme="",e.username="",e.password="",e.host=null,e.port=null,e.path=[],e.query=null,e.fragment=null,e.cannotBeABaseURL=!1,t=t.replace(H,"")),t=t.replace(F,""),a=f(t);h<=a.length;){switch(s=a[h],u){case ne:if(!s||!C.test(s)){if(i)return A;u=ae;continue}p+=s.toLowerCase(),u=re;break;case re:if(s&&(D.test(s)||"+"==s||"-"==s||"."==s))p+=s.toLowerCase();else{if(":"!=s){if(i)return A;p="",u=ae,h=0;continue}if(i&&(Z(e)!=d(G,p)||"file"==p&&(K(e)||null!==e.port)||"file"==e.scheme&&!e.host))return;if(e.scheme=p,i)return void(Z(e)&&G[e.scheme]==e.port&&(e.port=null));p="","file"==e.scheme?u=ge:Z(e)&&r&&r.scheme==e.scheme?u=se:Z(e)?u=ue:"/"==a[h+1]?(u=oe,h++):(e.cannotBeABaseURL=!0,e.path.push(""),u=_e)}break;case ae:if(!r||r.cannotBeABaseURL&&"#"!=s)return A;if(r.cannotBeABaseURL&&"#"==s){e.scheme=r.scheme,e.path=r.path.slice(),e.query=r.query,e.fragment="",e.cannotBeABaseURL=!0,u=ke;break}u="file"==r.scheme?ge:le;continue;case se:if("/"!=s||"/"!=a[h+1]){u=le;continue}u=de,h++;break;case oe:if("/"==s){u=he;break}u=xe;continue;case le:if(e.scheme=r.scheme,s==n)e.username=r.username,e.password=r.password,e.host=r.host,e.port=r.port,e.path=r.path.slice(),e.query=r.query;else if("/"==s||"\\"==s&&Z(e))u=ce;else if("?"==s)e.username=r.username,e.password=r.password,e.host=r.host,e.port=r.port,e.path=r.path.slice(),e.query="",u=we;else{if("#"!=s){e.username=r.username,e.password=r.password,e.host=r.host,e.port=r.port,e.path=r.path.slice(),e.path.pop(),u=xe;continue}e.username=r.username,e.password=r.password,e.host=r.host,e.port=r.port,e.path=r.path.slice(),e.query=r.query,e.fragment="",u=ke}break;case ce:if(!Z(e)||"/"!=s&&"\\"!=s){if("/"!=s){e.username=r.username,e.password=r.password,e.host=r.host,e.port=r.port,u=xe;continue}u=he}else u=de;break;case ue:if(u=de,"/"!=s||"/"!=p.charAt(h+1))continue;h++;break;case de:if("/"!=s&&"\\"!=s){u=he;continue}break;case he:if("@"==s){m&&(p="%40"+p),m=!0,o=f(p);for(var y=0;y<o.length;y++){var b=o[y];if(":"!=b||v){var x=X(b,$);v?e.password+=x:e.username+=x}else v=!0}p=""}else if(s==n||"/"==s||"?"==s||"#"==s||"\\"==s&&Z(e)){if(m&&""==p)return"Invalid authority";h-=f(p).length+1,p="",u=fe}else p+=s;break;case fe:case pe:if(i&&"file"==e.scheme){u=ye;continue}if(":"!=s||g){if(s==n||"/"==s||"?"==s||"#"==s||"\\"==s&&Z(e)){if(Z(e)&&""==p)return L;if(i&&""==p&&(K(e)||null!==e.port))return;if(l=R(e,p))return l;if(p="",u=be,i)return;continue}"["==s?g=!0:"]"==s&&(g=!1),p+=s}else{if(""==p)return L;if(l=R(e,p))return l;if(p="",u=me,i==pe)return}break;case me:if(!E.test(s)){if(s==n||"/"==s||"?"==s||"#"==s||"\\"==s&&Z(e)||i){if(""!=p){var _=parseInt(p,10);if(_>65535)return T;e.port=Z(e)&&_===G[e.scheme]?null:_,p=""}if(i)return;u=be;continue}return T}p+=s;break;case ge:if(e.scheme="file","/"==s||"\\"==s)u=ve;else{if(!r||"file"!=r.scheme){u=xe;continue}if(s==n)e.host=r.host,e.path=r.path.slice(),e.query=r.query;else if("?"==s)e.host=r.host,e.path=r.path.slice(),e.query="",u=we;else{if("#"!=s){ee(a.slice(h).join(""))||(e.host=r.host,e.path=r.path.slice(),te(e)),u=xe;continue}e.host=r.host,e.path=r.path.slice(),e.query=r.query,e.fragment="",u=ke}}break;case ve:if("/"==s||"\\"==s){u=ye;break}r&&"file"==r.scheme&&!ee(a.slice(h).join(""))&&(Q(r.path[0],!0)?e.path.push(r.path[0]):e.host=r.host),u=xe;continue;case ye:if(s==n||"/"==s||"\\"==s||"?"==s||"#"==s){if(!i&&Q(p))u=xe;else if(""==p){if(e.host="",i)return;u=be}else{if(l=R(e,p))return l;if("localhost"==e.host&&(e.host=""),i)return;p="",u=be}continue}p+=s;break;case be:if(Z(e)){if(u=xe,"/"!=s&&"\\"!=s)continue}else if(i||"?"!=s)if(i||"#"!=s){if(s!=n&&(u=xe,"/"!=s))continue}else e.fragment="",u=ke;else e.query="",u=we;break;case xe:if(s==n||"/"==s||"\\"==s&&Z(e)||!i&&("?"==s||"#"==s)){if(".."===(c=(c=p).toLowerCase())||"%2e."===c||".%2e"===c||"%2e%2e"===c?(te(e),"/"==s||"\\"==s&&Z(e)||e.path.push("")):ie(p)?"/"==s||"\\"==s&&Z(e)||e.path.push(""):("file"==e.scheme&&!e.path.length&&Q(p)&&(e.host&&(e.host=""),p=p.charAt(0)+":"),e.path.push(p)),p="","file"==e.scheme&&(s==n||"?"==s||"#"==s))for(;e.path.length>1&&""===e.path[0];)e.path.shift();"?"==s?(e.query="",u=we):"#"==s&&(e.fragment="",u=ke)}else p+=X(s,q);break;case _e:"?"==s?(e.query="",u=we):"#"==s?(e.fragment="",u=ke):s!=n&&(e.path[0]+=X(s,W));break;case we:i||"#"!=s?s!=n&&("'"==s&&Z(e)?e.query+="%27":e.query+="#"==s?"%23":X(s,W)):(e.fragment="",u=ke);break;case ke:s!=n&&(e.fragment+=X(s,U))}h++}},Se=function(e){var t,i,n=u(this,Se,"URL"),r=arguments.length>1?arguments[1]:void 0,s=String(e),o=w(n,{type:"URL"});if(void 0!==r)if(r instanceof Se)t=k(r);else if(i=Me(t={},String(r)))throw TypeError(i);if(i=Me(o,s,null,t))throw TypeError(i);var l=o.searchParams=new x,c=_(l);c.updateSearchParams(o.query),c.updateURL=function(){o.query=String(l)||null},a||(n.href=Le.call(n),n.origin=Te.call(n),n.protocol=Ce.call(n),n.username=De.call(n),n.password=Ee.call(n),n.host=Oe.call(n),n.hostname=Pe.call(n),n.port=Ye.call(n),n.pathname=Ie.call(n),n.search=Ne.call(n),n.searchParams=je.call(n),n.hash=He.call(n))},Ae=Se.prototype,Le=function(){var e=k(this),t=e.scheme,i=e.username,n=e.password,r=e.host,a=e.port,s=e.path,o=e.query,l=e.fragment,c=t+":";return null!==r?(c+="//",K(e)&&(c+=i+(n?":"+n:"")+"@"),c+=V(r),null!==a&&(c+=":"+a)):"file"==t&&(c+="//"),c+=e.cannotBeABaseURL?s[0]:s.length?"/"+s.join("/"):"",null!==o&&(c+="?"+o),null!==l&&(c+="#"+l),c},Te=function(){var e=k(this),t=e.scheme,i=e.port;if("blob"==t)try{return new URL(t.path[0]).origin}catch(e){return"null"}return"file"!=t&&Z(e)?t+"://"+V(e.host)+(null!==i?":"+i:""):"null"},Ce=function(){return k(this).scheme+":"},De=function(){return k(this).username},Ee=function(){return k(this).password},Oe=function(){var e=k(this),t=e.host,i=e.port;return null===t?"":null===i?V(t):V(t)+":"+i},Pe=function(){var e=k(this).host;return null===e?"":V(e)},Ye=function(){var e=k(this).port;return null===e?"":String(e)},Ie=function(){var e=k(this),t=e.path;return e.cannotBeABaseURL?t[0]:t.length?"/"+t.join("/"):""},Ne=function(){var e=k(this).query;return e?"?"+e:""},je=function(){return k(this).searchParams},He=function(){var e=k(this).fragment;return e?"#"+e:""},Fe=function(e,t){return{get:e,set:t,configurable:!0,enumerable:!0}};if(a&&l(Ae,{href:Fe(Le,(function(e){var t=k(this),i=String(e),n=Me(t,i);if(n)throw TypeError(n);_(t.searchParams).updateSearchParams(t.query)})),origin:Fe(Te),protocol:Fe(Ce,(function(e){var t=k(this);Me(t,String(e)+":",ne)})),username:Fe(De,(function(e){var t=k(this),i=f(String(e));if(!J(t)){t.username="";for(var n=0;n<i.length;n++)t.username+=X(i[n],$)}})),password:Fe(Ee,(function(e){var t=k(this),i=f(String(e));if(!J(t)){t.password="";for(var n=0;n<i.length;n++)t.password+=X(i[n],$)}})),host:Fe(Oe,(function(e){var t=k(this);t.cannotBeABaseURL||Me(t,String(e),fe)})),hostname:Fe(Pe,(function(e){var t=k(this);t.cannotBeABaseURL||Me(t,String(e),pe)})),port:Fe(Ye,(function(e){var t=k(this);J(t)||(""==(e=String(e))?t.port=null:Me(t,e,me))})),pathname:Fe(Ie,(function(e){var t=k(this);t.cannotBeABaseURL||(t.path=[],Me(t,e+"",be))})),search:Fe(Ne,(function(e){var t=k(this);""==(e=String(e))?t.query=null:("?"==e.charAt(0)&&(e=e.slice(1)),t.query="",Me(t,e,we)),_(t.searchParams).updateSearchParams(t.query)})),searchParams:Fe(je),hash:Fe(He,(function(e){var t=k(this);""!=(e=String(e))?("#"==e.charAt(0)&&(e=e.slice(1)),t.fragment="",Me(t,e,ke)):t.fragment=null}))}),c(Ae,"toJSON",(function(){return Le.call(this)}),{enumerable:!0}),c(Ae,"toString",(function(){return Le.call(this)}),{enumerable:!0}),b){var Re=b.createObjectURL,ze=b.revokeObjectURL;Re&&c(Se,"createObjectURL",(function(e){return Re.apply(b,arguments)})),ze&&c(Se,"revokeObjectURL",(function(e){return ze.apply(b,arguments)}))}g(Se,"URL"),r({global:!0,forced:!s,sham:!a},{URL:Se})}},t={};function i(n){if(t[n])return t[n].exports;var r=t[n]={exports:{}};return e[n](r,r.exports,i),r.exports}i.d=function(e,t){for(var n in t)i.o(t,n)&&!i.o(e,n)&&Object.defineProperty(e,n,{enumerable:!0,get:t[n]})},i.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),i.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},i.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})};var n={};return function(){"use strict";i.r(n),i.d(n,{Dropzone:function(){return x},default:function(){return S}});i(2222),i(7327),i(2772),i(6992),i(1249),i(7042),i(561),i(8264),i(8309),i(489),i(1539),i(4916),i(9714),i(8783),i(4723),i(5306),i(3123),i(3210),i(2472),i(2990),i(8927),i(3105),i(5035),i(4345),i(7174),i(2846),i(4731),i(7209),i(6319),i(8867),i(7789),i(3739),i(9368),i(4483),i(2056),i(3462),i(678),i(7462),i(3824),i(5021),i(2974),i(5016),i(4747),i(3948),i(285);function e(e,i){var n;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(n=function(e,i){if(!e)return;if("string"==typeof e)return t(e,i);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return t(e,i)}(e))||i&&e&&"number"==typeof e.length){n&&(e=n);var r=0,a=function(){};return{s:a,n:function(){return r>=e.length?{done:!0}:{done:!1,value:e[r++]}},e:function(e){throw e},f:a}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var s,o=!0,l=!1;return{s:function(){n=e[Symbol.iterator]()},n:function(){var e=n.next();return o=e.done,e},e:function(e){l=!0,s=e},f:function(){try{o||null==n.return||n.return()}finally{if(l)throw s}}}}function t(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function r(e,t){for(var i=0;i<t.length;i++){var n=t[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}var a=function(){function t(){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,t)}var i,n,a;return i=t,n=[{key:"on",value:function(e,t){return this._callbacks=this._callbacks||{},this._callbacks[e]||(this._callbacks[e]=[]),this._callbacks[e].push(t),this}},{key:"emit",value:function(t){this._callbacks=this._callbacks||{};for(var i=this._callbacks[t],n=arguments.length,r=new Array(n>1?n-1:0),a=1;a<n;a++)r[a-1]=arguments[a];if(i){var s,o=e(i,!0);try{for(o.s();!(s=o.n()).done;)s.value.apply(this,r)}catch(e){o.e(e)}finally{o.f()}}return this.element&&this.element.dispatchEvent(this.makeEvent("dropzone:"+t,{args:r})),this}},{key:"makeEvent",value:function(e,t){var i={bubbles:!0,cancelable:!0,detail:t};if("function"==typeof window.CustomEvent)return new CustomEvent(e,i);var n=document.createEvent("CustomEvent");return n.initCustomEvent(e,i.bubbles,i.cancelable,i.detail),n}},{key:"off",value:function(e,t){if(!this._callbacks||0===arguments.length)return this._callbacks={},this;var i=this._callbacks[e];if(!i)return this;if(1===arguments.length)return delete this._callbacks[e],this;for(var n=0;n<i.length;n++)if(i[n]===t){i.splice(n,1);break}return this}}],n&&r(i.prototype,n),a&&r(i,a),t}();function s(e,t){var i;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(i=function(e,t){if(!e)return;if("string"==typeof e)return o(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);"Object"===i&&e.constructor&&(i=e.constructor.name);if("Map"===i||"Set"===i)return Array.from(e);if("Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i))return o(e,t)}(e))||t&&e&&"number"==typeof e.length){i&&(e=i);var n=0,r=function(){};return{s:r,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,s=!0,l=!1;return{s:function(){i=e[Symbol.iterator]()},n:function(){var e=i.next();return s=e.done,e},e:function(e){l=!0,a=e},f:function(){try{s||null==i.return||i.return()}finally{if(l)throw a}}}}function o(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}var l={url:null,method:"post",withCredentials:!1,timeout:null,parallelUploads:2,uploadMultiple:!1,chunking:!1,forceChunking:!1,chunkSize:2e6,parallelChunkUploads:!1,retryChunks:!1,retryChunksLimit:3,maxFilesize:256,paramName:"file",createImageThumbnails:!0,maxThumbnailFilesize:10,thumbnailWidth:120,thumbnailHeight:120,thumbnailMethod:"crop",resizeWidth:null,resizeHeight:null,resizeMimeType:null,resizeQuality:.8,resizeMethod:"contain",filesizeBase:1e3,maxFiles:null,headers:null,clickable:!0,ignoreHiddenFiles:!0,acceptedFiles:null,acceptedMimeTypes:null,autoProcessQueue:!0,autoQueue:!0,addRemoveLinks:!1,previewsContainer:null,disablePreviews:!1,hiddenInputContainer:"body",capture:null,renameFilename:null,renameFile:null,forceFallback:!1,dictDefaultMessage:"Drop files here to upload",dictFallbackMessage:"Your browser does not support drag'n'drop file uploads.",dictFallbackText:"Please use the fallback form below to upload your files like in the olden days.",dictFileTooBig:"File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.",dictInvalidFileType:"You can't upload files of this type.",dictResponseError:"Server responded with {{statusCode}} code.",dictCancelUpload:"Cancel upload",dictUploadCanceled:"Upload canceled.",dictCancelUploadConfirmation:"Are you sure you want to cancel this upload?",dictRemoveFile:"Remove file",dictRemoveFileConfirmation:null,dictMaxFilesExceeded:"You can not upload any more files.",dictFileSizeUnits:{tb:"TB",gb:"GB",mb:"MB",kb:"KB",b:"b"},init:function(){},params:function(e,t,i){if(i)return{dzuuid:i.file.upload.uuid,dzchunkindex:i.index,dztotalfilesize:i.file.size,dzchunksize:this.options.chunkSize,dztotalchunkcount:i.file.upload.totalChunkCount,dzchunkbyteoffset:i.index*this.options.chunkSize}},accept:function(e,t){return t()},chunksUploaded:function(e,t){t()},fallback:function(){var e;this.element.className="".concat(this.element.className," dz-browser-not-supported");var t,i=s(this.element.getElementsByTagName("div"),!0);try{for(i.s();!(t=i.n()).done;){var n=t.value;if(/(^| )dz-message($| )/.test(n.className)){e=n,n.className="dz-message";break}}}catch(e){i.e(e)}finally{i.f()}e||(e=x.createElement('<div class="dz-message"><span></span></div>'),this.element.appendChild(e));var r=e.getElementsByTagName("span")[0];return r&&(null!=r.textContent?r.textContent=this.options.dictFallbackMessage:null!=r.innerText&&(r.innerText=this.options.dictFallbackMessage)),this.element.appendChild(this.getFallbackForm())},resize:function(e,t,i,n){var r={srcX:0,srcY:0,srcWidth:e.width,srcHeight:e.height},a=e.width/e.height;null==t&&null==i?(t=r.srcWidth,i=r.srcHeight):null==t?t=i*a:null==i&&(i=t/a);var s=(t=Math.min(t,r.srcWidth))/(i=Math.min(i,r.srcHeight));if(r.srcWidth>t||r.srcHeight>i)if("crop"===n)a>s?(r.srcHeight=e.height,r.srcWidth=r.srcHeight*s):(r.srcWidth=e.width,r.srcHeight=r.srcWidth/s);else{if("contain"!==n)throw new Error("Unknown resizeMethod '".concat(n,"'"));a>s?i=t/a:t=i*a}return r.srcX=(e.width-r.srcWidth)/2,r.srcY=(e.height-r.srcHeight)/2,r.trgWidth=t,r.trgHeight=i,r},transformFile:function(e,t){return(this.options.resizeWidth||this.options.resizeHeight)&&e.type.match(/image.*/)?this.resizeImage(e,this.options.resizeWidth,this.options.resizeHeight,this.options.resizeMethod,t):t(e)},previewTemplate:'<div class="dz-preview dz-file-preview"> <div class="dz-image"><img data-dz-thumbnail/></div> <div class="dz-details"> <div class="dz-size"><span data-dz-size></span></div> <div class="dz-filename"><span data-dz-name></span></div> </div> <div class="dz-progress"> <span class="dz-upload" data-dz-uploadprogress></span> </div> <div class="dz-error-message"><span data-dz-errormessage></span></div> <div class="dz-success-mark"> <svg width="54px" height="54px" viewBox="0 0 54 54" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <title>Check</title> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <path d="M23.5,31.8431458 L17.5852419,25.9283877 C16.0248253,24.3679711 13.4910294,24.366835 11.9289322,25.9289322 C10.3700136,27.4878508 10.3665912,30.0234455 11.9283877,31.5852419 L20.4147581,40.0716123 C20.5133999,40.1702541 20.6159315,40.2626649 20.7218615,40.3488435 C22.2835669,41.8725651 24.794234,41.8626202 26.3461564,40.3106978 L43.3106978,23.3461564 C44.8771021,21.7797521 44.8758057,19.2483887 43.3137085,17.6862915 C41.7547899,16.1273729 39.2176035,16.1255422 37.6538436,17.6893022 L23.5,31.8431458 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z" stroke-opacity="0.198794158" stroke="#747474" fill-opacity="0.816519475" fill="#FFFFFF"></path> </g> </svg> </div> <div class="dz-error-mark"> <svg width="54px" height="54px" viewBox="0 0 54 54" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <title>Error</title> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g stroke="#747474" stroke-opacity="0.198794158" fill="#FFFFFF" fill-opacity="0.816519475"> <path d="M32.6568542,29 L38.3106978,23.3461564 C39.8771021,21.7797521 39.8758057,19.2483887 38.3137085,17.6862915 C36.7547899,16.1273729 34.2176035,16.1255422 32.6538436,17.6893022 L27,23.3431458 L21.3461564,17.6893022 C19.7823965,16.1255422 17.2452101,16.1273729 15.6862915,17.6862915 C14.1241943,19.2483887 14.1228979,21.7797521 15.6893022,23.3461564 L21.3431458,29 L15.6893022,34.6538436 C14.1228979,36.2202479 14.1241943,38.7516113 15.6862915,40.3137085 C17.2452101,41.8726271 19.7823965,41.8744578 21.3461564,40.3106978 L27,34.6568542 L32.6538436,40.3106978 C34.2176035,41.8744578 36.7547899,41.8726271 38.3137085,40.3137085 C39.8758057,38.7516113 39.8771021,36.2202479 38.3106978,34.6538436 L32.6568542,29 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z"></path> </g> </g> </svg> </div> </div> ',drop:function(e){return this.element.classList.remove("dz-drag-hover")},dragstart:function(e){},dragend:function(e){return this.element.classList.remove("dz-drag-hover")},dragenter:function(e){return this.element.classList.add("dz-drag-hover")},dragover:function(e){return this.element.classList.add("dz-drag-hover")},dragleave:function(e){return this.element.classList.remove("dz-drag-hover")},paste:function(e){},reset:function(){return this.element.classList.remove("dz-started")},addedfile:function(e){var t=this;if(this.element===this.previewsContainer&&this.element.classList.add("dz-started"),this.previewsContainer&&!this.options.disablePreviews){e.previewElement=x.createElement(this.options.previewTemplate.trim()),e.previewTemplate=e.previewElement,this.previewsContainer.appendChild(e.previewElement);var i,n=s(e.previewElement.querySelectorAll("[data-dz-name]"),!0);try{for(n.s();!(i=n.n()).done;){var r=i.value;r.textContent=e.name}}catch(e){n.e(e)}finally{n.f()}var a,o=s(e.previewElement.querySelectorAll("[data-dz-size]"),!0);try{for(o.s();!(a=o.n()).done;)(r=a.value).innerHTML=this.filesize(e.size)}catch(e){o.e(e)}finally{o.f()}this.options.addRemoveLinks&&(e._removeLink=x.createElement('<a class="dz-remove" href="javascript:undefined;" data-dz-remove>'.concat(this.options.dictRemoveFile,"</a>")),e.previewElement.appendChild(e._removeLink));var l,c=function(i){return i.preventDefault(),i.stopPropagation(),e.status===x.UPLOADING?x.confirm(t.options.dictCancelUploadConfirmation,(function(){return t.removeFile(e)})):t.options.dictRemoveFileConfirmation?x.confirm(t.options.dictRemoveFileConfirmation,(function(){return t.removeFile(e)})):t.removeFile(e)},u=s(e.previewElement.querySelectorAll("[data-dz-remove]"),!0);try{for(u.s();!(l=u.n()).done;){l.value.addEventListener("click",c)}}catch(e){u.e(e)}finally{u.f()}}},removedfile:function(e){return null!=e.previewElement&&null!=e.previewElement.parentNode&&e.previewElement.parentNode.removeChild(e.previewElement),this._updateMaxFilesReachedClass()},thumbnail:function(e,t){if(e.previewElement){e.previewElement.classList.remove("dz-file-preview");var i,n=s(e.previewElement.querySelectorAll("[data-dz-thumbnail]"),!0);try{for(n.s();!(i=n.n()).done;){var r=i.value;r.alt=e.name,r.src=t}}catch(e){n.e(e)}finally{n.f()}return setTimeout((function(){return e.previewElement.classList.add("dz-image-preview")}),1)}},error:function(e,t){if(e.previewElement){e.previewElement.classList.add("dz-error"),"string"!=typeof t&&t.error&&(t=t.error);var i,n=s(e.previewElement.querySelectorAll("[data-dz-errormessage]"),!0);try{for(n.s();!(i=n.n()).done;){i.value.textContent=t}}catch(e){n.e(e)}finally{n.f()}}},errormultiple:function(){},processing:function(e){if(e.previewElement&&(e.previewElement.classList.add("dz-processing"),e._removeLink))return e._removeLink.innerHTML=this.options.dictCancelUpload},processingmultiple:function(){},uploadprogress:function(e,t,i){if(e.previewElement){var n,r=s(e.previewElement.querySelectorAll("[data-dz-uploadprogress]"),!0);try{for(r.s();!(n=r.n()).done;){var a=n.value;"PROGRESS"===a.nodeName?a.value=t:a.style.width="".concat(t,"%")}}catch(e){r.e(e)}finally{r.f()}}},totaluploadprogress:function(){},sending:function(){},sendingmultiple:function(){},success:function(e){if(e.previewElement)return e.previewElement.classList.add("dz-success")},successmultiple:function(){},canceled:function(e){return this.emit("error",e,this.options.dictUploadCanceled)},canceledmultiple:function(){},complete:function(e){if(e._removeLink&&(e._removeLink.innerHTML=this.options.dictRemoveFile),e.previewElement)return e.previewElement.classList.add("dz-complete")},completemultiple:function(){},maxfilesexceeded:function(){},maxfilesreached:function(){},queuecomplete:function(){},addedfiles:function(){}};function c(e){return c="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},c(e)}function u(e,t){var i;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(i=function(e,t){if(!e)return;if("string"==typeof e)return d(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);"Object"===i&&e.constructor&&(i=e.constructor.name);if("Map"===i||"Set"===i)return Array.from(e);if("Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i))return d(e,t)}(e))||t&&e&&"number"==typeof e.length){i&&(e=i);var n=0,r=function(){};return{s:r,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var a,s=!0,o=!1;return{s:function(){i=e[Symbol.iterator]()},n:function(){var e=i.next();return s=e.done,e},e:function(e){o=!0,a=e},f:function(){try{s||null==i.return||i.return()}finally{if(o)throw a}}}}function d(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function h(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function f(e,t){for(var i=0;i<t.length;i++){var n=t[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}function p(e,t,i){return t&&f(e.prototype,t),i&&f(e,i),e}function m(e,t){return m=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e},m(e,t)}function g(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],(function(){}))),!0}catch(e){return!1}}();return function(){var i,n=b(e);if(t){var r=b(this).constructor;i=Reflect.construct(n,arguments,r)}else i=n.apply(this,arguments);return v(this,i)}}function v(e,t){return!t||"object"!==c(t)&&"function"!=typeof t?y(e):t}function y(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function b(e){return b=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)},b(e)}var x=function(e){!function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&m(e,t)}(i,e);var t=g(i);function i(e,n){var r,a,s;if(h(this,i),(r=t.call(this)).element=e,r.version=i.version,r.clickableElements=[],r.listeners=[],r.files=[],"string"==typeof r.element&&(r.element=document.querySelector(r.element)),!r.element||null==r.element.nodeType)throw new Error("Invalid dropzone element.");if(r.element.dropzone)throw new Error("Dropzone already attached.");i.instances.push(y(r)),r.element.dropzone=y(r);var o=null!=(s=i.optionsForElement(r.element))?s:{};if(r.options=i.extend({},l,o,null!=n?n:{}),r.options.previewTemplate=r.options.previewTemplate.replace(/\n*/g,""),r.options.forceFallback||!i.isBrowserSupported())return v(r,r.options.fallback.call(y(r)));if(null==r.options.url&&(r.options.url=r.element.getAttribute("action")),!r.options.url)throw new Error("No URL provided.");if(r.options.acceptedFiles&&r.options.acceptedMimeTypes)throw new Error("You can't provide both 'acceptedFiles' and 'acceptedMimeTypes'. 'acceptedMimeTypes' is deprecated.");if(r.options.uploadMultiple&&r.options.chunking)throw new Error("You cannot set both: uploadMultiple and chunking.");return r.options.acceptedMimeTypes&&(r.options.acceptedFiles=r.options.acceptedMimeTypes,delete r.options.acceptedMimeTypes),null!=r.options.renameFilename&&(r.options.renameFile=function(e){return r.options.renameFilename.call(y(r),e.name,e)}),"string"==typeof r.options.method&&(r.options.method=r.options.method.toUpperCase()),(a=r.getExistingFallback())&&a.parentNode&&a.parentNode.removeChild(a),!1!==r.options.previewsContainer&&(r.options.previewsContainer?r.previewsContainer=i.getElement(r.options.previewsContainer,"previewsContainer"):r.previewsContainer=r.element),r.options.clickable&&(!0===r.options.clickable?r.clickableElements=[r.element]:r.clickableElements=i.getElements(r.options.clickable,"clickable")),r.init(),r}return p(i,[{key:"getAcceptedFiles",value:function(){return this.files.filter((function(e){return e.accepted})).map((function(e){return e}))}},{key:"getRejectedFiles",value:function(){return this.files.filter((function(e){return!e.accepted})).map((function(e){return e}))}},{key:"getFilesWithStatus",value:function(e){return this.files.filter((function(t){return t.status===e})).map((function(e){return e}))}},{key:"getQueuedFiles",value:function(){return this.getFilesWithStatus(i.QUEUED)}},{key:"getUploadingFiles",value:function(){return this.getFilesWithStatus(i.UPLOADING)}},{key:"getAddedFiles",value:function(){return this.getFilesWithStatus(i.ADDED)}},{key:"getActiveFiles",value:function(){return this.files.filter((function(e){return e.status===i.UPLOADING||e.status===i.QUEUED})).map((function(e){return e}))}},{key:"init",value:function(){var e=this;if("form"===this.element.tagName&&this.element.setAttribute("enctype","multipart/form-data"),this.element.classList.contains("dropzone")&&!this.element.querySelector(".dz-message")&&this.element.appendChild(i.createElement('<div class="dz-default dz-message"><button class="dz-button" type="button">'.concat(this.options.dictDefaultMessage,"</button></div>"))),this.clickableElements.length){!function t(){e.hiddenFileInput&&e.hiddenFileInput.parentNode.removeChild(e.hiddenFileInput),e.hiddenFileInput=document.createElement("input"),e.hiddenFileInput.setAttribute("type","file"),(null===e.options.maxFiles||e.options.maxFiles>1)&&e.hiddenFileInput.setAttribute("multiple","multiple"),e.hiddenFileInput.className="dz-hidden-input",null!==e.options.acceptedFiles&&e.hiddenFileInput.setAttribute("accept",e.options.acceptedFiles),null!==e.options.capture&&e.hiddenFileInput.setAttribute("capture",e.options.capture),e.hiddenFileInput.setAttribute("tabindex","-1"),e.hiddenFileInput.style.visibility="hidden",e.hiddenFileInput.style.position="absolute",e.hiddenFileInput.style.top="0",e.hiddenFileInput.style.left="0",e.hiddenFileInput.style.height="0",e.hiddenFileInput.style.width="0",i.getElement(e.options.hiddenInputContainer,"hiddenInputContainer").appendChild(e.hiddenFileInput),e.hiddenFileInput.addEventListener("change",(function(){var i=e.hiddenFileInput.files;if(i.length){var n,r=u(i,!0);try{for(r.s();!(n=r.n()).done;){var a=n.value;e.addFile(a)}}catch(e){r.e(e)}finally{r.f()}}e.emit("addedfiles",i),t()}))}()}this.URL=null!==window.URL?window.URL:window.webkitURL;var t,n=u(this.events,!0);try{for(n.s();!(t=n.n()).done;){var r=t.value;this.on(r,this.options[r])}}catch(e){n.e(e)}finally{n.f()}this.on("uploadprogress",(function(){return e.updateTotalUploadProgress()})),this.on("removedfile",(function(){return e.updateTotalUploadProgress()})),this.on("canceled",(function(t){return e.emit("complete",t)})),this.on("complete",(function(t){if(0===e.getAddedFiles().length&&0===e.getUploadingFiles().length&&0===e.getQueuedFiles().length)return setTimeout((function(){return e.emit("queuecomplete")}),0)}));var a=function(e){if(function(e){if(e.dataTransfer.types)for(var t=0;t<e.dataTransfer.types.length;t++)if("Files"===e.dataTransfer.types[t])return!0;return!1}(e))return e.stopPropagation(),e.preventDefault?e.preventDefault():e.returnValue=!1};return this.listeners=[{element:this.element,events:{dragstart:function(t){return e.emit("dragstart",t)},dragenter:function(t){return a(t),e.emit("dragenter",t)},dragover:function(t){var i;try{i=t.dataTransfer.effectAllowed}catch(e){}return t.dataTransfer.dropEffect="move"===i||"linkMove"===i?"move":"copy",a(t),e.emit("dragover",t)},dragleave:function(t){return e.emit("dragleave",t)},drop:function(t){return a(t),e.drop(t)},dragend:function(t){return e.emit("dragend",t)}}}],this.clickableElements.forEach((function(t){return e.listeners.push({element:t,events:{click:function(n){return(t!==e.element||n.target===e.element||i.elementInside(n.target,e.element.querySelector(".dz-message")))&&e.hiddenFileInput.click(),!0}}})})),this.enable(),this.options.init.call(this)}},{key:"destroy",value:function(){return this.disable(),this.removeAllFiles(!0),(null!=this.hiddenFileInput?this.hiddenFileInput.parentNode:void 0)&&(this.hiddenFileInput.parentNode.removeChild(this.hiddenFileInput),this.hiddenFileInput=null),delete this.element.dropzone,i.instances.splice(i.instances.indexOf(this),1)}},{key:"updateTotalUploadProgress",value:function(){var e,t=0,i=0;if(this.getActiveFiles().length){var n,r=u(this.getActiveFiles(),!0);try{for(r.s();!(n=r.n()).done;){var a=n.value;t+=a.upload.bytesSent,i+=a.upload.total}}catch(e){r.e(e)}finally{r.f()}e=100*t/i}else e=100;return this.emit("totaluploadprogress",e,i,t)}},{key:"_getParamName",value:function(e){return"function"==typeof this.options.paramName?this.options.paramName(e):"".concat(this.options.paramName).concat(this.options.uploadMultiple?"[".concat(e,"]"):"")}},{key:"_renameFile",value:function(e){return"function"!=typeof this.options.renameFile?e.name:this.options.renameFile(e)}},{key:"getFallbackForm",value:function(){var e,t;if(e=this.getExistingFallback())return e;var n='<div class="dz-fallback">';this.options.dictFallbackText&&(n+="<p>".concat(this.options.dictFallbackText,"</p>")),n+='<input type="file" name="'.concat(this._getParamName(0),'" ').concat(this.options.uploadMultiple?'multiple="multiple"':void 0,' /><input type="submit" value="Upload!"></div>');var r=i.createElement(n);return"FORM"!==this.element.tagName?(t=i.createElement('<form action="'.concat(this.options.url,'" enctype="multipart/form-data" method="').concat(this.options.method,'"></form>'))).appendChild(r):(this.element.setAttribute("enctype","multipart/form-data"),this.element.setAttribute("method",this.options.method)),null!=t?t:r}},{key:"getExistingFallback",value:function(){for(var e=function(e){var t,i=u(e,!0);try{for(i.s();!(t=i.n()).done;){var n=t.value;if(/(^| )fallback($| )/.test(n.className))return n}}catch(e){i.e(e)}finally{i.f()}},t=0,i=["div","form"];t<i.length;t++){var n,r=i[t];if(n=e(this.element.getElementsByTagName(r)))return n}}},{key:"setupEventListeners",value:function(){return this.listeners.map((function(e){return function(){var t=[];for(var i in e.events){var n=e.events[i];t.push(e.element.addEventListener(i,n,!1))}return t}()}))}},{key:"removeEventListeners",value:function(){return this.listeners.map((function(e){return function(){var t=[];for(var i in e.events){var n=e.events[i];t.push(e.element.removeEventListener(i,n,!1))}return t}()}))}},{key:"disable",value:function(){var e=this;return this.clickableElements.forEach((function(e){return e.classList.remove("dz-clickable")})),this.removeEventListeners(),this.disabled=!0,this.files.map((function(t){return e.cancelUpload(t)}))}},{key:"enable",value:function(){return delete this.disabled,this.clickableElements.forEach((function(e){return e.classList.add("dz-clickable")})),this.setupEventListeners()}},{key:"filesize",value:function(e){var t=0,i="b";if(e>0){for(var n=["tb","gb","mb","kb","b"],r=0;r<n.length;r++){var a=n[r];if(e>=Math.pow(this.options.filesizeBase,4-r)/10){t=e/Math.pow(this.options.filesizeBase,4-r),i=a;break}}t=Math.round(10*t)/10}return"<strong>".concat(t,"</strong> ").concat(this.options.dictFileSizeUnits[i])}},{key:"_updateMaxFilesReachedClass",value:function(){return null!=this.options.maxFiles&&this.getAcceptedFiles().length>=this.options.maxFiles?(this.getAcceptedFiles().length===this.options.maxFiles&&this.emit("maxfilesreached",this.files),this.element.classList.add("dz-max-files-reached")):this.element.classList.remove("dz-max-files-reached")}},{key:"drop",value:function(e){if(e.dataTransfer){this.emit("drop",e);for(var t=[],i=0;i<e.dataTransfer.files.length;i++)t[i]=e.dataTransfer.files[i];if(t.length){var n=e.dataTransfer.items;n&&n.length&&null!=n[0].webkitGetAsEntry?this._addFilesFromItems(n):this.handleFiles(t)}this.emit("addedfiles",t)}}},{key:"paste",value:function(e){if(null!=(t=null!=e?e.clipboardData:void 0,i=function(e){return e.items},null!=t?i(t):void 0)){var t,i;this.emit("paste",e);var n=e.clipboardData.items;return n.length?this._addFilesFromItems(n):void 0}}},{key:"handleFiles",value:function(e){var t,i=u(e,!0);try{for(i.s();!(t=i.n()).done;){var n=t.value;this.addFile(n)}}catch(e){i.e(e)}finally{i.f()}}},{key:"_addFilesFromItems",value:function(e){var t=this;return function(){var i,n=[],r=u(e,!0);try{for(r.s();!(i=r.n()).done;){var a,s=i.value;null!=s.webkitGetAsEntry&&(a=s.webkitGetAsEntry())?a.isFile?n.push(t.addFile(s.getAsFile())):a.isDirectory?n.push(t._addFilesFromDirectory(a,a.name)):n.push(void 0):null!=s.getAsFile&&(null==s.kind||"file"===s.kind)?n.push(t.addFile(s.getAsFile())):n.push(void 0)}}catch(e){r.e(e)}finally{r.f()}return n}()}},{key:"_addFilesFromDirectory",value:function(e,t){var i=this,n=e.createReader(),r=function(e){return t=console,i="log",n=function(t){return t.log(e)},null!=t&&"function"==typeof t[i]?n(t,i):void 0;var t,i,n};return function e(){return n.readEntries((function(n){if(n.length>0){var r,a=u(n,!0);try{for(a.s();!(r=a.n()).done;){var s=r.value;s.isFile?s.file((function(e){if(!i.options.ignoreHiddenFiles||"."!==e.name.substring(0,1))return e.fullPath="".concat(t,"/").concat(e.name),i.addFile(e)})):s.isDirectory&&i._addFilesFromDirectory(s,"".concat(t,"/").concat(s.name))}}catch(e){a.e(e)}finally{a.f()}e()}return null}),r)}()}},{key:"accept",value:function(e,t){this.options.maxFilesize&&e.size>1024*this.options.maxFilesize*1024?t(this.options.dictFileTooBig.replace("{{filesize}}",Math.round(e.size/1024/10.24)/100).replace("{{maxFilesize}}",this.options.maxFilesize)):i.isValidFile(e,this.options.acceptedFiles)?null!=this.options.maxFiles&&this.getAcceptedFiles().length>=this.options.maxFiles?(t(this.options.dictMaxFilesExceeded.replace("{{maxFiles}}",this.options.maxFiles)),this.emit("maxfilesexceeded",e)):this.options.accept.call(this,e,t):t(this.options.dictInvalidFileType)}},{key:"addFile",value:function(e){var t=this;e.upload={uuid:i.uuidv4(),progress:0,total:e.size,bytesSent:0,filename:this._renameFile(e)},this.files.push(e),e.status=i.ADDED,this.emit("addedfile",e),this._enqueueThumbnail(e),this.accept(e,(function(i){i?(e.accepted=!1,t._errorProcessing([e],i)):(e.accepted=!0,t.options.autoQueue&&t.enqueueFile(e)),t._updateMaxFilesReachedClass()}))}},{key:"enqueueFiles",value:function(e){var t,i=u(e,!0);try{for(i.s();!(t=i.n()).done;){var n=t.value;this.enqueueFile(n)}}catch(e){i.e(e)}finally{i.f()}return null}},{key:"enqueueFile",value:function(e){var t=this;if(e.status!==i.ADDED||!0!==e.accepted)throw new Error("This file can't be queued because it has already been processed or was rejected.");if(e.status=i.QUEUED,this.options.autoProcessQueue)return setTimeout((function(){return t.processQueue()}),0)}},{key:"_enqueueThumbnail",value:function(e){var t=this;if(this.options.createImageThumbnails&&e.type.match(/image.*/)&&e.size<=1024*this.options.maxThumbnailFilesize*1024)return this._thumbnailQueue.push(e),setTimeout((function(){return t._processThumbnailQueue()}),0)}},{key:"_processThumbnailQueue",value:function(){var e=this;if(!this._processingThumbnail&&0!==this._thumbnailQueue.length){this._processingThumbnail=!0;var t=this._thumbnailQueue.shift();return this.createThumbnail(t,this.options.thumbnailWidth,this.options.thumbnailHeight,this.options.thumbnailMethod,!0,(function(i){return e.emit("thumbnail",t,i),e._processingThumbnail=!1,e._processThumbnailQueue()}))}}},{key:"removeFile",value:function(e){if(e.status===i.UPLOADING&&this.cancelUpload(e),this.files=_(this.files,e),this.emit("removedfile",e),0===this.files.length)return this.emit("reset")}},{key:"removeAllFiles",value:function(e){null==e&&(e=!1);var t,n=u(this.files.slice(),!0);try{for(n.s();!(t=n.n()).done;){var r=t.value;(r.status!==i.UPLOADING||e)&&this.removeFile(r)}}catch(e){n.e(e)}finally{n.f()}return null}},{key:"resizeImage",value:function(e,t,n,r,a){var s=this;return this.createThumbnail(e,t,n,r,!0,(function(t,n){if(null==n)return a(e);var r=s.options.resizeMimeType;null==r&&(r=e.type);var o=n.toDataURL(r,s.options.resizeQuality);return"image/jpeg"!==r&&"image/jpg"!==r||(o=M.restore(e.dataURL,o)),a(i.dataURItoBlob(o))}))}},{key:"createThumbnail",value:function(e,t,i,n,r,a){var s=this,o=new FileReader;o.onload=function(){e.dataURL=o.result,"image/svg+xml"!==e.type?s.createThumbnailFromUrl(e,t,i,n,r,a):null!=a&&a(o.result)},o.readAsDataURL(e)}},{key:"displayExistingFile",value:function(e,t,i,n){var r=this,a=!(arguments.length>4&&void 0!==arguments[4])||arguments[4];if(this.emit("addedfile",e),this.emit("complete",e),a){e.dataURL=t,this.createThumbnailFromUrl(e,this.options.thumbnailWidth,this.options.thumbnailHeight,this.options.thumbnailMethod,this.options.fixOrientation,(function(t){r.emit("thumbnail",e,t),i&&i()}),n)}else this.emit("thumbnail",e,t),i&&i()}},{key:"createThumbnailFromUrl",value:function(e,t,i,n,r,a,s){var o=this,l=document.createElement("img");return s&&(l.crossOrigin=s),r="from-image"!=getComputedStyle(document.body).imageOrientation&&r,l.onload=function(){var s=function(e){return e(1)};return"undefined"!=typeof EXIF&&null!==EXIF&&r&&(s=function(e){return EXIF.getData(l,(function(){return e(EXIF.getTag(this,"Orientation"))}))}),s((function(r){e.width=l.width,e.height=l.height;var s=o.options.resize.call(o,e,t,i,n),c=document.createElement("canvas"),u=c.getContext("2d");switch(c.width=s.trgWidth,c.height=s.trgHeight,r>4&&(c.width=s.trgHeight,c.height=s.trgWidth),r){case 2:u.translate(c.width,0),u.scale(-1,1);break;case 3:u.translate(c.width,c.height),u.rotate(Math.PI);break;case 4:u.translate(0,c.height),u.scale(1,-1);break;case 5:u.rotate(.5*Math.PI),u.scale(1,-1);break;case 6:u.rotate(.5*Math.PI),u.translate(0,-c.width);break;case 7:u.rotate(.5*Math.PI),u.translate(c.height,-c.width),u.scale(-1,1);break;case 8:u.rotate(-.5*Math.PI),u.translate(-c.height,0)}k(u,l,null!=s.srcX?s.srcX:0,null!=s.srcY?s.srcY:0,s.srcWidth,s.srcHeight,null!=s.trgX?s.trgX:0,null!=s.trgY?s.trgY:0,s.trgWidth,s.trgHeight);var d=c.toDataURL("image/png");if(null!=a)return a(d,c)}))},null!=a&&(l.onerror=a),l.src=e.dataURL}},{key:"processQueue",value:function(){var e=this.options.parallelUploads,t=this.getUploadingFiles().length,i=t;if(!(t>=e)){var n=this.getQueuedFiles();if(n.length>0){if(this.options.uploadMultiple)return this.processFiles(n.slice(0,e-t));for(;i<e;){if(!n.length)return;this.processFile(n.shift()),i++}}}}},{key:"processFile",value:function(e){return this.processFiles([e])}},{key:"processFiles",value:function(e){var t,n=u(e,!0);try{for(n.s();!(t=n.n()).done;){var r=t.value;r.processing=!0,r.status=i.UPLOADING,this.emit("processing",r)}}catch(e){n.e(e)}finally{n.f()}return this.options.uploadMultiple&&this.emit("processingmultiple",e),this.uploadFiles(e)}},{key:"_getFilesWithXhr",value:function(e){return this.files.filter((function(t){return t.xhr===e})).map((function(e){return e}))}},{key:"cancelUpload",value:function(e){if(e.status===i.UPLOADING){var t,n=this._getFilesWithXhr(e.xhr),r=u(n,!0);try{for(r.s();!(t=r.n()).done;){t.value.status=i.CANCELED}}catch(e){r.e(e)}finally{r.f()}void 0!==e.xhr&&e.xhr.abort();var a,s=u(n,!0);try{for(s.s();!(a=s.n()).done;){var o=a.value;this.emit("canceled",o)}}catch(e){s.e(e)}finally{s.f()}this.options.uploadMultiple&&this.emit("canceledmultiple",n)}else e.status!==i.ADDED&&e.status!==i.QUEUED||(e.status=i.CANCELED,this.emit("canceled",e),this.options.uploadMultiple&&this.emit("canceledmultiple",[e]));if(this.options.autoProcessQueue)return this.processQueue()}},{key:"resolveOption",value:function(e){if("function"==typeof e){for(var t=arguments.length,i=new Array(t>1?t-1:0),n=1;n<t;n++)i[n-1]=arguments[n];return e.apply(this,i)}return e}},{key:"uploadFile",value:function(e){return this.uploadFiles([e])}},{key:"uploadFiles",value:function(e){var t=this;this._transformFiles(e,(function(n){if(t.options.chunking){var r=n[0];e[0].upload.chunked=t.options.chunking&&(t.options.forceChunking||r.size>t.options.chunkSize),e[0].upload.totalChunkCount=Math.ceil(r.size/t.options.chunkSize)}if(e[0].upload.chunked){var a=e[0],s=n[0];a.upload.chunks=[];var o=function(){for(var n=0;void 0!==a.upload.chunks[n];)n++;if(!(n>=a.upload.totalChunkCount)){0;var r=n*t.options.chunkSize,o=Math.min(r+t.options.chunkSize,s.size),l={name:t._getParamName(0),data:s.webkitSlice?s.webkitSlice(r,o):s.slice(r,o),filename:a.upload.filename,chunkIndex:n};a.upload.chunks[n]={file:a,index:n,dataBlock:l,status:i.UPLOADING,progress:0,retries:0},t._uploadData(e,[l])}};if(a.upload.finishedChunkUpload=function(n,r){var s=!0;n.status=i.SUCCESS,n.dataBlock=null,n.xhr=null;for(var l=0;l<a.upload.totalChunkCount;l++){if(void 0===a.upload.chunks[l])return o();a.upload.chunks[l].status!==i.SUCCESS&&(s=!1)}s&&t.options.chunksUploaded(a,(function(){t._finished(e,r,null)}))},t.options.parallelChunkUploads)for(var l=0;l<a.upload.totalChunkCount;l++)o();else o()}else{for(var c=[],u=0;u<e.length;u++)c[u]={name:t._getParamName(u),data:n[u],filename:e[u].upload.filename};t._uploadData(e,c)}}))}},{key:"_getChunk",value:function(e,t){for(var i=0;i<e.upload.totalChunkCount;i++)if(void 0!==e.upload.chunks[i]&&e.upload.chunks[i].xhr===t)return e.upload.chunks[i]}},{key:"_uploadData",value:function(e,t){var n,r=this,a=new XMLHttpRequest,s=u(e,!0);try{for(s.s();!(n=s.n()).done;){n.value.xhr=a}}catch(e){s.e(e)}finally{s.f()}e[0].upload.chunked&&(e[0].upload.chunks[t[0].chunkIndex].xhr=a);var o=this.resolveOption(this.options.method,e),l=this.resolveOption(this.options.url,e);a.open(o,l,!0),this.resolveOption(this.options.timeout,e)&&(a.timeout=this.resolveOption(this.options.timeout,e)),a.withCredentials=!!this.options.withCredentials,a.onload=function(t){r._finishedUploading(e,a,t)},a.ontimeout=function(){r._handleUploadError(e,a,"Request timedout after ".concat(r.options.timeout/1e3," seconds"))},a.onerror=function(){r._handleUploadError(e,a)},(null!=a.upload?a.upload:a).onprogress=function(t){return r._updateFilesUploadProgress(e,a,t)};var c={Accept:"application/json","Cache-Control":"no-cache","X-Requested-With":"XMLHttpRequest"};for(var d in this.options.headers&&i.extend(c,this.options.headers),c){var h=c[d];h&&a.setRequestHeader(d,h)}var f=new FormData;if(this.options.params){var p=this.options.params;for(var m in"function"==typeof p&&(p=p.call(this,e,a,e[0].upload.chunked?this._getChunk(e[0],a):null)),p){var g=p[m];if(Array.isArray(g))for(var v=0;v<g.length;v++)f.append(m,g[v]);else f.append(m,g)}}var y,b=u(e,!0);try{for(b.s();!(y=b.n()).done;){var x=y.value;this.emit("sending",x,a,f)}}catch(e){b.e(e)}finally{b.f()}this.options.uploadMultiple&&this.emit("sendingmultiple",e,a,f),this._addFormElementData(f);for(var _=0;_<t.length;_++){var w=t[_];f.append(w.name,w.data,w.filename)}this.submitRequest(a,f,e)}},{key:"_transformFiles",value:function(e,t){for(var i=this,n=[],r=0,a=function(a){i.options.transformFile.call(i,e[a],(function(i){n[a]=i,++r===e.length&&t(n)}))},s=0;s<e.length;s++)a(s)}},{key:"_addFormElementData",value:function(e){if("FORM"===this.element.tagName){var t,i=u(this.element.querySelectorAll("input, textarea, select, button"),!0);try{for(i.s();!(t=i.n()).done;){var n=t.value,r=n.getAttribute("name"),a=n.getAttribute("type");if(a&&(a=a.toLowerCase()),null!=r)if("SELECT"===n.tagName&&n.hasAttribute("multiple")){var s,o=u(n.options,!0);try{for(o.s();!(s=o.n()).done;){var l=s.value;l.selected&&e.append(r,l.value)}}catch(e){o.e(e)}finally{o.f()}}else(!a||"checkbox"!==a&&"radio"!==a||n.checked)&&e.append(r,n.value)}}catch(e){i.e(e)}finally{i.f()}}}},{key:"_updateFilesUploadProgress",value:function(e,t,i){if(e[0].upload.chunked){var n=e[0],r=this._getChunk(n,t);i?(r.progress=100*i.loaded/i.total,r.total=i.total,r.bytesSent=i.loaded):(r.progress=100,r.bytesSent=r.total),n.upload.progress=0,n.upload.total=0,n.upload.bytesSent=0;for(var a=0;a<n.upload.totalChunkCount;a++)n.upload.chunks[a]&&void 0!==n.upload.chunks[a].progress&&(n.upload.progress+=n.upload.chunks[a].progress,n.upload.total+=n.upload.chunks[a].total,n.upload.bytesSent+=n.upload.chunks[a].bytesSent);n.upload.progress=n.upload.progress/n.upload.totalChunkCount,this.emit("uploadprogress",n,n.upload.progress,n.upload.bytesSent)}else{var s,o=u(e,!0);try{for(o.s();!(s=o.n()).done;){var l=s.value;l.upload.total&&l.upload.bytesSent&&l.upload.bytesSent==l.upload.total||(i?(l.upload.progress=100*i.loaded/i.total,l.upload.total=i.total,l.upload.bytesSent=i.loaded):(l.upload.progress=100,l.upload.bytesSent=l.upload.total),this.emit("uploadprogress",l,l.upload.progress,l.upload.bytesSent))}}catch(e){o.e(e)}finally{o.f()}}}},{key:"_finishedUploading",value:function(e,t,n){var r;if(e[0].status!==i.CANCELED&&4===t.readyState){if("arraybuffer"!==t.responseType&&"blob"!==t.responseType&&(r=t.responseText,t.getResponseHeader("content-type")&&~t.getResponseHeader("content-type").indexOf("application/json")))try{r=JSON.parse(r)}catch(e){n=e,r="Invalid JSON response from server."}this._updateFilesUploadProgress(e,t),200<=t.status&&t.status<300?e[0].upload.chunked?e[0].upload.finishedChunkUpload(this._getChunk(e[0],t),r):this._finished(e,r,n):this._handleUploadError(e,t,r)}}},{key:"_handleUploadError",value:function(e,t,n){if(e[0].status!==i.CANCELED){if(e[0].upload.chunked&&this.options.retryChunks){var r=this._getChunk(e[0],t);if(r.retries++<this.options.retryChunksLimit)return void this._uploadData(e,[r.dataBlock]);console.warn("Retried this chunk too often. Giving up.")}this._errorProcessing(e,n||this.options.dictResponseError.replace("{{statusCode}}",t.status),t)}}},{key:"submitRequest",value:function(e,t,i){1==e.readyState?e.send(t):console.warn("Cannot send this request because the XMLHttpRequest.readyState is not OPENED.")}},{key:"_finished",value:function(e,t,n){var r,a=u(e,!0);try{for(a.s();!(r=a.n()).done;){var s=r.value;s.status=i.SUCCESS,this.emit("success",s,t,n),this.emit("complete",s)}}catch(e){a.e(e)}finally{a.f()}if(this.options.uploadMultiple&&(this.emit("successmultiple",e,t,n),this.emit("completemultiple",e)),this.options.autoProcessQueue)return this.processQueue()}},{key:"_errorProcessing",value:function(e,t,n){var r,a=u(e,!0);try{for(a.s();!(r=a.n()).done;){var s=r.value;s.status=i.ERROR,this.emit("error",s,t,n),this.emit("complete",s)}}catch(e){a.e(e)}finally{a.f()}if(this.options.uploadMultiple&&(this.emit("errormultiple",e,t,n),this.emit("completemultiple",e)),this.options.autoProcessQueue)return this.processQueue()}}],[{key:"initClass",value:function(){this.prototype.Emitter=a,this.prototype.events=["drop","dragstart","dragend","dragenter","dragover","dragleave","addedfile","addedfiles","removedfile","thumbnail","error","errormultiple","processing","processingmultiple","uploadprogress","totaluploadprogress","sending","sendingmultiple","success","successmultiple","canceled","canceledmultiple","complete","completemultiple","reset","maxfilesexceeded","maxfilesreached","queuecomplete"],this.prototype._thumbnailQueue=[],this.prototype._processingThumbnail=!1}},{key:"extend",value:function(e){for(var t=arguments.length,i=new Array(t>1?t-1:0),n=1;n<t;n++)i[n-1]=arguments[n];for(var r=0,a=i;r<a.length;r++){var s=a[r];for(var o in s){var l=s[o];e[o]=l}}return e}},{key:"uuidv4",value:function(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,(function(e){var t=16*Math.random()|0;return("x"===e?t:3&t|8).toString(16)}))}}]),i}(a);x.initClass(),x.version="5.9.3",x.options={},x.optionsForElement=function(e){return e.getAttribute("id")?x.options[w(e.getAttribute("id"))]:void 0},x.instances=[],x.forElement=function(e){if("string"==typeof e&&(e=document.querySelector(e)),null==(null!=e?e.dropzone:void 0))throw new Error("No Dropzone found for given element. This is probably because you're trying to access it before Dropzone had the time to initialize. Use the `init` option to setup any additional observers on your Dropzone.");return e.dropzone},x.autoDiscover=!0,x.discover=function(){var e;if(document.querySelectorAll)e=document.querySelectorAll(".dropzone");else{e=[];var t=function(t){return function(){var i,n=[],r=u(t,!0);try{for(r.s();!(i=r.n()).done;){var a=i.value;/(^| )dropzone($| )/.test(a.className)?n.push(e.push(a)):n.push(void 0)}}catch(e){r.e(e)}finally{r.f()}return n}()};t(document.getElementsByTagName("div")),t(document.getElementsByTagName("form"))}return function(){var t,i=[],n=u(e,!0);try{for(n.s();!(t=n.n()).done;){var r=t.value;!1!==x.optionsForElement(r)?i.push(new x(r)):i.push(void 0)}}catch(e){n.e(e)}finally{n.f()}return i}()},x.blockedBrowsers=[/opera.*(Macintosh|Windows Phone).*version\/12/i],x.isBrowserSupported=function(){var e=!0;if(window.File&&window.FileReader&&window.FileList&&window.Blob&&window.FormData&&document.querySelector)if("classList"in document.createElement("a")){void 0!==x.blacklistedBrowsers&&(x.blockedBrowsers=x.blacklistedBrowsers);var t,i=u(x.blockedBrowsers,!0);try{for(i.s();!(t=i.n()).done;){t.value.test(navigator.userAgent)&&(e=!1)}}catch(e){i.e(e)}finally{i.f()}}else e=!1;else e=!1;return e},x.dataURItoBlob=function(e){for(var t=atob(e.split(",")[1]),i=e.split(",")[0].split(":")[1].split(";")[0],n=new ArrayBuffer(t.length),r=new Uint8Array(n),a=0,s=t.length,o=0<=s;o?a<=s:a>=s;o?a++:a--)r[a]=t.charCodeAt(a);return new Blob([n],{type:i})};var _=function(e,t){return e.filter((function(e){return e!==t})).map((function(e){return e}))},w=function(e){return e.replace(/[\-_](\w)/g,(function(e){return e.charAt(1).toUpperCase()}))};x.createElement=function(e){var t=document.createElement("div");return t.innerHTML=e,t.childNodes[0]},x.elementInside=function(e,t){if(e===t)return!0;for(;e=e.parentNode;)if(e===t)return!0;return!1},x.getElement=function(e,t){var i;if("string"==typeof e?i=document.querySelector(e):null!=e.nodeType&&(i=e),null==i)throw new Error("Invalid `".concat(t,"` option provided. Please provide a CSS selector or a plain HTML element."));return i},x.getElements=function(e,t){var i,n;if(e instanceof Array){n=[];try{var r,a=u(e,!0);try{for(a.s();!(r=a.n()).done;)i=r.value,n.push(this.getElement(i,t))}catch(e){a.e(e)}finally{a.f()}}catch(e){n=null}}else if("string"==typeof e){n=[];var s,o=u(document.querySelectorAll(e),!0);try{for(o.s();!(s=o.n()).done;)i=s.value,n.push(i)}catch(e){o.e(e)}finally{o.f()}}else null!=e.nodeType&&(n=[e]);if(null==n||!n.length)throw new Error("Invalid `".concat(t,"` option provided. Please provide a CSS selector, a plain HTML element or a list of those."));return n},x.confirm=function(e,t,i){return window.confirm(e)?t():null!=i?i():void 0},x.isValidFile=function(e,t){if(!t)return!0;t=t.split(",");var i,n=e.type,r=n.replace(/\/.*$/,""),a=u(t,!0);try{for(a.s();!(i=a.n()).done;){var s=i.value;if("."===(s=s.trim()).charAt(0)){if(-1!==e.name.toLowerCase().indexOf(s.toLowerCase(),e.name.length-s.length))return!0}else if(/\/\*$/.test(s)){if(r===s.replace(/\/.*$/,""))return!0}else if(n===s)return!0}}catch(e){a.e(e)}finally{a.f()}return!1},"undefined"!=typeof jQuery&&null!==jQuery&&(jQuery.fn.dropzone=function(e){return this.each((function(){return new x(this,e)}))}),x.ADDED="added",x.QUEUED="queued",x.ACCEPTED=x.QUEUED,x.UPLOADING="uploading",x.PROCESSING=x.UPLOADING,x.CANCELED="canceled",x.ERROR="error",x.SUCCESS="success";var k=function(e,t,i,n,r,a,s,o,l,c){var u=function(e){e.naturalWidth;var t=e.naturalHeight,i=document.createElement("canvas");i.width=1,i.height=t;var n=i.getContext("2d");n.drawImage(e,0,0);for(var r=n.getImageData(1,0,1,t).data,a=0,s=t,o=t;o>a;)0===r[4*(o-1)+3]?s=o:a=o,o=s+a>>1;var l=o/t;return 0===l?1:l}(t);return e.drawImage(t,i,n,r,a,s,o,l,c/u)},M=function(){function e(){h(this,e)}return p(e,null,[{key:"initClass",value:function(){this.KEY_STR="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="}},{key:"encode64",value:function(e){for(var t="",i=void 0,n=void 0,r="",a=void 0,s=void 0,o=void 0,l="",c=0;a=(i=e[c++])>>2,s=(3&i)<<4|(n=e[c++])>>4,o=(15&n)<<2|(r=e[c++])>>6,l=63&r,isNaN(n)?o=l=64:isNaN(r)&&(l=64),t=t+this.KEY_STR.charAt(a)+this.KEY_STR.charAt(s)+this.KEY_STR.charAt(o)+this.KEY_STR.charAt(l),i=n=r="",a=s=o=l="",c<e.length;);return t}},{key:"restore",value:function(e,t){if(!e.match("data:image/jpeg;base64,"))return t;var i=this.decode64(e.replace("data:image/jpeg;base64,","")),n=this.slice2Segments(i),r=this.exifManipulation(t,n);return"data:image/jpeg;base64,".concat(this.encode64(r))}},{key:"exifManipulation",value:function(e,t){var i=this.getExifArray(t),n=this.insertExif(e,i);return new Uint8Array(n)}},{key:"getExifArray",value:function(e){for(var t=void 0,i=0;i<e.length;){if(255===(t=e[i])[0]&225===t[1])return t;i++}return[]}},{key:"insertExif",value:function(e,t){var i=e.replace("data:image/jpeg;base64,",""),n=this.decode64(i),r=n.indexOf(255,3),a=n.slice(0,r),s=n.slice(r),o=a;return o=(o=o.concat(t)).concat(s)}},{key:"slice2Segments",value:function(e){for(var t=0,i=[];;){if(255===e[t]&218===e[t+1])break;if(255===e[t]&216===e[t+1])t+=2;else{var n=t+(256*e[t+2]+e[t+3])+2,r=e.slice(t,n);i.push(r),t=n}if(t>e.length)break}return i}},{key:"decode64",value:function(e){var t=void 0,i=void 0,n="",r=void 0,a=void 0,s="",o=0,l=[];for(/[^A-Za-z0-9\+\/\=]/g.exec(e)&&console.warn("There were invalid base64 characters in the input text.\nValid base64 characters are A-Z, a-z, 0-9, '+', '/',and '='\nExpect errors in decoding."),e=e.replace(/[^A-Za-z0-9\+\/\=]/g,"");t=this.KEY_STR.indexOf(e.charAt(o++))<<2|(r=this.KEY_STR.indexOf(e.charAt(o++)))>>4,i=(15&r)<<4|(a=this.KEY_STR.indexOf(e.charAt(o++)))>>2,n=(3&a)<<6|(s=this.KEY_STR.indexOf(e.charAt(o++))),l.push(t),64!==a&&l.push(i),64!==s&&l.push(n),t=i=n="",r=a=s="",o<e.length;);return l}}]),e}();M.initClass();x._autoDiscoverFunction=function(){if(x.autoDiscover)return x.discover()},function(e,t){var i=!1,n=!0,r=e.document,a=r.documentElement,s=r.addEventListener?"addEventListener":"attachEvent",o=r.addEventListener?"removeEventListener":"detachEvent",l=r.addEventListener?"":"on",c=function n(a){if("readystatechange"!==a.type||"complete"===r.readyState)return("load"===a.type?e:r)[o](l+a.type,n,!1),!i&&(i=!0)?t.call(e,a.type||a):void 0};if("complete"!==r.readyState){if(r.createEventObject&&a.doScroll){try{n=!e.frameElement}catch(e){}n&&function e(){try{a.doScroll("left")}catch(t){return void setTimeout(e,50)}return c("poll")}()}r[s](l+"DOMContentLoaded",c,!1),r[s](l+"readystatechange",c,!1),e[s](l+"load",c,!1)}}(window,x._autoDiscoverFunction),window.Dropzone=x;var S=x}(),n}()})),Dropzone.autoDiscover=!1,Dropzone.prototype.previewTemplate='    <div class="dz-preview dz-file-preview">\n        <div class="dz-image"><img data-dz-thumbnail /></div>\n        \n        <div class="dz-details">\n            <div class="dz-size"><span data-dz-size></span></div>\n            <div class="dz-filename"><span data-dz-name></span></div>\n        </div>\n\n        <div class="dz-progress"><span class="dz-upload" data-dz-uploadprogress></span></div>\n\n        <div class="dz-error-message"><span data-dz-errormessage></span></div>\n        \n        <div class="dz-success-mark">\n            <svg width="54px" height="54px" viewBox="0 0 54 54" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">\n                <title>Check</title>\n                <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">\n                    <path d="M23.5,31.8431458 L17.5852419,25.9283877 C16.0248253,24.3679711 13.4910294,24.366835 11.9289322,25.9289322 C10.3700136,27.4878508 10.3665912,30.0234455 11.9283877,31.5852419 L20.4147581,40.0716123 C20.5133999,40.1702541 20.6159315,40.2626649 20.7218615,40.3488435 C22.2835669,41.8725651 24.794234,41.8626202 26.3461564,40.3106978 L43.3106978,23.3461564 C44.8771021,21.7797521 44.8758057,19.2483887 43.3137085,17.6862915 C41.7547899,16.1273729 39.2176035,16.1255422 37.6538436,17.6893022 L23.5,31.8431458 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z" stroke-opacity="0.198794158" stroke="#747474" fill-opacity="0.816519475" fill="#FFFFFF"></path>\n                </g>\n            </svg>\n        </div>\n\n        <div class="dz-error-mark">\n            <svg width="54px" height="54px" viewBox="0 0 54 54" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">\n                <title>Error</title>\n                <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">\n                    <g stroke="#747474" stroke-opacity="0.198794158" fill="#FFFFFF" fill-opacity="0.816519475">\n                    <path d="M32.6568542,29 L38.3106978,23.3461564 C39.8771021,21.7797521 39.8758057,19.2483887 38.3137085,17.6862915 C36.7547899,16.1273729 34.2176035,16.1255422 32.6538436,17.6893022 L27,23.3431458 L21.3461564,17.6893022 C19.7823965,16.1255422 17.2452101,16.1273729 15.6862915,17.6862915 C14.1241943,19.2483887 14.1228979,21.7797521 15.6893022,23.3461564 L21.3431458,29 L15.6893022,34.6538436 C14.1228979,36.2202479 14.1241943,38.7516113 15.6862915,40.3137085 C17.2452101,41.8726271 19.7823965,41.8744578 21.3461564,40.3106978 L27,34.6568542 L32.6538436,40.3106978 C34.2176035,41.8744578 36.7547899,41.8726271 38.3137085,40.3137085 C39.8758057,38.7516113 39.8771021,36.2202479 38.3106978,34.6538436 L32.6568542,29 Z M27,53 C41.3594035,53 53,41.3594035 53,27 C53,12.6405965 41.3594035,1 27,1 C12.6405965,1 1,12.6405965 1,27 C1,41.3594035 12.6405965,53 27,53 Z"></path>\n                    </g>\n                </g>\n            </svg>\n        </div>\n    </div>',function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define([],t):"object"==typeof exports?exports.Quill=t():e.Quill=t()}(self,(function(){return function(){var e={9698:function(e,t,i){"use strict";i.d(t,{Ay:function(){return c},Ji:function(){return h},mG:function(){return d},zo:function(){return u}});var n=i(6003),r=i(5232),a=i.n(r),s=i(3036),o=i(4850),l=i(5508);class c extends n.BlockBlot{cache={};delta(){return null==this.cache.delta&&(this.cache.delta=d(this)),this.cache.delta}deleteAt(e,t){super.deleteAt(e,t),this.cache={}}formatAt(e,t,i,r){t<=0||(this.scroll.query(i,n.Scope.BLOCK)?e+t===this.length()&&this.format(i,r):super.formatAt(e,Math.min(t,this.length()-e-1),i,r),this.cache={})}insertAt(e,t,i){if(null!=i)return super.insertAt(e,t,i),void(this.cache={});if(0===t.length)return;const n=t.split("\n"),r=n.shift();r.length>0&&(e<this.length()-1||null==this.children.tail?super.insertAt(Math.min(e,this.length()-1),r):this.children.tail.insertAt(this.children.tail.length(),r),this.cache={});let a=this;n.reduce(((e,t)=>(a=a.split(e,!0),a.insertAt(0,t),t.length)),e+r.length)}insertBefore(e,t){const{head:i}=this.children;super.insertBefore(e,t),i instanceof s.A&&i.remove(),this.cache={}}length(){return null==this.cache.length&&(this.cache.length=super.length()+1),this.cache.length}moveChildren(e,t){super.moveChildren(e,t),this.cache={}}optimize(e){super.optimize(e),this.cache={}}path(e){return super.path(e,!0)}removeChild(e){super.removeChild(e),this.cache={}}split(e){let t=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(t&&(0===e||e>=this.length()-1)){const t=this.clone();return 0===e?(this.parent.insertBefore(t,this),this):(this.parent.insertBefore(t,this.next),t)}const i=super.split(e,t);return this.cache={},i}}c.blotName="block",c.tagName="P",c.defaultChild=s.A,c.allowedChildren=[s.A,o.A,n.EmbedBlot,l.A];class u extends n.EmbedBlot{attach(){super.attach(),this.attributes=new n.AttributorStore(this.domNode)}delta(){return(new(a())).insert(this.value(),{...this.formats(),...this.attributes.values()})}format(e,t){const i=this.scroll.query(e,n.Scope.BLOCK_ATTRIBUTE);null!=i&&this.attributes.attribute(i,t)}formatAt(e,t,i,n){this.format(i,n)}insertAt(e,t,i){if(null!=i)return void super.insertAt(e,t,i);const n=t.split("\n"),r=n.pop(),a=n.map((e=>{const t=this.scroll.create(c.blotName);return t.insertAt(0,e),t})),s=this.split(e);a.forEach((e=>{this.parent.insertBefore(e,s)})),r&&this.parent.insertBefore(this.scroll.create("text",r),s)}}function d(e){let t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];return e.descendants(n.LeafBlot).reduce(((e,i)=>0===i.length()?e:e.insert(i.value(),h(i,{},t))),new(a())).insert("\n",h(e))}function h(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},i=!(arguments.length>2&&void 0!==arguments[2])||arguments[2];return null==e?t:("formats"in e&&"function"==typeof e.formats&&(t={...t,...e.formats()},i&&delete t["code-token"]),null==e.parent||"scroll"===e.parent.statics.blotName||e.parent.statics.scope!==e.statics.scope?t:h(e.parent,t,i))}u.scope=n.Scope.BLOCK_BLOT},3036:function(e,t,i){"use strict";var n=i(6003);class r extends n.EmbedBlot{static value(){}optimize(){(this.prev||this.next)&&this.remove()}length(){return 0}value(){return""}}r.blotName="break",r.tagName="BR",t.A=r},580:function(e,t,i){"use strict";var n=i(6003);class r extends n.ContainerBlot{}t.A=r},4541:function(e,t,i){"use strict";var n=i(6003),r=i(5508);class a extends n.EmbedBlot{static blotName="cursor";static className="ql-cursor";static tagName="span";static CONTENTS="\ufeff";static value(){}constructor(e,t,i){super(e,t),this.selection=i,this.textNode=document.createTextNode(a.CONTENTS),this.domNode.appendChild(this.textNode),this.savedLength=0}detach(){null!=this.parent&&this.parent.removeChild(this)}format(e,t){if(0!==this.savedLength)return void super.format(e,t);let i=this,r=0;for(;null!=i&&i.statics.scope!==n.Scope.BLOCK_BLOT;)r+=i.offset(i.parent),i=i.parent;null!=i&&(this.savedLength=a.CONTENTS.length,i.optimize(),i.formatAt(r,a.CONTENTS.length,e,t),this.savedLength=0)}index(e,t){return e===this.textNode?0:super.index(e,t)}length(){return this.savedLength}position(){return[this.textNode,this.textNode.data.length]}remove(){super.remove(),this.parent=null}restore(){if(this.selection.composing||null==this.parent)return null;const e=this.selection.getNativeRange();for(;null!=this.domNode.lastChild&&this.domNode.lastChild!==this.textNode;)this.domNode.parentNode.insertBefore(this.domNode.lastChild,this.domNode);const t=this.prev instanceof r.A?this.prev:null,i=t?t.length():0,n=this.next instanceof r.A?this.next:null,s=n?n.text:"",{textNode:o}=this,l=o.data.split(a.CONTENTS).join("");let c;if(o.data=a.CONTENTS,t)c=t,(l||n)&&(t.insertAt(t.length(),l+s),n&&n.remove());else if(n)c=n,n.insertAt(0,l);else{const e=document.createTextNode(l);c=this.scroll.create(e),this.parent.insertBefore(c,this)}if(this.remove(),e){const r=(e,r)=>t&&e===t.domNode?r:e===o?i+r-1:n&&e===n.domNode?i+l.length+r:null,a=r(e.start.node,e.start.offset),s=r(e.end.node,e.end.offset);if(null!==a&&null!==s)return{startNode:c.domNode,startOffset:a,endNode:c.domNode,endOffset:s}}return null}update(e,t){if(e.some((e=>"characterData"===e.type&&e.target===this.textNode))){const e=this.restore();e&&(t.range=e)}}optimize(e){super.optimize(e);let{parent:t}=this;for(;t;){if("A"===t.domNode.tagName){this.savedLength=a.CONTENTS.length,t.isolate(this.offset(t),this.length()).unwrap(),this.savedLength=0;break}t=t.parent}}value(){return""}}t.A=a},746:function(e,t,i){"use strict";var n=i(6003),r=i(5508);const a="\ufeff";class s extends n.EmbedBlot{constructor(e,t){super(e,t),this.contentNode=document.createElement("span"),this.contentNode.setAttribute("contenteditable","false"),Array.from(this.domNode.childNodes).forEach((e=>{this.contentNode.appendChild(e)})),this.leftGuard=document.createTextNode(a),this.rightGuard=document.createTextNode(a),this.domNode.appendChild(this.leftGuard),this.domNode.appendChild(this.contentNode),this.domNode.appendChild(this.rightGuard)}index(e,t){return e===this.leftGuard?0:e===this.rightGuard?1:super.index(e,t)}restore(e){let t,i=null;const n=e.data.split(a).join("");if(e===this.leftGuard)if(this.prev instanceof r.A){const e=this.prev.length();this.prev.insertAt(e,n),i={startNode:this.prev.domNode,startOffset:e+n.length}}else t=document.createTextNode(n),this.parent.insertBefore(this.scroll.create(t),this),i={startNode:t,startOffset:n.length};else e===this.rightGuard&&(this.next instanceof r.A?(this.next.insertAt(0,n),i={startNode:this.next.domNode,startOffset:n.length}):(t=document.createTextNode(n),this.parent.insertBefore(this.scroll.create(t),this.next),i={startNode:t,startOffset:n.length}));return e.data=a,i}update(e,t){e.forEach((e=>{if("characterData"===e.type&&(e.target===this.leftGuard||e.target===this.rightGuard)){const i=this.restore(e.target);i&&(t.range=i)}}))}}t.A=s},4850:function(e,t,i){"use strict";var n=i(6003),r=i(3036),a=i(5508);class s extends n.InlineBlot{static allowedChildren=[s,r.A,n.EmbedBlot,a.A];static order=["cursor","inline","link","underline","strike","italic","bold","script","code"];static compare(e,t){const i=s.order.indexOf(e),n=s.order.indexOf(t);return i>=0||n>=0?i-n:e===t?0:e<t?-1:1}formatAt(e,t,i,r){if(s.compare(this.statics.blotName,i)<0&&this.scroll.query(i,n.Scope.BLOT)){const n=this.isolate(e,t);r&&n.wrap(i,r)}else super.formatAt(e,t,i,r)}optimize(e){if(super.optimize(e),this.parent instanceof s&&s.compare(this.statics.blotName,this.parent.statics.blotName)>0){const e=this.parent.isolate(this.offset(),this.length());this.moveChildren(e),e.wrap(this)}}}t.A=s},5508:function(e,t,i){"use strict";i.d(t,{A:function(){return r},X:function(){return a}});var n=i(6003);class r extends n.TextBlot{}function a(e){return e.replace(/[&<>"']/g,(e=>({"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"}[e])))}},3729:function(e,t,i){"use strict";i.d(t,{default:function(){return Y}});var n=i(6142),r=i(9698),a=i(3036),s=i(580),o=i(4541),l=i(746),c=i(4850),u=i(6003),d=i(5232),h=i.n(d),f=i(5374);function p(e){return e instanceof r.Ay||e instanceof r.zo}function m(e){return"function"==typeof e.updateContent}class g extends u.ScrollBlot{static blotName="scroll";static className="ql-editor";static tagName="DIV";static defaultChild=r.Ay;static allowedChildren=[r.Ay,r.zo,s.A];constructor(e,t,i){let{emitter:n}=i;super(e,t),this.emitter=n,this.batch=!1,this.optimize(),this.enable(),this.domNode.addEventListener("dragstart",(e=>this.handleDragStart(e)))}batchStart(){Array.isArray(this.batch)||(this.batch=[])}batchEnd(){if(!this.batch)return;const e=this.batch;this.batch=!1,this.update(e)}emitMount(e){this.emitter.emit(f.A.events.SCROLL_BLOT_MOUNT,e)}emitUnmount(e){this.emitter.emit(f.A.events.SCROLL_BLOT_UNMOUNT,e)}emitEmbedUpdate(e,t){this.emitter.emit(f.A.events.SCROLL_EMBED_UPDATE,e,t)}deleteAt(e,t){const[i,n]=this.line(e),[s]=this.line(e+t);if(super.deleteAt(e,t),null!=s&&i!==s&&n>0){if(i instanceof r.zo||s instanceof r.zo)return void this.optimize();const e=s.children.head instanceof a.A?null:s.children.head;i.moveChildren(s,e),i.remove()}this.optimize()}enable(){let e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0];this.domNode.setAttribute("contenteditable",e?"true":"false")}formatAt(e,t,i,n){super.formatAt(e,t,i,n),this.optimize()}insertAt(e,t,i){if(e>=this.length())if(null==i||null==this.scroll.query(t,u.Scope.BLOCK)){const e=this.scroll.create(this.statics.defaultChild.blotName);this.appendChild(e),null==i&&t.endsWith("\n")?e.insertAt(0,t.slice(0,-1),i):e.insertAt(0,t,i)}else{const e=this.scroll.create(t,i);this.appendChild(e)}else super.insertAt(e,t,i);this.optimize()}insertBefore(e,t){if(e.statics.scope===u.Scope.INLINE_BLOT){const i=this.scroll.create(this.statics.defaultChild.blotName);i.appendChild(e),super.insertBefore(i,t)}else super.insertBefore(e,t)}insertContents(e,t){const i=this.deltaToRenderBlocks(t.concat((new(h())).insert("\n"))),n=i.pop();if(null==n)return;this.batchStart();const a=i.shift();if(a){const t="block"===a.type&&(0===a.delta.length()||!this.descendant(r.zo,e)[0]&&e<this.length()),i="block"===a.type?a.delta:(new(h())).insert({[a.key]:a.value});v(this,e,i);const n="block"===a.type?1:0,s=e+i.length()+n;t&&this.insertAt(s-1,"\n");const o=(0,r.Ji)(this.line(e)[0]),l=d.AttributeMap.diff(o,a.attributes)||{};Object.keys(l).forEach((e=>{this.formatAt(s-1,1,e,l[e])})),e=s}let[s,o]=this.children.find(e);i.length&&(s&&(s=s.split(o),o=0),i.forEach((e=>{if("block"===e.type)v(this.createBlock(e.attributes,s||void 0),0,e.delta);else{const t=this.create(e.key,e.value);this.insertBefore(t,s||void 0),Object.keys(e.attributes).forEach((i=>{t.format(i,e.attributes[i])}))}}))),"block"===n.type&&n.delta.length()&&v(this,s?s.offset(s.scroll)+o:this.length(),n.delta),this.batchEnd(),this.optimize()}isEnabled(){return"true"===this.domNode.getAttribute("contenteditable")}leaf(e){const t=this.path(e).pop();if(!t)return[null,-1];const[i,n]=t;return i instanceof u.LeafBlot?[i,n]:[null,-1]}line(e){return e===this.length()?this.line(e-1):this.descendant(p,e)}lines(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0,t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Number.MAX_VALUE;const i=(e,t,n)=>{let r=[],a=n;return e.children.forEachAt(t,n,((e,t,n)=>{p(e)?r.push(e):e instanceof u.ContainerBlot&&(r=r.concat(i(e,t,a))),a-=n})),r};return i(this,e,t)}optimize(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};this.batch||(super.optimize(e,t),e.length>0&&this.emitter.emit(f.A.events.SCROLL_OPTIMIZE,e,t))}path(e){return super.path(e).slice(1)}remove(){}update(e){if(this.batch)return void(Array.isArray(e)&&(this.batch=this.batch.concat(e)));let t=f.A.sources.USER;"string"==typeof e&&(t=e),Array.isArray(e)||(e=this.observer.takeRecords()),(e=e.filter((e=>{let{target:t}=e;const i=this.find(t,!0);return i&&!m(i)}))).length>0&&this.emitter.emit(f.A.events.SCROLL_BEFORE_UPDATE,t,e),super.update(e.concat([])),e.length>0&&this.emitter.emit(f.A.events.SCROLL_UPDATE,t,e)}updateEmbedAt(e,t,i){const[n]=this.descendant((e=>e instanceof r.zo),e);n&&n.statics.blotName===t&&m(n)&&n.updateContent(i)}handleDragStart(e){e.preventDefault()}deltaToRenderBlocks(e){const t=[];let i=new(h());return e.forEach((e=>{const n=e?.insert;if(n)if("string"==typeof n){const r=n.split("\n");r.slice(0,-1).forEach((n=>{i.insert(n,e.attributes),t.push({type:"block",delta:i,attributes:e.attributes??{}}),i=new(h())}));const a=r[r.length-1];a&&i.insert(a,e.attributes)}else{const r=Object.keys(n)[0];if(!r)return;this.query(r,u.Scope.INLINE)?i.push(e):(i.length()&&t.push({type:"block",delta:i,attributes:{}}),i=new(h()),t.push({type:"blockEmbed",key:r,value:n[r],attributes:e.attributes??{}}))}})),i.length()&&t.push({type:"block",delta:i,attributes:{}}),t}createBlock(e,t){let i;const n={};Object.entries(e).forEach((e=>{let[t,r]=e;null!=this.query(t,u.Scope.BLOCK&u.Scope.BLOT)?i=t:n[t]=r}));const r=this.create(i||this.statics.defaultChild.blotName,i?e[i]:void 0);this.insertBefore(r,t||void 0);const a=r.length();return Object.entries(n).forEach((e=>{let[t,i]=e;r.formatAt(0,a,t,i)})),r}}function v(e,t,i){i.reduce(((t,i)=>{const n=d.Op.length(i);let a=i.attributes||{};if(null!=i.insert)if("string"==typeof i.insert){const n=i.insert;e.insertAt(t,n);const[s]=e.descendant(u.LeafBlot,t),o=(0,r.Ji)(s);a=d.AttributeMap.diff(o,a)||{}}else if("object"==typeof i.insert){const n=Object.keys(i.insert)[0];if(null==n)return t;if(e.insertAt(t,n,i.insert[n]),null!=e.scroll.query(n,u.Scope.INLINE)){const[i]=e.descendant(u.LeafBlot,t),n=(0,r.Ji)(i);a=d.AttributeMap.diff(n,a)||{}}}return Object.keys(a).forEach((i=>{e.formatAt(t,n,i,a[i])})),t+n}),t)}var y=g,b=i(5508),x=i(584),_=i(4266);class w extends _.A{static DEFAULTS={delay:1e3,maxStack:100,userOnly:!1};lastRecorded=0;ignoreChange=!1;stack={undo:[],redo:[]};currentRange=null;constructor(e,t){super(e,t),this.quill.on(n.Ay.events.EDITOR_CHANGE,((e,t,i,r)=>{e===n.Ay.events.SELECTION_CHANGE?t&&r!==n.Ay.sources.SILENT&&(this.currentRange=t):e===n.Ay.events.TEXT_CHANGE&&(this.ignoreChange||(this.options.userOnly&&r!==n.Ay.sources.USER?this.transform(t):this.record(t,i)),this.currentRange=M(this.currentRange,t))})),this.quill.keyboard.addBinding({key:"z",shortKey:!0},this.undo.bind(this)),this.quill.keyboard.addBinding({key:["z","Z"],shortKey:!0,shiftKey:!0},this.redo.bind(this)),/Win/i.test(navigator.platform)&&this.quill.keyboard.addBinding({key:"y",shortKey:!0},this.redo.bind(this)),this.quill.root.addEventListener("beforeinput",(e=>{"historyUndo"===e.inputType?(this.undo(),e.preventDefault()):"historyRedo"===e.inputType&&(this.redo(),e.preventDefault())}))}change(e,t){if(0===this.stack[e].length)return;const i=this.stack[e].pop();if(!i)return;const r=this.quill.getContents(),a=i.delta.invert(r);this.stack[t].push({delta:a,range:M(i.range,a)}),this.lastRecorded=0,this.ignoreChange=!0,this.quill.updateContents(i.delta,n.Ay.sources.USER),this.ignoreChange=!1,this.restoreSelection(i)}clear(){this.stack={undo:[],redo:[]}}cutoff(){this.lastRecorded=0}record(e,t){if(0===e.ops.length)return;this.stack.redo=[];let i=e.invert(t),n=this.currentRange;const r=Date.now();if(this.lastRecorded+this.options.delay>r&&this.stack.undo.length>0){const e=this.stack.undo.pop();e&&(i=i.compose(e.delta),n=e.range)}else this.lastRecorded=r;0!==i.length()&&(this.stack.undo.push({delta:i,range:n}),this.stack.undo.length>this.options.maxStack&&this.stack.undo.shift())}redo(){this.change("redo","undo")}transform(e){k(this.stack.undo,e),k(this.stack.redo,e)}undo(){this.change("undo","redo")}restoreSelection(e){if(e.range)this.quill.setSelection(e.range,n.Ay.sources.USER);else{const t=function(e,t){const i=t.reduce(((e,t)=>e+(t.delete||0)),0);let n=t.length()-i;return function(e,t){const i=t.ops[t.ops.length-1];return null!=i&&(null!=i.insert?"string"==typeof i.insert&&i.insert.endsWith("\n"):null!=i.attributes&&Object.keys(i.attributes).some((t=>null!=e.query(t,u.Scope.BLOCK))))}(e,t)&&(n-=1),n}(this.quill.scroll,e.delta);this.quill.setSelection(t,n.Ay.sources.USER)}}}function k(e,t){let i=t;for(let t=e.length-1;t>=0;t-=1){const n=e[t];e[t]={delta:i.transform(n.delta,!0),range:n.range&&M(n.range,i)},i=n.delta.transform(i),0===e[t].delta.length()&&e.splice(t,1)}}function M(e,t){if(!e)return e;const i=t.transformPosition(e.index);return{index:i,length:t.transformPosition(e.index+e.length)-i}}var S=i(8123);class A extends _.A{constructor(e,t){super(e,t),e.root.addEventListener("drop",(t=>{t.preventDefault();let i=null;if(document.caretRangeFromPoint)i=document.caretRangeFromPoint(t.clientX,t.clientY);else if(document.caretPositionFromPoint){const e=document.caretPositionFromPoint(t.clientX,t.clientY);i=document.createRange(),i.setStart(e.offsetNode,e.offset),i.setEnd(e.offsetNode,e.offset)}const n=i&&e.selection.normalizeNative(i);if(n){const i=e.selection.normalizedToRange(n);t.dataTransfer?.files&&this.upload(i,t.dataTransfer.files)}}))}upload(e,t){const i=[];Array.from(t).forEach((e=>{e&&this.options.mimetypes?.includes(e.type)&&i.push(e)})),i.length>0&&this.options.handler.call(this,e,i)}}A.DEFAULTS={mimetypes:["image/png","image/jpeg"],handler(e,t){if(!this.quill.scroll.query("image"))return;const i=t.map((e=>new Promise((t=>{const i=new FileReader;i.onload=()=>{t(i.result)},i.readAsDataURL(e)}))));Promise.all(i).then((t=>{const i=t.reduce(((e,t)=>e.insert({image:t})),(new(h())).retain(e.index).delete(e.length));this.quill.updateContents(i,f.A.sources.USER),this.quill.setSelection(e.index+t.length,f.A.sources.SILENT)}))}};var L=A;const T=["insertText","insertReplacementText"];class C extends _.A{constructor(e,t){super(e,t),e.root.addEventListener("beforeinput",(e=>{this.handleBeforeInput(e)})),/Android/i.test(navigator.userAgent)||e.on(n.Ay.events.COMPOSITION_BEFORE_START,(()=>{this.handleCompositionStart()}))}deleteRange(e){(0,S.Xo)({range:e,quill:this.quill})}replaceText(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"";if(0===e.length)return!1;if(t){const i=this.quill.getFormat(e.index,1);this.deleteRange(e),this.quill.updateContents((new(h())).retain(e.index).insert(t,i),n.Ay.sources.USER)}else this.deleteRange(e);return this.quill.setSelection(e.index+t.length,0,n.Ay.sources.SILENT),!0}handleBeforeInput(e){if(this.quill.composition.isComposing||e.defaultPrevented||!T.includes(e.inputType))return;const t=e.getTargetRanges?e.getTargetRanges()[0]:null;if(!t||!0===t.collapsed)return;const i=function(e){return"string"==typeof e.data?e.data:e.dataTransfer?.types.includes("text/plain")?e.dataTransfer.getData("text/plain"):null}(e);if(null==i)return;const n=this.quill.selection.normalizeNative(t),r=n?this.quill.selection.normalizedToRange(n):null;r&&this.replaceText(r,i)&&e.preventDefault()}handleCompositionStart(){const e=this.quill.getSelection();e&&this.replaceText(e)}}var D=C;const E=/Mac/i.test(navigator.platform);class O extends _.A{isListening=!1;selectionChangeDeadline=0;constructor(e,t){super(e,t),this.handleArrowKeys(),this.handleNavigationShortcuts()}handleArrowKeys(){this.quill.keyboard.addBinding({key:["ArrowLeft","ArrowRight"],offset:0,shiftKey:null,handler(e,t){let{line:i,event:r}=t;if(!(i instanceof u.ParentBlot&&i.uiNode))return!0;const a="rtl"===getComputedStyle(i.domNode).direction;return!!(a&&"ArrowRight"!==r.key||!a&&"ArrowLeft"!==r.key)||(this.quill.setSelection(e.index-1,e.length+(r.shiftKey?1:0),n.Ay.sources.USER),!1)}})}handleNavigationShortcuts(){this.quill.root.addEventListener("keydown",(e=>{!e.defaultPrevented&&(e=>"ArrowLeft"===e.key||"ArrowRight"===e.key||"ArrowUp"===e.key||"ArrowDown"===e.key||"Home"===e.key||!(!E||"a"!==e.key||!0!==e.ctrlKey))(e)&&this.ensureListeningToSelectionChange()}))}ensureListeningToSelectionChange(){this.selectionChangeDeadline=Date.now()+100,this.isListening||(this.isListening=!0,document.addEventListener("selectionchange",(()=>{this.isListening=!1,Date.now()<=this.selectionChangeDeadline&&this.handleSelectionChange()}),{once:!0}))}handleSelectionChange(){const e=document.getSelection();if(!e)return;const t=e.getRangeAt(0);if(!0!==t.collapsed||0!==t.startOffset)return;const i=this.quill.scroll.find(t.startContainer);if(!(i instanceof u.ParentBlot&&i.uiNode))return;const n=document.createRange();n.setStartAfter(i.uiNode),n.setEndAfter(i.uiNode),e.removeAllRanges(),e.addRange(n)}}var P=O;n.Ay.register({"blots/block":r.Ay,"blots/block/embed":r.zo,"blots/break":a.A,"blots/container":s.A,"blots/cursor":o.A,"blots/embed":l.A,"blots/inline":c.A,"blots/scroll":y,"blots/text":b.A,"modules/clipboard":x.Ay,"modules/history":w,"modules/keyboard":S.Ay,"modules/uploader":L,"modules/input":D,"modules/uiNode":P});var Y=n.Ay},5374:function(e,t,i){"use strict";i.d(t,{A:function(){return s}});var n=i(8920),r=i(7356);const a=(0,i(6078).A)("quill:events");["selectionchange","mousedown","mouseup","click"].forEach((e=>{document.addEventListener(e,(function(){for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];Array.from(document.querySelectorAll(".ql-container")).forEach((e=>{const i=r.A.get(e);i&&i.emitter&&i.emitter.handleDOM(...t)}))}))}));var s=class extends n{static events={EDITOR_CHANGE:"editor-change",SCROLL_BEFORE_UPDATE:"scroll-before-update",SCROLL_BLOT_MOUNT:"scroll-blot-mount",SCROLL_BLOT_UNMOUNT:"scroll-blot-unmount",SCROLL_OPTIMIZE:"scroll-optimize",SCROLL_UPDATE:"scroll-update",SCROLL_EMBED_UPDATE:"scroll-embed-update",SELECTION_CHANGE:"selection-change",TEXT_CHANGE:"text-change",COMPOSITION_BEFORE_START:"composition-before-start",COMPOSITION_START:"composition-start",COMPOSITION_BEFORE_END:"composition-before-end",COMPOSITION_END:"composition-end"};static sources={API:"api",SILENT:"silent",USER:"user"};constructor(){super(),this.domListeners={},this.on("error",a.error)}emit(){for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];return a.log.call(a,...t),super.emit(...t)}handleDOM(e){for(var t=arguments.length,i=new Array(t>1?t-1:0),n=1;n<t;n++)i[n-1]=arguments[n];(this.domListeners[e.type]||[]).forEach((t=>{let{node:n,handler:r}=t;(e.target===n||n.contains(e.target))&&r(e,...i)}))}listenDOM(e,t,i){this.domListeners[e]||(this.domListeners[e]=[]),this.domListeners[e].push({node:t,handler:i})}}},7356:function(e,t){"use strict";t.A=new WeakMap},6078:function(e,t){"use strict";const i=["error","warn","log","info"];let n="warn";function r(e){if(n&&i.indexOf(e)<=i.indexOf(n)){for(var t=arguments.length,r=new Array(t>1?t-1:0),a=1;a<t;a++)r[a-1]=arguments[a];console[e](...r)}}function a(e){return i.reduce(((t,i)=>(t[i]=r.bind(console,i,e),t)),{})}a.level=e=>{n=e},r.level=a.level,t.A=a},4266:function(e,t){"use strict";t.A=class{static DEFAULTS={};constructor(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};this.quill=e,this.options=t}}},6142:function(e,t,i){"use strict";i.d(t,{Ay:function(){return I}});var n=i(8347),r=i(6003),a=i(5232),s=i.n(a),o=i(3707),l=i(5123),c=i(9698),u=i(3036),d=i(4541),h=i(5508),f=i(8298);const p=/^[ -~]*$/;function m(e,t,i){if(0===e.length){const[e]=y(i.pop());return t<=0?`</li></${e}>`:`</li></${e}>${m([],t-1,i)}`}const[{child:n,offset:r,length:a,indent:s,type:o},...l]=e,[c,u]=y(o);if(s>t)return i.push(o),s===t+1?`<${c}><li${u}>${g(n,r,a)}${m(l,s,i)}`:`<${c}><li>${m(e,t+1,i)}`;const d=i[i.length-1];if(s===t&&o===d)return`</li><li${u}>${g(n,r,a)}${m(l,s,i)}`;const[h]=y(i.pop());return`</li></${h}>${m(e,t-1,i)}`}function g(e,t,i){let n=arguments.length>3&&void 0!==arguments[3]&&arguments[3];if("html"in e&&"function"==typeof e.html)return e.html(t,i);if(e instanceof h.A)return(0,h.X)(e.value().slice(t,t+i));if(e instanceof r.ParentBlot){if("list-container"===e.statics.blotName){const n=[];return e.children.forEachAt(t,i,((e,t,i)=>{const r="formats"in e&&"function"==typeof e.formats?e.formats():{};n.push({child:e,offset:t,length:i,indent:r.indent||0,type:r.list})})),m(n,-1,[])}const r=[];if(e.children.forEachAt(t,i,((e,t,i)=>{r.push(g(e,t,i))})),n||"list"===e.statics.blotName)return r.join("");const{outerHTML:a,innerHTML:s}=e.domNode,[o,l]=a.split(`>${s}<`);return"<table"===o?`<table style="border: 1px solid #000;">${r.join("")}<${l}`:`${o}>${r.join("")}<${l}`}return e.domNode instanceof Element?e.domNode.outerHTML:""}function v(e,t){return Object.keys(t).reduce(((i,n)=>{if(null==e[n])return i;const r=t[n];return r===e[n]?i[n]=r:Array.isArray(r)?r.indexOf(e[n])<0?i[n]=r.concat([e[n]]):i[n]=r:i[n]=[r,e[n]],i}),{})}function y(e){const t="ordered"===e?"ol":"ul";switch(e){case"checked":return[t,' data-list="checked"'];case"unchecked":return[t,' data-list="unchecked"'];default:return[t,""]}}function b(e){return e.reduce(((e,t)=>{if("string"==typeof t.insert){const i=t.insert.replace(/\r\n/g,"\n").replace(/\r/g,"\n");return e.insert(i,t.attributes)}return e.push(t)}),new(s()))}function x(e,t){let{index:i,length:n}=e;return new f.Q(i+t,n)}var _=class{constructor(e){this.scroll=e,this.delta=this.getDelta()}applyDelta(e){this.scroll.update();let t=this.scroll.length();this.scroll.batchStart();const i=b(e),o=new(s());return function(e){const t=[];return e.forEach((e=>{"string"==typeof e.insert?e.insert.split("\n").forEach(((i,n)=>{n&&t.push({insert:"\n",attributes:e.attributes}),i&&t.push({insert:i,attributes:e.attributes})})):t.push(e)})),t}(i.ops.slice()).reduce(((e,i)=>{const s=a.Op.length(i);let l=i.attributes||{},u=!1,d=!1;if(null!=i.insert){if(o.retain(s),"string"==typeof i.insert){const s=i.insert;d=!s.endsWith("\n")&&(t<=e||!!this.scroll.descendant(c.zo,e)[0]),this.scroll.insertAt(e,s);const[o,u]=this.scroll.line(e);let h=(0,n.A)({},(0,c.Ji)(o));if(o instanceof c.Ay){const[e]=o.descendant(r.LeafBlot,u);e&&(h=(0,n.A)(h,(0,c.Ji)(e)))}l=a.AttributeMap.diff(h,l)||{}}else if("object"==typeof i.insert){const s=Object.keys(i.insert)[0];if(null==s)return e;const o=null!=this.scroll.query(s,r.Scope.INLINE);if(o)(t<=e||this.scroll.descendant(c.zo,e)[0])&&(d=!0);else if(e>0){const[t,i]=this.scroll.descendant(r.LeafBlot,e-1);t instanceof h.A?"\n"!==t.value()[i]&&(u=!0):t instanceof r.EmbedBlot&&t.statics.scope===r.Scope.INLINE_BLOT&&(u=!0)}if(this.scroll.insertAt(e,s,i.insert[s]),o){const[t]=this.scroll.descendant(r.LeafBlot,e);if(t){const e=(0,n.A)({},(0,c.Ji)(t));l=a.AttributeMap.diff(e,l)||{}}}}t+=s}else if(o.push(i),null!==i.retain&&"object"==typeof i.retain){const t=Object.keys(i.retain)[0];if(null==t)return e;this.scroll.updateEmbedAt(e,t,i.retain[t])}Object.keys(l).forEach((t=>{this.scroll.formatAt(e,s,t,l[t])}));const f=u?1:0,p=d?1:0;return t+=f+p,o.retain(f),o.delete(p),e+s+f+p}),0),o.reduce(((e,t)=>"number"==typeof t.delete?(this.scroll.deleteAt(e,t.delete),e):e+a.Op.length(t)),0),this.scroll.batchEnd(),this.scroll.optimize(),this.update(i)}deleteText(e,t){return this.scroll.deleteAt(e,t),this.update((new(s())).retain(e).delete(t))}formatLine(e,t){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};this.scroll.update(),Object.keys(i).forEach((n=>{this.scroll.lines(e,Math.max(t,1)).forEach((e=>{e.format(n,i[n])}))})),this.scroll.optimize();const n=(new(s())).retain(e).retain(t,(0,o.A)(i));return this.update(n)}formatText(e,t){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};Object.keys(i).forEach((n=>{this.scroll.formatAt(e,t,n,i[n])}));const n=(new(s())).retain(e).retain(t,(0,o.A)(i));return this.update(n)}getContents(e,t){return this.delta.slice(e,e+t)}getDelta(){return this.scroll.lines().reduce(((e,t)=>e.concat(t.delta())),new(s()))}getFormat(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,i=[],n=[];0===t?this.scroll.path(e).forEach((e=>{const[t]=e;t instanceof c.Ay?i.push(t):t instanceof r.LeafBlot&&n.push(t)})):(i=this.scroll.lines(e,t),n=this.scroll.descendants(r.LeafBlot,e,t));const[a,s]=[i,n].map((e=>{const t=e.shift();if(null==t)return{};let i=(0,c.Ji)(t);for(;Object.keys(i).length>0;){const t=e.shift();if(null==t)return i;i=v((0,c.Ji)(t),i)}return i}));return{...a,...s}}getHTML(e,t){const[i,n]=this.scroll.line(e);if(i){const r=i.length();return i.length()>=n+t&&(0!==n||t!==r)?g(i,n,t,!0):g(this.scroll,e,t,!0)}return""}getText(e,t){return this.getContents(e,t).filter((e=>"string"==typeof e.insert)).map((e=>e.insert)).join("")}insertContents(e,t){const i=b(t),n=(new(s())).retain(e).concat(i);return this.scroll.insertContents(e,i),this.update(n)}insertEmbed(e,t,i){return this.scroll.insertAt(e,t,i),this.update((new(s())).retain(e).insert({[t]:i}))}insertText(e,t){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return t=t.replace(/\r\n/g,"\n").replace(/\r/g,"\n"),this.scroll.insertAt(e,t),Object.keys(i).forEach((n=>{this.scroll.formatAt(e,t.length,n,i[n])})),this.update((new(s())).retain(e).insert(t,(0,o.A)(i)))}isBlank(){if(0===this.scroll.children.length)return!0;if(this.scroll.children.length>1)return!1;const e=this.scroll.children.head;if(e?.statics.blotName!==c.Ay.blotName)return!1;const t=e;return!(t.children.length>1)&&t.children.head instanceof u.A}removeFormat(e,t){const i=this.getText(e,t),[n,r]=this.scroll.line(e+t);let a=0,o=new(s());null!=n&&(a=n.length()-r,o=n.delta().slice(r,r+a-1).insert("\n"));const l=this.getContents(e,t+a).diff((new(s())).insert(i).concat(o)),c=(new(s())).retain(e).concat(l);return this.applyDelta(c)}update(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:[],i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:void 0;const n=this.delta;if(1===t.length&&"characterData"===t[0].type&&t[0].target.data.match(p)&&this.scroll.find(t[0].target)){const r=this.scroll.find(t[0].target),a=(0,c.Ji)(r),o=r.offset(this.scroll),l=t[0].oldValue.replace(d.A.CONTENTS,""),u=(new(s())).insert(l),h=(new(s())).insert(r.value()),f=i&&{oldRange:x(i.oldRange,-o),newRange:x(i.newRange,-o)};e=(new(s())).retain(o).concat(u.diff(h,f)).reduce(((e,t)=>t.insert?e.insert(t.insert,a):e.push(t)),new(s())),this.delta=n.compose(e)}else this.delta=this.getDelta(),e&&(0,l.A)(n.compose(e),this.delta)||(e=n.diff(this.delta,i));return e}},w=i(5374),k=i(7356),M=i(6078),S=i(4266),A=i(746),L=class{isComposing=!1;constructor(e,t){this.scroll=e,this.emitter=t,this.setupListeners()}setupListeners(){this.scroll.domNode.addEventListener("compositionstart",(e=>{this.isComposing||this.handleCompositionStart(e)})),this.scroll.domNode.addEventListener("compositionend",(e=>{this.isComposing&&queueMicrotask((()=>{this.handleCompositionEnd(e)}))}))}handleCompositionStart(e){const t=e.target instanceof Node?this.scroll.find(e.target,!0):null;!t||t instanceof A.A||(this.emitter.emit(w.A.events.COMPOSITION_BEFORE_START,e),this.scroll.batchStart(),this.emitter.emit(w.A.events.COMPOSITION_START,e),this.isComposing=!0)}handleCompositionEnd(e){this.emitter.emit(w.A.events.COMPOSITION_BEFORE_END,e),this.scroll.batchEnd(),this.emitter.emit(w.A.events.COMPOSITION_END,e),this.isComposing=!1}},T=i(9609);const C=e=>{const t=e.getBoundingClientRect(),i="offsetWidth"in e&&Math.abs(t.width)/e.offsetWidth||1,n="offsetHeight"in e&&Math.abs(t.height)/e.offsetHeight||1;return{top:t.top,right:t.left+e.clientWidth*i,bottom:t.top+e.clientHeight*n,left:t.left}},D=e=>{const t=parseInt(e,10);return Number.isNaN(t)?0:t},E=(e,t,i,n,r,a)=>e<i&&t>n?0:e<i?-(i-e+r):t>n?t-e>n-i?e+r-i:t-n+a:0,O=["block","break","cursor","inline","scroll","text"],P=(0,M.A)("quill"),Y=new r.Registry;r.ParentBlot.uiClass="ql-ui";class I{static DEFAULTS={bounds:null,modules:{clipboard:!0,keyboard:!0,history:!0,uploader:!0},placeholder:"",readOnly:!1,registry:Y,theme:"default"};static events=w.A.events;static sources=w.A.sources;static version="2.0.2";static imports={delta:s(),parchment:r,"core/module":S.A,"core/theme":T.A};static debug(e){!0===e&&(e="log"),M.A.level(e)}static find(e){let t=arguments.length>1&&void 0!==arguments[1]&&arguments[1];return k.A.get(e)||Y.find(e,t)}static import(e){return null==this.imports[e]&&P.error(`Cannot import ${e}. Are you sure it was registered?`),this.imports[e]}static register(){if("string"!=typeof(arguments.length<=0?void 0:arguments[0])){const e=arguments.length<=0?void 0:arguments[0],t=!!(arguments.length<=1?void 0:arguments[1]),i="attrName"in e?e.attrName:e.blotName;"string"==typeof i?this.register(`formats/${i}`,e,t):Object.keys(e).forEach((i=>{this.register(i,e[i],t)}))}else{const e=arguments.length<=0?void 0:arguments[0],t=arguments.length<=1?void 0:arguments[1],i=!!(arguments.length<=2?void 0:arguments[2]);null==this.imports[e]||i||P.warn(`Overwriting ${e} with`,t),this.imports[e]=t,(e.startsWith("blots/")||e.startsWith("formats/"))&&t&&"boolean"!=typeof t&&"abstract"!==t.blotName&&Y.register(t),"function"==typeof t.register&&t.register(Y)}}constructor(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};if(this.options=function(e,t){const i=N(e);if(!i)throw new Error("Invalid Quill container");const a=t.theme&&t.theme!==I.DEFAULTS.theme?I.import(`themes/${t.theme}`):T.A;if(!a)throw new Error(`Invalid theme ${t.theme}. Did you register it?`);const{modules:s,...o}=I.DEFAULTS,{modules:l,...c}=a.DEFAULTS;let u=j(t.modules);null!=u&&u.toolbar&&u.toolbar.constructor!==Object&&(u={...u,toolbar:{container:u.toolbar}});const d=(0,n.A)({},j(s),j(l),u),h={...o,...H(c),...H(t)};let f=t.registry;return f?t.formats&&P.warn('Ignoring "formats" option because "registry" is specified'):f=t.formats?((e,t,i)=>{const n=new r.Registry;return O.forEach((e=>{const i=t.query(e);i&&n.register(i)})),e.forEach((e=>{let r=t.query(e);r||i.error(`Cannot register "${e}" specified in "formats" config. Are you sure it was registered?`);let a=0;for(;r;)if(n.register(r),r="blotName"in r?r.requiredContainer??null:null,a+=1,a>100){i.error(`Cycle detected in registering blot requiredContainer: "${e}"`);break}})),n})(t.formats,h.registry,P):h.registry,{...h,registry:f,container:i,theme:a,modules:Object.entries(d).reduce(((e,t)=>{let[i,r]=t;if(!r)return e;const a=I.import(`modules/${i}`);return null==a?(P.error(`Cannot load ${i} module. Are you sure you registered it?`),e):{...e,[i]:(0,n.A)({},a.DEFAULTS||{},r)}}),{}),bounds:N(h.bounds)}}(e,t),this.container=this.options.container,null==this.container)return void P.error("Invalid Quill container",e);this.options.debug&&I.debug(this.options.debug);const i=this.container.innerHTML.trim();this.container.classList.add("ql-container"),this.container.innerHTML="",k.A.set(this.container,this),this.root=this.addContainer("ql-editor"),this.root.classList.add("ql-blank"),this.emitter=new w.A;const a=r.ScrollBlot.blotName,o=this.options.registry.query(a);if(!o||!("blotName"in o))throw new Error(`Cannot initialize Quill without "${a}" blot`);if(this.scroll=new o(this.options.registry,this.root,{emitter:this.emitter}),this.editor=new _(this.scroll),this.selection=new f.A(this.scroll,this.emitter),this.composition=new L(this.scroll,this.emitter),this.theme=new this.options.theme(this,this.options),this.keyboard=this.theme.addModule("keyboard"),this.clipboard=this.theme.addModule("clipboard"),this.history=this.theme.addModule("history"),this.uploader=this.theme.addModule("uploader"),this.theme.addModule("input"),this.theme.addModule("uiNode"),this.theme.init(),this.emitter.on(w.A.events.EDITOR_CHANGE,(e=>{e===w.A.events.TEXT_CHANGE&&this.root.classList.toggle("ql-blank",this.editor.isBlank())})),this.emitter.on(w.A.events.SCROLL_UPDATE,((e,t)=>{const i=this.selection.lastRange,[n]=this.selection.getRange(),r=i&&n?{oldRange:i,newRange:n}:void 0;F.call(this,(()=>this.editor.update(null,t,r)),e)})),this.emitter.on(w.A.events.SCROLL_EMBED_UPDATE,((e,t)=>{const i=this.selection.lastRange,[n]=this.selection.getRange(),r=i&&n?{oldRange:i,newRange:n}:void 0;F.call(this,(()=>{const i=(new(s())).retain(e.offset(this)).retain({[e.statics.blotName]:t});return this.editor.update(i,[],r)}),I.sources.USER)})),i){const e=this.clipboard.convert({html:`${i}<p><br></p>`,text:"\n"});this.setContents(e)}this.history.clear(),this.options.placeholder&&this.root.setAttribute("data-placeholder",this.options.placeholder),this.options.readOnly&&this.disable(),this.allowReadOnlyEdits=!1}addContainer(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;if("string"==typeof e){const t=e;(e=document.createElement("div")).classList.add(t)}return this.container.insertBefore(e,t),e}blur(){this.selection.setRange(null)}deleteText(e,t,i){return[e,t,,i]=R(e,t,i),F.call(this,(()=>this.editor.deleteText(e,t)),i,e,-1*t)}disable(){this.enable(!1)}editReadOnly(e){this.allowReadOnlyEdits=!0;const t=e();return this.allowReadOnlyEdits=!1,t}enable(){let e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0];this.scroll.enable(e),this.container.classList.toggle("ql-disabled",!e)}focus(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};this.selection.focus(),e.preventScroll||this.scrollSelectionIntoView()}format(e,t){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:w.A.sources.API;return F.call(this,(()=>{const i=this.getSelection(!0);let n=new(s());if(null==i)return n;if(this.scroll.query(e,r.Scope.BLOCK))n=this.editor.formatLine(i.index,i.length,{[e]:t});else{if(0===i.length)return this.selection.format(e,t),n;n=this.editor.formatText(i.index,i.length,{[e]:t})}return this.setSelection(i,w.A.sources.SILENT),n}),i)}formatLine(e,t,i,n,r){let a;return[e,t,a,r]=R(e,t,i,n,r),F.call(this,(()=>this.editor.formatLine(e,t,a)),r,e,0)}formatText(e,t,i,n,r){let a;return[e,t,a,r]=R(e,t,i,n,r),F.call(this,(()=>this.editor.formatText(e,t,a)),r,e,0)}getBounds(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,i=null;if(i="number"==typeof e?this.selection.getBounds(e,t):this.selection.getBounds(e.index,e.length),!i)return null;const n=this.container.getBoundingClientRect();return{bottom:i.bottom-n.top,height:i.height,left:i.left-n.left,right:i.right-n.left,top:i.top-n.top,width:i.width}}getContents(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0,t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:this.getLength()-e;return[e,t]=R(e,t),this.editor.getContents(e,t)}getFormat(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:this.getSelection(!0),t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0;return"number"==typeof e?this.editor.getFormat(e,t):this.editor.getFormat(e.index,e.length)}getIndex(e){return e.offset(this.scroll)}getLength(){return this.scroll.length()}getLeaf(e){return this.scroll.leaf(e)}getLine(e){return this.scroll.line(e)}getLines(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0,t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Number.MAX_VALUE;return"number"!=typeof e?this.scroll.lines(e.index,e.length):this.scroll.lines(e,t)}getModule(e){return this.theme.modules[e]}getSelection(){return arguments.length>0&&void 0!==arguments[0]&&arguments[0]&&this.focus(),this.update(),this.selection.getRange()[0]}getSemanticHTML(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0,t=arguments.length>1?arguments[1]:void 0;return"number"==typeof e&&(t=t??this.getLength()-e),[e,t]=R(e,t),this.editor.getHTML(e,t)}getText(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0,t=arguments.length>1?arguments[1]:void 0;return"number"==typeof e&&(t=t??this.getLength()-e),[e,t]=R(e,t),this.editor.getText(e,t)}hasFocus(){return this.selection.hasFocus()}insertEmbed(e,t,i){let n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:I.sources.API;return F.call(this,(()=>this.editor.insertEmbed(e,t,i)),n,e)}insertText(e,t,i,n,r){let a;return[e,,a,r]=R(e,0,i,n,r),F.call(this,(()=>this.editor.insertText(e,t,a)),r,e,t.length)}isEnabled(){return this.scroll.isEnabled()}off(){return this.emitter.off(...arguments)}on(){return this.emitter.on(...arguments)}once(){return this.emitter.once(...arguments)}removeFormat(e,t,i){return[e,t,,i]=R(e,t,i),F.call(this,(()=>this.editor.removeFormat(e,t)),i,e)}scrollRectIntoView(e){((e,t)=>{const i=e.ownerDocument;let n=t,r=e;for(;r;){const e=r===i.body,t=e?{top:0,right:window.visualViewport?.width??i.documentElement.clientWidth,bottom:window.visualViewport?.height??i.documentElement.clientHeight,left:0}:C(r),s=getComputedStyle(r),o=E(n.left,n.right,t.left,t.right,D(s.scrollPaddingLeft),D(s.scrollPaddingRight)),l=E(n.top,n.bottom,t.top,t.bottom,D(s.scrollPaddingTop),D(s.scrollPaddingBottom));if(o||l)if(e)i.defaultView?.scrollBy(o,l);else{const{scrollLeft:e,scrollTop:t}=r;l&&(r.scrollTop+=l),o&&(r.scrollLeft+=o);const i=r.scrollLeft-e,a=r.scrollTop-t;n={left:n.left-i,top:n.top-a,right:n.right-i,bottom:n.bottom-a}}r=e||"fixed"===s.position?null:(a=r).parentElement||a.getRootNode().host||null}var a})(this.root,e)}scrollIntoView(){console.warn("Quill#scrollIntoView() has been deprecated and will be removed in the near future. Please use Quill#scrollSelectionIntoView() instead."),this.scrollSelectionIntoView()}scrollSelectionIntoView(){const e=this.selection.lastRange,t=e&&this.selection.getBounds(e.index,e.length);t&&this.scrollRectIntoView(t)}setContents(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:w.A.sources.API;return F.call(this,(()=>{e=new(s())(e);const t=this.getLength(),i=this.editor.deleteText(0,t),n=this.editor.insertContents(0,e),r=this.editor.deleteText(this.getLength()-1,1);return i.compose(n).compose(r)}),t)}setSelection(e,t,i){null==e?this.selection.setRange(null,t||I.sources.API):([e,t,,i]=R(e,t,i),this.selection.setRange(new f.Q(Math.max(0,e),t),i),i!==w.A.sources.SILENT&&this.scrollSelectionIntoView())}setText(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:w.A.sources.API;const i=(new(s())).insert(e);return this.setContents(i,t)}update(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:w.A.sources.USER;const t=this.scroll.update(e);return this.selection.update(e),t}updateContents(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:w.A.sources.API;return F.call(this,(()=>(e=new(s())(e),this.editor.applyDelta(e))),t,!0)}}function N(e){return"string"==typeof e?document.querySelector(e):e}function j(e){return Object.entries(e??{}).reduce(((e,t)=>{let[i,n]=t;return{...e,[i]:!0===n?{}:n}}),{})}function H(e){return Object.fromEntries(Object.entries(e).filter((e=>void 0!==e[1])))}function F(e,t,i,n){if(!this.isEnabled()&&t===w.A.sources.USER&&!this.allowReadOnlyEdits)return new(s());let r=null==i?null:this.getSelection();const a=this.editor.delta,o=e();if(null!=r&&(!0===i&&(i=r.index),null==n?r=z(r,o,t):0!==n&&(r=z(r,i,n,t)),this.setSelection(r,w.A.sources.SILENT)),o.length()>0){const e=[w.A.events.TEXT_CHANGE,o,a,t];this.emitter.emit(w.A.events.EDITOR_CHANGE,...e),t!==w.A.sources.SILENT&&this.emitter.emit(...e)}return o}function R(e,t,i,n,r){let a={};return"number"==typeof e.index&&"number"==typeof e.length?"number"!=typeof t?(r=n,n=i,i=t,t=e.length,e=e.index):(t=e.length,e=e.index):"number"!=typeof t&&(r=n,n=i,i=t,t=0),"object"==typeof i?(a=i,r=n):"string"==typeof i&&(null!=n?a[i]=n:r=i),[e,t,a,r=r||w.A.sources.API]}function z(e,t,i,n){const r="number"==typeof i?i:0;if(null==e)return null;let a,s;return t&&"function"==typeof t.transformPosition?[a,s]=[e.index,e.index+e.length].map((e=>t.transformPosition(e,n!==w.A.sources.USER))):[a,s]=[e.index,e.index+e.length].map((e=>e<t||e===t&&n===w.A.sources.USER?e:r>=0?e+r:Math.max(t,e+r))),new f.Q(a,s-a)}},8298:function(e,t,i){"use strict";i.d(t,{Q:function(){return l}});var n=i(6003),r=i(5123),a=i(3707),s=i(5374);const o=(0,i(6078).A)("quill:selection");class l{constructor(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0;this.index=e,this.length=t}}function c(e,t){try{t.parentNode}catch(e){return!1}return e.contains(t)}t.A=class{constructor(e,t){this.emitter=t,this.scroll=e,this.composing=!1,this.mouseDown=!1,this.root=this.scroll.domNode,this.cursor=this.scroll.create("cursor",this),this.savedRange=new l(0,0),this.lastRange=this.savedRange,this.lastNative=null,this.handleComposition(),this.handleDragging(),this.emitter.listenDOM("selectionchange",document,(()=>{this.mouseDown||this.composing||setTimeout(this.update.bind(this,s.A.sources.USER),1)})),this.emitter.on(s.A.events.SCROLL_BEFORE_UPDATE,(()=>{if(!this.hasFocus())return;const e=this.getNativeRange();null!=e&&e.start.node!==this.cursor.textNode&&this.emitter.once(s.A.events.SCROLL_UPDATE,((t,i)=>{try{this.root.contains(e.start.node)&&this.root.contains(e.end.node)&&this.setNativeRange(e.start.node,e.start.offset,e.end.node,e.end.offset);const n=i.some((e=>"characterData"===e.type||"childList"===e.type||"attributes"===e.type&&e.target===this.root));this.update(n?s.A.sources.SILENT:t)}catch(e){}}))})),this.emitter.on(s.A.events.SCROLL_OPTIMIZE,((e,t)=>{if(t.range){const{startNode:e,startOffset:i,endNode:n,endOffset:r}=t.range;this.setNativeRange(e,i,n,r),this.update(s.A.sources.SILENT)}})),this.update(s.A.sources.SILENT)}handleComposition(){this.emitter.on(s.A.events.COMPOSITION_BEFORE_START,(()=>{this.composing=!0})),this.emitter.on(s.A.events.COMPOSITION_END,(()=>{if(this.composing=!1,this.cursor.parent){const e=this.cursor.restore();if(!e)return;setTimeout((()=>{this.setNativeRange(e.startNode,e.startOffset,e.endNode,e.endOffset)}),1)}}))}handleDragging(){this.emitter.listenDOM("mousedown",document.body,(()=>{this.mouseDown=!0})),this.emitter.listenDOM("mouseup",document.body,(()=>{this.mouseDown=!1,this.update(s.A.sources.USER)}))}focus(){this.hasFocus()||(this.root.focus({preventScroll:!0}),this.setRange(this.savedRange))}format(e,t){this.scroll.update();const i=this.getNativeRange();if(null!=i&&i.native.collapsed&&!this.scroll.query(e,n.Scope.BLOCK)){if(i.start.node!==this.cursor.textNode){const e=this.scroll.find(i.start.node,!1);if(null==e)return;if(e instanceof n.LeafBlot){const t=e.split(i.start.offset);e.parent.insertBefore(this.cursor,t)}else e.insertBefore(this.cursor,i.start.node);this.cursor.attach()}this.cursor.format(e,t),this.scroll.optimize(),this.setNativeRange(this.cursor.textNode,this.cursor.textNode.data.length),this.update()}}getBounds(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0;const i=this.scroll.length();let n;e=Math.min(e,i-1),t=Math.min(e+t,i-1)-e;let[r,a]=this.scroll.leaf(e);if(null==r)return null;if(t>0&&a===r.length()){const[t]=this.scroll.leaf(e+1);if(t){const[i]=this.scroll.line(e),[n]=this.scroll.line(e+1);i===n&&(r=t,a=0)}}[n,a]=r.position(a,!0);const s=document.createRange();if(t>0)return s.setStart(n,a),[r,a]=this.scroll.leaf(e+t),null==r?null:([n,a]=r.position(a,!0),s.setEnd(n,a),s.getBoundingClientRect());let o,l="left";if(n instanceof Text){if(!n.data.length)return null;a<n.data.length?(s.setStart(n,a),s.setEnd(n,a+1)):(s.setStart(n,a-1),s.setEnd(n,a),l="right"),o=s.getBoundingClientRect()}else{if(!(r.domNode instanceof Element))return null;o=r.domNode.getBoundingClientRect(),a>0&&(l="right")}return{bottom:o.top+o.height,height:o.height,left:o[l],right:o[l],top:o.top,width:0}}getNativeRange(){const e=document.getSelection();if(null==e||e.rangeCount<=0)return null;const t=e.getRangeAt(0);if(null==t)return null;const i=this.normalizeNative(t);return o.info("getNativeRange",i),i}getRange(){const e=this.scroll.domNode;if("isConnected"in e&&!e.isConnected)return[null,null];const t=this.getNativeRange();return null==t?[null,null]:[this.normalizedToRange(t),t]}hasFocus(){return document.activeElement===this.root||null!=document.activeElement&&c(this.root,document.activeElement)}normalizedToRange(e){const t=[[e.start.node,e.start.offset]];e.native.collapsed||t.push([e.end.node,e.end.offset]);const i=t.map((e=>{const[t,i]=e,r=this.scroll.find(t,!0),a=r.offset(this.scroll);return 0===i?a:r instanceof n.LeafBlot?a+r.index(t,i):a+r.length()})),r=Math.min(Math.max(...i),this.scroll.length()-1),a=Math.min(r,...i);return new l(a,r-a)}normalizeNative(e){if(!c(this.root,e.startContainer)||!e.collapsed&&!c(this.root,e.endContainer))return null;const t={start:{node:e.startContainer,offset:e.startOffset},end:{node:e.endContainer,offset:e.endOffset},native:e};return[t.start,t.end].forEach((e=>{let{node:t,offset:i}=e;for(;!(t instanceof Text)&&t.childNodes.length>0;)if(t.childNodes.length>i)t=t.childNodes[i],i=0;else{if(t.childNodes.length!==i)break;t=t.lastChild,i=t instanceof Text?t.data.length:t.childNodes.length>0?t.childNodes.length:t.childNodes.length+1}e.node=t,e.offset=i})),t}rangeToNative(e){const t=this.scroll.length(),i=(e,i)=>{e=Math.min(t-1,e);const[n,r]=this.scroll.leaf(e);return n?n.position(r,i):[null,-1]};return[...i(e.index,!1),...i(e.index+e.length,!0)]}setNativeRange(e,t){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:e,n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:t,r=arguments.length>4&&void 0!==arguments[4]&&arguments[4];if(o.info("setNativeRange",e,t,i,n),null!=e&&(null==this.root.parentNode||null==e.parentNode||null==i.parentNode))return;const a=document.getSelection();if(null!=a)if(null!=e){this.hasFocus()||this.root.focus({preventScroll:!0});const{native:s}=this.getNativeRange()||{};if(null==s||r||e!==s.startContainer||t!==s.startOffset||i!==s.endContainer||n!==s.endOffset){e instanceof Element&&"BR"===e.tagName&&(t=Array.from(e.parentNode.childNodes).indexOf(e),e=e.parentNode),i instanceof Element&&"BR"===i.tagName&&(n=Array.from(i.parentNode.childNodes).indexOf(i),i=i.parentNode);const r=document.createRange();r.setStart(e,t),r.setEnd(i,n),a.removeAllRanges(),a.addRange(r)}}else a.removeAllRanges(),this.root.blur()}setRange(e){let t=arguments.length>1&&void 0!==arguments[1]&&arguments[1],i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:s.A.sources.API;if("string"==typeof t&&(i=t,t=!1),o.info("setRange",e),null!=e){const i=this.rangeToNative(e);this.setNativeRange(...i,t)}else this.setNativeRange(null);this.update(i)}update(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:s.A.sources.USER;const t=this.lastRange,[i,n]=this.getRange();if(this.lastRange=i,this.lastNative=n,null!=this.lastRange&&(this.savedRange=this.lastRange),!(0,r.A)(t,this.lastRange)){if(!this.composing&&null!=n&&n.native.collapsed&&n.start.node!==this.cursor.textNode){const e=this.cursor.restore();e&&this.setNativeRange(e.startNode,e.startOffset,e.endNode,e.endOffset)}const i=[s.A.events.SELECTION_CHANGE,(0,a.A)(this.lastRange),(0,a.A)(t),e];this.emitter.emit(s.A.events.EDITOR_CHANGE,...i),e!==s.A.sources.SILENT&&this.emitter.emit(...i)}}}},9609:function(e,t){"use strict";class i{static DEFAULTS={modules:{}};static themes={default:i};modules={};constructor(e,t){this.quill=e,this.options=t}init(){Object.keys(this.options.modules).forEach((e=>{null==this.modules[e]&&this.addModule(e)}))}addModule(e){const t=this.quill.constructor.import(`modules/${e}`);return this.modules[e]=new t(this.quill,this.options.modules[e]||{}),this.modules[e]}}t.A=i},8276:function(e,t,i){"use strict";i.d(t,{Hu:function(){return o},gS:function(){return a},qh:function(){return s}});var n=i(6003);const r={scope:n.Scope.BLOCK,whitelist:["right","center","justify"]},a=new n.Attributor("align","align",r),s=new n.ClassAttributor("align","ql-align",r),o=new n.StyleAttributor("align","text-align",r)},9541:function(e,t,i){"use strict";i.d(t,{l:function(){return a},s:function(){return s}});var n=i(6003),r=i(8638);const a=new n.ClassAttributor("background","ql-bg",{scope:n.Scope.INLINE}),s=new r.a2("background","background-color",{scope:n.Scope.INLINE})},9404:function(e,t,i){"use strict";i.d(t,{Ay:function(){return d},Cy:function(){return h},EJ:function(){return u}});var n=i(9698),r=i(3036),a=i(4541),s=i(4850),o=i(5508),l=i(580),c=i(6142);class u extends l.A{static create(e){const t=super.create(e);return t.setAttribute("spellcheck","false"),t}code(e,t){return this.children.map((e=>e.length()<=1?"":e.domNode.innerText)).join("\n").slice(e,e+t)}html(e,t){return`<pre>\n${(0,o.X)(this.code(e,t))}\n</pre>`}}class d extends n.Ay{static TAB="  ";static register(){c.Ay.register(u)}}class h extends s.A{}h.blotName="code",h.tagName="CODE",d.blotName="code-block",d.className="ql-code-block",d.tagName="DIV",u.blotName="code-block-container",u.className="ql-code-block-container",u.tagName="DIV",u.allowedChildren=[d],d.allowedChildren=[o.A,r.A,a.A],d.requiredContainer=u},8638:function(e,t,i){"use strict";i.d(t,{JM:function(){return s},a2:function(){return r},g3:function(){return a}});var n=i(6003);class r extends n.StyleAttributor{value(e){let t=super.value(e);return t.startsWith("rgb(")?(t=t.replace(/^[^\d]+/,"").replace(/[^\d]+$/,""),`#${t.split(",").map((e=>`00${parseInt(e,10).toString(16)}`.slice(-2))).join("")}`):t}}const a=new n.ClassAttributor("color","ql-color",{scope:n.Scope.INLINE}),s=new r("color","color",{scope:n.Scope.INLINE})},7912:function(e,t,i){"use strict";i.d(t,{Mc:function(){return a},VL:function(){return o},sY:function(){return s}});var n=i(6003);const r={scope:n.Scope.BLOCK,whitelist:["rtl"]},a=new n.Attributor("direction","dir",r),s=new n.ClassAttributor("direction","ql-direction",r),o=new n.StyleAttributor("direction","direction",r)},6772:function(e,t,i){"use strict";i.d(t,{q:function(){return a},z:function(){return o}});var n=i(6003);const r={scope:n.Scope.INLINE,whitelist:["serif","monospace"]},a=new n.ClassAttributor("font","ql-font",r);class s extends n.StyleAttributor{value(e){return super.value(e).replace(/["']/g,"")}}const o=new s("font","font-family",r)},664:function(e,t,i){"use strict";i.d(t,{U:function(){return r},r:function(){return a}});var n=i(6003);const r=new n.ClassAttributor("size","ql-size",{scope:n.Scope.INLINE,whitelist:["small","large","huge"]}),a=new n.StyleAttributor("size","font-size",{scope:n.Scope.INLINE,whitelist:["10px","18px","32px"]})},584:function(e,t,i){"use strict";i.d(t,{Ay:function(){return C},hV:function(){return I}});var n=i(6003),r=i(5232),a=i.n(r),s=i(9698),o=i(6078),l=i(4266),c=i(6142),u=i(8276),d=i(9541),h=i(9404),f=i(8638),p=i(7912),m=i(6772),g=i(664),v=i(8123);const y=/font-weight:\s*normal/,b=["P","OL","UL"],x=e=>e&&b.includes(e.tagName),_=/\bmso-list:[^;]*ignore/i,w=/\bmso-list:[^;]*\bl(\d+)/i,k=/\bmso-list:[^;]*\blevel(\d+)/i,M=[function(e){"urn:schemas-microsoft-com:office:word"===e.documentElement.getAttribute("xmlns:w")&&(e=>{const t=Array.from(e.querySelectorAll("[style*=mso-list]")),i=[],n=[];t.forEach((e=>{(e.getAttribute("style")||"").match(_)?i.push(e):n.push(e)})),i.forEach((e=>e.parentNode?.removeChild(e)));const r=e.documentElement.innerHTML,a=n.map((e=>((e,t)=>{const i=e.getAttribute("style"),n=i?.match(w);if(!n)return null;const r=Number(n[1]),a=i?.match(k),s=a?Number(a[1]):1,o=new RegExp(`@list l${r}:level${s}\\s*\\{[^\\}]*mso-level-number-format:\\s*([\\w-]+)`,"i"),l=t.match(o);return{id:r,indent:s,type:l&&"bullet"===l[1]?"bullet":"ordered",element:e}})(e,r))).filter((e=>e));for(;a.length;){const e=[];let t=a.shift();for(;t;)e.push(t),t=a.length&&a[0]?.element===t.element.nextElementSibling&&a[0].id===t.id?a.shift():null;const i=document.createElement("ul");e.forEach((e=>{const t=document.createElement("li");t.setAttribute("data-list",e.type),e.indent>1&&t.setAttribute("class","ql-indent-"+(e.indent-1)),t.innerHTML=e.element.innerHTML,i.appendChild(t)}));const n=e[0]?.element,{parentNode:r}=n??{};n&&r?.replaceChild(i,n),e.slice(1).forEach((e=>{let{element:t}=e;r?.removeChild(t)}))}})(e)},function(e){e.querySelector('[id^="docs-internal-guid-"]')&&((e=>{Array.from(e.querySelectorAll('b[style*="font-weight"]')).filter((e=>e.getAttribute("style")?.match(y))).forEach((t=>{const i=e.createDocumentFragment();i.append(...t.childNodes),t.parentNode?.replaceChild(i,t)}))})(e),(e=>{Array.from(e.querySelectorAll("br")).filter((e=>x(e.previousElementSibling)&&x(e.nextElementSibling))).forEach((e=>{e.parentNode?.removeChild(e)}))})(e))}],S=(0,o.A)("quill:clipboard"),A=[[Node.TEXT_NODE,function(e,t,i){let n=e.data;if("O:P"===e.parentElement?.tagName)return t.insert(n.trim());if(!Y(e)){if(0===n.trim().length&&n.includes("\n")&&!function(e,t){return e.previousElementSibling&&e.nextElementSibling&&!O(e.previousElementSibling,t)&&!O(e.nextElementSibling,t)}(e,i))return t;const r=(e,t)=>{const i=t.replace(/[^\u00a0]/g,"");return i.length<1&&e?" ":i};n=n.replace(/\r\n/g," ").replace(/\n/g," "),n=n.replace(/\s\s+/g,r.bind(r,!0)),(null==e.previousSibling&&null!=e.parentElement&&O(e.parentElement,i)||e.previousSibling instanceof Element&&O(e.previousSibling,i))&&(n=n.replace(/^\s+/,r.bind(r,!1))),(null==e.nextSibling&&null!=e.parentElement&&O(e.parentElement,i)||e.nextSibling instanceof Element&&O(e.nextSibling,i))&&(n=n.replace(/\s+$/,r.bind(r,!1)))}return t.insert(n)}],[Node.TEXT_NODE,j],["br",function(e,t){return E(t,"\n")||t.insert("\n"),t}],[Node.ELEMENT_NODE,j],[Node.ELEMENT_NODE,function(e,t,i){const r=i.query(e);if(null==r)return t;if(r.prototype instanceof n.EmbedBlot){const t={},n=r.value(e);if(null!=n)return t[r.blotName]=n,(new(a())).insert(t,r.formats(e,i))}else if(r.prototype instanceof n.BlockBlot&&!E(t,"\n")&&t.insert("\n"),"blotName"in r&&"formats"in r&&"function"==typeof r.formats)return D(t,r.blotName,r.formats(e,i),i);return t}],[Node.ELEMENT_NODE,function(e,t,i){const r=n.Attributor.keys(e),a=n.ClassAttributor.keys(e),s=n.StyleAttributor.keys(e),o={};return r.concat(a).concat(s).forEach((t=>{let r=i.query(t,n.Scope.ATTRIBUTE);null!=r&&(o[r.attrName]=r.value(e),o[r.attrName])||(r=L[t],null==r||r.attrName!==t&&r.keyName!==t||(o[r.attrName]=r.value(e)||void 0),r=T[t],null==r||r.attrName!==t&&r.keyName!==t||(r=T[t],o[r.attrName]=r.value(e)||void 0))})),Object.entries(o).reduce(((e,t)=>{let[n,r]=t;return D(e,n,r,i)}),t)}],[Node.ELEMENT_NODE,function(e,t,i){const n={},r=e.style||{};return"italic"===r.fontStyle&&(n.italic=!0),"underline"===r.textDecoration&&(n.underline=!0),"line-through"===r.textDecoration&&(n.strike=!0),(r.fontWeight?.startsWith("bold")||parseInt(r.fontWeight,10)>=700)&&(n.bold=!0),t=Object.entries(n).reduce(((e,t)=>{let[n,r]=t;return D(e,n,r,i)}),t),parseFloat(r.textIndent||0)>0?(new(a())).insert("\t").concat(t):t}],["li",function(e,t,i){const n=i.query(e);if(null==n||"list"!==n.blotName||!E(t,"\n"))return t;let r=-1,s=e.parentNode;for(;null!=s;)["OL","UL"].includes(s.tagName)&&(r+=1),s=s.parentNode;return r<=0?t:t.reduce(((e,t)=>t.insert?t.attributes&&"number"==typeof t.attributes.indent?e.push(t):e.insert(t.insert,{indent:r,...t.attributes||{}}):e),new(a()))}],["ol, ul",function(e,t,i){const n=e;let r="OL"===n.tagName?"ordered":"bullet";const a=n.getAttribute("data-checked");return a&&(r="true"===a?"checked":"unchecked"),D(t,"list",r,i)}],["pre",function(e,t,i){const n=i.query("code-block");return D(t,"code-block",!n||!("formats"in n)||"function"!=typeof n.formats||n.formats(e,i),i)}],["tr",function(e,t,i){const n="TABLE"===e.parentElement?.tagName?e.parentElement:e.parentElement?.parentElement;return null!=n?D(t,"table",Array.from(n.querySelectorAll("tr")).indexOf(e)+1,i):t}],["b",N("bold")],["i",N("italic")],["strike",N("strike")],["style",function(){return new(a())}]],L=[u.gS,p.Mc].reduce(((e,t)=>(e[t.keyName]=t,e)),{}),T=[u.Hu,d.s,f.JM,p.VL,m.z,g.r].reduce(((e,t)=>(e[t.keyName]=t,e)),{});class C extends l.A{static DEFAULTS={matchers:[]};constructor(e,t){super(e,t),this.quill.root.addEventListener("copy",(e=>this.onCaptureCopy(e,!1))),this.quill.root.addEventListener("cut",(e=>this.onCaptureCopy(e,!0))),this.quill.root.addEventListener("paste",this.onCapturePaste.bind(this)),this.matchers=[],A.concat(this.options.matchers??[]).forEach((e=>{let[t,i]=e;this.addMatcher(t,i)}))}addMatcher(e,t){this.matchers.push([e,t])}convert(e){let{html:t,text:i}=e,n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};if(n[h.Ay.blotName])return(new(a())).insert(i||"",{[h.Ay.blotName]:n[h.Ay.blotName]});if(!t)return(new(a())).insert(i||"",n);const r=this.convertHTML(t);return E(r,"\n")&&(null==r.ops[r.ops.length-1].attributes||n.table)?r.compose((new(a())).retain(r.length()-1).delete(1)):r}normalizeHTML(e){(e=>{e.documentElement&&M.forEach((t=>{t(e)}))})(e)}convertHTML(e){const t=(new DOMParser).parseFromString(e,"text/html");this.normalizeHTML(t);const i=t.body,n=new WeakMap,[r,a]=this.prepareMatching(i,n);return I(this.quill.scroll,i,r,a,n)}dangerouslyPasteHTML(e,t){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:c.Ay.sources.API;if("string"==typeof e){const i=this.convert({html:e,text:""});this.quill.setContents(i,t),this.quill.setSelection(0,c.Ay.sources.SILENT)}else{const n=this.convert({html:t,text:""});this.quill.updateContents((new(a())).retain(e).concat(n),i),this.quill.setSelection(e+n.length(),c.Ay.sources.SILENT)}}onCaptureCopy(e){let t=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(e.defaultPrevented)return;e.preventDefault();const[i]=this.quill.selection.getRange();if(null==i)return;const{html:n,text:r}=this.onCopy(i,t);e.clipboardData?.setData("text/plain",r),e.clipboardData?.setData("text/html",n),t&&(0,v.Xo)({range:i,quill:this.quill})}normalizeURIList(e){return e.split(/\r?\n/).filter((e=>"#"!==e[0])).join("\n")}onCapturePaste(e){if(e.defaultPrevented||!this.quill.isEnabled())return;e.preventDefault();const t=this.quill.getSelection(!0);if(null==t)return;const i=e.clipboardData?.getData("text/html");let n=e.clipboardData?.getData("text/plain");if(!i&&!n){const t=e.clipboardData?.getData("text/uri-list");t&&(n=this.normalizeURIList(t))}const r=Array.from(e.clipboardData?.files||[]);if(!i&&r.length>0)this.quill.uploader.upload(t,r);else{if(i&&r.length>0){const e=(new DOMParser).parseFromString(i,"text/html");if(1===e.body.childElementCount&&"IMG"===e.body.firstElementChild?.tagName)return void this.quill.uploader.upload(t,r)}this.onPaste(t,{html:i,text:n})}}onCopy(e){const t=this.quill.getText(e);return{html:this.quill.getSemanticHTML(e),text:t}}onPaste(e,t){let{text:i,html:n}=t;const r=this.quill.getFormat(e.index),s=this.convert({text:i,html:n},r);S.log("onPaste",s,{text:i,html:n});const o=(new(a())).retain(e.index).delete(e.length).concat(s);this.quill.updateContents(o,c.Ay.sources.USER),this.quill.setSelection(o.length()-e.length,c.Ay.sources.SILENT),this.quill.scrollSelectionIntoView()}prepareMatching(e,t){const i=[],n=[];return this.matchers.forEach((r=>{const[a,s]=r;switch(a){case Node.TEXT_NODE:n.push(s);break;case Node.ELEMENT_NODE:i.push(s);break;default:Array.from(e.querySelectorAll(a)).forEach((e=>{if(t.has(e)){const i=t.get(e);i?.push(s)}else t.set(e,[s])}))}})),[i,n]}}function D(e,t,i,n){return n.query(t)?e.reduce(((e,n)=>{if(!n.insert)return e;if(n.attributes&&n.attributes[t])return e.push(n);const r=i?{[t]:i}:{};return e.insert(n.insert,{...r,...n.attributes})}),new(a())):e}function E(e,t){let i="";for(let n=e.ops.length-1;n>=0&&i.length<t.length;--n){const t=e.ops[n];if("string"!=typeof t.insert)break;i=t.insert+i}return i.slice(-1*t.length)===t}function O(e,t){if(!(e instanceof Element))return!1;const i=t.query(e);return!(i&&i.prototype instanceof n.EmbedBlot)&&["address","article","blockquote","canvas","dd","div","dl","dt","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","iframe","li","main","nav","ol","output","p","pre","section","table","td","tr","ul","video"].includes(e.tagName.toLowerCase())}const P=new WeakMap;function Y(e){return null!=e&&(P.has(e)||("PRE"===e.tagName?P.set(e,!0):P.set(e,Y(e.parentNode))),P.get(e))}function I(e,t,i,n,r){return t.nodeType===t.TEXT_NODE?n.reduce(((i,n)=>n(t,i,e)),new(a())):t.nodeType===t.ELEMENT_NODE?Array.from(t.childNodes||[]).reduce(((a,s)=>{let o=I(e,s,i,n,r);return s.nodeType===t.ELEMENT_NODE&&(o=i.reduce(((t,i)=>i(s,t,e)),o),o=(r.get(s)||[]).reduce(((t,i)=>i(s,t,e)),o)),a.concat(o)}),new(a())):new(a())}function N(e){return(t,i,n)=>D(i,e,!0,n)}function j(e,t,i){if(!E(t,"\n")){if(O(e,i)&&(e.childNodes.length>0||e instanceof HTMLParagraphElement))return t.insert("\n");if(t.length()>0&&e.nextSibling){let n=e.nextSibling;for(;null!=n;){if(O(n,i))return t.insert("\n");const e=i.query(n);if(e&&e.prototype instanceof s.zo)return t.insert("\n");n=n.firstChild}}}return t}},8123:function(e,t,i){"use strict";i.d(t,{Ay:function(){return f},Xo:function(){return b}});var n=i(5123),r=i(3707),a=i(5232),s=i.n(a),o=i(6003),l=i(6142),c=i(6078),u=i(4266);const d=(0,c.A)("quill:keyboard"),h=/Mac/i.test(navigator.platform)?"metaKey":"ctrlKey";class f extends u.A{static match(e,t){return!["altKey","ctrlKey","metaKey","shiftKey"].some((i=>!!t[i]!==e[i]&&null!==t[i]))&&(t.key===e.key||t.key===e.which)}constructor(e,t){super(e,t),this.bindings={},Object.keys(this.options.bindings).forEach((e=>{this.options.bindings[e]&&this.addBinding(this.options.bindings[e])})),this.addBinding({key:"Enter",shiftKey:null},this.handleEnter),this.addBinding({key:"Enter",metaKey:null,ctrlKey:null,altKey:null},(()=>{})),/Firefox/i.test(navigator.userAgent)?(this.addBinding({key:"Backspace"},{collapsed:!0},this.handleBackspace),this.addBinding({key:"Delete"},{collapsed:!0},this.handleDelete)):(this.addBinding({key:"Backspace"},{collapsed:!0,prefix:/^.?$/},this.handleBackspace),this.addBinding({key:"Delete"},{collapsed:!0,suffix:/^.?$/},this.handleDelete)),this.addBinding({key:"Backspace"},{collapsed:!1},this.handleDeleteRange),this.addBinding({key:"Delete"},{collapsed:!1},this.handleDeleteRange),this.addBinding({key:"Backspace",altKey:null,ctrlKey:null,metaKey:null,shiftKey:null},{collapsed:!0,offset:0},this.handleBackspace),this.listen()}addBinding(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};const n=function(e){if("string"==typeof e||"number"==typeof e)e={key:e};else{if("object"!=typeof e)return null;e=(0,r.A)(e)}return e.shortKey&&(e[h]=e.shortKey,delete e.shortKey),e}(e);null!=n?("function"==typeof t&&(t={handler:t}),"function"==typeof i&&(i={handler:i}),(Array.isArray(n.key)?n.key:[n.key]).forEach((e=>{const r={...n,key:e,...t,...i};this.bindings[r.key]=this.bindings[r.key]||[],this.bindings[r.key].push(r)}))):d.warn("Attempted to add invalid keyboard binding",n)}listen(){this.quill.root.addEventListener("keydown",(e=>{if(e.defaultPrevented||e.isComposing)return;if(229===e.keyCode&&("Enter"===e.key||"Backspace"===e.key))return;const t=(this.bindings[e.key]||[]).concat(this.bindings[e.which]||[]).filter((t=>f.match(e,t)));if(0===t.length)return;const i=l.Ay.find(e.target,!0);if(i&&i.scroll!==this.quill.scroll)return;const r=this.quill.getSelection();if(null==r||!this.quill.hasFocus())return;const[a,s]=this.quill.getLine(r.index),[c,u]=this.quill.getLeaf(r.index),[d,h]=0===r.length?[c,u]:this.quill.getLeaf(r.index+r.length),p=c instanceof o.TextBlot?c.value().slice(0,u):"",m=d instanceof o.TextBlot?d.value().slice(h):"",g={collapsed:0===r.length,empty:0===r.length&&a.length()<=1,format:this.quill.getFormat(r),line:a,offset:s,prefix:p,suffix:m,event:e};t.some((e=>{if(null!=e.collapsed&&e.collapsed!==g.collapsed)return!1;if(null!=e.empty&&e.empty!==g.empty)return!1;if(null!=e.offset&&e.offset!==g.offset)return!1;if(Array.isArray(e.format)){if(e.format.every((e=>null==g.format[e])))return!1}else if("object"==typeof e.format&&!Object.keys(e.format).every((t=>!0===e.format[t]?null!=g.format[t]:!1===e.format[t]?null==g.format[t]:(0,n.A)(e.format[t],g.format[t]))))return!1;return!(null!=e.prefix&&!e.prefix.test(g.prefix)||null!=e.suffix&&!e.suffix.test(g.suffix)||!0===e.handler.call(this,r,g,e))}))&&e.preventDefault()}))}handleBackspace(e,t){const i=/[\uD800-\uDBFF][\uDC00-\uDFFF]$/.test(t.prefix)?2:1;if(0===e.index||this.quill.getLength()<=1)return;let n={};const[r]=this.quill.getLine(e.index);let o=(new(s())).retain(e.index-i).delete(i);if(0===t.offset){const[t]=this.quill.getLine(e.index-1);if(t&&!("block"===t.statics.blotName&&t.length()<=1)){const t=r.formats(),i=this.quill.getFormat(e.index-1,1);if(n=a.AttributeMap.diff(t,i)||{},Object.keys(n).length>0){const t=(new(s())).retain(e.index+r.length()-2).retain(1,n);o=o.compose(t)}}}this.quill.updateContents(o,l.Ay.sources.USER),this.quill.focus()}handleDelete(e,t){const i=/^[\uD800-\uDBFF][\uDC00-\uDFFF]/.test(t.suffix)?2:1;if(e.index>=this.quill.getLength()-i)return;let n={};const[r]=this.quill.getLine(e.index);let o=(new(s())).retain(e.index).delete(i);if(t.offset>=r.length()-1){const[t]=this.quill.getLine(e.index+1);if(t){const i=r.formats(),s=this.quill.getFormat(e.index,1);n=a.AttributeMap.diff(i,s)||{},Object.keys(n).length>0&&(o=o.retain(t.length()-1).retain(1,n))}}this.quill.updateContents(o,l.Ay.sources.USER),this.quill.focus()}handleDeleteRange(e){b({range:e,quill:this.quill}),this.quill.focus()}handleEnter(e,t){const i=Object.keys(t.format).reduce(((e,i)=>(this.quill.scroll.query(i,o.Scope.BLOCK)&&!Array.isArray(t.format[i])&&(e[i]=t.format[i]),e)),{}),n=(new(s())).retain(e.index).delete(e.length).insert("\n",i);this.quill.updateContents(n,l.Ay.sources.USER),this.quill.setSelection(e.index+1,l.Ay.sources.SILENT),this.quill.focus()}}const p={bindings:{bold:v("bold"),italic:v("italic"),underline:v("underline"),indent:{key:"Tab",format:["blockquote","indent","list"],handler(e,t){return!(!t.collapsed||0===t.offset)||(this.quill.format("indent","+1",l.Ay.sources.USER),!1)}},outdent:{key:"Tab",shiftKey:!0,format:["blockquote","indent","list"],handler(e,t){return!(!t.collapsed||0===t.offset)||(this.quill.format("indent","-1",l.Ay.sources.USER),!1)}},"outdent backspace":{key:"Backspace",collapsed:!0,shiftKey:null,metaKey:null,ctrlKey:null,altKey:null,format:["indent","list"],offset:0,handler(e,t){null!=t.format.indent?this.quill.format("indent","-1",l.Ay.sources.USER):null!=t.format.list&&this.quill.format("list",!1,l.Ay.sources.USER)}},"indent code-block":m(!0),"outdent code-block":m(!1),"remove tab":{key:"Tab",shiftKey:!0,collapsed:!0,prefix:/\t$/,handler(e){this.quill.deleteText(e.index-1,1,l.Ay.sources.USER)}},tab:{key:"Tab",handler(e,t){if(t.format.table)return!0;this.quill.history.cutoff();const i=(new(s())).retain(e.index).delete(e.length).insert("\t");return this.quill.updateContents(i,l.Ay.sources.USER),this.quill.history.cutoff(),this.quill.setSelection(e.index+1,l.Ay.sources.SILENT),!1}},"blockquote empty enter":{key:"Enter",collapsed:!0,format:["blockquote"],empty:!0,handler(){this.quill.format("blockquote",!1,l.Ay.sources.USER)}},"list empty enter":{key:"Enter",collapsed:!0,format:["list"],empty:!0,handler(e,t){const i={list:!1};t.format.indent&&(i.indent=!1),this.quill.formatLine(e.index,e.length,i,l.Ay.sources.USER)}},"checklist enter":{key:"Enter",collapsed:!0,format:{list:"checked"},handler(e){const[t,i]=this.quill.getLine(e.index),n={...t.formats(),list:"checked"},r=(new(s())).retain(e.index).insert("\n",n).retain(t.length()-i-1).retain(1,{list:"unchecked"});this.quill.updateContents(r,l.Ay.sources.USER),this.quill.setSelection(e.index+1,l.Ay.sources.SILENT),this.quill.scrollSelectionIntoView()}},"header enter":{key:"Enter",collapsed:!0,format:["header"],suffix:/^$/,handler(e,t){const[i,n]=this.quill.getLine(e.index),r=(new(s())).retain(e.index).insert("\n",t.format).retain(i.length()-n-1).retain(1,{header:null});this.quill.updateContents(r,l.Ay.sources.USER),this.quill.setSelection(e.index+1,l.Ay.sources.SILENT),this.quill.scrollSelectionIntoView()}},"table backspace":{key:"Backspace",format:["table"],collapsed:!0,offset:0,handler(){}},"table delete":{key:"Delete",format:["table"],collapsed:!0,suffix:/^$/,handler(){}},"table enter":{key:"Enter",shiftKey:null,format:["table"],handler(e){const t=this.quill.getModule("table");if(t){const[i,n,r,a]=t.getTable(e),o=function(e,t,i,n){return null==t.prev&&null==t.next?null==i.prev&&null==i.next?0===n?-1:1:null==i.prev?-1:1:null==t.prev?-1:null==t.next?1:null}(0,n,r,a);if(null==o)return;let c=i.offset();if(o<0){const t=(new(s())).retain(c).insert("\n");this.quill.updateContents(t,l.Ay.sources.USER),this.quill.setSelection(e.index+1,e.length,l.Ay.sources.SILENT)}else if(o>0){c+=i.length();const e=(new(s())).retain(c).insert("\n");this.quill.updateContents(e,l.Ay.sources.USER),this.quill.setSelection(c,l.Ay.sources.USER)}}}},"table tab":{key:"Tab",shiftKey:null,format:["table"],handler(e,t){const{event:i,line:n}=t,r=n.offset(this.quill.scroll);i.shiftKey?this.quill.setSelection(r-1,l.Ay.sources.USER):this.quill.setSelection(r+n.length(),l.Ay.sources.USER)}},"list autofill":{key:" ",shiftKey:null,collapsed:!0,format:{"code-block":!1,blockquote:!1,table:!1},prefix:/^\s*?(\d+\.|-|\*|\[ ?\]|\[x\])$/,handler(e,t){if(null==this.quill.scroll.query("list"))return!0;const{length:i}=t.prefix,[n,r]=this.quill.getLine(e.index);if(r>i)return!0;let a;switch(t.prefix.trim()){case"[]":case"[ ]":a="unchecked";break;case"[x]":a="checked";break;case"-":case"*":a="bullet";break;default:a="ordered"}this.quill.insertText(e.index," ",l.Ay.sources.USER),this.quill.history.cutoff();const o=(new(s())).retain(e.index-r).delete(i+1).retain(n.length()-2-r).retain(1,{list:a});return this.quill.updateContents(o,l.Ay.sources.USER),this.quill.history.cutoff(),this.quill.setSelection(e.index-i,l.Ay.sources.SILENT),!1}},"code exit":{key:"Enter",collapsed:!0,format:["code-block"],prefix:/^$/,suffix:/^\s*$/,handler(e){const[t,i]=this.quill.getLine(e.index);let n=2,r=t;for(;null!=r&&r.length()<=1&&r.formats()["code-block"];)if(r=r.prev,n-=1,n<=0){const n=(new(s())).retain(e.index+t.length()-i-2).retain(1,{"code-block":null}).delete(1);return this.quill.updateContents(n,l.Ay.sources.USER),this.quill.setSelection(e.index-1,l.Ay.sources.SILENT),!1}return!0}},"embed left":g("ArrowLeft",!1),"embed left shift":g("ArrowLeft",!0),"embed right":g("ArrowRight",!1),"embed right shift":g("ArrowRight",!0),"table down":y(!1),"table up":y(!0)}};function m(e){return{key:"Tab",shiftKey:!e,format:{"code-block":!0},handler(t,i){let{event:n}=i;const r=this.quill.scroll.query("code-block"),{TAB:a}=r;if(0===t.length&&!n.shiftKey)return this.quill.insertText(t.index,a,l.Ay.sources.USER),void this.quill.setSelection(t.index+a.length,l.Ay.sources.SILENT);const s=0===t.length?this.quill.getLines(t.index,1):this.quill.getLines(t);let{index:o,length:c}=t;s.forEach(((t,i)=>{e?(t.insertAt(0,a),0===i?o+=a.length:c+=a.length):t.domNode.textContent.startsWith(a)&&(t.deleteAt(0,a.length),0===i?o-=a.length:c-=a.length)})),this.quill.update(l.Ay.sources.USER),this.quill.setSelection(o,c,l.Ay.sources.SILENT)}}}function g(e,t){return{key:e,shiftKey:t,altKey:null,["ArrowLeft"===e?"prefix":"suffix"]:/^$/,handler(i){let{index:n}=i;"ArrowRight"===e&&(n+=i.length+1);const[r]=this.quill.getLeaf(n);return!(r instanceof o.EmbedBlot&&("ArrowLeft"===e?t?this.quill.setSelection(i.index-1,i.length+1,l.Ay.sources.USER):this.quill.setSelection(i.index-1,l.Ay.sources.USER):t?this.quill.setSelection(i.index,i.length+1,l.Ay.sources.USER):this.quill.setSelection(i.index+i.length+1,l.Ay.sources.USER),1))}}}function v(e){return{key:e[0],shortKey:!0,handler(t,i){this.quill.format(e,!i.format[e],l.Ay.sources.USER)}}}function y(e){return{key:e?"ArrowUp":"ArrowDown",collapsed:!0,format:["table"],handler(t,i){const n=e?"prev":"next",r=i.line,a=r.parent[n];if(null!=a){if("table-row"===a.statics.blotName){let e=a.children.head,t=r;for(;null!=t.prev;)t=t.prev,e=e.next;const n=e.offset(this.quill.scroll)+Math.min(i.offset,e.length()-1);this.quill.setSelection(n,0,l.Ay.sources.USER)}}else{const t=r.table()[n];null!=t&&(e?this.quill.setSelection(t.offset(this.quill.scroll)+t.length()-1,0,l.Ay.sources.USER):this.quill.setSelection(t.offset(this.quill.scroll),0,l.Ay.sources.USER))}return!1}}}function b(e){let{quill:t,range:i}=e;const n=t.getLines(i);let r={};if(n.length>1){const e=n[0].formats(),t=n[n.length-1].formats();r=a.AttributeMap.diff(t,e)||{}}t.deleteText(i,l.Ay.sources.USER),Object.keys(r).length>0&&t.formatLine(i.index,1,r,l.Ay.sources.USER),t.setSelection(i.index,l.Ay.sources.SILENT)}f.DEFAULTS=p},8920:function(e){"use strict";var t=Object.prototype.hasOwnProperty,i="~";function n(){}function r(e,t,i){this.fn=e,this.context=t,this.once=i||!1}function a(e,t,n,a,s){if("function"!=typeof n)throw new TypeError("The listener must be a function");var o=new r(n,a||e,s),l=i?i+t:t;return e._events[l]?e._events[l].fn?e._events[l]=[e._events[l],o]:e._events[l].push(o):(e._events[l]=o,e._eventsCount++),e}function s(e,t){0==--e._eventsCount?e._events=new n:delete e._events[t]}function o(){this._events=new n,this._eventsCount=0}Object.create&&(n.prototype=Object.create(null),(new n).__proto__||(i=!1)),o.prototype.eventNames=function(){var e,n,r=[];if(0===this._eventsCount)return r;for(n in e=this._events)t.call(e,n)&&r.push(i?n.slice(1):n);return Object.getOwnPropertySymbols?r.concat(Object.getOwnPropertySymbols(e)):r},o.prototype.listeners=function(e){var t=i?i+e:e,n=this._events[t];if(!n)return[];if(n.fn)return[n.fn];for(var r=0,a=n.length,s=new Array(a);r<a;r++)s[r]=n[r].fn;return s},o.prototype.listenerCount=function(e){var t=i?i+e:e,n=this._events[t];return n?n.fn?1:n.length:0},o.prototype.emit=function(e,t,n,r,a,s){var o=i?i+e:e;if(!this._events[o])return!1;var l,c,u=this._events[o],d=arguments.length;if(u.fn){switch(u.once&&this.removeListener(e,u.fn,void 0,!0),d){case 1:return u.fn.call(u.context),!0;case 2:return u.fn.call(u.context,t),!0;case 3:return u.fn.call(u.context,t,n),!0;case 4:return u.fn.call(u.context,t,n,r),!0;case 5:return u.fn.call(u.context,t,n,r,a),!0;case 6:return u.fn.call(u.context,t,n,r,a,s),!0}for(c=1,l=new Array(d-1);c<d;c++)l[c-1]=arguments[c];u.fn.apply(u.context,l)}else{var h,f=u.length;for(c=0;c<f;c++)switch(u[c].once&&this.removeListener(e,u[c].fn,void 0,!0),d){case 1:u[c].fn.call(u[c].context);break;case 2:u[c].fn.call(u[c].context,t);break;case 3:u[c].fn.call(u[c].context,t,n);break;case 4:u[c].fn.call(u[c].context,t,n,r);break;default:if(!l)for(h=1,l=new Array(d-1);h<d;h++)l[h-1]=arguments[h];u[c].fn.apply(u[c].context,l)}}return!0},o.prototype.on=function(e,t,i){return a(this,e,t,i,!1)},o.prototype.once=function(e,t,i){return a(this,e,t,i,!0)},o.prototype.removeListener=function(e,t,n,r){var a=i?i+e:e;if(!this._events[a])return this;if(!t)return s(this,a),this;var o=this._events[a];if(o.fn)o.fn!==t||r&&!o.once||n&&o.context!==n||s(this,a);else{for(var l=0,c=[],u=o.length;l<u;l++)(o[l].fn!==t||r&&!o[l].once||n&&o[l].context!==n)&&c.push(o[l]);c.length?this._events[a]=1===c.length?c[0]:c:s(this,a)}return this},o.prototype.removeAllListeners=function(e){var t;return e?(t=i?i+e:e,this._events[t]&&s(this,t)):(this._events=new n,this._eventsCount=0),this},o.prototype.off=o.prototype.removeListener,o.prototype.addListener=o.prototype.on,o.prefixed=i,o.EventEmitter=o,e.exports=o},5090:function(e){var t=-1,i=1,n=0;function r(e,m,g,v,y){if(e===m)return e?[[n,e]]:[];if(null!=g){var x=function(e,t,i){var n="number"==typeof i?{index:i,length:0}:i.oldRange,r="number"==typeof i?null:i.newRange,a=e.length,s=t.length;if(0===n.length&&(null===r||0===r.length)){var o=n.index,l=e.slice(0,o),c=e.slice(o),u=r?r.index:null,d=o+s-a;if((null===u||u===d)&&!(d<0||d>s)){var h=t.slice(0,d);if((m=t.slice(d))===c){var f=Math.min(o,d);if((v=l.slice(0,f))===(x=h.slice(0,f)))return b(v,l.slice(f),h.slice(f),c)}}if(null===u||u===o){var p=o,m=(h=t.slice(0,p),t.slice(p));if(h===l){var g=Math.min(a-p,s-p);if((y=c.slice(c.length-g))===(_=m.slice(m.length-g)))return b(l,c.slice(0,c.length-g),m.slice(0,m.length-g),y)}}}if(n.length>0&&r&&0===r.length){var v=e.slice(0,n.index),y=e.slice(n.index+n.length);if(!(s<(f=v.length)+(g=y.length))){var x=t.slice(0,f),_=t.slice(s-g);if(v===x&&y===_)return b(v,e.slice(f,a-g),t.slice(f,s-g),y)}}return null}(e,m,g);if(x)return x}var _=s(e,m),w=e.substring(0,_);_=l(e=e.substring(_),m=m.substring(_));var k=e.substring(e.length-_),M=function(e,o){var c;if(!e)return[[i,o]];if(!o)return[[t,e]];var u=e.length>o.length?e:o,d=e.length>o.length?o:e,h=u.indexOf(d);if(-1!==h)return c=[[i,u.substring(0,h)],[n,d],[i,u.substring(h+d.length)]],e.length>o.length&&(c[0][0]=c[2][0]=t),c;if(1===d.length)return[[t,e],[i,o]];var f=function(e,t){var i=e.length>t.length?e:t,n=e.length>t.length?t:e;if(i.length<4||2*n.length<i.length)return null;function r(e,t,i){for(var n,r,a,o,c=e.substring(i,i+Math.floor(e.length/4)),u=-1,d="";-1!==(u=t.indexOf(c,u+1));){var h=s(e.substring(i),t.substring(u)),f=l(e.substring(0,i),t.substring(0,u));d.length<f+h&&(d=t.substring(u-f,u)+t.substring(u,u+h),n=e.substring(0,i-f),r=e.substring(i+h),a=t.substring(0,u-f),o=t.substring(u+h))}return 2*d.length>=e.length?[n,r,a,o,d]:null}var a,o,c,u,d,h=r(i,n,Math.ceil(i.length/4)),f=r(i,n,Math.ceil(i.length/2));return h||f?(a=f?h&&h[4].length>f[4].length?h:f:h,e.length>t.length?(o=a[0],c=a[1],u=a[2],d=a[3]):(u=a[0],d=a[1],o=a[2],c=a[3]),[o,c,u,d,a[4]]):null}(e,o);if(f){var p=f[0],m=f[1],g=f[2],v=f[3],y=f[4],b=r(p,g),x=r(m,v);return b.concat([[n,y]],x)}return function(e,n){for(var r=e.length,s=n.length,o=Math.ceil((r+s)/2),l=o,c=2*o,u=new Array(c),d=new Array(c),h=0;h<c;h++)u[h]=-1,d[h]=-1;u[l+1]=0,d[l+1]=0;for(var f=r-s,p=f%2!=0,m=0,g=0,v=0,y=0,b=0;b<o;b++){for(var x=-b+m;x<=b-g;x+=2){for(var _=l+x,w=(L=x===-b||x!==b&&u[_-1]<u[_+1]?u[_+1]:u[_-1]+1)-x;L<r&&w<s&&e.charAt(L)===n.charAt(w);)L++,w++;if(u[_]=L,L>r)g+=2;else if(w>s)m+=2;else if(p&&(S=l+f-x)>=0&&S<c&&-1!==d[S]&&L>=(M=r-d[S]))return a(e,n,L,w)}for(var k=-b+v;k<=b-y;k+=2){for(var M,S=l+k,A=(M=k===-b||k!==b&&d[S-1]<d[S+1]?d[S+1]:d[S-1]+1)-k;M<r&&A<s&&e.charAt(r-M-1)===n.charAt(s-A-1);)M++,A++;if(d[S]=M,M>r)y+=2;else if(A>s)v+=2;else if(!p){var L;if((_=l+f-k)>=0&&_<c&&-1!==u[_]&&(w=l+(L=u[_])-_,L>=(M=r-M)))return a(e,n,L,w)}}}return[[t,e],[i,n]]}(e,o)}(e=e.substring(0,e.length-_),m=m.substring(0,m.length-_));return w&&M.unshift([n,w]),k&&M.push([n,k]),p(M,y),v&&function(e){for(var r=!1,a=[],s=0,m=null,g=0,v=0,y=0,b=0,x=0;g<e.length;)e[g][0]==n?(a[s++]=g,v=b,y=x,b=0,x=0,m=e[g][1]):(e[g][0]==i?b+=e[g][1].length:x+=e[g][1].length,m&&m.length<=Math.max(v,y)&&m.length<=Math.max(b,x)&&(e.splice(a[s-1],0,[t,m]),e[a[s-1]+1][0]=i,s--,g=--s>0?a[s-1]:-1,v=0,y=0,b=0,x=0,m=null,r=!0)),g++;for(r&&p(e),function(e){function t(e,t){if(!e||!t)return 6;var i=e.charAt(e.length-1),n=t.charAt(0),r=i.match(c),a=n.match(c),s=r&&i.match(u),o=a&&n.match(u),l=s&&i.match(d),p=o&&n.match(d),m=l&&e.match(h),g=p&&t.match(f);return m||g?5:l||p?4:r&&!s&&o?3:s||o?2:r||a?1:0}for(var i=1;i<e.length-1;){if(e[i-1][0]==n&&e[i+1][0]==n){var r=e[i-1][1],a=e[i][1],s=e[i+1][1],o=l(r,a);if(o){var p=a.substring(a.length-o);r=r.substring(0,r.length-o),a=p+a.substring(0,a.length-o),s=p+s}for(var m=r,g=a,v=s,y=t(r,a)+t(a,s);a.charAt(0)===s.charAt(0);){r+=a.charAt(0),a=a.substring(1)+s.charAt(0),s=s.substring(1);var b=t(r,a)+t(a,s);b>=y&&(y=b,m=r,g=a,v=s)}e[i-1][1]!=m&&(m?e[i-1][1]=m:(e.splice(i-1,1),i--),e[i][1]=g,v?e[i+1][1]=v:(e.splice(i+1,1),i--))}i++}}(e),g=1;g<e.length;){if(e[g-1][0]==t&&e[g][0]==i){var _=e[g-1][1],w=e[g][1],k=o(_,w),M=o(w,_);k>=M?(k>=_.length/2||k>=w.length/2)&&(e.splice(g,0,[n,w.substring(0,k)]),e[g-1][1]=_.substring(0,_.length-k),e[g+1][1]=w.substring(k),g++):(M>=_.length/2||M>=w.length/2)&&(e.splice(g,0,[n,_.substring(0,M)]),e[g-1][0]=i,e[g-1][1]=w.substring(0,w.length-M),e[g+1][0]=t,e[g+1][1]=_.substring(M),g++),g++}g++}}(M),M}function a(e,t,i,n){var a=e.substring(0,i),s=t.substring(0,n),o=e.substring(i),l=t.substring(n),c=r(a,s),u=r(o,l);return c.concat(u)}function s(e,t){if(!e||!t||e.charAt(0)!==t.charAt(0))return 0;for(var i=0,n=Math.min(e.length,t.length),r=n,a=0;i<r;)e.substring(a,r)==t.substring(a,r)?a=i=r:n=r,r=Math.floor((n-i)/2+i);return m(e.charCodeAt(r-1))&&r--,r}function o(e,t){var i=e.length,n=t.length;if(0==i||0==n)return 0;i>n?e=e.substring(i-n):i<n&&(t=t.substring(0,i));var r=Math.min(i,n);if(e==t)return r;for(var a=0,s=1;;){var o=e.substring(r-s),l=t.indexOf(o);if(-1==l)return a;s+=l,0!=l&&e.substring(r-s)!=t.substring(0,s)||(a=s,s++)}}function l(e,t){if(!e||!t||e.slice(-1)!==t.slice(-1))return 0;for(var i=0,n=Math.min(e.length,t.length),r=n,a=0;i<r;)e.substring(e.length-r,e.length-a)==t.substring(t.length-r,t.length-a)?a=i=r:n=r,r=Math.floor((n-i)/2+i);return g(e.charCodeAt(e.length-r))&&r--,r}var c=/[^a-zA-Z0-9]/,u=/\s/,d=/[\r\n]/,h=/\n\r?\n$/,f=/^\r?\n\r?\n/;function p(e,r){e.push([n,""]);for(var a,o=0,c=0,u=0,d="",h="";o<e.length;)if(o<e.length-1&&!e[o][1])e.splice(o,1);else switch(e[o][0]){case i:u++,h+=e[o][1],o++;break;case t:c++,d+=e[o][1],o++;break;case n:var f=o-u-c-1;if(r){if(f>=0&&y(e[f][1])){var m=e[f][1].slice(-1);if(e[f][1]=e[f][1].slice(0,-1),d=m+d,h=m+h,!e[f][1]){e.splice(f,1),o--;var g=f-1;e[g]&&e[g][0]===i&&(u++,h=e[g][1]+h,g--),e[g]&&e[g][0]===t&&(c++,d=e[g][1]+d,g--),f=g}}v(e[o][1])&&(m=e[o][1].charAt(0),e[o][1]=e[o][1].slice(1),d+=m,h+=m)}if(o<e.length-1&&!e[o][1]){e.splice(o,1);break}if(d.length>0||h.length>0){d.length>0&&h.length>0&&(0!==(a=s(h,d))&&(f>=0?e[f][1]+=h.substring(0,a):(e.splice(0,0,[n,h.substring(0,a)]),o++),h=h.substring(a),d=d.substring(a)),0!==(a=l(h,d))&&(e[o][1]=h.substring(h.length-a)+e[o][1],h=h.substring(0,h.length-a),d=d.substring(0,d.length-a)));var b=u+c;0===d.length&&0===h.length?(e.splice(o-b,b),o-=b):0===d.length?(e.splice(o-b,b,[i,h]),o=o-b+1):0===h.length?(e.splice(o-b,b,[t,d]),o=o-b+1):(e.splice(o-b,b,[t,d],[i,h]),o=o-b+2)}0!==o&&e[o-1][0]===n?(e[o-1][1]+=e[o][1],e.splice(o,1)):o++,u=0,c=0,d="",h=""}""===e[e.length-1][1]&&e.pop();var x=!1;for(o=1;o<e.length-1;)e[o-1][0]===n&&e[o+1][0]===n&&(e[o][1].substring(e[o][1].length-e[o-1][1].length)===e[o-1][1]?(e[o][1]=e[o-1][1]+e[o][1].substring(0,e[o][1].length-e[o-1][1].length),e[o+1][1]=e[o-1][1]+e[o+1][1],e.splice(o-1,1),x=!0):e[o][1].substring(0,e[o+1][1].length)==e[o+1][1]&&(e[o-1][1]+=e[o+1][1],e[o][1]=e[o][1].substring(e[o+1][1].length)+e[o+1][1],e.splice(o+1,1),x=!0)),o++;x&&p(e,r)}function m(e){return e>=55296&&e<=56319}function g(e){return e>=56320&&e<=57343}function v(e){return g(e.charCodeAt(0))}function y(e){return m(e.charCodeAt(e.length-1))}function b(e,r,a,s){return y(e)||v(s)?null:function(e){for(var t=[],i=0;i<e.length;i++)e[i][1].length>0&&t.push(e[i]);return t}([[n,e],[t,r],[i,a],[n,s]])}function x(e,t,i,n){return r(e,t,i,n,!0)}x.INSERT=i,x.DELETE=t,x.EQUAL=n,e.exports=x},9629:function(e,t,i){e=i.nmd(e);var n="__lodash_hash_undefined__",r=9007199254740991,a="[object Arguments]",s="[object Boolean]",o="[object Date]",l="[object Function]",c="[object GeneratorFunction]",u="[object Map]",d="[object Number]",h="[object Object]",f="[object Promise]",p="[object RegExp]",m="[object Set]",g="[object String]",v="[object Symbol]",y="[object WeakMap]",b="[object ArrayBuffer]",x="[object DataView]",_="[object Float32Array]",w="[object Float64Array]",k="[object Int8Array]",M="[object Int16Array]",S="[object Int32Array]",A="[object Uint8Array]",L="[object Uint8ClampedArray]",T="[object Uint16Array]",C="[object Uint32Array]",D=/\w*$/,E=/^\[object .+?Constructor\]$/,O=/^(?:0|[1-9]\d*)$/,P={};P[a]=P["[object Array]"]=P[b]=P[x]=P[s]=P[o]=P[_]=P[w]=P[k]=P[M]=P[S]=P[u]=P[d]=P[h]=P[p]=P[m]=P[g]=P[v]=P[A]=P[L]=P[T]=P[C]=!0,P["[object Error]"]=P[l]=P[y]=!1;var Y="object"==typeof i.g&&i.g&&i.g.Object===Object&&i.g,I="object"==typeof self&&self&&self.Object===Object&&self,N=Y||I||Function("return this")(),j=t&&!t.nodeType&&t,H=j&&e&&!e.nodeType&&e,F=H&&H.exports===j;function R(e,t){return e.set(t[0],t[1]),e}function z(e,t){return e.add(t),e}function B(e,t,i,n){var r=-1,a=e?e.length:0;for(n&&a&&(i=e[++r]);++r<a;)i=t(i,e[r],r,e);return i}function V(e){var t=!1;if(null!=e&&"function"!=typeof e.toString)try{t=!!(e+"")}catch(e){}return t}function W(e){var t=-1,i=Array(e.size);return e.forEach((function(e,n){i[++t]=[n,e]})),i}function U(e,t){return function(i){return e(t(i))}}function q(e){var t=-1,i=Array(e.size);return e.forEach((function(e){i[++t]=e})),i}var $,X=Array.prototype,G=Function.prototype,Z=Object.prototype,K=N["__core-js_shared__"],J=($=/[^.]+$/.exec(K&&K.keys&&K.keys.IE_PROTO||""))?"Symbol(src)_1."+$:"",Q=G.toString,ee=Z.hasOwnProperty,te=Z.toString,ie=RegExp("^"+Q.call(ee).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),ne=F?N.Buffer:void 0,re=N.Symbol,ae=N.Uint8Array,se=U(Object.getPrototypeOf,Object),oe=Object.create,le=Z.propertyIsEnumerable,ce=X.splice,ue=Object.getOwnPropertySymbols,de=ne?ne.isBuffer:void 0,he=U(Object.keys,Object),fe=Ne(N,"DataView"),pe=Ne(N,"Map"),me=Ne(N,"Promise"),ge=Ne(N,"Set"),ve=Ne(N,"WeakMap"),ye=Ne(Object,"create"),be=ze(fe),xe=ze(pe),_e=ze(me),we=ze(ge),ke=ze(ve),Me=re?re.prototype:void 0,Se=Me?Me.valueOf:void 0;function Ae(e){var t=-1,i=e?e.length:0;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}function Le(e){var t=-1,i=e?e.length:0;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}function Te(e){var t=-1,i=e?e.length:0;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}function Ce(e){this.__data__=new Le(e)}function De(e,t,i){var n=e[t];ee.call(e,t)&&Be(n,i)&&(void 0!==i||t in e)||(e[t]=i)}function Ee(e,t){for(var i=e.length;i--;)if(Be(e[i][0],t))return i;return-1}function Oe(e,t,i,n,r,f,y){var E;if(n&&(E=f?n(e,r,f,y):n(e)),void 0!==E)return E;if(!$e(e))return e;var O=Ve(e);if(O){if(E=function(e){var t=e.length,i=e.constructor(t);return t&&"string"==typeof e[0]&&ee.call(e,"index")&&(i.index=e.index,i.input=e.input),i}(e),!t)return function(e,t){var i=-1,n=e.length;for(t||(t=Array(n));++i<n;)t[i]=e[i];return t}(e,E)}else{var Y=He(e),I=Y==l||Y==c;if(Ue(e))return function(e,t){if(t)return e.slice();var i=new e.constructor(e.length);return e.copy(i),i}(e,t);if(Y==h||Y==a||I&&!f){if(V(e))return f?e:{};if(E=function(e){return"function"!=typeof e.constructor||Re(e)?{}:$e(t=se(e))?oe(t):{};var t}(I?{}:e),!t)return function(e,t){return Ye(e,je(e),t)}(e,function(e,t){return e&&Ye(t,Xe(t),e)}(E,e))}else{if(!P[Y])return f?e:{};E=function(e,t,i,n){var r,a=e.constructor;switch(t){case b:return Pe(e);case s:case o:return new a(+e);case x:return function(e,t){var i=t?Pe(e.buffer):e.buffer;return new e.constructor(i,e.byteOffset,e.byteLength)}(e,n);case _:case w:case k:case M:case S:case A:case L:case T:case C:return function(e,t){var i=t?Pe(e.buffer):e.buffer;return new e.constructor(i,e.byteOffset,e.length)}(e,n);case u:return function(e,t,i){return B(t?i(W(e),!0):W(e),R,new e.constructor)}(e,n,i);case d:case g:return new a(e);case p:return function(e){var t=new e.constructor(e.source,D.exec(e));return t.lastIndex=e.lastIndex,t}(e);case m:return function(e,t,i){return B(t?i(q(e),!0):q(e),z,new e.constructor)}(e,n,i);case v:return r=e,Se?Object(Se.call(r)):{}}}(e,Y,Oe,t)}}y||(y=new Ce);var N=y.get(e);if(N)return N;if(y.set(e,E),!O)var j=i?function(e){return function(e,t,i){var n=t(e);return Ve(e)?n:function(e,t){for(var i=-1,n=t.length,r=e.length;++i<n;)e[r+i]=t[i];return e}(n,i(e))}(e,Xe,je)}(e):Xe(e);return function(e,t){for(var i=-1,n=e?e.length:0;++i<n&&!1!==t(e[i],i););}(j||e,(function(r,a){j&&(r=e[a=r]),De(E,a,Oe(r,t,i,n,a,e,y))})),E}function Pe(e){var t=new e.constructor(e.byteLength);return new ae(t).set(new ae(e)),t}function Ye(e,t,i,n){i||(i={});for(var r=-1,a=t.length;++r<a;){var s=t[r],o=n?n(i[s],e[s],s,i,e):void 0;De(i,s,void 0===o?e[s]:o)}return i}function Ie(e,t){var i,n,r=e.__data__;return("string"==(n=typeof(i=t))||"number"==n||"symbol"==n||"boolean"==n?"__proto__"!==i:null===i)?r["string"==typeof t?"string":"hash"]:r.map}function Ne(e,t){var i=function(e,t){return null==e?void 0:e[t]}(e,t);return function(e){return!(!$e(e)||(t=e,J&&J in t))&&(qe(e)||V(e)?ie:E).test(ze(e));var t}(i)?i:void 0}Ae.prototype.clear=function(){this.__data__=ye?ye(null):{}},Ae.prototype.delete=function(e){return this.has(e)&&delete this.__data__[e]},Ae.prototype.get=function(e){var t=this.__data__;if(ye){var i=t[e];return i===n?void 0:i}return ee.call(t,e)?t[e]:void 0},Ae.prototype.has=function(e){var t=this.__data__;return ye?void 0!==t[e]:ee.call(t,e)},Ae.prototype.set=function(e,t){return this.__data__[e]=ye&&void 0===t?n:t,this},Le.prototype.clear=function(){this.__data__=[]},Le.prototype.delete=function(e){var t=this.__data__,i=Ee(t,e);return!(i<0||(i==t.length-1?t.pop():ce.call(t,i,1),0))},Le.prototype.get=function(e){var t=this.__data__,i=Ee(t,e);return i<0?void 0:t[i][1]},Le.prototype.has=function(e){return Ee(this.__data__,e)>-1},Le.prototype.set=function(e,t){var i=this.__data__,n=Ee(i,e);return n<0?i.push([e,t]):i[n][1]=t,this},Te.prototype.clear=function(){this.__data__={hash:new Ae,map:new(pe||Le),string:new Ae}},Te.prototype.delete=function(e){return Ie(this,e).delete(e)},Te.prototype.get=function(e){return Ie(this,e).get(e)},Te.prototype.has=function(e){return Ie(this,e).has(e)},Te.prototype.set=function(e,t){return Ie(this,e).set(e,t),this},Ce.prototype.clear=function(){this.__data__=new Le},Ce.prototype.delete=function(e){return this.__data__.delete(e)},Ce.prototype.get=function(e){return this.__data__.get(e)},Ce.prototype.has=function(e){return this.__data__.has(e)},Ce.prototype.set=function(e,t){var i=this.__data__;if(i instanceof Le){var n=i.__data__;if(!pe||n.length<199)return n.push([e,t]),this;i=this.__data__=new Te(n)}return i.set(e,t),this};var je=ue?U(ue,Object):function(){return[]},He=function(e){return te.call(e)};function Fe(e,t){return!!(t=null==t?r:t)&&("number"==typeof e||O.test(e))&&e>-1&&e%1==0&&e<t}function Re(e){var t=e&&e.constructor;return e===("function"==typeof t&&t.prototype||Z)}function ze(e){if(null!=e){try{return Q.call(e)}catch(e){}try{return e+""}catch(e){}}return""}function Be(e,t){return e===t||e!=e&&t!=t}(fe&&He(new fe(new ArrayBuffer(1)))!=x||pe&&He(new pe)!=u||me&&He(me.resolve())!=f||ge&&He(new ge)!=m||ve&&He(new ve)!=y)&&(He=function(e){var t=te.call(e),i=t==h?e.constructor:void 0,n=i?ze(i):void 0;if(n)switch(n){case be:return x;case xe:return u;case _e:return f;case we:return m;case ke:return y}return t});var Ve=Array.isArray;function We(e){return null!=e&&function(e){return"number"==typeof e&&e>-1&&e%1==0&&e<=r}(e.length)&&!qe(e)}var Ue=de||function(){return!1};function qe(e){var t=$e(e)?te.call(e):"";return t==l||t==c}function $e(e){var t=typeof e;return!!e&&("object"==t||"function"==t)}function Xe(e){return We(e)?function(e,t){var i=Ve(e)||function(e){return function(e){return function(e){return!!e&&"object"==typeof e}(e)&&We(e)}(e)&&ee.call(e,"callee")&&(!le.call(e,"callee")||te.call(e)==a)}(e)?function(e,t){for(var i=-1,n=Array(e);++i<e;)n[i]=t(i);return n}(e.length,String):[],n=i.length,r=!!n;for(var s in e)!ee.call(e,s)||r&&("length"==s||Fe(s,n))||i.push(s);return i}(e):function(e){if(!Re(e))return he(e);var t=[];for(var i in Object(e))ee.call(e,i)&&"constructor"!=i&&t.push(i);return t}(e)}e.exports=function(e){return Oe(e,!0,!0)}},4162:function(e,t,i){e=i.nmd(e);var n="__lodash_hash_undefined__",r=1,a=2,s=9007199254740991,o="[object Arguments]",l="[object Array]",c="[object AsyncFunction]",u="[object Boolean]",d="[object Date]",h="[object Error]",f="[object Function]",p="[object GeneratorFunction]",m="[object Map]",g="[object Number]",v="[object Null]",y="[object Object]",b="[object Promise]",x="[object Proxy]",_="[object RegExp]",w="[object Set]",k="[object String]",M="[object Undefined]",S="[object WeakMap]",A="[object ArrayBuffer]",L="[object DataView]",T=/^\[object .+?Constructor\]$/,C=/^(?:0|[1-9]\d*)$/,D={};D["[object Float32Array]"]=D["[object Float64Array]"]=D["[object Int8Array]"]=D["[object Int16Array]"]=D["[object Int32Array]"]=D["[object Uint8Array]"]=D["[object Uint8ClampedArray]"]=D["[object Uint16Array]"]=D["[object Uint32Array]"]=!0,D[o]=D[l]=D[A]=D[u]=D[L]=D[d]=D[h]=D[f]=D[m]=D[g]=D[y]=D[_]=D[w]=D[k]=D[S]=!1;var E="object"==typeof i.g&&i.g&&i.g.Object===Object&&i.g,O="object"==typeof self&&self&&self.Object===Object&&self,P=E||O||Function("return this")(),Y=t&&!t.nodeType&&t,I=Y&&e&&!e.nodeType&&e,N=I&&I.exports===Y,j=N&&E.process,H=function(){try{return j&&j.binding&&j.binding("util")}catch(e){}}(),F=H&&H.isTypedArray;function R(e,t){for(var i=-1,n=null==e?0:e.length;++i<n;)if(t(e[i],i,e))return!0;return!1}function z(e){var t=-1,i=Array(e.size);return e.forEach((function(e,n){i[++t]=[n,e]})),i}function B(e){var t=-1,i=Array(e.size);return e.forEach((function(e){i[++t]=e})),i}var V,W,U,q=Array.prototype,$=Function.prototype,X=Object.prototype,G=P["__core-js_shared__"],Z=$.toString,K=X.hasOwnProperty,J=(V=/[^.]+$/.exec(G&&G.keys&&G.keys.IE_PROTO||""))?"Symbol(src)_1."+V:"",Q=X.toString,ee=RegExp("^"+Z.call(K).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),te=N?P.Buffer:void 0,ie=P.Symbol,ne=P.Uint8Array,re=X.propertyIsEnumerable,ae=q.splice,se=ie?ie.toStringTag:void 0,oe=Object.getOwnPropertySymbols,le=te?te.isBuffer:void 0,ce=(W=Object.keys,U=Object,function(e){return W(U(e))}),ue=Ie(P,"DataView"),de=Ie(P,"Map"),he=Ie(P,"Promise"),fe=Ie(P,"Set"),pe=Ie(P,"WeakMap"),me=Ie(Object,"create"),ge=Fe(ue),ve=Fe(de),ye=Fe(he),be=Fe(fe),xe=Fe(pe),_e=ie?ie.prototype:void 0,we=_e?_e.valueOf:void 0;function ke(e){var t=-1,i=null==e?0:e.length;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}function Me(e){var t=-1,i=null==e?0:e.length;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}function Se(e){var t=-1,i=null==e?0:e.length;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}function Ae(e){var t=-1,i=null==e?0:e.length;for(this.__data__=new Se;++t<i;)this.add(e[t])}function Le(e){var t=this.__data__=new Me(e);this.size=t.size}function Te(e,t){for(var i=e.length;i--;)if(Re(e[i][0],t))return i;return-1}function Ce(e){return null==e?void 0===e?M:v:se&&se in Object(e)?function(e){var t=K.call(e,se),i=e[se];try{e[se]=void 0;var n=!0}catch(e){}var r=Q.call(e);return n&&(t?e[se]=i:delete e[se]),r}(e):function(e){return Q.call(e)}(e)}function De(e){return $e(e)&&Ce(e)==o}function Ee(e,t,i,n,s){return e===t||(null==e||null==t||!$e(e)&&!$e(t)?e!=e&&t!=t:function(e,t,i,n,s,c){var f=Be(e),p=Be(t),v=f?l:je(e),b=p?l:je(t),x=(v=v==o?y:v)==y,M=(b=b==o?y:b)==y,S=v==b;if(S&&Ve(e)){if(!Ve(t))return!1;f=!0,x=!1}if(S&&!x)return c||(c=new Le),f||Xe(e)?Oe(e,t,i,n,s,c):function(e,t,i,n,s,o,l){switch(i){case L:if(e.byteLength!=t.byteLength||e.byteOffset!=t.byteOffset)return!1;e=e.buffer,t=t.buffer;case A:return!(e.byteLength!=t.byteLength||!o(new ne(e),new ne(t)));case u:case d:case g:return Re(+e,+t);case h:return e.name==t.name&&e.message==t.message;case _:case k:return e==t+"";case m:var c=z;case w:var f=n&r;if(c||(c=B),e.size!=t.size&&!f)return!1;var p=l.get(e);if(p)return p==t;n|=a,l.set(e,t);var v=Oe(c(e),c(t),n,s,o,l);return l.delete(e),v;case"[object Symbol]":if(we)return we.call(e)==we.call(t)}return!1}(e,t,v,i,n,s,c);if(!(i&r)){var T=x&&K.call(e,"__wrapped__"),C=M&&K.call(t,"__wrapped__");if(T||C){var D=T?e.value():e,E=C?t.value():t;return c||(c=new Le),s(D,E,i,n,c)}}return!!S&&(c||(c=new Le),function(e,t,i,n,a,s){var o=i&r,l=Pe(e),c=l.length;if(c!=Pe(t).length&&!o)return!1;for(var u=c;u--;){var d=l[u];if(!(o?d in t:K.call(t,d)))return!1}var h=s.get(e);if(h&&s.get(t))return h==t;var f=!0;s.set(e,t),s.set(t,e);for(var p=o;++u<c;){var m=e[d=l[u]],g=t[d];if(n)var v=o?n(g,m,d,t,e,s):n(m,g,d,e,t,s);if(!(void 0===v?m===g||a(m,g,i,n,s):v)){f=!1;break}p||(p="constructor"==d)}if(f&&!p){var y=e.constructor,b=t.constructor;y==b||!("constructor"in e)||!("constructor"in t)||"function"==typeof y&&y instanceof y&&"function"==typeof b&&b instanceof b||(f=!1)}return s.delete(e),s.delete(t),f}(e,t,i,n,s,c))}(e,t,i,n,Ee,s))}function Oe(e,t,i,n,s,o){var l=i&r,c=e.length,u=t.length;if(c!=u&&!(l&&u>c))return!1;var d=o.get(e);if(d&&o.get(t))return d==t;var h=-1,f=!0,p=i&a?new Ae:void 0;for(o.set(e,t),o.set(t,e);++h<c;){var m=e[h],g=t[h];if(n)var v=l?n(g,m,h,t,e,o):n(m,g,h,e,t,o);if(void 0!==v){if(v)continue;f=!1;break}if(p){if(!R(t,(function(e,t){if(r=t,!p.has(r)&&(m===e||s(m,e,i,n,o)))return p.push(t);var r}))){f=!1;break}}else if(m!==g&&!s(m,g,i,n,o)){f=!1;break}}return o.delete(e),o.delete(t),f}function Pe(e){return function(e,t,i){var n=t(e);return Be(e)?n:function(e,t){for(var i=-1,n=t.length,r=e.length;++i<n;)e[r+i]=t[i];return e}(n,i(e))}(e,Ge,Ne)}function Ye(e,t){var i,n,r=e.__data__;return("string"==(n=typeof(i=t))||"number"==n||"symbol"==n||"boolean"==n?"__proto__"!==i:null===i)?r["string"==typeof t?"string":"hash"]:r.map}function Ie(e,t){var i=function(e,t){return null==e?void 0:e[t]}(e,t);return function(e){return!(!qe(e)||function(e){return!!J&&J in e}(e))&&(We(e)?ee:T).test(Fe(e))}(i)?i:void 0}ke.prototype.clear=function(){this.__data__=me?me(null):{},this.size=0},ke.prototype.delete=function(e){var t=this.has(e)&&delete this.__data__[e];return this.size-=t?1:0,t},ke.prototype.get=function(e){var t=this.__data__;if(me){var i=t[e];return i===n?void 0:i}return K.call(t,e)?t[e]:void 0},ke.prototype.has=function(e){var t=this.__data__;return me?void 0!==t[e]:K.call(t,e)},ke.prototype.set=function(e,t){var i=this.__data__;return this.size+=this.has(e)?0:1,i[e]=me&&void 0===t?n:t,this},Me.prototype.clear=function(){this.__data__=[],this.size=0},Me.prototype.delete=function(e){var t=this.__data__,i=Te(t,e);return!(i<0||(i==t.length-1?t.pop():ae.call(t,i,1),--this.size,0))},Me.prototype.get=function(e){var t=this.__data__,i=Te(t,e);return i<0?void 0:t[i][1]},Me.prototype.has=function(e){return Te(this.__data__,e)>-1},Me.prototype.set=function(e,t){var i=this.__data__,n=Te(i,e);return n<0?(++this.size,i.push([e,t])):i[n][1]=t,this},Se.prototype.clear=function(){this.size=0,this.__data__={hash:new ke,map:new(de||Me),string:new ke}},Se.prototype.delete=function(e){var t=Ye(this,e).delete(e);return this.size-=t?1:0,t},Se.prototype.get=function(e){return Ye(this,e).get(e)},Se.prototype.has=function(e){return Ye(this,e).has(e)},Se.prototype.set=function(e,t){var i=Ye(this,e),n=i.size;return i.set(e,t),this.size+=i.size==n?0:1,this},Ae.prototype.add=Ae.prototype.push=function(e){return this.__data__.set(e,n),this},Ae.prototype.has=function(e){return this.__data__.has(e)},Le.prototype.clear=function(){this.__data__=new Me,this.size=0},Le.prototype.delete=function(e){var t=this.__data__,i=t.delete(e);return this.size=t.size,i},Le.prototype.get=function(e){return this.__data__.get(e)},Le.prototype.has=function(e){return this.__data__.has(e)},Le.prototype.set=function(e,t){var i=this.__data__;if(i instanceof Me){var n=i.__data__;if(!de||n.length<199)return n.push([e,t]),this.size=++i.size,this;i=this.__data__=new Se(n)}return i.set(e,t),this.size=i.size,this};var Ne=oe?function(e){return null==e?[]:(e=Object(e),function(t,i){for(var n=-1,r=null==t?0:t.length,a=0,s=[];++n<r;){var o=t[n];l=o,re.call(e,l)&&(s[a++]=o)}var l;return s}(oe(e)))}:function(){return[]},je=Ce;function He(e,t){return!!(t=null==t?s:t)&&("number"==typeof e||C.test(e))&&e>-1&&e%1==0&&e<t}function Fe(e){if(null!=e){try{return Z.call(e)}catch(e){}try{return e+""}catch(e){}}return""}function Re(e,t){return e===t||e!=e&&t!=t}(ue&&je(new ue(new ArrayBuffer(1)))!=L||de&&je(new de)!=m||he&&je(he.resolve())!=b||fe&&je(new fe)!=w||pe&&je(new pe)!=S)&&(je=function(e){var t=Ce(e),i=t==y?e.constructor:void 0,n=i?Fe(i):"";if(n)switch(n){case ge:return L;case ve:return m;case ye:return b;case be:return w;case xe:return S}return t});var ze=De(function(){return arguments}())?De:function(e){return $e(e)&&K.call(e,"callee")&&!re.call(e,"callee")},Be=Array.isArray,Ve=le||function(){return!1};function We(e){if(!qe(e))return!1;var t=Ce(e);return t==f||t==p||t==c||t==x}function Ue(e){return"number"==typeof e&&e>-1&&e%1==0&&e<=s}function qe(e){var t=typeof e;return null!=e&&("object"==t||"function"==t)}function $e(e){return null!=e&&"object"==typeof e}var Xe=F?function(e){return function(t){return e(t)}}(F):function(e){return $e(e)&&Ue(e.length)&&!!D[Ce(e)]};function Ge(e){return null!=(t=e)&&Ue(t.length)&&!We(t)?function(e,t){var i=Be(e),n=!i&&ze(e),r=!i&&!n&&Ve(e),a=!i&&!n&&!r&&Xe(e),s=i||n||r||a,o=s?function(e,t){for(var i=-1,n=Array(e);++i<e;)n[i]=t(i);return n}(e.length,String):[],l=o.length;for(var c in e)!K.call(e,c)||s&&("length"==c||r&&("offset"==c||"parent"==c)||a&&("buffer"==c||"byteLength"==c||"byteOffset"==c)||He(c,l))||o.push(c);return o}(e):function(e){if(i=(t=e)&&t.constructor,t!==("function"==typeof i&&i.prototype||X))return ce(e);var t,i,n=[];for(var r in Object(e))K.call(e,r)&&"constructor"!=r&&n.push(r);return n}(e);var t}e.exports=function(e,t){return Ee(e,t)}},1270:function(e,t,i){"use strict";Object.defineProperty(t,"__esModule",{value:!0});const n=i(9629),r=i(4162);var a;!function(e){e.compose=function(e={},t={},i=!1){"object"!=typeof e&&(e={}),"object"!=typeof t&&(t={});let r=n(t);i||(r=Object.keys(r).reduce(((e,t)=>(null!=r[t]&&(e[t]=r[t]),e)),{}));for(const i in e)void 0!==e[i]&&void 0===t[i]&&(r[i]=e[i]);return Object.keys(r).length>0?r:void 0},e.diff=function(e={},t={}){"object"!=typeof e&&(e={}),"object"!=typeof t&&(t={});const i=Object.keys(e).concat(Object.keys(t)).reduce(((i,n)=>(r(e[n],t[n])||(i[n]=void 0===t[n]?null:t[n]),i)),{});return Object.keys(i).length>0?i:void 0},e.invert=function(e={},t={}){e=e||{};const i=Object.keys(t).reduce(((i,n)=>(t[n]!==e[n]&&void 0!==e[n]&&(i[n]=t[n]),i)),{});return Object.keys(e).reduce(((i,n)=>(e[n]!==t[n]&&void 0===t[n]&&(i[n]=null),i)),i)},e.transform=function(e,t,i=!1){if("object"!=typeof e)return t;if("object"!=typeof t)return;if(!i)return t;const n=Object.keys(t).reduce(((i,n)=>(void 0===e[n]&&(i[n]=t[n]),i)),{});return Object.keys(n).length>0?n:void 0}}(a||(a={})),t.default=a},5232:function(e,t,i){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.AttributeMap=t.OpIterator=t.Op=void 0;const n=i(5090),r=i(9629),a=i(4162),s=i(1270);t.AttributeMap=s.default;const o=i(4123);t.Op=o.default;const l=i(7033);t.OpIterator=l.default;const c=String.fromCharCode(0),u=(e,t)=>{if("object"!=typeof e||null===e)throw new Error("cannot retain a "+typeof e);if("object"!=typeof t||null===t)throw new Error("cannot retain a "+typeof t);const i=Object.keys(e)[0];if(!i||i!==Object.keys(t)[0])throw new Error(`embed types not matched: ${i} != ${Object.keys(t)[0]}`);return[i,e[i],t[i]]};class d{constructor(e){Array.isArray(e)?this.ops=e:null!=e&&Array.isArray(e.ops)?this.ops=e.ops:this.ops=[]}static registerEmbed(e,t){this.handlers[e]=t}static unregisterEmbed(e){delete this.handlers[e]}static getHandler(e){const t=this.handlers[e];if(!t)throw new Error(`no handlers for embed type "${e}"`);return t}insert(e,t){const i={};return"string"==typeof e&&0===e.length?this:(i.insert=e,null!=t&&"object"==typeof t&&Object.keys(t).length>0&&(i.attributes=t),this.push(i))}delete(e){return e<=0?this:this.push({delete:e})}retain(e,t){if("number"==typeof e&&e<=0)return this;const i={retain:e};return null!=t&&"object"==typeof t&&Object.keys(t).length>0&&(i.attributes=t),this.push(i)}push(e){let t=this.ops.length,i=this.ops[t-1];if(e=r(e),"object"==typeof i){if("number"==typeof e.delete&&"number"==typeof i.delete)return this.ops[t-1]={delete:i.delete+e.delete},this;if("number"==typeof i.delete&&null!=e.insert&&(t-=1,i=this.ops[t-1],"object"!=typeof i))return this.ops.unshift(e),this;if(a(e.attributes,i.attributes)){if("string"==typeof e.insert&&"string"==typeof i.insert)return this.ops[t-1]={insert:i.insert+e.insert},"object"==typeof e.attributes&&(this.ops[t-1].attributes=e.attributes),this;if("number"==typeof e.retain&&"number"==typeof i.retain)return this.ops[t-1]={retain:i.retain+e.retain},"object"==typeof e.attributes&&(this.ops[t-1].attributes=e.attributes),this}}return t===this.ops.length?this.ops.push(e):this.ops.splice(t,0,e),this}chop(){const e=this.ops[this.ops.length-1];return e&&"number"==typeof e.retain&&!e.attributes&&this.ops.pop(),this}filter(e){return this.ops.filter(e)}forEach(e){this.ops.forEach(e)}map(e){return this.ops.map(e)}partition(e){const t=[],i=[];return this.forEach((n=>{(e(n)?t:i).push(n)})),[t,i]}reduce(e,t){return this.ops.reduce(e,t)}changeLength(){return this.reduce(((e,t)=>t.insert?e+o.default.length(t):t.delete?e-t.delete:e),0)}length(){return this.reduce(((e,t)=>e+o.default.length(t)),0)}slice(e=0,t=1/0){const i=[],n=new l.default(this.ops);let r=0;for(;r<t&&n.hasNext();){let a;r<e?a=n.next(e-r):(a=n.next(t-r),i.push(a)),r+=o.default.length(a)}return new d(i)}compose(e){const t=new l.default(this.ops),i=new l.default(e.ops),n=[],r=i.peek();if(null!=r&&"number"==typeof r.retain&&null==r.attributes){let e=r.retain;for(;"insert"===t.peekType()&&t.peekLength()<=e;)e-=t.peekLength(),n.push(t.next());r.retain-e>0&&i.next(r.retain-e)}const o=new d(n);for(;t.hasNext()||i.hasNext();)if("insert"===i.peekType())o.push(i.next());else if("delete"===t.peekType())o.push(t.next());else{const e=Math.min(t.peekLength(),i.peekLength()),n=t.next(e),r=i.next(e);if(r.retain){const l={};if("number"==typeof n.retain)l.retain="number"==typeof r.retain?e:r.retain;else if("number"==typeof r.retain)null==n.retain?l.insert=n.insert:l.retain=n.retain;else{const e=null==n.retain?"insert":"retain",[t,i,a]=u(n[e],r.retain),s=d.getHandler(t);l[e]={[t]:s.compose(i,a,"retain"===e)}}const c=s.default.compose(n.attributes,r.attributes,"number"==typeof n.retain);if(c&&(l.attributes=c),o.push(l),!i.hasNext()&&a(o.ops[o.ops.length-1],l)){const e=new d(t.rest());return o.concat(e).chop()}}else"number"==typeof r.delete&&("number"==typeof n.retain||"object"==typeof n.retain&&null!==n.retain)&&o.push(r)}return o.chop()}concat(e){const t=new d(this.ops.slice());return e.ops.length>0&&(t.push(e.ops[0]),t.ops=t.ops.concat(e.ops.slice(1))),t}diff(e,t){if(this.ops===e.ops)return new d;const i=[this,e].map((t=>t.map((i=>{if(null!=i.insert)return"string"==typeof i.insert?i.insert:c;throw new Error("diff() called "+(t===e?"on":"with")+" non-document")})).join(""))),r=new d,o=n(i[0],i[1],t,!0),u=new l.default(this.ops),h=new l.default(e.ops);return o.forEach((e=>{let t=e[1].length;for(;t>0;){let i=0;switch(e[0]){case n.INSERT:i=Math.min(h.peekLength(),t),r.push(h.next(i));break;case n.DELETE:i=Math.min(t,u.peekLength()),u.next(i),r.delete(i);break;case n.EQUAL:i=Math.min(u.peekLength(),h.peekLength(),t);const e=u.next(i),o=h.next(i);a(e.insert,o.insert)?r.retain(i,s.default.diff(e.attributes,o.attributes)):r.push(o).delete(i)}t-=i}})),r.chop()}eachLine(e,t="\n"){const i=new l.default(this.ops);let n=new d,r=0;for(;i.hasNext();){if("insert"!==i.peekType())return;const a=i.peek(),s=o.default.length(a)-i.peekLength(),l="string"==typeof a.insert?a.insert.indexOf(t,s)-s:-1;if(l<0)n.push(i.next());else if(l>0)n.push(i.next(l));else{if(!1===e(n,i.next(1).attributes||{},r))return;r+=1,n=new d}}n.length()>0&&e(n,{},r)}invert(e){const t=new d;return this.reduce(((i,n)=>{if(n.insert)t.delete(o.default.length(n));else{if("number"==typeof n.retain&&null==n.attributes)return t.retain(n.retain),i+n.retain;if(n.delete||"number"==typeof n.retain){const r=n.delete||n.retain;return e.slice(i,i+r).forEach((e=>{n.delete?t.push(e):n.retain&&n.attributes&&t.retain(o.default.length(e),s.default.invert(n.attributes,e.attributes))})),i+r}if("object"==typeof n.retain&&null!==n.retain){const r=e.slice(i,i+1),a=new l.default(r.ops).next(),[o,c,h]=u(n.retain,a.insert),f=d.getHandler(o);return t.retain({[o]:f.invert(c,h)},s.default.invert(n.attributes,a.attributes)),i+1}}return i}),0),t.chop()}transform(e,t=!1){if(t=!!t,"number"==typeof e)return this.transformPosition(e,t);const i=e,n=new l.default(this.ops),r=new l.default(i.ops),a=new d;for(;n.hasNext()||r.hasNext();)if("insert"!==n.peekType()||!t&&"insert"===r.peekType())if("insert"===r.peekType())a.push(r.next());else{const e=Math.min(n.peekLength(),r.peekLength()),i=n.next(e),o=r.next(e);if(i.delete)continue;if(o.delete)a.push(o);else{const n=i.retain,r=o.retain;let l="object"==typeof r&&null!==r?r:e;if("object"==typeof n&&null!==n&&"object"==typeof r&&null!==r){const e=Object.keys(n)[0];if(e===Object.keys(r)[0]){const i=d.getHandler(e);i&&(l={[e]:i.transform(n[e],r[e],t)})}}a.retain(l,s.default.transform(i.attributes,o.attributes,t))}}else a.retain(o.default.length(n.next()));return a.chop()}transformPosition(e,t=!1){t=!!t;const i=new l.default(this.ops);let n=0;for(;i.hasNext()&&n<=e;){const r=i.peekLength(),a=i.peekType();i.next(),"delete"!==a?("insert"===a&&(n<e||!t)&&(e+=r),n+=r):e-=Math.min(r,e-n)}return e}}d.Op=o.default,d.OpIterator=l.default,d.AttributeMap=s.default,d.handlers={},t.default=d,e.exports=d,e.exports.default=d},4123:function(e,t){"use strict";var i;Object.defineProperty(t,"__esModule",{value:!0}),function(e){e.length=function(e){return"number"==typeof e.delete?e.delete:"number"==typeof e.retain?e.retain:"object"==typeof e.retain&&null!==e.retain?1:"string"==typeof e.insert?e.insert.length:1}}(i||(i={})),t.default=i},7033:function(e,t,i){"use strict";Object.defineProperty(t,"__esModule",{value:!0});const n=i(4123);t.default=class{constructor(e){this.ops=e,this.index=0,this.offset=0}hasNext(){return this.peekLength()<1/0}next(e){e||(e=1/0);const t=this.ops[this.index];if(t){const i=this.offset,r=n.default.length(t);if(e>=r-i?(e=r-i,this.index+=1,this.offset=0):this.offset+=e,"number"==typeof t.delete)return{delete:e};{const n={};return t.attributes&&(n.attributes=t.attributes),"number"==typeof t.retain?n.retain=e:"object"==typeof t.retain&&null!==t.retain?n.retain=t.retain:"string"==typeof t.insert?n.insert=t.insert.substr(i,e):n.insert=t.insert,n}}return{retain:1/0}}peek(){return this.ops[this.index]}peekLength(){return this.ops[this.index]?n.default.length(this.ops[this.index])-this.offset:1/0}peekType(){const e=this.ops[this.index];return e?"number"==typeof e.delete?"delete":"number"==typeof e.retain||"object"==typeof e.retain&&null!==e.retain?"retain":"insert":"retain"}rest(){if(this.hasNext()){if(0===this.offset)return this.ops.slice(this.index);{const e=this.offset,t=this.index,i=this.next(),n=this.ops.slice(this.index);return this.offset=e,this.index=t,[i].concat(n)}}return[]}}},8820:function(e,t,i){"use strict";i.d(t,{A:function(){return o}});var n=i(8138),r=function(e,t){for(var i=e.length;i--;)if((0,n.A)(e[i][0],t))return i;return-1},a=Array.prototype.splice;function s(e){var t=-1,i=null==e?0:e.length;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}s.prototype.clear=function(){this.__data__=[],this.size=0},s.prototype.delete=function(e){var t=this.__data__,i=r(t,e);return!(i<0||(i==t.length-1?t.pop():a.call(t,i,1),--this.size,0))},s.prototype.get=function(e){var t=this.__data__,i=r(t,e);return i<0?void 0:t[i][1]},s.prototype.has=function(e){return r(this.__data__,e)>-1},s.prototype.set=function(e,t){var i=this.__data__,n=r(i,e);return n<0?(++this.size,i.push([e,t])):i[n][1]=t,this};var o=s},2461:function(e,t,i){"use strict";var n=i(2281),r=i(5507),a=(0,n.A)(r.A,"Map");t.A=a},3558:function(e,t,i){"use strict";i.d(t,{A:function(){return h}});var n=(0,i(2281).A)(Object,"create"),r=Object.prototype.hasOwnProperty,a=Object.prototype.hasOwnProperty;function s(e){var t=-1,i=null==e?0:e.length;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}s.prototype.clear=function(){this.__data__=n?n(null):{},this.size=0},s.prototype.delete=function(e){var t=this.has(e)&&delete this.__data__[e];return this.size-=t?1:0,t},s.prototype.get=function(e){var t=this.__data__;if(n){var i=t[e];return"__lodash_hash_undefined__"===i?void 0:i}return r.call(t,e)?t[e]:void 0},s.prototype.has=function(e){var t=this.__data__;return n?void 0!==t[e]:a.call(t,e)},s.prototype.set=function(e,t){var i=this.__data__;return this.size+=this.has(e)?0:1,i[e]=n&&void 0===t?"__lodash_hash_undefined__":t,this};var o=s,l=i(8820),c=i(2461),u=function(e,t){var i,n,r=e.__data__;return("string"==(n=typeof(i=t))||"number"==n||"symbol"==n||"boolean"==n?"__proto__"!==i:null===i)?r["string"==typeof t?"string":"hash"]:r.map};function d(e){var t=-1,i=null==e?0:e.length;for(this.clear();++t<i;){var n=e[t];this.set(n[0],n[1])}}d.prototype.clear=function(){this.size=0,this.__data__={hash:new o,map:new(c.A||l.A),string:new o}},d.prototype.delete=function(e){var t=u(this,e).delete(e);return this.size-=t?1:0,t},d.prototype.get=function(e){return u(this,e).get(e)},d.prototype.has=function(e){return u(this,e).has(e)},d.prototype.set=function(e,t){var i=u(this,e),n=i.size;return i.set(e,t),this.size+=i.size==n?0:1,this};var h=d},2673:function(e,t,i){"use strict";i.d(t,{A:function(){return o}});var n=i(8820),r=i(2461),a=i(3558);function s(e){var t=this.__data__=new n.A(e);this.size=t.size}s.prototype.clear=function(){this.__data__=new n.A,this.size=0},s.prototype.delete=function(e){var t=this.__data__,i=t.delete(e);return this.size=t.size,i},s.prototype.get=function(e){return this.__data__.get(e)},s.prototype.has=function(e){return this.__data__.has(e)},s.prototype.set=function(e,t){var i=this.__data__;if(i instanceof n.A){var s=i.__data__;if(!r.A||s.length<199)return s.push([e,t]),this.size=++i.size,this;i=this.__data__=new a.A(s)}return i.set(e,t),this.size=i.size,this};var o=s},439:function(e,t,i){"use strict";var n=i(5507).A.Symbol;t.A=n},7218:function(e,t,i){"use strict";var n=i(5507).A.Uint8Array;t.A=n},6753:function(e,t,i){"use strict";i.d(t,{A:function(){return c}});var n=i(8412),r=i(723),a=i(776),s=i(3767),o=i(5755),l=Object.prototype.hasOwnProperty,c=function(e,t){var i=(0,r.A)(e),c=!i&&(0,n.A)(e),u=!i&&!c&&(0,a.A)(e),d=!i&&!c&&!u&&(0,o.A)(e),h=i||c||u||d,f=h?function(e,t){for(var i=-1,n=Array(e);++i<e;)n[i]=t(i);return n}(e.length,String):[],p=f.length;for(var m in e)!t&&!l.call(e,m)||h&&("length"==m||u&&("offset"==m||"parent"==m)||d&&("buffer"==m||"byteLength"==m||"byteOffset"==m)||(0,s.A)(m,p))||f.push(m);return f}},802:function(e,t){"use strict";t.A=function(e,t){for(var i=-1,n=t.length,r=e.length;++i<n;)e[r+i]=t[i];return e}},6437:function(e,t,i){"use strict";var n=i(6770),r=i(8138),a=Object.prototype.hasOwnProperty;t.A=function(e,t,i){var s=e[t];a.call(e,t)&&(0,r.A)(s,i)&&(void 0!==i||t in e)||(0,n.A)(e,t,i)}},6770:function(e,t,i){"use strict";var n=i(7889);t.A=function(e,t,i){"__proto__"==t&&n.A?(0,n.A)(e,t,{configurable:!0,enumerable:!0,value:i,writable:!0}):e[t]=i}},1381:function(e,t,i){"use strict";var n=i(802),r=i(723);t.A=function(e,t,i){var a=t(e);return(0,r.A)(e)?a:(0,n.A)(a,i(e))}},2159:function(e,t,i){"use strict";i.d(t,{A:function(){return u}});var n=i(439),r=Object.prototype,a=r.hasOwnProperty,s=r.toString,o=n.A?n.A.toStringTag:void 0,l=Object.prototype.toString,c=n.A?n.A.toStringTag:void 0,u=function(e){return null==e?void 0===e?"[object Undefined]":"[object Null]":c&&c in Object(e)?function(e){var t=a.call(e,o),i=e[o];try{e[o]=void 0;var n=!0}catch(e){}var r=s.call(e);return n&&(t?e[o]=i:delete e[o]),r}(e):function(e){return l.call(e)}(e)}},5771:function(e,t){"use strict";t.A=function(e){return function(t){return e(t)}}},2899:function(e,t,i){"use strict";var n=i(7218);t.A=function(e){var t=new e.constructor(e.byteLength);return new n.A(t).set(new n.A(e)),t}},3812:function(e,t,i){"use strict";var n=i(5507),r="object"==typeof exports&&exports&&!exports.nodeType&&exports,a=r&&"object"==typeof module&&module&&!module.nodeType&&module,s=a&&a.exports===r?n.A.Buffer:void 0,o=s?s.allocUnsafe:void 0;t.A=function(e,t){if(t)return e.slice();var i=e.length,n=o?o(i):new e.constructor(i);return e.copy(n),n}},1827:function(e,t,i){"use strict";var n=i(2899);t.A=function(e,t){var i=t?(0,n.A)(e.buffer):e.buffer;return new e.constructor(i,e.byteOffset,e.length)}},4405:function(e,t){"use strict";t.A=function(e,t){var i=-1,n=e.length;for(t||(t=Array(n));++i<n;)t[i]=e[i];return t}},9601:function(e,t,i){"use strict";var n=i(6437),r=i(6770);t.A=function(e,t,i,a){var s=!i;i||(i={});for(var o=-1,l=t.length;++o<l;){var c=t[o],u=a?a(i[c],e[c],c,i,e):void 0;void 0===u&&(u=e[c]),s?(0,r.A)(i,c,u):(0,n.A)(i,c,u)}return i}},7889:function(e,t,i){"use strict";var n=i(2281),r=function(){try{var e=(0,n.A)(Object,"defineProperty");return e({},"",{}),e}catch(e){}}();t.A=r},9646:function(e,t){"use strict";var i="object"==typeof global&&global&&global.Object===Object&&global;t.A=i},2816:function(e,t,i){"use strict";var n=i(1381),r=i(9844),a=i(3169);t.A=function(e){return(0,n.A)(e,a.A,r.A)}},2281:function(e,t,i){"use strict";i.d(t,{A:function(){return m}});var n,r=i(7572),a=i(5507).A["__core-js_shared__"],s=(n=/[^.]+$/.exec(a&&a.keys&&a.keys.IE_PROTO||""))?"Symbol(src)_1."+n:"",o=i(659),l=i(1543),c=/^\[object .+?Constructor\]$/,u=Function.prototype,d=Object.prototype,h=u.toString,f=d.hasOwnProperty,p=RegExp("^"+h.call(f).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),m=function(e,t){var i=function(e,t){return null==e?void 0:e[t]}(e,t);return function(e){return!(!(0,o.A)(e)||(t=e,s&&s in t))&&((0,r.A)(e)?p:c).test((0,l.A)(e));var t}(i)?i:void 0}},8769:function(e,t,i){"use strict";var n=(0,i(2217).A)(Object.getPrototypeOf,Object);t.A=n},9844:function(e,t,i){"use strict";i.d(t,{A:function(){return s}});var n=i(6935),r=Object.prototype.propertyIsEnumerable,a=Object.getOwnPropertySymbols,s=a?function(e){return null==e?[]:(e=Object(e),function(e,t){for(var i=-1,n=null==e?0:e.length,r=0,a=[];++i<n;){var s=e[i];t(s)&&(a[r++]=s)}return a}(a(e),(function(t){return r.call(e,t)})))}:n.A},7995:function(e,t,i){"use strict";i.d(t,{A:function(){return k}});var n=i(2281),r=i(5507),a=(0,n.A)(r.A,"DataView"),s=i(2461),o=(0,n.A)(r.A,"Promise"),l=(0,n.A)(r.A,"Set"),c=(0,n.A)(r.A,"WeakMap"),u=i(2159),d=i(1543),h="[object Map]",f="[object Promise]",p="[object Set]",m="[object WeakMap]",g="[object DataView]",v=(0,d.A)(a),y=(0,d.A)(s.A),b=(0,d.A)(o),x=(0,d.A)(l),_=(0,d.A)(c),w=u.A;(a&&w(new a(new ArrayBuffer(1)))!=g||s.A&&w(new s.A)!=h||o&&w(o.resolve())!=f||l&&w(new l)!=p||c&&w(new c)!=m)&&(w=function(e){var t=(0,u.A)(e),i="[object Object]"==t?e.constructor:void 0,n=i?(0,d.A)(i):"";if(n)switch(n){case v:return g;case y:return h;case b:return f;case x:return p;case _:return m}return t});var k=w},1683:function(e,t,i){"use strict";i.d(t,{A:function(){return l}});var n=i(659),r=Object.create,a=function(){function e(){}return function(t){if(!(0,n.A)(t))return{};if(r)return r(t);e.prototype=t;var i=new e;return e.prototype=void 0,i}}(),s=i(8769),o=i(501),l=function(e){return"function"!=typeof e.constructor||(0,o.A)(e)?{}:a((0,s.A)(e))}},3767:function(e,t){"use strict";var i=/^(?:0|[1-9]\d*)$/;t.A=function(e,t){var n=typeof e;return!!(t=null==t?9007199254740991:t)&&("number"==n||"symbol"!=n&&i.test(e))&&e>-1&&e%1==0&&e<t}},501:function(e,t){"use strict";var i=Object.prototype;t.A=function(e){var t=e&&e.constructor;return e===("function"==typeof t&&t.prototype||i)}},8795:function(e,t,i){"use strict";var n=i(9646),r="object"==typeof exports&&exports&&!exports.nodeType&&exports,a=r&&"object"==typeof module&&module&&!module.nodeType&&module,s=a&&a.exports===r&&n.A.process,o=function(){try{return a&&a.require&&a.require("util").types||s&&s.binding&&s.binding("util")}catch(e){}}();t.A=o},2217:function(e,t){"use strict";t.A=function(e,t){return function(i){return e(t(i))}}},5507:function(e,t,i){"use strict";var n=i(9646),r="object"==typeof self&&self&&self.Object===Object&&self,a=n.A||r||Function("return this")();t.A=a},1543:function(e,t){"use strict";var i=Function.prototype.toString;t.A=function(e){if(null!=e){try{return i.call(e)}catch(e){}try{return e+""}catch(e){}}return""}},3707:function(e,t,i){"use strict";i.d(t,{A:function(){return V}});var n=i(2673),r=i(6437),a=i(9601),s=i(3169),o=i(2624),l=i(3812),c=i(4405),u=i(9844),d=i(802),h=i(8769),f=i(6935),p=Object.getOwnPropertySymbols?function(e){for(var t=[];e;)(0,d.A)(t,(0,u.A)(e)),e=(0,h.A)(e);return t}:f.A,m=i(2816),g=i(1381),v=function(e){return(0,g.A)(e,o.A,p)},y=i(7995),b=Object.prototype.hasOwnProperty,x=i(2899),_=/\w*$/,w=i(439),k=w.A?w.A.prototype:void 0,M=k?k.valueOf:void 0,S=i(1827),A=function(e,t,i){var n,r,a,s=e.constructor;switch(t){case"[object ArrayBuffer]":return(0,x.A)(e);case"[object Boolean]":case"[object Date]":return new s(+e);case"[object DataView]":return function(e,t){var i=t?(0,x.A)(e.buffer):e.buffer;return new e.constructor(i,e.byteOffset,e.byteLength)}(e,i);case"[object Float32Array]":case"[object Float64Array]":case"[object Int8Array]":case"[object Int16Array]":case"[object Int32Array]":case"[object Uint8Array]":case"[object Uint8ClampedArray]":case"[object Uint16Array]":case"[object Uint32Array]":return(0,S.A)(e,i);case"[object Map]":case"[object Set]":return new s;case"[object Number]":case"[object String]":return new s(e);case"[object RegExp]":return(a=new(r=e).constructor(r.source,_.exec(r))).lastIndex=r.lastIndex,a;case"[object Symbol]":return n=e,M?Object(M.call(n)):{}}},L=i(1683),T=i(723),C=i(776),D=i(7948),E=i(5771),O=i(8795),P=O.A&&O.A.isMap,Y=P?(0,E.A)(P):function(e){return(0,D.A)(e)&&"[object Map]"==(0,y.A)(e)},I=i(659),N=O.A&&O.A.isSet,j=N?(0,E.A)(N):function(e){return(0,D.A)(e)&&"[object Set]"==(0,y.A)(e)},H="[object Arguments]",F="[object Function]",R="[object Object]",z={};z[H]=z["[object Array]"]=z["[object ArrayBuffer]"]=z["[object DataView]"]=z["[object Boolean]"]=z["[object Date]"]=z["[object Float32Array]"]=z["[object Float64Array]"]=z["[object Int8Array]"]=z["[object Int16Array]"]=z["[object Int32Array]"]=z["[object Map]"]=z["[object Number]"]=z[R]=z["[object RegExp]"]=z["[object Set]"]=z["[object String]"]=z["[object Symbol]"]=z["[object Uint8Array]"]=z["[object Uint8ClampedArray]"]=z["[object Uint16Array]"]=z["[object Uint32Array]"]=!0,z["[object Error]"]=z[F]=z["[object WeakMap]"]=!1;var B=function e(t,i,d,h,f,g){var x,_=1&i,w=2&i,k=4&i;if(d&&(x=f?d(t,h,f,g):d(t)),void 0!==x)return x;if(!(0,I.A)(t))return t;var M=(0,T.A)(t);if(M){if(x=function(e){var t=e.length,i=new e.constructor(t);return t&&"string"==typeof e[0]&&b.call(e,"index")&&(i.index=e.index,i.input=e.input),i}(t),!_)return(0,c.A)(t,x)}else{var S=(0,y.A)(t),D=S==F||"[object GeneratorFunction]"==S;if((0,C.A)(t))return(0,l.A)(t,_);if(S==R||S==H||D&&!f){if(x=w||D?{}:(0,L.A)(t),!_)return w?function(e,t){return(0,a.A)(e,p(e),t)}(t,function(e,t){return e&&(0,a.A)(t,(0,o.A)(t),e)}(x,t)):function(e,t){return(0,a.A)(e,(0,u.A)(e),t)}(t,function(e,t){return e&&(0,a.A)(t,(0,s.A)(t),e)}(x,t))}else{if(!z[S])return f?t:{};x=A(t,S,_)}}g||(g=new n.A);var E=g.get(t);if(E)return E;g.set(t,x),j(t)?t.forEach((function(n){x.add(e(n,i,d,n,t,g))})):Y(t)&&t.forEach((function(n,r){x.set(r,e(n,i,d,r,t,g))}));var O=k?w?v:m.A:w?o.A:s.A,P=M?void 0:O(t);return function(e,t){for(var i=-1,n=null==e?0:e.length;++i<n&&!1!==t(e[i],i););}(P||t,(function(n,a){P&&(n=t[a=n]),(0,r.A)(x,a,e(n,i,d,a,t,g))})),x},V=function(e){return B(e,5)}},8138:function(e,t){"use strict";t.A=function(e,t){return e===t||e!=e&&t!=t}},8412:function(e,t,i){"use strict";i.d(t,{A:function(){return u}});var n=i(2159),r=i(7948),a=function(e){return(0,r.A)(e)&&"[object Arguments]"==(0,n.A)(e)},s=Object.prototype,o=s.hasOwnProperty,l=s.propertyIsEnumerable,c=a(function(){return arguments}())?a:function(e){return(0,r.A)(e)&&o.call(e,"callee")&&!l.call(e,"callee")},u=c},723:function(e,t){"use strict";var i=Array.isArray;t.A=i},3628:function(e,t,i){"use strict";var n=i(7572),r=i(1628);t.A=function(e){return null!=e&&(0,r.A)(e.length)&&!(0,n.A)(e)}},776:function(e,t,i){"use strict";i.d(t,{A:function(){return o}});var n=i(5507),r="object"==typeof exports&&exports&&!exports.nodeType&&exports,a=r&&"object"==typeof module&&module&&!module.nodeType&&module,s=a&&a.exports===r?n.A.Buffer:void 0,o=(s?s.isBuffer:void 0)||function(){return!1}},5123:function(e,t,i){"use strict";i.d(t,{A:function(){return C}});var n=i(2673),r=i(3558);function a(e){var t=-1,i=null==e?0:e.length;for(this.__data__=new r.A;++t<i;)this.add(e[t])}a.prototype.add=a.prototype.push=function(e){return this.__data__.set(e,"__lodash_hash_undefined__"),this},a.prototype.has=function(e){return this.__data__.has(e)};var s=a,o=function(e,t){for(var i=-1,n=null==e?0:e.length;++i<n;)if(t(e[i],i,e))return!0;return!1},l=function(e,t,i,n,r,a){var l=1&i,c=e.length,u=t.length;if(c!=u&&!(l&&u>c))return!1;var d=a.get(e),h=a.get(t);if(d&&h)return d==t&&h==e;var f=-1,p=!0,m=2&i?new s:void 0;for(a.set(e,t),a.set(t,e);++f<c;){var g=e[f],v=t[f];if(n)var y=l?n(v,g,f,t,e,a):n(g,v,f,e,t,a);if(void 0!==y){if(y)continue;p=!1;break}if(m){if(!o(t,(function(e,t){if(s=t,!m.has(s)&&(g===e||r(g,e,i,n,a)))return m.push(t);var s}))){p=!1;break}}else if(g!==v&&!r(g,v,i,n,a)){p=!1;break}}return a.delete(e),a.delete(t),p},c=i(439),u=i(7218),d=i(8138),h=function(e){var t=-1,i=Array(e.size);return e.forEach((function(e,n){i[++t]=[n,e]})),i},f=function(e){var t=-1,i=Array(e.size);return e.forEach((function(e){i[++t]=e})),i},p=c.A?c.A.prototype:void 0,m=p?p.valueOf:void 0,g=i(2816),v=Object.prototype.hasOwnProperty,y=i(7995),b=i(723),x=i(776),_=i(5755),w="[object Arguments]",k="[object Array]",M="[object Object]",S=Object.prototype.hasOwnProperty,A=function(e,t,i,r,a,s){var o=(0,b.A)(e),c=(0,b.A)(t),p=o?k:(0,y.A)(e),A=c?k:(0,y.A)(t),L=(p=p==w?M:p)==M,T=(A=A==w?M:A)==M,C=p==A;if(C&&(0,x.A)(e)){if(!(0,x.A)(t))return!1;o=!0,L=!1}if(C&&!L)return s||(s=new n.A),o||(0,_.A)(e)?l(e,t,i,r,a,s):function(e,t,i,n,r,a,s){switch(i){case"[object DataView]":if(e.byteLength!=t.byteLength||e.byteOffset!=t.byteOffset)return!1;e=e.buffer,t=t.buffer;case"[object ArrayBuffer]":return!(e.byteLength!=t.byteLength||!a(new u.A(e),new u.A(t)));case"[object Boolean]":case"[object Date]":case"[object Number]":return(0,d.A)(+e,+t);case"[object Error]":return e.name==t.name&&e.message==t.message;case"[object RegExp]":case"[object String]":return e==t+"";case"[object Map]":var o=h;case"[object Set]":var c=1&n;if(o||(o=f),e.size!=t.size&&!c)return!1;var p=s.get(e);if(p)return p==t;n|=2,s.set(e,t);var g=l(o(e),o(t),n,r,a,s);return s.delete(e),g;case"[object Symbol]":if(m)return m.call(e)==m.call(t)}return!1}(e,t,p,i,r,a,s);if(!(1&i)){var D=L&&S.call(e,"__wrapped__"),E=T&&S.call(t,"__wrapped__");if(D||E){var O=D?e.value():e,P=E?t.value():t;return s||(s=new n.A),a(O,P,i,r,s)}}return!!C&&(s||(s=new n.A),function(e,t,i,n,r,a){var s=1&i,o=(0,g.A)(e),l=o.length;if(l!=(0,g.A)(t).length&&!s)return!1;for(var c=l;c--;){var u=o[c];if(!(s?u in t:v.call(t,u)))return!1}var d=a.get(e),h=a.get(t);if(d&&h)return d==t&&h==e;var f=!0;a.set(e,t),a.set(t,e);for(var p=s;++c<l;){var m=e[u=o[c]],y=t[u];if(n)var b=s?n(y,m,u,t,e,a):n(m,y,u,e,t,a);if(!(void 0===b?m===y||r(m,y,i,n,a):b)){f=!1;break}p||(p="constructor"==u)}if(f&&!p){var x=e.constructor,_=t.constructor;x==_||!("constructor"in e)||!("constructor"in t)||"function"==typeof x&&x instanceof x&&"function"==typeof _&&_ instanceof _||(f=!1)}return a.delete(e),a.delete(t),f}(e,t,i,r,a,s))},L=i(7948),T=function e(t,i,n,r,a){return t===i||(null==t||null==i||!(0,L.A)(t)&&!(0,L.A)(i)?t!=t&&i!=i:A(t,i,n,r,e,a))},C=function(e,t){return T(e,t)}},7572:function(e,t,i){"use strict";var n=i(2159),r=i(659);t.A=function(e){if(!(0,r.A)(e))return!1;var t=(0,n.A)(e);return"[object Function]"==t||"[object GeneratorFunction]"==t||"[object AsyncFunction]"==t||"[object Proxy]"==t}},1628:function(e,t){"use strict";t.A=function(e){return"number"==typeof e&&e>-1&&e%1==0&&e<=9007199254740991}},659:function(e,t){"use strict";t.A=function(e){var t=typeof e;return null!=e&&("object"==t||"function"==t)}},7948:function(e,t){"use strict";t.A=function(e){return null!=e&&"object"==typeof e}},5755:function(e,t,i){"use strict";i.d(t,{A:function(){return u}});var n=i(2159),r=i(1628),a=i(7948),s={};s["[object Float32Array]"]=s["[object Float64Array]"]=s["[object Int8Array]"]=s["[object Int16Array]"]=s["[object Int32Array]"]=s["[object Uint8Array]"]=s["[object Uint8ClampedArray]"]=s["[object Uint16Array]"]=s["[object Uint32Array]"]=!0,s["[object Arguments]"]=s["[object Array]"]=s["[object ArrayBuffer]"]=s["[object Boolean]"]=s["[object DataView]"]=s["[object Date]"]=s["[object Error]"]=s["[object Function]"]=s["[object Map]"]=s["[object Number]"]=s["[object Object]"]=s["[object RegExp]"]=s["[object Set]"]=s["[object String]"]=s["[object WeakMap]"]=!1;var o=i(5771),l=i(8795),c=l.A&&l.A.isTypedArray,u=c?(0,o.A)(c):function(e){return(0,a.A)(e)&&(0,r.A)(e.length)&&!!s[(0,n.A)(e)]}},3169:function(e,t,i){"use strict";i.d(t,{A:function(){return l}});var n=i(6753),r=i(501),a=(0,i(2217).A)(Object.keys,Object),s=Object.prototype.hasOwnProperty,o=i(3628),l=function(e){return(0,o.A)(e)?(0,n.A)(e):function(e){if(!(0,r.A)(e))return a(e);var t=[];for(var i in Object(e))s.call(e,i)&&"constructor"!=i&&t.push(i);return t}(e)}},2624:function(e,t,i){"use strict";i.d(t,{A:function(){return l}});var n=i(6753),r=i(659),a=i(501),s=Object.prototype.hasOwnProperty,o=i(3628),l=function(e){return(0,o.A)(e)?(0,n.A)(e,!0):function(e){if(!(0,r.A)(e))return function(e){var t=[];if(null!=e)for(var i in Object(e))t.push(i);return t}(e);var t=(0,a.A)(e),i=[];for(var n in e)("constructor"!=n||!t&&s.call(e,n))&&i.push(n);return i}(e)}},8347:function(e,t,i){"use strict";i.d(t,{A:function(){return z}});var n,r,a,s,o=i(2673),l=i(6770),c=i(8138),u=function(e,t,i){(void 0!==i&&!(0,c.A)(e[t],i)||void 0===i&&!(t in e))&&(0,l.A)(e,t,i)},d=i(3812),h=i(1827),f=i(4405),p=i(1683),m=i(8412),g=i(723),v=i(3628),y=i(7948),b=i(776),x=i(7572),_=i(659),w=i(2159),k=i(8769),M=Function.prototype,S=Object.prototype,A=M.toString,L=S.hasOwnProperty,T=A.call(Object),C=i(5755),D=function(e,t){if(("constructor"!==t||"function"!=typeof e[t])&&"__proto__"!=t)return e[t]},E=i(9601),O=i(2624),P=function e(t,i,n,r,a){t!==i&&function(e,t,i){for(var n=-1,r=Object(e),a=i(e),s=a.length;s--;){var o=a[++n];if(!1===t(r[o],o,r))break}}(i,(function(s,l){if(a||(a=new o.A),(0,_.A)(s))!function(e,t,i,n,r,a,s){var o,l=D(e,i),c=D(t,i),M=s.get(c);if(M)u(e,i,M);else{var S=a?a(l,c,i+"",e,t,s):void 0,P=void 0===S;if(P){var Y=(0,g.A)(c),I=!Y&&(0,b.A)(c),N=!Y&&!I&&(0,C.A)(c);S=c,Y||I||N?(0,g.A)(l)?S=l:(o=l,(0,y.A)(o)&&(0,v.A)(o)?S=(0,f.A)(l):I?(P=!1,S=(0,d.A)(c,!0)):N?(P=!1,S=(0,h.A)(c,!0)):S=[]):function(e){if(!(0,y.A)(e)||"[object Object]"!=(0,w.A)(e))return!1;var t=(0,k.A)(e);if(null===t)return!0;var i=L.call(t,"constructor")&&t.constructor;return"function"==typeof i&&i instanceof i&&A.call(i)==T}(c)||(0,m.A)(c)?(S=l,(0,m.A)(l)?S=function(e){return(0,E.A)(e,(0,O.A)(e))}(l):(0,_.A)(l)&&!(0,x.A)(l)||(S=(0,p.A)(c))):P=!1}P&&(s.set(c,S),r(S,c,n,a,s),s.delete(c)),u(e,i,S)}}(t,i,l,n,e,r,a);else{var c=r?r(D(t,l),s,l+"",t,i,a):void 0;void 0===c&&(c=s),u(t,l,c)}}),O.A)},Y=function(e){return e},I=Math.max,N=i(7889),j=N.A?function(e,t){return(0,N.A)(e,"toString",{configurable:!0,enumerable:!1,value:(i=t,function(){return i}),writable:!0});var i}:Y,H=Date.now,F=(n=j,r=0,a=0,function(){var e=H(),t=16-(e-a);if(a=e,t>0){if(++r>=800)return arguments[0]}else r=0;return n.apply(void 0,arguments)}),R=i(3767),z=(s=function(e,t,i){P(e,t,i)},function(e,t){return F(function(e,t,i){return t=I(void 0===t?e.length-1:t,0),function(){for(var n=arguments,r=-1,a=I(n.length-t,0),s=Array(a);++r<a;)s[r]=n[t+r];r=-1;for(var o=Array(t+1);++r<t;)o[r]=n[r];return o[t]=i(s),function(e,t,i){switch(i.length){case 0:return e.call(t);case 1:return e.call(t,i[0]);case 2:return e.call(t,i[0],i[1]);case 3:return e.call(t,i[0],i[1],i[2])}return e.apply(t,i)}(e,this,o)}}(e,t,Y),e+"")}((function(e,t){var i=-1,n=t.length,r=n>1?t[n-1]:void 0,a=n>2?t[2]:void 0;for(r=s.length>3&&"function"==typeof r?(n--,r):void 0,a&&function(e,t,i){if(!(0,_.A)(i))return!1;var n=typeof t;return!!("number"==n?(0,v.A)(i)&&(0,R.A)(t,i.length):"string"==n&&t in i)&&(0,c.A)(i[t],e)}(t[0],t[1],a)&&(r=n<3?void 0:r,n=1),e=Object(e);++i<n;){var o=t[i];o&&s(e,o,i)}return e})))},6935:function(e,t){"use strict";t.A=function(){return[]}},6003:function(e,t,i){"use strict";i.r(t),i.d(t,{Attributor:function(){return r},AttributorStore:function(){return h},BlockBlot:function(){return M},ClassAttributor:function(){return c},ContainerBlot:function(){return A},EmbedBlot:function(){return L},InlineBlot:function(){return w},LeafBlot:function(){return g},ParentBlot:function(){return x},Registry:function(){return o},Scope:function(){return n},ScrollBlot:function(){return D},StyleAttributor:function(){return d},TextBlot:function(){return O}});var n=(e=>(e[e.TYPE=3]="TYPE",e[e.LEVEL=12]="LEVEL",e[e.ATTRIBUTE=13]="ATTRIBUTE",e[e.BLOT=14]="BLOT",e[e.INLINE=7]="INLINE",e[e.BLOCK=11]="BLOCK",e[e.BLOCK_BLOT=10]="BLOCK_BLOT",e[e.INLINE_BLOT=6]="INLINE_BLOT",e[e.BLOCK_ATTRIBUTE=9]="BLOCK_ATTRIBUTE",e[e.INLINE_ATTRIBUTE=5]="INLINE_ATTRIBUTE",e[e.ANY=15]="ANY",e))(n||{});class r{constructor(e,t,i={}){this.attrName=e,this.keyName=t;const r=n.TYPE&n.ATTRIBUTE;this.scope=null!=i.scope?i.scope&n.LEVEL|r:n.ATTRIBUTE,null!=i.whitelist&&(this.whitelist=i.whitelist)}static keys(e){return Array.from(e.attributes).map((e=>e.name))}add(e,t){return!!this.canAdd(e,t)&&(e.setAttribute(this.keyName,t),!0)}canAdd(e,t){return null==this.whitelist||("string"==typeof t?this.whitelist.indexOf(t.replace(/["']/g,""))>-1:this.whitelist.indexOf(t)>-1)}remove(e){e.removeAttribute(this.keyName)}value(e){const t=e.getAttribute(this.keyName);return this.canAdd(e,t)&&t?t:""}}class a extends Error{constructor(e){super(e="[Parchment] "+e),this.message=e,this.name=this.constructor.name}}const s=class e{constructor(){this.attributes={},this.classes={},this.tags={},this.types={}}static find(e,t=!1){if(null==e)return null;if(this.blots.has(e))return this.blots.get(e)||null;if(t){let i=null;try{i=e.parentNode}catch{return null}return this.find(i,t)}return null}create(t,i,n){const r=this.query(i);if(null==r)throw new a(`Unable to create ${i} blot`);const s=r,o=i instanceof Node||i.nodeType===Node.TEXT_NODE?i:s.create(n),l=new s(t,o,n);return e.blots.set(l.domNode,l),l}find(t,i=!1){return e.find(t,i)}query(e,t=n.ANY){let i;return"string"==typeof e?i=this.types[e]||this.attributes[e]:e instanceof Text||e.nodeType===Node.TEXT_NODE?i=this.types.text:"number"==typeof e?e&n.LEVEL&n.BLOCK?i=this.types.block:e&n.LEVEL&n.INLINE&&(i=this.types.inline):e instanceof Element&&((e.getAttribute("class")||"").split(/\s+/).some((e=>(i=this.classes[e],!!i))),i=i||this.tags[e.tagName]),null==i?null:"scope"in i&&t&n.LEVEL&i.scope&&t&n.TYPE&i.scope?i:null}register(...e){return e.map((e=>{const t="blotName"in e,i="attrName"in e;if(!t&&!i)throw new a("Invalid definition");if(t&&"abstract"===e.blotName)throw new a("Cannot register abstract class");const n=t?e.blotName:i?e.attrName:void 0;return this.types[n]=e,i?"string"==typeof e.keyName&&(this.attributes[e.keyName]=e):t&&(e.className&&(this.classes[e.className]=e),e.tagName&&(Array.isArray(e.tagName)?e.tagName=e.tagName.map((e=>e.toUpperCase())):e.tagName=e.tagName.toUpperCase(),(Array.isArray(e.tagName)?e.tagName:[e.tagName]).forEach((t=>{(null==this.tags[t]||null==e.className)&&(this.tags[t]=e)})))),e}))}};s.blots=new WeakMap;let o=s;function l(e,t){return(e.getAttribute("class")||"").split(/\s+/).filter((e=>0===e.indexOf(`${t}-`)))}const c=class extends r{static keys(e){return(e.getAttribute("class")||"").split(/\s+/).map((e=>e.split("-").slice(0,-1).join("-")))}add(e,t){return!!this.canAdd(e,t)&&(this.remove(e),e.classList.add(`${this.keyName}-${t}`),!0)}remove(e){l(e,this.keyName).forEach((t=>{e.classList.remove(t)})),0===e.classList.length&&e.removeAttribute("class")}value(e){const t=(l(e,this.keyName)[0]||"").slice(this.keyName.length+1);return this.canAdd(e,t)?t:""}};function u(e){const t=e.split("-"),i=t.slice(1).map((e=>e[0].toUpperCase()+e.slice(1))).join("");return t[0]+i}const d=class extends r{static keys(e){return(e.getAttribute("style")||"").split(";").map((e=>e.split(":")[0].trim()))}add(e,t){return!!this.canAdd(e,t)&&(e.style[u(this.keyName)]=t,!0)}remove(e){e.style[u(this.keyName)]="",e.getAttribute("style")||e.removeAttribute("style")}value(e){const t=e.style[u(this.keyName)];return this.canAdd(e,t)?t:""}},h=class{constructor(e){this.attributes={},this.domNode=e,this.build()}attribute(e,t){t?e.add(this.domNode,t)&&(null!=e.value(this.domNode)?this.attributes[e.attrName]=e:delete this.attributes[e.attrName]):(e.remove(this.domNode),delete this.attributes[e.attrName])}build(){this.attributes={};const e=o.find(this.domNode);if(null==e)return;const t=r.keys(this.domNode),i=c.keys(this.domNode),a=d.keys(this.domNode);t.concat(i).concat(a).forEach((t=>{const i=e.scroll.query(t,n.ATTRIBUTE);i instanceof r&&(this.attributes[i.attrName]=i)}))}copy(e){Object.keys(this.attributes).forEach((t=>{const i=this.attributes[t].value(this.domNode);e.format(t,i)}))}move(e){this.copy(e),Object.keys(this.attributes).forEach((e=>{this.attributes[e].remove(this.domNode)})),this.attributes={}}values(){return Object.keys(this.attributes).reduce(((e,t)=>(e[t]=this.attributes[t].value(this.domNode),e)),{})}},f=class{constructor(e,t){this.scroll=e,this.domNode=t,o.blots.set(t,this),this.prev=null,this.next=null}static create(e){if(null==this.tagName)throw new a("Blot definition missing tagName");let t,i;return Array.isArray(this.tagName)?("string"==typeof e?(i=e.toUpperCase(),parseInt(i,10).toString()===i&&(i=parseInt(i,10))):"number"==typeof e&&(i=e),t="number"==typeof i?document.createElement(this.tagName[i-1]):i&&this.tagName.indexOf(i)>-1?document.createElement(i):document.createElement(this.tagName[0])):t=document.createElement(this.tagName),this.className&&t.classList.add(this.className),t}get statics(){return this.constructor}attach(){}clone(){const e=this.domNode.cloneNode(!1);return this.scroll.create(e)}detach(){null!=this.parent&&this.parent.removeChild(this),o.blots.delete(this.domNode)}deleteAt(e,t){this.isolate(e,t).remove()}formatAt(e,t,i,r){const a=this.isolate(e,t);if(null!=this.scroll.query(i,n.BLOT)&&r)a.wrap(i,r);else if(null!=this.scroll.query(i,n.ATTRIBUTE)){const e=this.scroll.create(this.statics.scope);a.wrap(e),e.format(i,r)}}insertAt(e,t,i){const n=null==i?this.scroll.create("text",t):this.scroll.create(t,i),r=this.split(e);this.parent.insertBefore(n,r||void 0)}isolate(e,t){const i=this.split(e);if(null==i)throw new Error("Attempt to isolate at end");return i.split(t),i}length(){return 1}offset(e=this.parent){return null==this.parent||this===e?0:this.parent.children.offset(this)+this.parent.offset(e)}optimize(e){this.statics.requiredContainer&&!(this.parent instanceof this.statics.requiredContainer)&&this.wrap(this.statics.requiredContainer.blotName)}remove(){null!=this.domNode.parentNode&&this.domNode.parentNode.removeChild(this.domNode),this.detach()}replaceWith(e,t){const i="string"==typeof e?this.scroll.create(e,t):e;return null!=this.parent&&(this.parent.insertBefore(i,this.next||void 0),this.remove()),i}split(e,t){return 0===e?this:this.next}update(e,t){}wrap(e,t){const i="string"==typeof e?this.scroll.create(e,t):e;if(null!=this.parent&&this.parent.insertBefore(i,this.next||void 0),"function"!=typeof i.appendChild)throw new a(`Cannot wrap ${e}`);return i.appendChild(this),i}};f.blotName="abstract";let p=f;const m=class extends p{static value(e){return!0}index(e,t){return this.domNode===e||this.domNode.compareDocumentPosition(e)&Node.DOCUMENT_POSITION_CONTAINED_BY?Math.min(t,1):-1}position(e,t){let i=Array.from(this.parent.domNode.childNodes).indexOf(this.domNode);return e>0&&(i+=1),[this.parent.domNode,i]}value(){return{[this.statics.blotName]:this.statics.value(this.domNode)||!0}}};m.scope=n.INLINE_BLOT;const g=m;class v{constructor(){this.head=null,this.tail=null,this.length=0}append(...e){if(this.insertBefore(e[0],null),e.length>1){const t=e.slice(1);this.append(...t)}}at(e){const t=this.iterator();let i=t();for(;i&&e>0;)e-=1,i=t();return i}contains(e){const t=this.iterator();let i=t();for(;i;){if(i===e)return!0;i=t()}return!1}indexOf(e){const t=this.iterator();let i=t(),n=0;for(;i;){if(i===e)return n;n+=1,i=t()}return-1}insertBefore(e,t){null!=e&&(this.remove(e),e.next=t,null!=t?(e.prev=t.prev,null!=t.prev&&(t.prev.next=e),t.prev=e,t===this.head&&(this.head=e)):null!=this.tail?(this.tail.next=e,e.prev=this.tail,this.tail=e):(e.prev=null,this.head=this.tail=e),this.length+=1)}offset(e){let t=0,i=this.head;for(;null!=i;){if(i===e)return t;t+=i.length(),i=i.next}return-1}remove(e){this.contains(e)&&(null!=e.prev&&(e.prev.next=e.next),null!=e.next&&(e.next.prev=e.prev),e===this.head&&(this.head=e.next),e===this.tail&&(this.tail=e.prev),this.length-=1)}iterator(e=this.head){return()=>{const t=e;return null!=e&&(e=e.next),t}}find(e,t=!1){const i=this.iterator();let n=i();for(;n;){const r=n.length();if(e<r||t&&e===r&&(null==n.next||0!==n.next.length()))return[n,e];e-=r,n=i()}return[null,0]}forEach(e){const t=this.iterator();let i=t();for(;i;)e(i),i=t()}forEachAt(e,t,i){if(t<=0)return;const[n,r]=this.find(e);let a=e-r;const s=this.iterator(n);let o=s();for(;o&&a<e+t;){const n=o.length();e>a?i(o,e-a,Math.min(t,a+n-e)):i(o,0,Math.min(n,e+t-a)),a+=n,o=s()}}map(e){return this.reduce(((t,i)=>(t.push(e(i)),t)),[])}reduce(e,t){const i=this.iterator();let n=i();for(;n;)t=e(t,n),n=i();return t}}function y(e,t){const i=t.find(e);if(i)return i;try{return t.create(e)}catch{const i=t.create(n.INLINE);return Array.from(e.childNodes).forEach((e=>{i.domNode.appendChild(e)})),e.parentNode&&e.parentNode.replaceChild(i.domNode,e),i.attach(),i}}const b=class e extends p{constructor(e,t){super(e,t),this.uiNode=null,this.build()}appendChild(e){this.insertBefore(e)}attach(){super.attach(),this.children.forEach((e=>{e.attach()}))}attachUI(t){null!=this.uiNode&&this.uiNode.remove(),this.uiNode=t,e.uiClass&&this.uiNode.classList.add(e.uiClass),this.uiNode.setAttribute("contenteditable","false"),this.domNode.insertBefore(this.uiNode,this.domNode.firstChild)}build(){this.children=new v,Array.from(this.domNode.childNodes).filter((e=>e!==this.uiNode)).reverse().forEach((e=>{try{const t=y(e,this.scroll);this.insertBefore(t,this.children.head||void 0)}catch(e){if(e instanceof a)return;throw e}}))}deleteAt(e,t){if(0===e&&t===this.length())return this.remove();this.children.forEachAt(e,t,((e,t,i)=>{e.deleteAt(t,i)}))}descendant(t,i=0){const[n,r]=this.children.find(i);return null==t.blotName&&t(n)||null!=t.blotName&&n instanceof t?[n,r]:n instanceof e?n.descendant(t,r):[null,-1]}descendants(t,i=0,n=Number.MAX_VALUE){let r=[],a=n;return this.children.forEachAt(i,n,((i,n,s)=>{(null==t.blotName&&t(i)||null!=t.blotName&&i instanceof t)&&r.push(i),i instanceof e&&(r=r.concat(i.descendants(t,n,a))),a-=s})),r}detach(){this.children.forEach((e=>{e.detach()})),super.detach()}enforceAllowedChildren(){let t=!1;this.children.forEach((i=>{t||this.statics.allowedChildren.some((e=>i instanceof e))||(i.statics.scope===n.BLOCK_BLOT?(null!=i.next&&this.splitAfter(i),null!=i.prev&&this.splitAfter(i.prev),i.parent.unwrap(),t=!0):i instanceof e?i.unwrap():i.remove())}))}formatAt(e,t,i,n){this.children.forEachAt(e,t,((e,t,r)=>{e.formatAt(t,r,i,n)}))}insertAt(e,t,i){const[n,r]=this.children.find(e);if(n)n.insertAt(r,t,i);else{const e=null==i?this.scroll.create("text",t):this.scroll.create(t,i);this.appendChild(e)}}insertBefore(e,t){null!=e.parent&&e.parent.children.remove(e);let i=null;this.children.insertBefore(e,t||null),e.parent=this,null!=t&&(i=t.domNode),(this.domNode.parentNode!==e.domNode||this.domNode.nextSibling!==i)&&this.domNode.insertBefore(e.domNode,i),e.attach()}length(){return this.children.reduce(((e,t)=>e+t.length()),0)}moveChildren(e,t){this.children.forEach((i=>{e.insertBefore(i,t)}))}optimize(e){if(super.optimize(e),this.enforceAllowedChildren(),null!=this.uiNode&&this.uiNode!==this.domNode.firstChild&&this.domNode.insertBefore(this.uiNode,this.domNode.firstChild),0===this.children.length)if(null!=this.statics.defaultChild){const e=this.scroll.create(this.statics.defaultChild.blotName);this.appendChild(e)}else this.remove()}path(t,i=!1){const[n,r]=this.children.find(t,i),a=[[this,t]];return n instanceof e?a.concat(n.path(r,i)):(null!=n&&a.push([n,r]),a)}removeChild(e){this.children.remove(e)}replaceWith(t,i){const n="string"==typeof t?this.scroll.create(t,i):t;return n instanceof e&&this.moveChildren(n),super.replaceWith(n)}split(e,t=!1){if(!t){if(0===e)return this;if(e===this.length())return this.next}const i=this.clone();return this.parent&&this.parent.insertBefore(i,this.next||void 0),this.children.forEachAt(e,this.length(),((e,n,r)=>{const a=e.split(n,t);null!=a&&i.appendChild(a)})),i}splitAfter(e){const t=this.clone();for(;null!=e.next;)t.appendChild(e.next);return this.parent&&this.parent.insertBefore(t,this.next||void 0),t}unwrap(){this.parent&&this.moveChildren(this.parent,this.next||void 0),this.remove()}update(e,t){const i=[],n=[];e.forEach((e=>{e.target===this.domNode&&"childList"===e.type&&(i.push(...e.addedNodes),n.push(...e.removedNodes))})),n.forEach((e=>{if(null!=e.parentNode&&"IFRAME"!==e.tagName&&document.body.compareDocumentPosition(e)&Node.DOCUMENT_POSITION_CONTAINED_BY)return;const t=this.scroll.find(e);null!=t&&(null==t.domNode.parentNode||t.domNode.parentNode===this.domNode)&&t.detach()})),i.filter((e=>e.parentNode===this.domNode&&e!==this.uiNode)).sort(((e,t)=>e===t?0:e.compareDocumentPosition(t)&Node.DOCUMENT_POSITION_FOLLOWING?1:-1)).forEach((e=>{let t=null;null!=e.nextSibling&&(t=this.scroll.find(e.nextSibling));const i=y(e,this.scroll);(i.next!==t||null==i.next)&&(null!=i.parent&&i.parent.removeChild(this),this.insertBefore(i,t||void 0))})),this.enforceAllowedChildren()}};b.uiClass="";const x=b,_=class e extends x{static create(e){return super.create(e)}static formats(t,i){const n=i.query(e.blotName);if(null==n||t.tagName!==n.tagName){if("string"==typeof this.tagName)return!0;if(Array.isArray(this.tagName))return t.tagName.toLowerCase()}}constructor(e,t){super(e,t),this.attributes=new h(this.domNode)}format(t,i){if(t!==this.statics.blotName||i){const e=this.scroll.query(t,n.INLINE);if(null==e)return;e instanceof r?this.attributes.attribute(e,i):i&&(t!==this.statics.blotName||this.formats()[t]!==i)&&this.replaceWith(t,i)}else this.children.forEach((t=>{t instanceof e||(t=t.wrap(e.blotName,!0)),this.attributes.copy(t)})),this.unwrap()}formats(){const e=this.attributes.values(),t=this.statics.formats(this.domNode,this.scroll);return null!=t&&(e[this.statics.blotName]=t),e}formatAt(e,t,i,r){null!=this.formats()[i]||this.scroll.query(i,n.ATTRIBUTE)?this.isolate(e,t).format(i,r):super.formatAt(e,t,i,r)}optimize(t){super.optimize(t);const i=this.formats();if(0===Object.keys(i).length)return this.unwrap();const n=this.next;n instanceof e&&n.prev===this&&function(e,t){if(Object.keys(e).length!==Object.keys(t).length)return!1;for(const i in e)if(e[i]!==t[i])return!1;return!0}(i,n.formats())&&(n.moveChildren(this),n.remove())}replaceWith(e,t){const i=super.replaceWith(e,t);return this.attributes.copy(i),i}update(e,t){super.update(e,t),e.some((e=>e.target===this.domNode&&"attributes"===e.type))&&this.attributes.build()}wrap(t,i){const n=super.wrap(t,i);return n instanceof e&&this.attributes.move(n),n}};_.allowedChildren=[_,g],_.blotName="inline",_.scope=n.INLINE_BLOT,_.tagName="SPAN";const w=_,k=class e extends x{static create(e){return super.create(e)}static formats(t,i){const n=i.query(e.blotName);if(null==n||t.tagName!==n.tagName){if("string"==typeof this.tagName)return!0;if(Array.isArray(this.tagName))return t.tagName.toLowerCase()}}constructor(e,t){super(e,t),this.attributes=new h(this.domNode)}format(t,i){const a=this.scroll.query(t,n.BLOCK);null!=a&&(a instanceof r?this.attributes.attribute(a,i):t!==this.statics.blotName||i?i&&(t!==this.statics.blotName||this.formats()[t]!==i)&&this.replaceWith(t,i):this.replaceWith(e.blotName))}formats(){const e=this.attributes.values(),t=this.statics.formats(this.domNode,this.scroll);return null!=t&&(e[this.statics.blotName]=t),e}formatAt(e,t,i,r){null!=this.scroll.query(i,n.BLOCK)?this.format(i,r):super.formatAt(e,t,i,r)}insertAt(e,t,i){if(null==i||null!=this.scroll.query(t,n.INLINE))super.insertAt(e,t,i);else{const n=this.split(e);if(null==n)throw new Error("Attempt to insertAt after block boundaries");{const e=this.scroll.create(t,i);n.parent.insertBefore(e,n)}}}replaceWith(e,t){const i=super.replaceWith(e,t);return this.attributes.copy(i),i}update(e,t){super.update(e,t),e.some((e=>e.target===this.domNode&&"attributes"===e.type))&&this.attributes.build()}};k.blotName="block",k.scope=n.BLOCK_BLOT,k.tagName="P",k.allowedChildren=[w,k,g];const M=k,S=class extends x{checkMerge(){return null!==this.next&&this.next.statics.blotName===this.statics.blotName}deleteAt(e,t){super.deleteAt(e,t),this.enforceAllowedChildren()}formatAt(e,t,i,n){super.formatAt(e,t,i,n),this.enforceAllowedChildren()}insertAt(e,t,i){super.insertAt(e,t,i),this.enforceAllowedChildren()}optimize(e){super.optimize(e),this.children.length>0&&null!=this.next&&this.checkMerge()&&(this.next.moveChildren(this),this.next.remove())}};S.blotName="container",S.scope=n.BLOCK_BLOT;const A=S,L=class extends g{static formats(e,t){}format(e,t){super.formatAt(0,this.length(),e,t)}formatAt(e,t,i,n){0===e&&t===this.length()?this.format(i,n):super.formatAt(e,t,i,n)}formats(){return this.statics.formats(this.domNode,this.scroll)}},T={attributes:!0,characterData:!0,characterDataOldValue:!0,childList:!0,subtree:!0},C=class extends x{constructor(e,t){super(null,t),this.registry=e,this.scroll=this,this.build(),this.observer=new MutationObserver((e=>{this.update(e)})),this.observer.observe(this.domNode,T),this.attach()}create(e,t){return this.registry.create(this,e,t)}find(e,t=!1){const i=this.registry.find(e,t);return i?i.scroll===this?i:t?this.find(i.scroll.domNode.parentNode,!0):null:null}query(e,t=n.ANY){return this.registry.query(e,t)}register(...e){return this.registry.register(...e)}build(){null!=this.scroll&&super.build()}detach(){super.detach(),this.observer.disconnect()}deleteAt(e,t){this.update(),0===e&&t===this.length()?this.children.forEach((e=>{e.remove()})):super.deleteAt(e,t)}formatAt(e,t,i,n){this.update(),super.formatAt(e,t,i,n)}insertAt(e,t,i){this.update(),super.insertAt(e,t,i)}optimize(e=[],t={}){super.optimize(t);const i=t.mutationsMap||new WeakMap;let n=Array.from(this.observer.takeRecords());for(;n.length>0;)e.push(n.pop());const r=(e,t=!0)=>{null==e||e===this||null!=e.domNode.parentNode&&(i.has(e.domNode)||i.set(e.domNode,[]),t&&r(e.parent))},a=e=>{i.has(e.domNode)&&(e instanceof x&&e.children.forEach(a),i.delete(e.domNode),e.optimize(t))};let s=e;for(let t=0;s.length>0;t+=1){if(t>=100)throw new Error("[Parchment] Maximum optimize iterations reached");for(s.forEach((e=>{const t=this.find(e.target,!0);null!=t&&(t.domNode===e.target&&("childList"===e.type?(r(this.find(e.previousSibling,!1)),Array.from(e.addedNodes).forEach((e=>{const t=this.find(e,!1);r(t,!1),t instanceof x&&t.children.forEach((e=>{r(e,!1)}))}))):"attributes"===e.type&&r(t.prev)),r(t))})),this.children.forEach(a),s=Array.from(this.observer.takeRecords()),n=s.slice();n.length>0;)e.push(n.pop())}}update(e,t={}){e=e||this.observer.takeRecords();const i=new WeakMap;e.map((e=>{const t=this.find(e.target,!0);return null==t?null:i.has(t.domNode)?(i.get(t.domNode).push(e),null):(i.set(t.domNode,[e]),t)})).forEach((e=>{null!=e&&e!==this&&i.has(e.domNode)&&e.update(i.get(e.domNode)||[],t)})),t.mutationsMap=i,i.has(this.domNode)&&super.update(i.get(this.domNode),t),this.optimize(e,t)}};C.blotName="scroll",C.defaultChild=M,C.allowedChildren=[M,A],C.scope=n.BLOCK_BLOT,C.tagName="DIV";const D=C,E=class e extends g{static create(e){return document.createTextNode(e)}static value(e){return e.data}constructor(e,t){super(e,t),this.text=this.statics.value(this.domNode)}deleteAt(e,t){this.domNode.data=this.text=this.text.slice(0,e)+this.text.slice(e+t)}index(e,t){return this.domNode===e?t:-1}insertAt(e,t,i){null==i?(this.text=this.text.slice(0,e)+t+this.text.slice(e),this.domNode.data=this.text):super.insertAt(e,t,i)}length(){return this.text.length}optimize(t){super.optimize(t),this.text=this.statics.value(this.domNode),0===this.text.length?this.remove():this.next instanceof e&&this.next.prev===this&&(this.insertAt(this.length(),this.next.value()),this.next.remove())}position(e,t=!1){return[this.domNode,e]}split(e,t=!1){if(!t){if(0===e)return this;if(e===this.length())return this.next}const i=this.scroll.create(this.domNode.splitText(e));return this.parent.insertBefore(i,this.next||void 0),this.text=this.statics.value(this.domNode),i}update(e,t){e.some((e=>"characterData"===e.type&&e.target===this.domNode))&&(this.text=this.statics.value(this.domNode))}value(){return this.text}};E.blotName="text",E.scope=n.INLINE_BLOT;const O=E}},t={};function i(n){var r=t[n];if(void 0!==r)return r.exports;var a=t[n]={id:n,loaded:!1,exports:{}};return e[n](a,a.exports,i),a.loaded=!0,a.exports}i.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return i.d(t,{a:t}),t},i.d=function(e,t){for(var n in t)i.o(t,n)&&!i.o(e,n)&&Object.defineProperty(e,n,{enumerable:!0,get:t[n]})},i.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),i.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},i.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},i.nmd=function(e){return e.paths=[],e.children||(e.children=[]),e};var n={};return function(){"use strict";i.d(n,{default:function(){return Ie}});var e=i(3729),t=i(8276),r=i(7912),a=i(6003);class s extends a.ClassAttributor{add(e,t){let i=0;if("+1"===t||"-1"===t){const n=this.value(e)||0;i="+1"===t?n+1:n-1}else"number"==typeof t&&(i=t);return 0===i?(this.remove(e),!0):super.add(e,i.toString())}canAdd(e,t){return super.canAdd(e,t)||super.canAdd(e,parseInt(t,10))}value(e){return parseInt(super.value(e),10)||void 0}}var o=new s("indent","ql-indent",{scope:a.Scope.BLOCK,whitelist:[1,2,3,4,5,6,7,8]}),l=i(9698);class c extends l.Ay{static blotName="blockquote";static tagName="blockquote"}var u=c;class d extends l.Ay{static blotName="header";static tagName=["H1","H2","H3","H4","H5","H6"];static formats(e){return this.tagName.indexOf(e.tagName)+1}}var h=d,f=i(580),p=i(6142);class m extends f.A{}m.blotName="list-container",m.tagName="OL";class g extends l.Ay{static create(e){const t=super.create();return t.setAttribute("data-list",e),t}static formats(e){return e.getAttribute("data-list")||void 0}static register(){p.Ay.register(m)}constructor(e,t){super(e,t);const i=t.ownerDocument.createElement("span"),n=i=>{if(!e.isEnabled())return;const n=this.statics.formats(t,e);"checked"===n?(this.format("list","unchecked"),i.preventDefault()):"unchecked"===n&&(this.format("list","checked"),i.preventDefault())};i.addEventListener("mousedown",n),i.addEventListener("touchstart",n),this.attachUI(i)}format(e,t){e===this.statics.blotName&&t?this.domNode.setAttribute("data-list",t):super.format(e,t)}}g.blotName="list",g.tagName="LI",m.allowedChildren=[g],g.requiredContainer=m;var v=i(9541),y=i(8638),b=i(6772),x=i(664),_=i(4850);class w extends _.A{static blotName="bold";static tagName=["STRONG","B"];static create(){return super.create()}static formats(){return!0}optimize(e){super.optimize(e),this.domNode.tagName!==this.statics.tagName[0]&&this.replaceWith(this.statics.blotName)}}var k=w;class M extends _.A{static blotName="link";static tagName="A";static SANITIZED_URL="about:blank";static PROTOCOL_WHITELIST=["http","https","mailto","tel","sms"];static create(e){const t=super.create(e);return t.setAttribute("href",this.sanitize(e)),t.setAttribute("rel","noopener noreferrer"),t.setAttribute("target","_blank"),t}static formats(e){return e.getAttribute("href")}static sanitize(e){return S(e,this.PROTOCOL_WHITELIST)?e:this.SANITIZED_URL}format(e,t){e===this.statics.blotName&&t?this.domNode.setAttribute("href",this.constructor.sanitize(t)):super.format(e,t)}}function S(e,t){const i=document.createElement("a");i.href=e;const n=i.href.slice(0,i.href.indexOf(":"));return t.indexOf(n)>-1}class A extends _.A{static blotName="script";static tagName=["SUB","SUP"];static create(e){return"super"===e?document.createElement("sup"):"sub"===e?document.createElement("sub"):super.create(e)}static formats(e){return"SUB"===e.tagName?"sub":"SUP"===e.tagName?"super":void 0}}var L=A;class T extends _.A{static blotName="underline";static tagName="U"}var C=T,D=i(746);class E extends D.A{static blotName="formula";static className="ql-formula";static tagName="SPAN";static create(e){if(null==window.katex)throw new Error("Formula module requires KaTeX.");const t=super.create(e);return"string"==typeof e&&(window.katex.render(e,t,{throwOnError:!1,errorColor:"#f00"}),t.setAttribute("data-value",e)),t}static value(e){return e.getAttribute("data-value")}html(){const{formula:e}=this.value();return`<span>${e}</span>`}}var O=E;const P=["alt","height","width"];class Y extends a.EmbedBlot{static blotName="image";static tagName="IMG";static create(e){const t=super.create(e);return"string"==typeof e&&t.setAttribute("src",this.sanitize(e)),t}static formats(e){return P.reduce(((t,i)=>(e.hasAttribute(i)&&(t[i]=e.getAttribute(i)),t)),{})}static match(e){return/\.(jpe?g|gif|png)$/.test(e)||/^data:image\/.+;base64/.test(e)}static sanitize(e){return S(e,["http","https","data"])?e:"//:0"}static value(e){return e.getAttribute("src")}format(e,t){P.indexOf(e)>-1?t?this.domNode.setAttribute(e,t):this.domNode.removeAttribute(e):super.format(e,t)}}var I=Y;const N=["height","width"];class j extends l.zo{static blotName="video";static className="ql-video";static tagName="IFRAME";static create(e){const t=super.create(e);return t.setAttribute("frameborder","0"),t.setAttribute("allowfullscreen","true"),t.setAttribute("src",this.sanitize(e)),t}static formats(e){return N.reduce(((t,i)=>(e.hasAttribute(i)&&(t[i]=e.getAttribute(i)),t)),{})}static sanitize(e){return M.sanitize(e)}static value(e){return e.getAttribute("src")}format(e,t){N.indexOf(e)>-1?t?this.domNode.setAttribute(e,t):this.domNode.removeAttribute(e):super.format(e,t)}html(){const{video:e}=this.value();return`<a href="${e}">${e}</a>`}}var H=j,F=i(9404),R=i(5232),z=i.n(R),B=i(4266),V=i(3036),W=i(4541),U=i(5508),q=i(584);const $=new a.ClassAttributor("code-token","hljs",{scope:a.Scope.INLINE});class X extends _.A{static formats(e,t){for(;null!=e&&e!==t.domNode;){if(e.classList&&e.classList.contains(F.Ay.className))return super.formats(e,t);e=e.parentNode}}constructor(e,t,i){super(e,t,i),$.add(this.domNode,i)}format(e,t){e!==X.blotName?super.format(e,t):t?$.add(this.domNode,t):($.remove(this.domNode),this.domNode.classList.remove(this.statics.className))}optimize(){super.optimize(...arguments),$.value(this.domNode)||this.unwrap()}}X.blotName="code-token",X.className="ql-token";class G extends F.Ay{static create(e){const t=super.create(e);return"string"==typeof e&&t.setAttribute("data-language",e),t}static formats(e){return e.getAttribute("data-language")||"plain"}static register(){}format(e,t){e===this.statics.blotName&&t?this.domNode.setAttribute("data-language",t):super.format(e,t)}replaceWith(e,t){return this.formatAt(0,this.length(),X.blotName,!1),super.replaceWith(e,t)}}class Z extends F.EJ{attach(){super.attach(),this.forceNext=!1,this.scroll.emitMount(this)}format(e,t){e===G.blotName&&(this.forceNext=!0,this.children.forEach((i=>{i.format(e,t)})))}formatAt(e,t,i,n){i===G.blotName&&(this.forceNext=!0),super.formatAt(e,t,i,n)}highlight(e){let t=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(null==this.children.head)return;const i=`${Array.from(this.domNode.childNodes).filter((e=>e!==this.uiNode)).map((e=>e.textContent)).join("\n")}\n`,n=G.formats(this.children.head.domNode);if(t||this.forceNext||this.cachedText!==i){if(i.trim().length>0||null==this.cachedText){const t=this.children.reduce(((e,t)=>e.concat((0,l.mG)(t,!1))),new(z())),r=e(i,n);t.diff(r).reduce(((e,t)=>{let{retain:i,attributes:n}=t;return i?(n&&Object.keys(n).forEach((t=>{[G.blotName,X.blotName].includes(t)&&this.formatAt(e,i,t,n[t])})),e+i):e}),0)}this.cachedText=i,this.forceNext=!1}}html(e,t){const[i]=this.children.find(e);return`<pre data-language="${i?G.formats(i.domNode):"plain"}">\n${(0,U.X)(this.code(e,t))}\n</pre>`}optimize(e){if(super.optimize(e),null!=this.parent&&null!=this.children.head&&null!=this.uiNode){const e=G.formats(this.children.head.domNode);e!==this.uiNode.value&&(this.uiNode.value=e)}}}Z.allowedChildren=[G],G.requiredContainer=Z,G.allowedChildren=[X,W.A,U.A,V.A];class K extends B.A{static register(){p.Ay.register(X,!0),p.Ay.register(G,!0),p.Ay.register(Z,!0)}constructor(e,t){if(super(e,t),null==this.options.hljs)throw new Error("Syntax module requires highlight.js. Please include the library on the page before Quill.");this.languages=this.options.languages.reduce(((e,t)=>{let{key:i}=t;return e[i]=!0,e}),{}),this.highlightBlot=this.highlightBlot.bind(this),this.initListener(),this.initTimer()}initListener(){this.quill.on(p.Ay.events.SCROLL_BLOT_MOUNT,(e=>{if(!(e instanceof Z))return;const t=this.quill.root.ownerDocument.createElement("select");this.options.languages.forEach((e=>{let{key:i,label:n}=e;const r=t.ownerDocument.createElement("option");r.textContent=n,r.setAttribute("value",i),t.appendChild(r)})),t.addEventListener("change",(()=>{e.format(G.blotName,t.value),this.quill.root.focus(),this.highlight(e,!0)})),null==e.uiNode&&(e.attachUI(t),e.children.head&&(t.value=G.formats(e.children.head.domNode)))}))}initTimer(){let e=null;this.quill.on(p.Ay.events.SCROLL_OPTIMIZE,(()=>{e&&clearTimeout(e),e=setTimeout((()=>{this.highlight(),e=null}),this.options.interval)}))}highlight(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null,t=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(this.quill.selection.composing)return;this.quill.update(p.Ay.sources.USER);const i=this.quill.getSelection();(null==e?this.quill.scroll.descendants(Z):[e]).forEach((e=>{e.highlight(this.highlightBlot,t)})),this.quill.update(p.Ay.sources.SILENT),null!=i&&this.quill.setSelection(i,p.Ay.sources.SILENT)}highlightBlot(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"plain";if(t=this.languages[t]?t:"plain","plain"===t)return(0,U.X)(e).split("\n").reduce(((e,i,n)=>(0!==n&&e.insert("\n",{[F.Ay.blotName]:t}),e.insert(i))),new(z()));const i=this.quill.root.ownerDocument.createElement("div");return i.classList.add(F.Ay.className),i.innerHTML=((e,t,i)=>{if("string"==typeof e.versionString){const n=e.versionString.split(".")[0];if(parseInt(n,10)>=11)return e.highlight(i,{language:t}).value}return e.highlight(t,i).value})(this.options.hljs,t,e),(0,q.hV)(this.quill.scroll,i,[(e,t)=>{const i=$.value(e);return i?t.compose((new(z())).retain(t.length(),{[X.blotName]:i})):t}],[(e,i)=>e.data.split("\n").reduce(((e,i,n)=>(0!==n&&e.insert("\n",{[F.Ay.blotName]:t}),e.insert(i))),i)],new WeakMap)}}K.DEFAULTS={hljs:window.hljs,interval:1e3,languages:[{key:"plain",label:"Plain"},{key:"bash",label:"Bash"},{key:"cpp",label:"C++"},{key:"cs",label:"C#"},{key:"css",label:"CSS"},{key:"diff",label:"Diff"},{key:"xml",label:"HTML/XML"},{key:"java",label:"Java"},{key:"javascript",label:"JavaScript"},{key:"markdown",label:"Markdown"},{key:"php",label:"PHP"},{key:"python",label:"Python"},{key:"ruby",label:"Ruby"},{key:"sql",label:"SQL"}]};class J extends l.Ay{static blotName="table";static tagName="TD";static create(e){const t=super.create();return e?t.setAttribute("data-row",e):t.setAttribute("data-row",ie()),t}static formats(e){if(e.hasAttribute("data-row"))return e.getAttribute("data-row")}cellOffset(){return this.parent?this.parent.children.indexOf(this):-1}format(e,t){e===J.blotName&&t?this.domNode.setAttribute("data-row",t):super.format(e,t)}row(){return this.parent}rowOffset(){return this.row()?this.row().rowOffset():-1}table(){return this.row()&&this.row().table()}}class Q extends f.A{static blotName="table-row";static tagName="TR";checkMerge(){if(super.checkMerge()&&null!=this.next.children.head){const e=this.children.head.formats(),t=this.children.tail.formats(),i=this.next.children.head.formats(),n=this.next.children.tail.formats();return e.table===t.table&&e.table===i.table&&e.table===n.table}return!1}optimize(e){super.optimize(e),this.children.forEach((e=>{if(null==e.next)return;const t=e.formats(),i=e.next.formats();if(t.table!==i.table){const t=this.splitAfter(e);t&&t.optimize(),this.prev&&this.prev.optimize()}}))}rowOffset(){return this.parent?this.parent.children.indexOf(this):-1}table(){return this.parent&&this.parent.parent}}class ee extends f.A{static blotName="table-body";static tagName="TBODY"}class te extends f.A{static blotName="table-container";static tagName="TABLE";balanceCells(){const e=this.descendants(Q),t=e.reduce(((e,t)=>Math.max(t.children.length,e)),0);e.forEach((e=>{new Array(t-e.children.length).fill(0).forEach((()=>{let t;null!=e.children.head&&(t=J.formats(e.children.head.domNode));const i=this.scroll.create(J.blotName,t);e.appendChild(i),i.optimize()}))}))}cells(e){return this.rows().map((t=>t.children.at(e)))}deleteColumn(e){const[t]=this.descendant(ee);null!=t&&null!=t.children.head&&t.children.forEach((t=>{const i=t.children.at(e);null!=i&&i.remove()}))}insertColumn(e){const[t]=this.descendant(ee);null!=t&&null!=t.children.head&&t.children.forEach((t=>{const i=t.children.at(e),n=J.formats(t.children.head.domNode),r=this.scroll.create(J.blotName,n);t.insertBefore(r,i)}))}insertRow(e){const[t]=this.descendant(ee);if(null==t||null==t.children.head)return;const i=ie(),n=this.scroll.create(Q.blotName);t.children.head.children.forEach((()=>{const e=this.scroll.create(J.blotName,i);n.appendChild(e)}));const r=t.children.at(e);t.insertBefore(n,r)}rows(){const e=this.children.head;return null==e?[]:e.children.map((e=>e))}}function ie(){return`row-${Math.random().toString(36).slice(2,6)}`}te.allowedChildren=[ee],ee.requiredContainer=te,ee.allowedChildren=[Q],Q.requiredContainer=ee,Q.allowedChildren=[J],J.requiredContainer=Q;class ne extends B.A{static register(){p.Ay.register(J),p.Ay.register(Q),p.Ay.register(ee),p.Ay.register(te)}constructor(){super(...arguments),this.listenBalanceCells()}balanceTables(){this.quill.scroll.descendants(te).forEach((e=>{e.balanceCells()}))}deleteColumn(){const[e,,t]=this.getTable();null!=t&&(e.deleteColumn(t.cellOffset()),this.quill.update(p.Ay.sources.USER))}deleteRow(){const[,e]=this.getTable();null!=e&&(e.remove(),this.quill.update(p.Ay.sources.USER))}deleteTable(){const[e]=this.getTable();if(null==e)return;const t=e.offset();e.remove(),this.quill.update(p.Ay.sources.USER),this.quill.setSelection(t,p.Ay.sources.SILENT)}getTable(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:this.quill.getSelection();if(null==e)return[null,null,null,-1];const[t,i]=this.quill.getLine(e.index);if(null==t||t.statics.blotName!==J.blotName)return[null,null,null,-1];const n=t.parent;return[n.parent.parent,n,t,i]}insertColumn(e){const t=this.quill.getSelection();if(!t)return;const[i,n,r]=this.getTable(t);if(null==r)return;const a=r.cellOffset();i.insertColumn(a+e),this.quill.update(p.Ay.sources.USER);let s=n.rowOffset();0===e&&(s+=1),this.quill.setSelection(t.index+s,t.length,p.Ay.sources.SILENT)}insertColumnLeft(){this.insertColumn(0)}insertColumnRight(){this.insertColumn(1)}insertRow(e){const t=this.quill.getSelection();if(!t)return;const[i,n,r]=this.getTable(t);if(null==r)return;const a=n.rowOffset();i.insertRow(a+e),this.quill.update(p.Ay.sources.USER),e>0?this.quill.setSelection(t,p.Ay.sources.SILENT):this.quill.setSelection(t.index+n.children.length,t.length,p.Ay.sources.SILENT)}insertRowAbove(){this.insertRow(0)}insertRowBelow(){this.insertRow(1)}insertTable(e,t){const i=this.quill.getSelection();if(null==i)return;const n=new Array(e).fill(0).reduce((e=>{const i=new Array(t).fill("\n").join("");return e.insert(i,{table:ie()})}),(new(z())).retain(i.index));this.quill.updateContents(n,p.Ay.sources.USER),this.quill.setSelection(i.index,p.Ay.sources.SILENT),this.balanceTables()}listenBalanceCells(){this.quill.on(p.Ay.events.SCROLL_OPTIMIZE,(e=>{e.some((e=>!!["TD","TR","TBODY","TABLE"].includes(e.target.tagName)&&(this.quill.once(p.Ay.events.TEXT_CHANGE,((e,t,i)=>{i===p.Ay.sources.USER&&this.balanceTables()})),!0)))}))}}var re=ne;const ae=(0,i(6078).A)("quill:toolbar");class se extends B.A{constructor(e,t){if(super(e,t),Array.isArray(this.options.container)){const t=document.createElement("div");t.setAttribute("role","toolbar"),function(e,t){Array.isArray(t[0])||(t=[t]),t.forEach((t=>{const i=document.createElement("span");i.classList.add("ql-formats"),t.forEach((e=>{if("string"==typeof e)oe(i,e);else{const t=Object.keys(e)[0],n=e[t];Array.isArray(n)?function(e,t,i){const n=document.createElement("select");n.classList.add(`ql-${t}`),i.forEach((e=>{const t=document.createElement("option");!1!==e?t.setAttribute("value",String(e)):t.setAttribute("selected","selected"),n.appendChild(t)})),e.appendChild(n)}(i,t,n):oe(i,t,n)}})),e.appendChild(i)}))}(t,this.options.container),e.container?.parentNode?.insertBefore(t,e.container),this.container=t}else"string"==typeof this.options.container?this.container=document.querySelector(this.options.container):this.container=this.options.container;this.container instanceof HTMLElement?(this.container.classList.add("ql-toolbar"),this.controls=[],this.handlers={},this.options.handlers&&Object.keys(this.options.handlers).forEach((e=>{const t=this.options.handlers?.[e];t&&this.addHandler(e,t)})),Array.from(this.container.querySelectorAll("button, select")).forEach((e=>{this.attach(e)})),this.quill.on(p.Ay.events.EDITOR_CHANGE,(()=>{const[e]=this.quill.selection.getRange();this.update(e)}))):ae.error("Container required for toolbar",this.options)}addHandler(e,t){this.handlers[e]=t}attach(e){let t=Array.from(e.classList).find((e=>0===e.indexOf("ql-")));if(!t)return;if(t=t.slice(3),"BUTTON"===e.tagName&&e.setAttribute("type","button"),null==this.handlers[t]&&null==this.quill.scroll.query(t))return void ae.warn("ignoring attaching to nonexistent format",t,e);const i="SELECT"===e.tagName?"change":"click";e.addEventListener(i,(i=>{let n;if("SELECT"===e.tagName){if(e.selectedIndex<0)return;const t=e.options[e.selectedIndex];n=!t.hasAttribute("selected")&&(t.value||!1)}else n=!e.classList.contains("ql-active")&&(e.value||!e.hasAttribute("value")),i.preventDefault();this.quill.focus();const[r]=this.quill.selection.getRange();if(null!=this.handlers[t])this.handlers[t].call(this,n);else if(this.quill.scroll.query(t).prototype instanceof a.EmbedBlot){if(n=prompt(`Enter ${t}`),!n)return;this.quill.updateContents((new(z())).retain(r.index).delete(r.length).insert({[t]:n}),p.Ay.sources.USER)}else this.quill.format(t,n,p.Ay.sources.USER);this.update(r)})),this.controls.push([t,e])}update(e){const t=null==e?{}:this.quill.getFormat(e);this.controls.forEach((i=>{const[n,r]=i;if("SELECT"===r.tagName){let i=null;if(null==e)i=null;else if(null==t[n])i=r.querySelector("option[selected]");else if(!Array.isArray(t[n])){let e=t[n];"string"==typeof e&&(e=e.replace(/"/g,'\\"')),i=r.querySelector(`option[value="${e}"]`)}null==i?(r.value="",r.selectedIndex=-1):i.selected=!0}else if(null==e)r.classList.remove("ql-active"),r.setAttribute("aria-pressed","false");else if(r.hasAttribute("value")){const e=t[n],i=e===r.getAttribute("value")||null!=e&&e.toString()===r.getAttribute("value")||null==e&&!r.getAttribute("value");r.classList.toggle("ql-active",i),r.setAttribute("aria-pressed",i.toString())}else{const e=null!=t[n];r.classList.toggle("ql-active",e),r.setAttribute("aria-pressed",e.toString())}}))}}function oe(e,t,i){const n=document.createElement("button");n.setAttribute("type","button"),n.classList.add(`ql-${t}`),n.setAttribute("aria-pressed","false"),null!=i?(n.value=i,n.setAttribute("aria-label",`${t}: ${i}`)):n.setAttribute("aria-label",t),e.appendChild(n)}se.DEFAULTS={},se.DEFAULTS={container:null,handlers:{clean(){const e=this.quill.getSelection();if(null!=e)if(0===e.length){const e=this.quill.getFormat();Object.keys(e).forEach((e=>{null!=this.quill.scroll.query(e,a.Scope.INLINE)&&this.quill.format(e,!1,p.Ay.sources.USER)}))}else this.quill.removeFormat(e.index,e.length,p.Ay.sources.USER)},direction(e){const{align:t}=this.quill.getFormat();"rtl"===e&&null==t?this.quill.format("align","right",p.Ay.sources.USER):e||"right"!==t||this.quill.format("align",!1,p.Ay.sources.USER),this.quill.format("direction",e,p.Ay.sources.USER)},indent(e){const t=this.quill.getSelection(),i=this.quill.getFormat(t),n=parseInt(i.indent||0,10);if("+1"===e||"-1"===e){let t="+1"===e?1:-1;"rtl"===i.direction&&(t*=-1),this.quill.format("indent",n+t,p.Ay.sources.USER)}},link(e){!0===e&&(e=prompt("Enter link URL:")),this.quill.format("link",e,p.Ay.sources.USER)},list(e){const t=this.quill.getSelection(),i=this.quill.getFormat(t);"check"===e?"checked"===i.list||"unchecked"===i.list?this.quill.format("list",!1,p.Ay.sources.USER):this.quill.format("list","unchecked",p.Ay.sources.USER):this.quill.format("list",e,p.Ay.sources.USER)}}};const le='<svg viewbox="0 0 18 18"><polyline class="ql-even ql-stroke" points="5 7 3 9 5 11"/><polyline class="ql-even ql-stroke" points="13 7 15 9 13 11"/><line class="ql-stroke" x1="10" x2="8" y1="5" y2="13"/></svg>';var ce={align:{"":'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="3" x2="15" y1="9" y2="9"/><line class="ql-stroke" x1="3" x2="13" y1="14" y2="14"/><line class="ql-stroke" x1="3" x2="9" y1="4" y2="4"/></svg>',center:'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="15" x2="3" y1="9" y2="9"/><line class="ql-stroke" x1="14" x2="4" y1="14" y2="14"/><line class="ql-stroke" x1="12" x2="6" y1="4" y2="4"/></svg>',right:'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="15" x2="3" y1="9" y2="9"/><line class="ql-stroke" x1="15" x2="5" y1="14" y2="14"/><line class="ql-stroke" x1="15" x2="9" y1="4" y2="4"/></svg>',justify:'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="15" x2="3" y1="9" y2="9"/><line class="ql-stroke" x1="15" x2="3" y1="14" y2="14"/><line class="ql-stroke" x1="15" x2="3" y1="4" y2="4"/></svg>'},background:'<svg viewbox="0 0 18 18"><g class="ql-fill ql-color-label"><polygon points="6 6.868 6 6 5 6 5 7 5.942 7 6 6.868"/><rect height="1" width="1" x="4" y="4"/><polygon points="6.817 5 6 5 6 6 6.38 6 6.817 5"/><rect height="1" width="1" x="2" y="6"/><rect height="1" width="1" x="3" y="5"/><rect height="1" width="1" x="4" y="7"/><polygon points="4 11.439 4 11 3 11 3 12 3.755 12 4 11.439"/><rect height="1" width="1" x="2" y="12"/><rect height="1" width="1" x="2" y="9"/><rect height="1" width="1" x="2" y="15"/><polygon points="4.63 10 4 10 4 11 4.192 11 4.63 10"/><rect height="1" width="1" x="3" y="8"/><path d="M10.832,4.2L11,4.582V4H10.708A1.948,1.948,0,0,1,10.832,4.2Z"/><path d="M7,4.582L7.168,4.2A1.929,1.929,0,0,1,7.292,4H7V4.582Z"/><path d="M8,13H7.683l-0.351.8a1.933,1.933,0,0,1-.124.2H8V13Z"/><rect height="1" width="1" x="12" y="2"/><rect height="1" width="1" x="11" y="3"/><path d="M9,3H8V3.282A1.985,1.985,0,0,1,9,3Z"/><rect height="1" width="1" x="2" y="3"/><rect height="1" width="1" x="6" y="2"/><rect height="1" width="1" x="3" y="2"/><rect height="1" width="1" x="5" y="3"/><rect height="1" width="1" x="9" y="2"/><rect height="1" width="1" x="15" y="14"/><polygon points="13.447 10.174 13.469 10.225 13.472 10.232 13.808 11 14 11 14 10 13.37 10 13.447 10.174"/><rect height="1" width="1" x="13" y="7"/><rect height="1" width="1" x="15" y="5"/><rect height="1" width="1" x="14" y="6"/><rect height="1" width="1" x="15" y="8"/><rect height="1" width="1" x="14" y="9"/><path d="M3.775,14H3v1H4V14.314A1.97,1.97,0,0,1,3.775,14Z"/><rect height="1" width="1" x="14" y="3"/><polygon points="12 6.868 12 6 11.62 6 12 6.868"/><rect height="1" width="1" x="15" y="2"/><rect height="1" width="1" x="12" y="5"/><rect height="1" width="1" x="13" y="4"/><polygon points="12.933 9 13 9 13 8 12.495 8 12.933 9"/><rect height="1" width="1" x="9" y="14"/><rect height="1" width="1" x="8" y="15"/><path d="M6,14.926V15H7V14.316A1.993,1.993,0,0,1,6,14.926Z"/><rect height="1" width="1" x="5" y="15"/><path d="M10.668,13.8L10.317,13H10v1h0.792A1.947,1.947,0,0,1,10.668,13.8Z"/><rect height="1" width="1" x="11" y="15"/><path d="M14.332,12.2a1.99,1.99,0,0,1,.166.8H15V12H14.245Z"/><rect height="1" width="1" x="14" y="15"/><rect height="1" width="1" x="15" y="11"/></g><polyline class="ql-stroke" points="5.5 13 9 5 12.5 13"/><line class="ql-stroke" x1="11.63" x2="6.38" y1="11" y2="11"/></svg>',blockquote:'<svg viewbox="0 0 18 18"><rect class="ql-fill ql-stroke" height="3" width="3" x="4" y="5"/><rect class="ql-fill ql-stroke" height="3" width="3" x="11" y="5"/><path class="ql-even ql-fill ql-stroke" d="M7,8c0,4.031-3,5-3,5"/><path class="ql-even ql-fill ql-stroke" d="M14,8c0,4.031-3,5-3,5"/></svg>',bold:'<svg viewbox="0 0 18 18"><path class="ql-stroke" d="M5,4H9.5A2.5,2.5,0,0,1,12,6.5v0A2.5,2.5,0,0,1,9.5,9H5A0,0,0,0,1,5,9V4A0,0,0,0,1,5,4Z"/><path class="ql-stroke" d="M5,9h5.5A2.5,2.5,0,0,1,13,11.5v0A2.5,2.5,0,0,1,10.5,14H5a0,0,0,0,1,0,0V9A0,0,0,0,1,5,9Z"/></svg>',clean:'<svg class="" viewbox="0 0 18 18"><line class="ql-stroke" x1="5" x2="13" y1="3" y2="3"/><line class="ql-stroke" x1="6" x2="9.35" y1="12" y2="3"/><line class="ql-stroke" x1="11" x2="15" y1="11" y2="15"/><line class="ql-stroke" x1="15" x2="11" y1="11" y2="15"/><rect class="ql-fill" height="1" rx="0.5" ry="0.5" width="7" x="2" y="14"/></svg>',code:le,"code-block":le,color:'<svg viewbox="0 0 18 18"><line class="ql-color-label ql-stroke ql-transparent" x1="3" x2="15" y1="15" y2="15"/><polyline class="ql-stroke" points="5.5 11 9 3 12.5 11"/><line class="ql-stroke" x1="11.63" x2="6.38" y1="9" y2="9"/></svg>',direction:{"":'<svg viewbox="0 0 18 18"><polygon class="ql-stroke ql-fill" points="3 11 5 9 3 7 3 11"/><line class="ql-stroke ql-fill" x1="15" x2="11" y1="4" y2="4"/><path class="ql-fill" d="M11,3a3,3,0,0,0,0,6h1V3H11Z"/><rect class="ql-fill" height="11" width="1" x="11" y="4"/><rect class="ql-fill" height="11" width="1" x="13" y="4"/></svg>',rtl:'<svg viewbox="0 0 18 18"><polygon class="ql-stroke ql-fill" points="15 12 13 10 15 8 15 12"/><line class="ql-stroke ql-fill" x1="9" x2="5" y1="4" y2="4"/><path class="ql-fill" d="M5,3A3,3,0,0,0,5,9H6V3H5Z"/><rect class="ql-fill" height="11" width="1" x="5" y="4"/><rect class="ql-fill" height="11" width="1" x="7" y="4"/></svg>'},formula:'<svg viewbox="0 0 18 18"><path class="ql-fill" d="M11.759,2.482a2.561,2.561,0,0,0-3.53.607A7.656,7.656,0,0,0,6.8,6.2C6.109,9.188,5.275,14.677,4.15,14.927a1.545,1.545,0,0,0-1.3-.933A0.922,0.922,0,0,0,2,15.036S1.954,16,4.119,16s3.091-2.691,3.7-5.553c0.177-.826.36-1.726,0.554-2.6L8.775,6.2c0.381-1.421.807-2.521,1.306-2.676a1.014,1.014,0,0,0,1.02.56A0.966,0.966,0,0,0,11.759,2.482Z"/><rect class="ql-fill" height="1.6" rx="0.8" ry="0.8" width="5" x="5.15" y="6.2"/><path class="ql-fill" d="M13.663,12.027a1.662,1.662,0,0,1,.266-0.276q0.193,0.069.456,0.138a2.1,2.1,0,0,0,.535.069,1.075,1.075,0,0,0,.767-0.3,1.044,1.044,0,0,0,.314-0.8,0.84,0.84,0,0,0-.238-0.619,0.8,0.8,0,0,0-.594-0.239,1.154,1.154,0,0,0-.781.3,4.607,4.607,0,0,0-.781,1q-0.091.15-.218,0.346l-0.246.38c-0.068-.288-0.137-0.582-0.212-0.885-0.459-1.847-2.494-.984-2.941-0.8-0.482.2-.353,0.647-0.094,0.529a0.869,0.869,0,0,1,1.281.585c0.217,0.751.377,1.436,0.527,2.038a5.688,5.688,0,0,1-.362.467,2.69,2.69,0,0,1-.264.271q-0.221-.08-0.471-0.147a2.029,2.029,0,0,0-.522-0.066,1.079,1.079,0,0,0-.768.3A1.058,1.058,0,0,0,9,15.131a0.82,0.82,0,0,0,.832.852,1.134,1.134,0,0,0,.787-0.3,5.11,5.11,0,0,0,.776-0.993q0.141-.219.215-0.34c0.046-.076.122-0.194,0.223-0.346a2.786,2.786,0,0,0,.918,1.726,2.582,2.582,0,0,0,2.376-.185c0.317-.181.212-0.565,0-0.494A0.807,0.807,0,0,1,14.176,15a5.159,5.159,0,0,1-.913-2.446l0,0Q13.487,12.24,13.663,12.027Z"/></svg>',header:{1:'<svg viewBox="0 0 18 18"><path class="ql-fill" d="M10,4V14a1,1,0,0,1-2,0V10H3v4a1,1,0,0,1-2,0V4A1,1,0,0,1,3,4V8H8V4a1,1,0,0,1,2,0Zm6.06787,9.209H14.98975V7.59863a.54085.54085,0,0,0-.605-.60547h-.62744a1.01119,1.01119,0,0,0-.748.29688L11.645,8.56641a.5435.5435,0,0,0-.022.8584l.28613.30762a.53861.53861,0,0,0,.84717.0332l.09912-.08789a1.2137,1.2137,0,0,0,.2417-.35254h.02246s-.01123.30859-.01123.60547V13.209H12.041a.54085.54085,0,0,0-.605.60547v.43945a.54085.54085,0,0,0,.605.60547h4.02686a.54085.54085,0,0,0,.605-.60547v-.43945A.54085.54085,0,0,0,16.06787,13.209Z"/></svg>',2:'<svg viewBox="0 0 18 18"><path class="ql-fill" d="M16.73975,13.81445v.43945a.54085.54085,0,0,1-.605.60547H11.855a.58392.58392,0,0,1-.64893-.60547V14.0127c0-2.90527,3.39941-3.42187,3.39941-4.55469a.77675.77675,0,0,0-.84717-.78125,1.17684,1.17684,0,0,0-.83594.38477c-.2749.26367-.561.374-.85791.13184l-.4292-.34082c-.30811-.24219-.38525-.51758-.1543-.81445a2.97155,2.97155,0,0,1,2.45361-1.17676,2.45393,2.45393,0,0,1,2.68408,2.40918c0,2.45312-3.1792,2.92676-3.27832,3.93848h2.79443A.54085.54085,0,0,1,16.73975,13.81445ZM9,3A.99974.99974,0,0,0,8,4V8H3V4A1,1,0,0,0,1,4V14a1,1,0,0,0,2,0V10H8v4a1,1,0,0,0,2,0V4A.99974.99974,0,0,0,9,3Z"/></svg>',3:'<svg viewBox="0 0 18 18"><path class="ql-fill" d="M16.65186,12.30664a2.6742,2.6742,0,0,1-2.915,2.68457,3.96592,3.96592,0,0,1-2.25537-.6709.56007.56007,0,0,1-.13232-.83594L11.64648,13c.209-.34082.48389-.36328.82471-.1543a2.32654,2.32654,0,0,0,1.12256.33008c.71484,0,1.12207-.35156,1.12207-.78125,0-.61523-.61621-.86816-1.46338-.86816H13.2085a.65159.65159,0,0,1-.68213-.41895l-.05518-.10937a.67114.67114,0,0,1,.14307-.78125l.71533-.86914a8.55289,8.55289,0,0,1,.68213-.7373V8.58887a3.93913,3.93913,0,0,1-.748.05469H11.9873a.54085.54085,0,0,1-.605-.60547V7.59863a.54085.54085,0,0,1,.605-.60547h3.75146a.53773.53773,0,0,1,.60547.59375v.17676a1.03723,1.03723,0,0,1-.27539.748L14.74854,10.0293A2.31132,2.31132,0,0,1,16.65186,12.30664ZM9,3A.99974.99974,0,0,0,8,4V8H3V4A1,1,0,0,0,1,4V14a1,1,0,0,0,2,0V10H8v4a1,1,0,0,0,2,0V4A.99974.99974,0,0,0,9,3Z"/></svg>',4:'<svg viewBox="0 0 18 18"><path class="ql-fill" d="M10,4V14a1,1,0,0,1-2,0V10H3v4a1,1,0,0,1-2,0V4A1,1,0,0,1,3,4V8H8V4a1,1,0,0,1,2,0Zm7.05371,7.96582v.38477c0,.39648-.165.60547-.46191.60547h-.47314v1.29785a.54085.54085,0,0,1-.605.60547h-.69336a.54085.54085,0,0,1-.605-.60547V12.95605H11.333a.5412.5412,0,0,1-.60547-.60547v-.15332a1.199,1.199,0,0,1,.22021-.748l2.56348-4.05957a.7819.7819,0,0,1,.72607-.39648h1.27637a.54085.54085,0,0,1,.605.60547v3.7627h.33008A.54055.54055,0,0,1,17.05371,11.96582ZM14.28125,8.7207h-.022a4.18969,4.18969,0,0,1-.38525.81348l-1.188,1.80469v.02246h1.5293V9.60059A7.04058,7.04058,0,0,1,14.28125,8.7207Z"/></svg>',5:'<svg viewBox="0 0 18 18"><path class="ql-fill" d="M16.74023,12.18555a2.75131,2.75131,0,0,1-2.91553,2.80566,3.908,3.908,0,0,1-2.25537-.68164.54809.54809,0,0,1-.13184-.8252L11.73438,13c.209-.34082.48389-.36328.8252-.1543a2.23757,2.23757,0,0,0,1.1001.33008,1.01827,1.01827,0,0,0,1.1001-.96777c0-.61621-.53906-.97949-1.25439-.97949a2.15554,2.15554,0,0,0-.64893.09961,1.15209,1.15209,0,0,1-.814.01074l-.12109-.04395a.64116.64116,0,0,1-.45117-.71484l.231-3.00391a.56666.56666,0,0,1,.62744-.583H15.541a.54085.54085,0,0,1,.605.60547v.43945a.54085.54085,0,0,1-.605.60547H13.41748l-.04395.72559a1.29306,1.29306,0,0,1-.04395.30859h.022a2.39776,2.39776,0,0,1,.57227-.07715A2.53266,2.53266,0,0,1,16.74023,12.18555ZM9,3A.99974.99974,0,0,0,8,4V8H3V4A1,1,0,0,0,1,4V14a1,1,0,0,0,2,0V10H8v4a1,1,0,0,0,2,0V4A.99974.99974,0,0,0,9,3Z"/></svg>',6:'<svg viewBox="0 0 18 18"><path class="ql-fill" d="M14.51758,9.64453a1.85627,1.85627,0,0,0-1.24316.38477H13.252a1.73532,1.73532,0,0,1,1.72754-1.4082,2.66491,2.66491,0,0,1,.5498.06641c.35254.05469.57227.01074.70508-.40723l.16406-.5166a.53393.53393,0,0,0-.373-.75977,4.83723,4.83723,0,0,0-1.17773-.14258c-2.43164,0-3.7627,2.17773-3.7627,4.43359,0,2.47559,1.60645,3.69629,3.19043,3.69629A2.70585,2.70585,0,0,0,16.96,12.19727,2.43861,2.43861,0,0,0,14.51758,9.64453Zm-.23047,3.58691c-.67187,0-1.22168-.81445-1.22168-1.45215,0-.47363.30762-.583.72559-.583.96875,0,1.27734.59375,1.27734,1.12207A.82182.82182,0,0,1,14.28711,13.23145ZM10,4V14a1,1,0,0,1-2,0V10H3v4a1,1,0,0,1-2,0V4A1,1,0,0,1,3,4V8H8V4a1,1,0,0,1,2,0Z"/></svg>'},italic:'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="7" x2="13" y1="4" y2="4"/><line class="ql-stroke" x1="5" x2="11" y1="14" y2="14"/><line class="ql-stroke" x1="8" x2="10" y1="14" y2="4"/></svg>',image:'<svg viewbox="0 0 18 18"><rect class="ql-stroke" height="10" width="12" x="3" y="4"/><circle class="ql-fill" cx="6" cy="7" r="1"/><polyline class="ql-even ql-fill" points="5 12 5 11 7 9 8 10 11 7 13 9 13 12 5 12"/></svg>',indent:{"+1":'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="3" x2="15" y1="14" y2="14"/><line class="ql-stroke" x1="3" x2="15" y1="4" y2="4"/><line class="ql-stroke" x1="9" x2="15" y1="9" y2="9"/><polyline class="ql-fill ql-stroke" points="3 7 3 11 5 9 3 7"/></svg>',"-1":'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="3" x2="15" y1="14" y2="14"/><line class="ql-stroke" x1="3" x2="15" y1="4" y2="4"/><line class="ql-stroke" x1="9" x2="15" y1="9" y2="9"/><polyline class="ql-stroke" points="5 7 5 11 3 9 5 7"/></svg>'},link:'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="7" x2="11" y1="7" y2="11"/><path class="ql-even ql-stroke" d="M8.9,4.577a3.476,3.476,0,0,1,.36,4.679A3.476,3.476,0,0,1,4.577,8.9C3.185,7.5,2.035,6.4,4.217,4.217S7.5,3.185,8.9,4.577Z"/><path class="ql-even ql-stroke" d="M13.423,9.1a3.476,3.476,0,0,0-4.679-.36,3.476,3.476,0,0,0,.36,4.679c1.392,1.392,2.5,2.542,4.679.36S14.815,10.5,13.423,9.1Z"/></svg>',list:{bullet:'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="6" x2="15" y1="4" y2="4"/><line class="ql-stroke" x1="6" x2="15" y1="9" y2="9"/><line class="ql-stroke" x1="6" x2="15" y1="14" y2="14"/><line class="ql-stroke" x1="3" x2="3" y1="4" y2="4"/><line class="ql-stroke" x1="3" x2="3" y1="9" y2="9"/><line class="ql-stroke" x1="3" x2="3" y1="14" y2="14"/></svg>',check:'<svg class="" viewbox="0 0 18 18"><line class="ql-stroke" x1="9" x2="15" y1="4" y2="4"/><polyline class="ql-stroke" points="3 4 4 5 6 3"/><line class="ql-stroke" x1="9" x2="15" y1="14" y2="14"/><polyline class="ql-stroke" points="3 14 4 15 6 13"/><line class="ql-stroke" x1="9" x2="15" y1="9" y2="9"/><polyline class="ql-stroke" points="3 9 4 10 6 8"/></svg>',ordered:'<svg viewbox="0 0 18 18"><line class="ql-stroke" x1="7" x2="15" y1="4" y2="4"/><line class="ql-stroke" x1="7" x2="15" y1="9" y2="9"/><line class="ql-stroke" x1="7" x2="15" y1="14" y2="14"/><line class="ql-stroke ql-thin" x1="2.5" x2="4.5" y1="5.5" y2="5.5"/><path class="ql-fill" d="M3.5,6A0.5,0.5,0,0,1,3,5.5V3.085l-0.276.138A0.5,0.5,0,0,1,2.053,3c-0.124-.247-0.023-0.324.224-0.447l1-.5A0.5,0.5,0,0,1,4,2.5v3A0.5,0.5,0,0,1,3.5,6Z"/><path class="ql-stroke ql-thin" d="M4.5,10.5h-2c0-.234,1.85-1.076,1.85-2.234A0.959,0.959,0,0,0,2.5,8.156"/><path class="ql-stroke ql-thin" d="M2.5,14.846a0.959,0.959,0,0,0,1.85-.109A0.7,0.7,0,0,0,3.75,14a0.688,0.688,0,0,0,.6-0.736,0.959,0.959,0,0,0-1.85-.109"/></svg>'},script:{sub:'<svg viewbox="0 0 18 18"><path class="ql-fill" d="M15.5,15H13.861a3.858,3.858,0,0,0,1.914-2.975,1.8,1.8,0,0,0-1.6-1.751A1.921,1.921,0,0,0,12.021,11.7a0.50013,0.50013,0,1,0,.957.291h0a0.914,0.914,0,0,1,1.053-.725,0.81,0.81,0,0,1,.744.762c0,1.076-1.16971,1.86982-1.93971,2.43082A1.45639,1.45639,0,0,0,12,15.5a0.5,0.5,0,0,0,.5.5h3A0.5,0.5,0,0,0,15.5,15Z"/><path class="ql-fill" d="M9.65,5.241a1,1,0,0,0-1.409.108L6,7.964,3.759,5.349A1,1,0,0,0,2.192,6.59178Q2.21541,6.6213,2.241,6.649L4.684,9.5,2.241,12.35A1,1,0,0,0,3.71,13.70722q0.02557-.02768.049-0.05722L6,11.036,8.241,13.65a1,1,0,1,0,1.567-1.24277Q9.78459,12.3777,9.759,12.35L7.316,9.5,9.759,6.651A1,1,0,0,0,9.65,5.241Z"/></svg>',super:'<svg viewbox="0 0 18 18"><path class="ql-fill" d="M15.5,7H13.861a4.015,4.015,0,0,0,1.914-2.975,1.8,1.8,0,0,0-1.6-1.751A1.922,1.922,0,0,0,12.021,3.7a0.5,0.5,0,1,0,.957.291,0.917,0.917,0,0,1,1.053-.725,0.81,0.81,0,0,1,.744.762c0,1.077-1.164,1.925-1.934,2.486A1.423,1.423,0,0,0,12,7.5a0.5,0.5,0,0,0,.5.5h3A0.5,0.5,0,0,0,15.5,7Z"/><path class="ql-fill" d="M9.651,5.241a1,1,0,0,0-1.41.108L6,7.964,3.759,5.349a1,1,0,1,0-1.519,1.3L4.683,9.5,2.241,12.35a1,1,0,1,0,1.519,1.3L6,11.036,8.241,13.65a1,1,0,0,0,1.519-1.3L7.317,9.5,9.759,6.651A1,1,0,0,0,9.651,5.241Z"/></svg>'},strike:'<svg viewbox="0 0 18 18"><line class="ql-stroke ql-thin" x1="15.5" x2="2.5" y1="8.5" y2="9.5"/><path class="ql-fill" d="M9.007,8C6.542,7.791,6,7.519,6,6.5,6,5.792,7.283,5,9,5c1.571,0,2.765.679,2.969,1.309a1,1,0,0,0,1.9-.617C13.356,4.106,11.354,3,9,3,6.2,3,4,4.538,4,6.5a3.2,3.2,0,0,0,.5,1.843Z"/><path class="ql-fill" d="M8.984,10C11.457,10.208,12,10.479,12,11.5c0,0.708-1.283,1.5-3,1.5-1.571,0-2.765-.679-2.969-1.309a1,1,0,1,0-1.9.617C4.644,13.894,6.646,15,9,15c2.8,0,5-1.538,5-3.5a3.2,3.2,0,0,0-.5-1.843Z"/></svg>',table:'<svg viewbox="0 0 18 18"><rect class="ql-stroke" height="12" width="12" x="3" y="3"/><rect class="ql-fill" height="2" width="3" x="5" y="5"/><rect class="ql-fill" height="2" width="4" x="9" y="5"/><g class="ql-fill ql-transparent"><rect height="2" width="3" x="5" y="8"/><rect height="2" width="4" x="9" y="8"/><rect height="2" width="3" x="5" y="11"/><rect height="2" width="4" x="9" y="11"/></g></svg>',underline:'<svg viewbox="0 0 18 18"><path class="ql-stroke" d="M5,3V9a4.012,4.012,0,0,0,4,4H9a4.012,4.012,0,0,0,4-4V3"/><rect class="ql-fill" height="1" rx="0.5" ry="0.5" width="12" x="3" y="15"/></svg>',video:'<svg viewbox="0 0 18 18"><rect class="ql-stroke" height="12" width="12" x="3" y="3"/><rect class="ql-fill" height="12" width="1" x="5" y="3"/><rect class="ql-fill" height="12" width="1" x="12" y="3"/><rect class="ql-fill" height="2" width="8" x="5" y="8"/><rect class="ql-fill" height="1" width="3" x="3" y="5"/><rect class="ql-fill" height="1" width="3" x="3" y="7"/><rect class="ql-fill" height="1" width="3" x="3" y="10"/><rect class="ql-fill" height="1" width="3" x="3" y="12"/><rect class="ql-fill" height="1" width="3" x="12" y="5"/><rect class="ql-fill" height="1" width="3" x="12" y="7"/><rect class="ql-fill" height="1" width="3" x="12" y="10"/><rect class="ql-fill" height="1" width="3" x="12" y="12"/></svg>'};let ue=0;function de(e,t){e.setAttribute(t,`${!("true"===e.getAttribute(t))}`)}var he=class{constructor(e){this.select=e,this.container=document.createElement("span"),this.buildPicker(),this.select.style.display="none",this.select.parentNode.insertBefore(this.container,this.select),this.label.addEventListener("mousedown",(()=>{this.togglePicker()})),this.label.addEventListener("keydown",(e=>{switch(e.key){case"Enter":this.togglePicker();break;case"Escape":this.escape(),e.preventDefault()}})),this.select.addEventListener("change",this.update.bind(this))}togglePicker(){this.container.classList.toggle("ql-expanded"),de(this.label,"aria-expanded"),de(this.options,"aria-hidden")}buildItem(e){const t=document.createElement("span");t.tabIndex="0",t.setAttribute("role","button"),t.classList.add("ql-picker-item");const i=e.getAttribute("value");return i&&t.setAttribute("data-value",i),e.textContent&&t.setAttribute("data-label",e.textContent),t.addEventListener("click",(()=>{this.selectItem(t,!0)})),t.addEventListener("keydown",(e=>{switch(e.key){case"Enter":this.selectItem(t,!0),e.preventDefault();break;case"Escape":this.escape(),e.preventDefault()}})),t}buildLabel(){const e=document.createElement("span");return e.classList.add("ql-picker-label"),e.innerHTML='<svg viewbox="0 0 18 18"><polygon class="ql-stroke" points="7 11 9 13 11 11 7 11"/><polygon class="ql-stroke" points="7 7 9 5 11 7 7 7"/></svg>',e.tabIndex="0",e.setAttribute("role","button"),e.setAttribute("aria-expanded","false"),this.container.appendChild(e),e}buildOptions(){const e=document.createElement("span");e.classList.add("ql-picker-options"),e.setAttribute("aria-hidden","true"),e.tabIndex="-1",e.id=`ql-picker-options-${ue}`,ue+=1,this.label.setAttribute("aria-controls",e.id),this.options=e,Array.from(this.select.options).forEach((t=>{const i=this.buildItem(t);e.appendChild(i),!0===t.selected&&this.selectItem(i)})),this.container.appendChild(e)}buildPicker(){Array.from(this.select.attributes).forEach((e=>{this.container.setAttribute(e.name,e.value)})),this.container.classList.add("ql-picker"),this.label=this.buildLabel(),this.buildOptions()}escape(){this.close(),setTimeout((()=>this.label.focus()),1)}close(){this.container.classList.remove("ql-expanded"),this.label.setAttribute("aria-expanded","false"),this.options.setAttribute("aria-hidden","true")}selectItem(e){let t=arguments.length>1&&void 0!==arguments[1]&&arguments[1];const i=this.container.querySelector(".ql-selected");e!==i&&(null!=i&&i.classList.remove("ql-selected"),null!=e&&(e.classList.add("ql-selected"),this.select.selectedIndex=Array.from(e.parentNode.children).indexOf(e),e.hasAttribute("data-value")?this.label.setAttribute("data-value",e.getAttribute("data-value")):this.label.removeAttribute("data-value"),e.hasAttribute("data-label")?this.label.setAttribute("data-label",e.getAttribute("data-label")):this.label.removeAttribute("data-label"),t&&(this.select.dispatchEvent(new Event("change")),this.close())))}update(){let e;if(this.select.selectedIndex>-1){const t=this.container.querySelector(".ql-picker-options").children[this.select.selectedIndex];e=this.select.options[this.select.selectedIndex],this.selectItem(t)}else this.selectItem(null);const t=null!=e&&e!==this.select.querySelector("option[selected]");this.label.classList.toggle("ql-active",t)}},fe=class extends he{constructor(e,t){super(e),this.label.innerHTML=t,this.container.classList.add("ql-color-picker"),Array.from(this.container.querySelectorAll(".ql-picker-item")).slice(0,7).forEach((e=>{e.classList.add("ql-primary")}))}buildItem(e){const t=super.buildItem(e);return t.style.backgroundColor=e.getAttribute("value")||"",t}selectItem(e,t){super.selectItem(e,t);const i=this.label.querySelector(".ql-color-label"),n=e&&e.getAttribute("data-value")||"";i&&("line"===i.tagName?i.style.stroke=n:i.style.fill=n)}},pe=class extends he{constructor(e,t){super(e),this.container.classList.add("ql-icon-picker"),Array.from(this.container.querySelectorAll(".ql-picker-item")).forEach((e=>{e.innerHTML=t[e.getAttribute("data-value")||""]})),this.defaultItem=this.container.querySelector(".ql-selected"),this.selectItem(this.defaultItem)}selectItem(e,t){super.selectItem(e,t);const i=e||this.defaultItem;if(null!=i){if(this.label.innerHTML===i.innerHTML)return;this.label.innerHTML=i.innerHTML}}},me=class{constructor(e,t){this.quill=e,this.boundsContainer=t||document.body,this.root=e.addContainer("ql-tooltip"),this.root.innerHTML=this.constructor.TEMPLATE,(e=>{const{overflowY:t}=getComputedStyle(e,null);return"visible"!==t&&"clip"!==t})(this.quill.root)&&this.quill.root.addEventListener("scroll",(()=>{this.root.style.marginTop=-1*this.quill.root.scrollTop+"px"})),this.hide()}hide(){this.root.classList.add("ql-hidden")}position(e){const t=e.left+e.width/2-this.root.offsetWidth/2,i=e.bottom+this.quill.root.scrollTop;this.root.style.left=`${t}px`,this.root.style.top=`${i}px`,this.root.classList.remove("ql-flip");const n=this.boundsContainer.getBoundingClientRect(),r=this.root.getBoundingClientRect();let a=0;if(r.right>n.right&&(a=n.right-r.right,this.root.style.left=`${t+a}px`),r.left<n.left&&(a=n.left-r.left,this.root.style.left=`${t+a}px`),r.bottom>n.bottom){const t=r.bottom-r.top,n=e.bottom-e.top+t;this.root.style.top=i-n+"px",this.root.classList.add("ql-flip")}return a}show(){this.root.classList.remove("ql-editing"),this.root.classList.remove("ql-hidden")}},ge=i(8347),ve=i(5374),ye=i(9609);const be=[!1,"center","right","justify"],xe=["#000000","#e60000","#ff9900","#ffff00","#008a00","#0066cc","#9933ff","#ffffff","#facccc","#ffebcc","#ffffcc","#cce8cc","#cce0f5","#ebd6ff","#bbbbbb","#f06666","#ffc266","#ffff66","#66b966","#66a3e0","#c285ff","#888888","#a10000","#b26b00","#b2b200","#006100","#0047b2","#6b24b2","#444444","#5c0000","#663d00","#666600","#003700","#002966","#3d1466"],_e=[!1,"serif","monospace"],we=["1","2","3",!1],ke=["small",!1,"large","huge"];class Me extends ye.A{constructor(e,t){super(e,t);const i=t=>{document.body.contains(e.root)?(null==this.tooltip||this.tooltip.root.contains(t.target)||document.activeElement===this.tooltip.textbox||this.quill.hasFocus()||this.tooltip.hide(),null!=this.pickers&&this.pickers.forEach((e=>{e.container.contains(t.target)||e.close()}))):document.body.removeEventListener("click",i)};e.emitter.listenDOM("click",document.body,i)}addModule(e){const t=super.addModule(e);return"toolbar"===e&&this.extendToolbar(t),t}buildButtons(e,t){Array.from(e).forEach((e=>{(e.getAttribute("class")||"").split(/\s+/).forEach((i=>{if(i.startsWith("ql-")&&(i=i.slice(3),null!=t[i]))if("direction"===i)e.innerHTML=t[i][""]+t[i].rtl;else if("string"==typeof t[i])e.innerHTML=t[i];else{const n=e.value||"";null!=n&&t[i][n]&&(e.innerHTML=t[i][n])}}))}))}buildPickers(e,t){this.pickers=Array.from(e).map((e=>{if(e.classList.contains("ql-align")&&(null==e.querySelector("option")&&Ae(e,be),"object"==typeof t.align))return new pe(e,t.align);if(e.classList.contains("ql-background")||e.classList.contains("ql-color")){const i=e.classList.contains("ql-background")?"background":"color";return null==e.querySelector("option")&&Ae(e,xe,"background"===i?"#ffffff":"#000000"),new fe(e,t[i])}return null==e.querySelector("option")&&(e.classList.contains("ql-font")?Ae(e,_e):e.classList.contains("ql-header")?Ae(e,we):e.classList.contains("ql-size")&&Ae(e,ke)),new he(e)})),this.quill.on(ve.A.events.EDITOR_CHANGE,(()=>{this.pickers.forEach((e=>{e.update()}))}))}}Me.DEFAULTS=(0,ge.A)({},ye.A.DEFAULTS,{modules:{toolbar:{handlers:{formula(){this.quill.theme.tooltip.edit("formula")},image(){let e=this.container.querySelector("input.ql-image[type=file]");null==e&&(e=document.createElement("input"),e.setAttribute("type","file"),e.setAttribute("accept",this.quill.uploader.options.mimetypes.join(", ")),e.classList.add("ql-image"),e.addEventListener("change",(()=>{const t=this.quill.getSelection(!0);this.quill.uploader.upload(t,e.files),e.value=""})),this.container.appendChild(e)),e.click()},video(){this.quill.theme.tooltip.edit("video")}}}}});class Se extends me{constructor(e,t){super(e,t),this.textbox=this.root.querySelector('input[type="text"]'),this.listen()}listen(){this.textbox.addEventListener("keydown",(e=>{"Enter"===e.key?(this.save(),e.preventDefault()):"Escape"===e.key&&(this.cancel(),e.preventDefault())}))}cancel(){this.hide(),this.restoreFocus()}edit(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"link",t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;if(this.root.classList.remove("ql-hidden"),this.root.classList.add("ql-editing"),null==this.textbox)return;null!=t?this.textbox.value=t:e!==this.root.getAttribute("data-mode")&&(this.textbox.value="");const i=this.quill.getBounds(this.quill.selection.savedRange);null!=i&&this.position(i),this.textbox.select(),this.textbox.setAttribute("placeholder",this.textbox.getAttribute(`data-${e}`)||""),this.root.setAttribute("data-mode",e)}restoreFocus(){this.quill.focus({preventScroll:!0})}save(){let{value:e}=this.textbox;switch(this.root.getAttribute("data-mode")){case"link":{const{scrollTop:t}=this.quill.root;this.linkRange?(this.quill.formatText(this.linkRange,"link",e,ve.A.sources.USER),delete this.linkRange):(this.restoreFocus(),this.quill.format("link",e,ve.A.sources.USER)),this.quill.root.scrollTop=t;break}case"video":e=function(e){let t=e.match(/^(?:(https?):\/\/)?(?:(?:www|m)\.)?youtube\.com\/watch.*v=([a-zA-Z0-9_-]+)/)||e.match(/^(?:(https?):\/\/)?(?:(?:www|m)\.)?youtu\.be\/([a-zA-Z0-9_-]+)/);return t?`${t[1]||"https"}://www.youtube.com/embed/${t[2]}?showinfo=0`:(t=e.match(/^(?:(https?):\/\/)?(?:www\.)?vimeo\.com\/(\d+)/))?`${t[1]||"https"}://player.vimeo.com/video/${t[2]}/`:e}(e);case"formula":{if(!e)break;const t=this.quill.getSelection(!0);if(null!=t){const i=t.index+t.length;this.quill.insertEmbed(i,this.root.getAttribute("data-mode"),e,ve.A.sources.USER),"formula"===this.root.getAttribute("data-mode")&&this.quill.insertText(i+1," ",ve.A.sources.USER),this.quill.setSelection(i+2,ve.A.sources.USER)}break}}this.textbox.value="",this.hide()}}function Ae(e,t){let i=arguments.length>2&&void 0!==arguments[2]&&arguments[2];t.forEach((t=>{const n=document.createElement("option");t===i?n.setAttribute("selected","selected"):n.setAttribute("value",String(t)),e.appendChild(n)}))}var Le=i(8298);const Te=[["bold","italic","link"],[{header:1},{header:2},"blockquote"]];class Ce extends Se{static TEMPLATE=['<span class="ql-tooltip-arrow"></span>','<div class="ql-tooltip-editor">','<input type="text" data-formula="e=mc^2" data-link="https://quilljs.com" data-video="Embed URL">','<a class="ql-close"></a>',"</div>"].join("");constructor(e,t){super(e,t),this.quill.on(ve.A.events.EDITOR_CHANGE,((e,t,i,n)=>{if(e===ve.A.events.SELECTION_CHANGE)if(null!=t&&t.length>0&&n===ve.A.sources.USER){this.show(),this.root.style.left="0px",this.root.style.width="",this.root.style.width=`${this.root.offsetWidth}px`;const e=this.quill.getLines(t.index,t.length);if(1===e.length){const e=this.quill.getBounds(t);null!=e&&this.position(e)}else{const i=e[e.length-1],n=this.quill.getIndex(i),r=Math.min(i.length()-1,t.index+t.length-n),a=this.quill.getBounds(new Le.Q(n,r));null!=a&&this.position(a)}}else document.activeElement!==this.textbox&&this.quill.hasFocus()&&this.hide()}))}listen(){super.listen(),this.root.querySelector(".ql-close").addEventListener("click",(()=>{this.root.classList.remove("ql-editing")})),this.quill.on(ve.A.events.SCROLL_OPTIMIZE,(()=>{setTimeout((()=>{if(this.root.classList.contains("ql-hidden"))return;const e=this.quill.getSelection();if(null!=e){const t=this.quill.getBounds(e);null!=t&&this.position(t)}}),1)}))}cancel(){this.show()}position(e){const t=super.position(e),i=this.root.querySelector(".ql-tooltip-arrow");return i.style.marginLeft="",0!==t&&(i.style.marginLeft=-1*t-i.offsetWidth/2+"px"),t}}class De extends Me{constructor(e,t){null!=t.modules.toolbar&&null==t.modules.toolbar.container&&(t.modules.toolbar.container=Te),super(e,t),this.quill.container.classList.add("ql-bubble")}extendToolbar(e){this.tooltip=new Ce(this.quill,this.options.bounds),null!=e.container&&(this.tooltip.root.appendChild(e.container),this.buildButtons(e.container.querySelectorAll("button"),ce),this.buildPickers(e.container.querySelectorAll("select"),ce))}}De.DEFAULTS=(0,ge.A)({},Me.DEFAULTS,{modules:{toolbar:{handlers:{link(e){e?this.quill.theme.tooltip.edit():this.quill.format("link",!1,p.Ay.sources.USER)}}}}});const Ee=[[{header:["1","2","3",!1]}],["bold","italic","underline","link"],[{list:"ordered"},{list:"bullet"}],["clean"]];class Oe extends Se{static TEMPLATE=['<a class="ql-preview" rel="noopener noreferrer" target="_blank" href="about:blank"></a>','<input type="text" data-formula="e=mc^2" data-link="https://quilljs.com" data-video="Embed URL">','<a class="ql-action"></a>','<a class="ql-remove"></a>'].join("");preview=this.root.querySelector("a.ql-preview");listen(){super.listen(),this.root.querySelector("a.ql-action").addEventListener("click",(e=>{this.root.classList.contains("ql-editing")?this.save():this.edit("link",this.preview.textContent),e.preventDefault()})),this.root.querySelector("a.ql-remove").addEventListener("click",(e=>{if(null!=this.linkRange){const e=this.linkRange;this.restoreFocus(),this.quill.formatText(e,"link",!1,ve.A.sources.USER),delete this.linkRange}e.preventDefault(),this.hide()})),this.quill.on(ve.A.events.SELECTION_CHANGE,((e,t,i)=>{if(null!=e){if(0===e.length&&i===ve.A.sources.USER){const[t,i]=this.quill.scroll.descendant(M,e.index);if(null!=t){this.linkRange=new Le.Q(e.index-i,t.length());const n=M.formats(t.domNode);this.preview.textContent=n,this.preview.setAttribute("href",n),this.show();const r=this.quill.getBounds(this.linkRange);return void(null!=r&&this.position(r))}}else delete this.linkRange;this.hide()}}))}show(){super.show(),this.root.removeAttribute("data-mode")}}class Pe extends Me{constructor(e,t){null!=t.modules.toolbar&&null==t.modules.toolbar.container&&(t.modules.toolbar.container=Ee),super(e,t),this.quill.container.classList.add("ql-snow")}extendToolbar(e){null!=e.container&&(e.container.classList.add("ql-snow"),this.buildButtons(e.container.querySelectorAll("button"),ce),this.buildPickers(e.container.querySelectorAll("select"),ce),this.tooltip=new Oe(this.quill,this.options.bounds),e.container.querySelector(".ql-link")&&this.quill.keyboard.addBinding({key:"k",shortKey:!0},((t,i)=>{e.handlers.link.call(e,!i.format.link)})))}}Pe.DEFAULTS=(0,ge.A)({},Me.DEFAULTS,{modules:{toolbar:{handlers:{link(e){if(e){const e=this.quill.getSelection();if(null==e||0===e.length)return;let t=this.quill.getText(e);/^\S+@\S+\.\S+$/.test(t)&&0!==t.indexOf("mailto:")&&(t=`mailto:${t}`);const{tooltip:i}=this.quill.theme;i.edit("link",t)}else this.quill.format("link",!1,p.Ay.sources.USER)}}}}});var Ye=Pe;e.default.register({"attributors/attribute/direction":r.Mc,"attributors/class/align":t.qh,"attributors/class/background":v.l,"attributors/class/color":y.g3,"attributors/class/direction":r.sY,"attributors/class/font":b.q,"attributors/class/size":x.U,"attributors/style/align":t.Hu,"attributors/style/background":v.s,"attributors/style/color":y.JM,"attributors/style/direction":r.VL,"attributors/style/font":b.z,"attributors/style/size":x.r},!0),e.default.register({"formats/align":t.qh,"formats/direction":r.sY,"formats/indent":o,"formats/background":v.s,"formats/color":y.JM,"formats/font":b.q,"formats/size":x.U,"formats/blockquote":u,"formats/code-block":F.Ay,"formats/header":h,"formats/list":g,"formats/bold":k,"formats/code":F.Cy,"formats/italic":class extends k{static blotName="italic";static tagName=["EM","I"]},"formats/link":M,"formats/script":L,"formats/strike":class extends k{static blotName="strike";static tagName=["S","STRIKE"]},"formats/underline":C,"formats/formula":O,"formats/image":I,"formats/video":H,"modules/syntax":K,"modules/table":re,"modules/toolbar":se,"themes/bubble":De,"themes/snow":Ye,"ui/icons":ce,"ui/picker":he,"ui/icon-picker":pe,"ui/color-picker":fe,"ui/tooltip":me},!0);var Ie=e.default}(),n.default}()})),function(e){"function"==typeof define&&define.amd?define(e):e()}((function(){"use strict";function e(e,t){t=t||{bubbles:!1,cancelable:!1,detail:void 0};var i=document.createEvent("CustomEvent");return i.initCustomEvent(e,t.bubbles,t.cancelable,t.detail),i}function t(e,t){return null!=t&&"undefined"!=typeof Symbol&&t[Symbol.hasInstance]?!!t[Symbol.hasInstance](e):e instanceof t}var i;"".trim||(String.prototype.trim=function(){return this.replace(/^[\s﻿]+|[\s﻿]+$/g,"")}),window.NodeList&&!NodeList.prototype.forEach&&(NodeList.prototype.forEach=Array.prototype.forEach),Array.prototype.findIndex||Object.defineProperty(Array.prototype,"findIndex",{value:function(e){if(null==this)throw new TypeError('"this" is null or not defined');var t=Object(this),i=t.length>>>0;if("function"!=typeof e)throw new TypeError("predicate must be a function");for(var n=arguments[1],r=0;r<i;){var a=t[r];if(e.call(n,a,r,t))return r;r++}return-1},configurable:!0,writable:!0}),Array.prototype.includes||(Array.prototype.includes=function(e){return!!~this.indexOf(e)}),Array.prototype.some||(Array.prototype.some=function(e,t){if(null==this)throw new TypeError("Array.prototype.some called on null or undefined");if("function"!=typeof e)throw new TypeError;for(var i=Object(this),n=i.length>>>0,r=0;r<n;r++)if(r in i&&e.call(t,i[r],r,i))return!0;return!1}),String.prototype.includes||(String.prototype.includes=function(e,t){return"number"!=typeof t&&(t=0),!(t+e.length>this.length)&&-1!==this.indexOf(e,t)}),"function"!=typeof Object.assign&&Object.defineProperty(Object,"assign",{value:function(e,t){if(null==e)throw new TypeError("Cannot convert undefined or null to object");for(var i=Object(e),n=1;n<arguments.length;n++){var r=arguments[n];if(null!=r)for(var a in r)Object.prototype.hasOwnProperty.call(r,a)&&(i[a]=r[a])}return i},writable:!0,configurable:!0}),e.prototype=window.Event.prototype,"function"!=typeof window.CustomEvent&&(window.CustomEvent=e),Element.prototype.matches||(Element.prototype.matches=Element.prototype.msMatchesSelector||Element.prototype.webkitMatchesSelector),Element.prototype.closest||(Element.prototype.closest=function(e){var t=this;if(!document.documentElement.contains(t))return null;do{if(t.matches(e))return t;t=t.parentElement||t.parentNode}while(null!==t&&1===t.nodeType);return null}),document.execCommand("AutoUrlDetect",!1,!1),/*! @source http://purl.eligrey.com/github/classList.js/blob/master/classList.js */"document"in self&&((!("classList"in document.createElement("_"))||document.createElementNS&&!("classList"in document.createElementNS("http://www.w3.org/2000/svg","g")))&&function(e){if("Element"in e){var t="classList",i="prototype",n=e.Element[i],r=Object,a=String[i].trim||function(){return this.replace(/^\s+|\s+$/g,"")},s=Array[i].indexOf||function(e){for(var t=0,i=this.length;t<i;t++)if(t in this&&this[t]===e)return t;return-1},o=function(e,t){this.name=e,this.code=DOMException[e],this.message=t},l=function(e,t){if(""===t)throw new o("SYNTAX_ERR","The token must not be empty.");if(/\s/.test(t))throw new o("INVALID_CHARACTER_ERR","The token must not contain space characters.");return s.call(e,t)},c=function(e){for(var t=a.call(e.getAttribute("class")||""),i=t?t.split(/\s+/):[],n=0,r=i.length;n<r;n++)this.push(i[n]);this._updateClassName=function(){e.setAttribute("class",this.toString())}},u=c[i]=[],d=function(){return new c(this)};if(o[i]=Error[i],u.item=function(e){return this[e]||null},u.contains=function(e){return~l(this,e+"")},u.add=function(){var e,t=arguments,i=0,n=t.length,r=!1;do{~l(this,e=t[i]+"")||(this.push(e),r=!0)}while(++i<n);r&&this._updateClassName()},u.remove=function(){var e,t,i=arguments,n=0,r=i.length,a=!1;do{for(t=l(this,e=i[n]+"");~t;)this.splice(t,1),a=!0,t=l(this,e)}while(++n<r);a&&this._updateClassName()},u.toggle=function(e,t){var i=this.contains(e),n=i?!0!==t&&"remove":!1!==t&&"add";return n&&this[n](e),!0===t||!1===t?t:!i},u.replace=function(e,t){var i=l(e+"");~i&&(this.splice(i,1,t),this._updateClassName())},u.toString=function(){return this.join(" ")},r.defineProperty){var h={get:d,enumerable:!0,configurable:!0};try{r.defineProperty(n,t,h)}catch(e){void 0!==e.number&&-2146823252!==e.number||(h.enumerable=!1,r.defineProperty(n,t,h))}}else r[i].__defineGetter__&&n.__defineGetter__(t,d)}}(self),function(){var e=document.createElement("_");if(e.classList.add("c1","c2"),!e.classList.contains("c2")){var t=function(e){var t=DOMTokenList.prototype[e];DOMTokenList.prototype[e]=function(e){var i,n=arguments.length;for(i=0;i<n;i++)e=arguments[i],t.call(this,e)}};t("add"),t("remove")}if(e.classList.toggle("c3",!1),e.classList.contains("c3")){var i=DOMTokenList.prototype.toggle;DOMTokenList.prototype.toggle=function(e,t){return 1 in arguments&&!this.contains(e)==!t?t:i.call(this,e)}}"replace"in document.createElement("_").classList||(DOMTokenList.prototype.replace=function(e,t){var i=this.toString().split(" "),n=i.indexOf(e+"");~n&&(i=i.slice(n),this.remove.apply(this,i),this.add(t),this.add.apply(this,i.slice(1)))}),e=null}()),globalThis,i=function(){function e(e){var t=this.constructor;return this.then((function(i){return t.resolve(e()).then((function(){return i}))}),(function(i){return t.resolve(e()).then((function(){return t.reject(i)}))}))}function i(e){return new this((function(t,i){if(!e||void 0===e.length)return i(new TypeError((void 0===e?"undefined":(n=e)&&"undefined"!=typeof Symbol&&n.constructor===Symbol?"symbol":typeof n)+" "+e+" is not iterable(cannot read property Symbol(Symbol.iterator))"));var n,r=Array.prototype.slice.call(e);if(0===r.length)return t([]);var a=r.length;function s(e,i){if(i&&("object"==typeof i||"function"==typeof i)){var n=i.then;if("function"==typeof n)return void n.call(i,(function(t){s(e,t)}),(function(i){r[e]={status:"rejected",reason:i},0==--a&&t(r)}))}r[e]={status:"fulfilled",value:i},0==--a&&t(r)}for(var o=0;o<r.length;o++)s(o,r[o])}))}var n=setTimeout;function r(e){return Boolean(e&&void 0!==e.length)}function a(){}function s(e){if(!t(this,s))throw new TypeError("Promises must be constructed via new");if("function"!=typeof e)throw new TypeError("not a function");this._state=0,this._handled=!1,this._value=void 0,this._deferreds=[],h(e,this)}function o(e,t){for(;3===e._state;)e=e._value;0!==e._state?(e._handled=!0,s._immediateFn((function(){var i=1===e._state?t.onFulfilled:t.onRejected;if(null!==i){var n;try{n=i(e._value)}catch(e){return void c(t.promise,e)}l(t.promise,n)}else(1===e._state?l:c)(t.promise,e._value)}))):e._deferreds.push(t)}function l(e,i){try{if(i===e)throw new TypeError("A promise cannot be resolved with itself.");if(i&&("object"==typeof i||"function"==typeof i)){var n=i.then;if(t(i,s))return e._state=3,e._value=i,void u(e);if("function"==typeof n)return void h((r=n,a=i,function(){r.apply(a,arguments)}),e)}e._state=1,e._value=i,u(e)}catch(t){c(e,t)}var r,a}function c(e,t){e._state=2,e._value=t,u(e)}function u(e){2===e._state&&0===e._deferreds.length&&s._immediateFn((function(){e._handled||s._unhandledRejectionFn(e._value)}));for(var t=0,i=e._deferreds.length;t<i;t++)o(e,e._deferreds[t]);e._deferreds=null}function d(e,t,i){this.onFulfilled="function"==typeof e?e:null,this.onRejected="function"==typeof t?t:null,this.promise=i}function h(e,t){var i=!1;try{e((function(e){i||(i=!0,l(t,e))}),(function(e){i||(i=!0,c(t,e))}))}catch(e){if(i)return;i=!0,c(t,e)}}s.prototype.catch=function(e){return this.then(null,e)},s.prototype.then=function(e,t){var i=new this.constructor(a);return o(this,new d(e,t,i)),i},s.prototype.finally=e,s.all=function(e){return new s((function(t,i){if(!r(e))return i(new TypeError("Promise.all accepts an array"));var n=Array.prototype.slice.call(e);if(0===n.length)return t([]);var a=n.length;function s(e,r){try{if(r&&("object"==typeof r||"function"==typeof r)){var o=r.then;if("function"==typeof o)return void o.call(r,(function(t){s(e,t)}),i)}n[e]=r,0==--a&&t(n)}catch(e){i(e)}}for(var o=0;o<n.length;o++)s(o,n[o])}))},s.allSettled=i,s.resolve=function(e){return e&&"object"==typeof e&&e.constructor===s?e:new s((function(t){t(e)}))},s.reject=function(e){return new s((function(t,i){i(e)}))},s.race=function(e){return new s((function(t,i){if(!r(e))return i(new TypeError("Promise.race accepts an array"));for(var n=0,a=e.length;n<a;n++)s.resolve(e[n]).then(t,i)}))},s._immediateFn="function"==typeof setImmediate&&function(e){setImmediate(e)}||function(e){n(e,0)},s._unhandledRejectionFn=function(e){"undefined"!=typeof console&&console&&console.warn("Possible Unhandled Promise Rejection:",e)};var f=function(){if("undefined"!=typeof self)return self;if("undefined"!=typeof window)return window;if("undefined"!=typeof global)return global;throw new Error("unable to locate global object")}();"function"!=typeof f.Promise?f.Promise=s:f.Promise.prototype.finally?f.Promise.allSettled||(f.Promise.allSettled=i):f.Promise.prototype.finally=e},"object"==typeof exports&&"undefined"!=typeof module?i():"function"==typeof define&&define.amd?define(i):i()})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(e="undefined"!=typeof globalThis?globalThis:e||self).Tagify=t()}(this,(function(){"use strict";var e="&#8203;";function t(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function i(e){return function(e){if(Array.isArray(e))return t(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||function(e,i){if(e){if("string"==typeof e)return t(e,i);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(n):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?t(e,i):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}var n={isEnabled:function(){var e;return null===(e=window.TAGIFY_DEBUG)||void 0===e||e},log:function(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];var r;this.isEnabled()&&(r=console).log.apply(r,["[Tagify]:"].concat(i(t)))},warn:function(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];var r;this.isEnabled()&&(r=console).warn.apply(r,["[Tagify]:"].concat(i(t)))}},r=function(e,t,i,n){return e=""+e,t=""+t,n&&(e=e.trim(),t=t.trim()),i?e==t:e.toLowerCase()==t.toLowerCase()},a=function(e,t){return e&&Array.isArray(e)&&e.map((function(e){return s(e,t)}))};function s(e,t){var i,n={};for(i in e)t.indexOf(i)<0&&(n[i]=e[i]);return n}function o(e){var t=document.createElement("div");return e.replace(/\&#?[0-9a-z]+;/gi,(function(e){return t.innerHTML=e,t.innerText}))}function l(e){return(new DOMParser).parseFromString(e.trim(),"text/html").body.firstElementChild}function c(e,t){for(t=t||"previous";e=e[t+"Sibling"];)if(3==e.nodeType)return e}function u(e){return"string"==typeof e?e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/`|'/g,"&#039;"):e}function d(e){var t=Object.prototype.toString.call(e).split(" ")[1].slice(0,-1);return e===Object(e)&&"Array"!=t&&"Function"!=t&&"RegExp"!=t&&"HTMLUnknownElement"!=t}function h(e,t,i){var n,r;function a(e,t){for(var i in t)if(t.hasOwnProperty(i)){if(d(t[i])){d(e[i])?a(e[i],t[i]):e[i]=Object.assign({},t[i]);continue}if(Array.isArray(t[i])){e[i]=Object.assign([],t[i]);continue}e[i]=t[i]}}return n=e,(null!=(r=Object)&&"undefined"!=typeof Symbol&&r[Symbol.hasInstance]?r[Symbol.hasInstance](n):n instanceof r)||(e={}),a(e,t),i&&a(e,i),e}function f(){var e=[],t={},i=!0,n=!1,r=void 0;try{for(var a,s=arguments[Symbol.iterator]();!(i=(a=s.next()).done);i=!0){var o=a.value,l=!0,c=!1,u=void 0;try{for(var h,f=o[Symbol.iterator]();!(l=(h=f.next()).done);l=!0){var p=h.value;d(p)?t[p.value]||(e.push(p),t[p.value]=1):e.includes(p)||e.push(p)}}catch(e){c=!0,u=e}finally{try{l||null==f.return||f.return()}finally{if(c)throw u}}}}catch(e){n=!0,r=e}finally{try{i||null==s.return||s.return()}finally{if(n)throw r}}return e}function p(e){return String.prototype.normalize?"string"==typeof e?e.normalize("NFD").replace(/[\u0300-\u036f]/g,""):void 0:e}var m=function(){return/(?=.*chrome)(?=.*android)/i.test(navigator.userAgent)};function g(){return([1e7]+-1e3+-4e3+-8e3+-1e11).replace(/[018]/g,(function(e){return(e^crypto.getRandomValues(new Uint8Array(1))[0]&15>>e/4).toString(16)}))}function v(e){return e&&e.classList&&e.classList.contains(this.settings.classNames.tag)}function y(e){return e&&e.closest(this.settings.classNames.tagSelector)}function b(e,t){var i=window.getSelection();return t=t||i.getRangeAt(0),"string"==typeof e&&(e=document.createTextNode(e)),t&&(t.deleteContents(),t.insertNode(e)),e}function x(e,t,i){return e?(t&&(e.__tagifyTagData=i?t:h({},e.__tagifyTagData||{},t)),e.__tagifyTagData):(n.warn("tag element doesn't exist",{tagElm:e,data:t}),t)}function _(e){if(e&&e.parentNode){var t=e,i=window.getSelection(),n=i.getRangeAt(0);i.rangeCount&&(n.setStartAfter(t),n.collapse(!0),i.removeAllRanges(),i.addRange(n))}}function w(e,t){e.forEach((function(e){if(x(e.previousSibling)||!e.previousSibling){var i=document.createTextNode("​");e.before(i),t&&_(i)}}))}var k={delimiters:",",pattern:null,tagTextProp:"value",maxTags:1/0,callbacks:{},addTagOnBlur:!0,addTagOn:["blur","tab","enter"],onChangeAfterBlur:!0,duplicates:!1,whitelist:[],blacklist:[],enforceWhitelist:!1,userInput:!0,focusable:!0,keepInvalidTags:!1,createInvalidTags:!0,mixTagsAllowedAfter:/,|\.|\:|\s/,mixTagsInterpolator:["[[","]]"],backspace:!0,skipInvalid:!1,pasteAsTags:!0,editTags:{clicks:2,keepInvalid:!0},transformTag:function(){},trim:!0,a11y:{focusableTags:!1},mixMode:{insertAfterTag:" "},autoComplete:{enabled:!0,rightKey:!1,tabKey:!1},classNames:{namespace:"tagify",mixMode:"tagify--mix",selectMode:"tagify--select",input:"tagify__input",focus:"tagify--focus",tagNoAnimation:"tagify--noAnim",tagInvalid:"tagify--invalid",tagNotAllowed:"tagify--notAllowed",scopeLoading:"tagify--loading",hasMaxTags:"tagify--hasMaxTags",hasNoTags:"tagify--noTags",empty:"tagify--empty",inputInvalid:"tagify__input--invalid",dropdown:"tagify__dropdown",dropdownWrapper:"tagify__dropdown__wrapper",dropdownHeader:"tagify__dropdown__header",dropdownFooter:"tagify__dropdown__footer",dropdownItem:"tagify__dropdown__item",dropdownItemActive:"tagify__dropdown__item--active",dropdownItemHidden:"tagify__dropdown__item--hidden",dropdownInital:"tagify__dropdown--initial",tag:"tagify__tag",tagText:"tagify__tag-text",tagX:"tagify__tag__removeBtn",tagLoading:"tagify__tag--loading",tagEditing:"tagify__tag--editable",tagFlash:"tagify__tag--flash",tagHide:"tagify__tag--hide"},dropdown:{classname:"",enabled:2,maxItems:10,searchKeys:["value","searchBy"],fuzzySearch:!0,caseSensitive:!1,accentedSearch:!0,includeSelectedTags:!1,escapeHTML:!0,highlightFirst:!0,closeOnSelect:!0,clearOnSelect:!0,position:"all",appendTarget:null},hooks:{beforeRemoveTag:function(){return Promise.resolve()},beforePaste:function(){return Promise.resolve()},suggestionClick:function(){return Promise.resolve()},beforeKeyDown:function(){return Promise.resolve()}}};function M(e,t,i){return t in e?Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}):e[t]=i,e}function S(e){for(var t=1;t<arguments.length;t++){var i=null!=arguments[t]?arguments[t]:{},n=Object.keys(i);"function"==typeof Object.getOwnPropertySymbols&&(n=n.concat(Object.getOwnPropertySymbols(i).filter((function(e){return Object.getOwnPropertyDescriptor(i,e).enumerable})))),n.forEach((function(t){M(e,t,i[t])}))}return e}function A(e,t){return t=null!=t?t:{},Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(t)):function(e,t){var i=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);i.push.apply(i,n)}return i}(Object(t)).forEach((function(i){Object.defineProperty(e,i,Object.getOwnPropertyDescriptor(t,i))})),e}var L={events:{binding:function(){var e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0],t=this.dropdown.events.callbacks,i=this.listeners.dropdown=this.listeners.dropdown||{position:this.dropdown.position.bind(this,null),onKeyDown:t.onKeyDown.bind(this),onMouseOver:t.onMouseOver.bind(this),onMouseLeave:t.onMouseLeave.bind(this),onClick:t.onClick.bind(this),onScroll:t.onScroll.bind(this)},n=e?"addEventListener":"removeEventListener";"manual"!=this.settings.dropdown.position&&(document[n]("scroll",i.position,!0),window[n]("resize",i.position),window[n]("keydown",i.onKeyDown)),this.DOM.dropdown[n]("mouseover",i.onMouseOver),this.DOM.dropdown[n]("mouseleave",i.onMouseLeave),this.DOM.dropdown[n]("mousedown",i.onClick),this.DOM.dropdown.content[n]("scroll",i.onScroll)},callbacks:{onKeyDown:function(e){var t=this;if(this.state.hasFocus&&!this.state.composing){var i=this.settings,r=this.DOM.dropdown.querySelector(i.classNames.dropdownItemActiveSelector),a=this.dropdown.getSuggestionDataByNode(r),s="mix"==i.mode,o="select"==i.mode;i.hooks.beforeKeyDown(e,{tagify:this}).then((function(l){switch(e.key){case"ArrowDown":case"ArrowUp":case"Down":case"Up":e.preventDefault();var c=t.dropdown.getAllSuggestionsRefs(),u="ArrowUp"==e.key||"Up"==e.key;r&&(r=t.dropdown.getNextOrPrevOption(r,!u)),r&&r.matches(i.classNames.dropdownItemSelector)||(r=c[u?c.length-1:0]),t.dropdown.highlightOption(r,!0);break;case"Escape":case"Esc":t.dropdown.hide();break;case"ArrowRight":if(t.state.actions.ArrowLeft||i.autoComplete.rightKey)return;case"Tab":var d=!i.autoComplete.rightKey||!i.autoComplete.tabKey;if(!s&&!o&&r&&d&&!t.state.editing&&a){e.preventDefault();var h=t.dropdown.getMappedValue(a);return t.input.autocomplete.set.call(t,h),!1}return!0;case"Enter":e.preventDefault(),i.hooks.suggestionClick(e,{tagify:t,tagData:a,suggestionElm:r}).then((function(){if(r)return t.dropdown.selectOption(r),r=t.dropdown.getNextOrPrevOption(r,!u),void t.dropdown.highlightOption(r);t.dropdown.hide(),s||t.addTags(t.state.inputText.trim(),!0)})).catch((function(e){return n.warn(e)}));break;case"Backspace":if(s||t.state.editing.scope)return;var f=t.input.raw.call(t);""!=f&&8203!=f.charCodeAt(0)||(!0===i.backspace?t.removeTags():"edit"==i.backspace&&setTimeout(t.editTag.bind(t),0))}}))}},onMouseOver:function(e){var t=e.target.closest(this.settings.classNames.dropdownItemSelector);this.dropdown.highlightOption(t)},onMouseLeave:function(e){this.dropdown.highlightOption()},onClick:function(e){var t=this;if(0==e.button&&e.target!=this.DOM.dropdown&&e.target!=this.DOM.dropdown.content){var i=e.target.closest(this.settings.classNames.dropdownItemSelector),r=this.dropdown.getSuggestionDataByNode(i);this.state.actions.selectOption=!0,setTimeout((function(){return t.state.actions.selectOption=!1}),50),this.settings.hooks.suggestionClick(e,{tagify:this,tagData:r,suggestionElm:i}).then((function(){i?t.dropdown.selectOption(i,e):t.dropdown.hide()})).catch((function(e){return n.warn(e)}))}},onScroll:function(e){var t=e.target,i=t.scrollTop/(t.scrollHeight-t.parentNode.clientHeight)*100;this.trigger("dropdown:scroll",{percentage:Math.round(i)})}}},refilter:function(e){e=e||this.state.dropdown.query||"",this.suggestedListItems=this.dropdown.filterListItems(e),this.dropdown.fill(),this.suggestedListItems.length||this.dropdown.hide(),this.trigger("dropdown:updated",this.DOM.dropdown)},getSuggestionDataByNode:function(e){for(var t,i=e&&e.getAttribute("value"),n=this.suggestedListItems.length;n--;){if(d(t=this.suggestedListItems[n])&&t.value==i)return t;if(t==i)return{value:t}}},getNextOrPrevOption:function(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=this.dropdown.getAllSuggestionsRefs(),n=i.findIndex((function(t){return t===e}));return t?i[n+1]:i[n-1]},highlightOption:function(e,t){var i,n=this.settings.classNames.dropdownItemActive;if(this.state.ddItemElm&&(this.state.ddItemElm.classList.remove(n),this.state.ddItemElm.removeAttribute("aria-selected")),!e)return this.state.ddItemData=null,this.state.ddItemElm=null,void this.input.autocomplete.suggest.call(this);i=this.dropdown.getSuggestionDataByNode(e),this.state.ddItemData=i,this.state.ddItemElm=e,e.classList.add(n),e.setAttribute("aria-selected",!0),t&&(e.parentNode.scrollTop=e.clientHeight+e.offsetTop-e.parentNode.clientHeight),this.settings.autoComplete&&(this.input.autocomplete.suggest.call(this,i),this.dropdown.position())},selectOption:function(e,t){var i=this,n=this.settings,r=n.dropdown,a=r.clearOnSelect,s=r.closeOnSelect;if(!e)return this.addTags(this.state.inputText,!0),void(s&&this.dropdown.hide());t=t||{};var o=e.getAttribute("value"),l="noMatch"==o,c="mix"==n.mode,u=this.suggestedListItems.find((function(e){var t;return(null!==(t=e.value)&&void 0!==t?t:e)==o}));if(this.trigger("dropdown:select",{data:u,elm:e,event:t}),o&&(u||l)){if(this.state.editing){var d=this.normalizeTags([u])[0];u=n.transformTag.call(this,d)||d,this.onEditTagDone(null,h({__isValid:!0},u))}else this[c?"addMixTags":"addTags"]([u||this.input.raw.call(this)],a);(c||this.DOM.input.parentNode)&&(setTimeout((function(){i.DOM.input.focus(),i.toggleFocusClass(!0)})),s&&setTimeout(this.dropdown.hide.bind(this)),e.addEventListener("transitionend",(function(){i.dropdown.fillHeaderFooter(),setTimeout((function(){e.remove(),i.dropdown.refilter()}),100)}),{once:!0}),e.classList.add(this.settings.classNames.dropdownItemHidden))}else s&&setTimeout(this.dropdown.hide.bind(this))},selectAll:function(e){this.suggestedListItems.length=0,this.dropdown.hide(),this.dropdown.filterListItems("");var t=this.dropdown.filterListItems("");return e||(t=this.state.dropdown.suggestions),this.addTags(t,!0),this},filterListItems:function(e,t){var i,n,r,a,s,o,l=function(){var e,l,c=void 0,u=void 0;e=g[b],n=(null!=(l=Object)&&"undefined"!=typeof Symbol&&l[Symbol.hasInstance]?l[Symbol.hasInstance](e):e instanceof l)?g[b]:{value:g[b]};var v,x=Object.keys(n).some((function(e){return y.includes(e)}))?y:["value"];h.fuzzySearch&&!t.exact?(a=x.reduce((function(e,t){return e+" "+(n[t]||"")}),"").toLowerCase().trim(),h.accentedSearch&&(a=p(a),o=p(o)),c=0==a.indexOf(o),u=a===o,v=a,r=o.toLowerCase().split(" ").every((function(e){return v.includes(e.toLowerCase())}))):(c=!0,r=x.some((function(e){var i=""+(n[e]||"");return h.accentedSearch&&(i=p(i),o=p(o)),h.caseSensitive||(i=i.toLowerCase()),u=i===o,t.exact?i===o:0==i.indexOf(o)}))),s=!h.includeSelectedTags&&i.isTagDuplicate(d(n)?n.value:n),r&&!s&&(u&&c?m.push(n):"startsWith"==h.sortby&&c?f.unshift(n):f.push(n))},c=this,u=this.settings,h=u.dropdown,f=(t=t||{},[]),m=[],g=u.whitelist,v=h.maxItems>=0?h.maxItems:1/0,y=h.searchKeys,b=0;if(!(e="select"==u.mode&&this.value.length&&this.value[0][u.tagTextProp]==e?"":e)||!y.length)return f=h.includeSelectedTags||"select"==u.mode?g:g.filter((function(e){return!c.isTagDuplicate(d(e)?e.value:e)})),this.state.dropdown.suggestions=f,f.slice(0,v);for(o=h.caseSensitive?""+e:(""+e).toLowerCase();b<g.length;b++)i=this,l();return this.state.dropdown.suggestions=m.concat(f),"function"==typeof h.sortby?h.sortby(m.concat(f),o):m.concat(f).slice(0,v)},getMappedValue:function(e){var t=this.settings.dropdown.mapValueTo;return t?"function"==typeof t?t(e):e[t]||e.value:e.value},createListHTML:function(e){var t=this;return h([],e).map((function(e,i){"string"!=typeof e&&"number"!=typeof e||(e={value:e});var n=t.dropdown.getMappedValue(e);return n="string"==typeof n&&t.settings.dropdown.escapeHTML?u(n):n,t.settings.templates.dropdownItem.apply(t,[A(S({},e),{mappedValue:n}),t])})).join("")}};function T(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function C(e,t,i){return t in e?Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}):e[t]=i,e}function D(){for(var e in this.dropdown={},this._dropdown)this.dropdown[e]="function"==typeof this._dropdown[e]?this._dropdown[e].bind(this):this._dropdown[e];this.dropdown.refs(),this.DOM.dropdown.__tagify=this}var E,O,P,Y=(E=function(e){for(var t=1;t<arguments.length;t++){var i=null!=arguments[t]?arguments[t]:{},n=Object.keys(i);"function"==typeof Object.getOwnPropertySymbols&&(n=n.concat(Object.getOwnPropertySymbols(i).filter((function(e){return Object.getOwnPropertyDescriptor(i,e).enumerable})))),n.forEach((function(t){C(e,t,i[t])}))}return e}({},L),O=null!=(O={refs:function(){this.DOM.dropdown=this.parseTemplate("dropdown",[this.settings]),this.DOM.dropdown.content=this.DOM.dropdown.querySelector("[data-selector='tagify-suggestions-wrapper']")},getHeaderRef:function(){return this.DOM.dropdown.querySelector("[data-selector='tagify-suggestions-header']")},getFooterRef:function(){return this.DOM.dropdown.querySelector("[data-selector='tagify-suggestions-footer']")},getAllSuggestionsRefs:function(){return function(e){return function(e){if(Array.isArray(e))return T(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return T(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(i):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?T(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(this.DOM.dropdown.content.querySelectorAll(this.settings.classNames.dropdownItemSelector))},show:function(e){var t,i,n,a=this,s=this.settings,o="mix"==s.mode&&!s.enforceWhitelist,l=!s.whitelist||!s.whitelist.length,c="manual"==s.dropdown.position;if(e=void 0===e?this.state.inputText:e,!(l&&!o&&!s.templates.dropdownItemNoMatch||!1===s.dropdown.enable||this.state.isLoading||this.settings.readonly)){if(clearTimeout(this.dropdownHide__bindEventsTimeout),this.suggestedListItems=this.dropdown.filterListItems(e),e&&!this.suggestedListItems.length&&(this.trigger("dropdown:noMatch",e),s.templates.dropdownItemNoMatch&&(n=s.templates.dropdownItemNoMatch.call(this,{value:e}))),!n){if(this.suggestedListItems.length)e&&o&&!this.state.editing.scope&&!r(this.suggestedListItems[0].value,e)&&this.suggestedListItems.unshift({value:e});else{if(!e||!o||this.state.editing.scope)return this.input.autocomplete.suggest.call(this),void this.dropdown.hide();this.suggestedListItems=[{value:e}]}i=""+(d(t=this.suggestedListItems[0])?t.value:t),s.autoComplete&&i&&0==i.indexOf(e)&&this.input.autocomplete.suggest.call(this,t)}this.dropdown.fill(n),s.dropdown.highlightFirst&&this.dropdown.highlightOption(this.DOM.dropdown.content.querySelector(s.classNames.dropdownItemSelector)),this.state.dropdown.visible||setTimeout(this.dropdown.events.binding.bind(this)),this.state.dropdown.visible=e||!0,this.state.dropdown.query=e,this.setStateSelection(),c||setTimeout((function(){a.dropdown.position(),a.dropdown.render()})),setTimeout((function(){a.trigger("dropdown:show",a.DOM.dropdown)}))}},hide:function(e){var t=this,i=this.DOM,n=i.scope,r=i.dropdown,a="manual"==this.settings.dropdown.position&&!e;if(r&&document.body.contains(r)&&!a)return window.removeEventListener("resize",this.dropdown.position),this.dropdown.events.binding.call(this,!1),n.setAttribute("aria-expanded",!1),r.parentNode.removeChild(r),setTimeout((function(){t.state.dropdown.visible=!1}),100),this.state.dropdown.query=this.state.ddItemData=this.state.ddItemElm=this.state.selection=null,this.state.tag&&this.state.tag.value.length&&(this.state.flaggedTags[this.state.tag.baseOffset]=this.state.tag),this.trigger("dropdown:hide",r),this},toggle:function(e){this.dropdown[this.state.dropdown.visible&&!e?"hide":"show"]()},getAppendTarget:function(){var e=this.settings.dropdown;return"function"==typeof e.appendTarget?e.appendTarget():e.appendTarget},render:function(){var e,t,i=this,n=((t=this.DOM.dropdown.cloneNode(!0)).style.cssText="position:fixed; top:-9999px; opacity:0",document.body.appendChild(t),e=t.clientHeight,t.parentNode.removeChild(t),e),r=this.settings,a="number"==typeof r.dropdown.enabled&&r.dropdown.enabled>=0,s=this.dropdown.getAppendTarget();return a?(this.DOM.scope.setAttribute("aria-expanded",!0),document.body.contains(this.DOM.dropdown)||(this.DOM.dropdown.classList.add(r.classNames.dropdownInital),this.dropdown.position(n),s.appendChild(this.DOM.dropdown),setTimeout((function(){return i.DOM.dropdown.classList.remove(r.classNames.dropdownInital)}))),this):this},fill:function(e){e="string"==typeof e?e:this.dropdown.createListHTML(e||this.suggestedListItems);var t,i=this.settings.templates.dropdownContent.call(this,e);this.DOM.dropdown.content.innerHTML=(t=i)?t.replace(/\>[\r\n ]+\</g,"><").split(/>\s+</).join("><").trim():""},fillHeaderFooter:function(){var e=this.dropdown.filterListItems(this.state.dropdown.query),t=this.parseTemplate("dropdownHeader",[e]),i=this.parseTemplate("dropdownFooter",[e]),n=this.dropdown.getHeaderRef(),r=this.dropdown.getFooterRef();t&&(null==n||n.parentNode.replaceChild(t,n)),i&&(null==r||r.parentNode.replaceChild(i,r))},position:function(e){var t=this.settings.dropdown,i=this.dropdown.getAppendTarget();if("manual"!=t.position&&i){var n,r,a,s,o,l,c,u,d,h=this.DOM.dropdown,f=t.RTL,p=i===document.body,m=i===this.DOM.scope,g=p?window.pageYOffset:i.scrollTop,v=document.fullscreenElement||document.webkitFullscreenElement||document.documentElement,y=v.clientHeight,b=Math.max(v.clientWidth||0,window.innerWidth||0)>480?t.position:"all",x=this.DOM["input"==b?"input":"scope"];if(e=e||h.clientHeight,this.state.dropdown.visible){if("text"==b?(a=(n=function(){var e=document.getSelection();if(e.rangeCount){var t,i,n=e.getRangeAt(0),r=n.startContainer,a=n.startOffset;if(a>0)return(i=document.createRange()).setStart(r,a-1),i.setEnd(r,a),{left:(t=i.getBoundingClientRect()).right,top:t.top,bottom:t.bottom};if(r.getBoundingClientRect)return r.getBoundingClientRect()}return{left:-9999,top:-9999}}()).bottom,r=n.top,s=n.left,o="auto"):(l=function(e){var t=0,i=0;for(e=e.parentNode;e&&e!=v;)t+=e.offsetTop||0,i+=e.offsetLeft||0,e=e.parentNode;return{top:t,left:i}}(i),n=x.getBoundingClientRect(),r=m?-1:n.top-l.top,a=(m?n.height:n.bottom-l.top)-1,s=m?-1:n.left-l.left,o=n.width+"px"),!p){var _=function(){for(var e=0,i=t.appendTarget.parentNode;i;)e+=i.scrollTop||0,i=i.parentNode;return e}();r+=_,a+=_}var w;r=Math.floor(r),a=Math.ceil(a),u=((c=null!==(w=t.placeAbove)&&void 0!==w?w:y-n.bottom<e)?r:a)+g,d="left: ".concat(s+(f&&n.width||0)+window.pageXOffset,"px;"),h.style.cssText="".concat(d,"; top: ").concat(u,"px; min-width: ").concat(o,"; max-width: ").concat(o),h.setAttribute("placement",c?"top":"bottom"),h.setAttribute("position",b)}}}})?O:{},Object.getOwnPropertyDescriptors?Object.defineProperties(E,Object.getOwnPropertyDescriptors(O)):function(e,t){var i=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);i.push.apply(i,n)}return i}(Object(O)).forEach((function(e){Object.defineProperty(E,e,Object.getOwnPropertyDescriptor(O,e))})),E),I="@yaireo/tagify/",N={empty:"empty",exceed:"number of tags exceeded",pattern:"pattern mismatch",duplicate:"already exists",notAllowed:"not allowed"},j={wrapper:function(t,i){return'<tags class="'.concat(i.classNames.namespace," ").concat(i.mode?"".concat(i.classNames[i.mode+"Mode"]):""," ").concat(t.className,'"\n                    ').concat(i.readonly?"readonly":"","\n                    ").concat(i.disabled?"disabled":"","\n                    ").concat(i.required?"required":"","\n                    ").concat("select"===i.mode?"spellcheck='false'":"",'\n                    tabIndex="-1">\n                    ').concat(this.settings.templates.input.call(this),"\n                ").concat(e,"\n        </tags>")},input:function(){var t=this.settings,i=t.placeholder||e;return"<span ".concat(!t.readonly&&t.userInput?"contenteditable":"",' tabIndex="0" data-placeholder="').concat(i,'" aria-placeholder="').concat(t.placeholder||"",'"\n                    class="').concat(t.classNames.input,'"\n                    role="textbox"\n                    aria-autocomplete="both"\n                    aria-multiline="').concat("mix"==t.mode,'"></span>')},tag:function(e,t){var i=t.settings;return'<tag title="'.concat(e.title||e.value,"\"\n                    contenteditable='false'\n                    spellcheck='false'\n                    tabIndex=\"").concat(i.a11y.focusableTags?0:-1,'"\n                    class="').concat(i.classNames.tag," ").concat(e.class||"",'"\n                    ').concat(this.getAttributes(e),">\n            <x title='' tabIndex=\"").concat(i.a11y.focusableTags?0:-1,'" class="').concat(i.classNames.tagX,"\" role='button' aria-label='remove tag'></x>\n            <div>\n                <span ").concat("select"===i.mode&&i.userInput?"contenteditable='true'":"",' class="').concat(i.classNames.tagText,'">').concat(e[i.tagTextProp]||e.value,"</span>\n            </div>\n        </tag>")},dropdown:function(e){var t=e.dropdown,i="manual"==t.position;return'<div class="'.concat(i?"":e.classNames.dropdown," ").concat(t.classname,'" role="listbox" aria-labelledby="dropdown" dir="').concat(t.RTL?"rtl":"","\">\n                    <div data-selector='tagify-suggestions-wrapper' class=\"").concat(e.classNames.dropdownWrapper,'"></div>\n                </div>')},dropdownContent:function(e){var t=this.settings.templates,i=this.state.dropdown.suggestions;return"\n            ".concat(t.dropdownHeader.call(this,i),"\n            ").concat(e,"\n            ").concat(t.dropdownFooter.call(this,i),"\n        ")},dropdownItem:function(e){return"<div ".concat(this.getAttributes(e),"\n                    class='").concat(this.settings.classNames.dropdownItem," ").concat(e.class||"",'\'\n                    tabindex="0"\n                    role="option">').concat(e.mappedValue||e.value,"</div>")},dropdownHeader:function(e){return"<header data-selector='tagify-suggestions-header' class=\"".concat(this.settings.classNames.dropdownHeader,'"></header>')},dropdownFooter:function(e){var t=e.length-this.settings.dropdown.maxItems;return t>0?"<footer data-selector='tagify-suggestions-footer' class=\"".concat(this.settings.classNames.dropdownFooter,'">\n                ').concat(t," more items. Refine your search.\n            </footer>"):""},dropdownItemNoMatch:null};function H(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function F(e,t){return null!=t&&"undefined"!=typeof Symbol&&t[Symbol.hasInstance]?!!t[Symbol.hasInstance](e):e instanceof t}function R(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function z(e,t,i){return t in e?Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}):e[t]=i,e}function B(e,t){return null!=t&&"undefined"!=typeof Symbol&&t[Symbol.hasInstance]?!!t[Symbol.hasInstance](e):e instanceof t}function V(e){return function(e){if(Array.isArray(e))return R(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return R(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(i):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?R(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}var W={customBinding:function(){var e=this;this.customEventsList.forEach((function(t){e.on(t,e.settings.callbacks[t])}))},binding:function(){var e,t=!(arguments.length>0&&void 0!==arguments[0])||arguments[0],i=this.settings,n=this.events.callbacks,r=t?"addEventListener":"removeEventListener";if(!this.state.mainEvents||!t){for(var a in this.state.mainEvents=t,t&&!this.listeners.main&&(this.events.bindGlobal.call(this),this.settings.isJQueryPlugin&&jQuery(this.DOM.originalInput).on("tagify.removeAllTags",this.removeAllTags.bind(this))),e=this.listeners.main=this.listeners.main||{keydown:["input",n.onKeydown.bind(this)],click:["scope",n.onClickScope.bind(this)],dblclick:"select"!=i.mode&&["scope",n.onDoubleClickScope.bind(this)],paste:["input",n.onPaste.bind(this)],drop:["input",n.onDrop.bind(this)],compositionstart:["input",n.onCompositionStart.bind(this)],compositionend:["input",n.onCompositionEnd.bind(this)]})e[a]&&this.DOM[e[a][0]][r](a,e[a][1]);var s=this.listeners.main.inputMutationObserver||new MutationObserver(n.onInputDOMChange.bind(this));s.disconnect(),"mix"==i.mode&&s.observe(this.DOM.input,{childList:!0}),this.events.bindOriginaInputListener.call(this)}},bindOriginaInputListener:function(e){var t=(e||0)+500;this.listeners.main&&(clearInterval(this.listeners.main.originalInputValueObserverInterval),this.listeners.main.originalInputValueObserverInterval=setInterval(this.events.callbacks.observeOriginalInputValue.bind(this),t))},bindGlobal:function(e){var t,i=this.events.callbacks,n=e?"removeEventListener":"addEventListener";if(this.listeners&&(e||!this.listeners.global)){this.listeners.global=this.listeners.global||[{type:this.isIE?"keydown":"input",target:this.DOM.input,cb:i[this.isIE?"onInputIE":"onInput"].bind(this)},{type:"keydown",target:window,cb:i.onWindowKeyDown.bind(this)},{type:"focusin",target:this.DOM.scope,cb:i.onFocusBlur.bind(this)},{type:"focusout",target:this.DOM.scope,cb:i.onFocusBlur.bind(this)},{type:"click",target:document,cb:i.onClickAnywhere.bind(this),useCapture:!0}];var r=!0,a=!1,s=void 0;try{for(var o,l=this.listeners.global[Symbol.iterator]();!(r=(o=l.next()).done);r=!0)(t=o.value).target[n](t.type,t.cb,!!t.useCapture)}catch(e){a=!0,s=e}finally{try{r||null==l.return||l.return()}finally{if(a)throw s}}}},unbindGlobal:function(){this.events.bindGlobal.call(this,!0)},callbacks:{onFocusBlur:function(e){var t,i,n=y.call(this,e.target),r=v.call(this,e.target),a="focusin"==e.type,s="focusout"==e.type;n&&a&&!r&&this.toggleFocusClass(this.state.hasFocus=+new Date);var o=this.settings,l=e.target?this.trim(this.DOM.input.textContent):"",c=null===(i=this.value)||void 0===i||null===(t=i[0])||void 0===t?void 0:t[o.tagTextProp],u=o.dropdown.enabled>=0,d={relatedTarget:e.relatedTarget},h=this.state.actions.selectOption&&(u||!o.dropdown.closeOnSelect),f=this.state.actions.addNew&&u;if(s){if(e.relatedTarget===this.DOM.scope)return this.dropdown.hide(),void this.DOM.input.focus();this.postUpdate(),o.onChangeAfterBlur&&this.triggerChangeEvent()}if(!h&&!f)if(a||n?(this.state.hasFocus=+new Date,this.toggleFocusClass(this.state.hasFocus)):this.state.hasFocus=!1,"mix"!=o.mode){if(a){if(!o.focusable)return;var p=0===o.dropdown.enabled&&!this.state.dropdown.visible;return this.toggleFocusClass(!0),this.trigger("focus",d),void(!p||r&&"select"!==o.mode||this.dropdown.show(this.value.length?"":void 0))}if(s){if(this.trigger("blur",d),this.loading(!1),"select"==o.mode){if(this.value.length){var m=this.getTagElms()[0];l=this.trim(m.textContent)}c===l&&(l="")}l&&!this.state.actions.selectOption&&o.addTagOnBlur&&o.addTagOn.includes("blur")&&this.addTags(l,!0)}n||(this.DOM.input.removeAttribute("style"),this.dropdown.hide())}else a?this.trigger("focus",d):s&&(this.trigger("blur",d),this.loading(!1),this.dropdown.hide(),this.state.dropdown.visible=void 0,this.setStateSelection())},onCompositionStart:function(e){this.state.composing=!0},onCompositionEnd:function(e){this.state.composing=!1},onWindowKeyDown:function(e){var t,i=this.settings,n=document.activeElement,r=y.call(this,n)&&this.DOM.scope.contains(document.activeElement),a=r&&n.hasAttribute("readonly");if(this.state.hasFocus||r&&!a){t=n.nextElementSibling;var s=e.target.classList.contains(i.classNames.tagX);switch(e.key){case"Backspace":i.readonly||this.state.editing||(this.removeTags(n),(t||this.DOM.input).focus());break;case"Enter":if(s)return void this.removeTags(e.target.parentNode);i.a11y.focusableTags&&v.call(this,n)&&setTimeout(this.editTag.bind(this),0,n);break;case"ArrowDown":this.state.dropdown.visible||"mix"==i.mode||this.dropdown.show()}}},onKeydown:function(e){var t=this,i=this.settings;if(!this.state.composing&&i.userInput){"select"==i.mode&&i.enforceWhitelist&&this.value.length&&"Tab"!=e.key&&e.preventDefault();var n=this.trim(e.target.textContent);this.trigger("keydown",{event:e}),i.hooks.beforeKeyDown(e,{tagify:this}).then((function(r){if("mix"==i.mode){switch(e.key){case"Left":case"ArrowLeft":t.state.actions.ArrowLeft=!0;break;case"Delete":case"Backspace":if(t.state.editing)return;var a=document.getSelection(),s="Delete"==e.key&&a.anchorOffset==(a.anchorNode.length||0),l=a.anchorNode.previousSibling,u=1==a.anchorNode.nodeType||!a.anchorOffset&&l&&1==l.nodeType&&a.anchorNode.previousSibling;o(t.DOM.input.innerHTML);var d,h,f,p=t.getTagElms(),g=1===a.anchorNode.length&&a.anchorNode.nodeValue==String.fromCharCode(8203);if("edit"==i.backspace&&u)return d=1==a.anchorNode.nodeType?null:a.anchorNode.previousElementSibling,setTimeout(t.editTag.bind(t),0,d),void e.preventDefault();if(m()&&B(u,Element))return f=c(u),u.hasAttribute("readonly")||u.remove(),t.DOM.input.focus(),void setTimeout((function(){_(f),t.DOM.input.click()}));if("BR"==a.anchorNode.nodeName)return;if((s||u)&&1==a.anchorNode.nodeType?h=0==a.anchorOffset?s?p[0]:null:p[Math.min(p.length,a.anchorOffset)-1]:s?h=a.anchorNode.nextElementSibling:B(u,Element)&&(h=u),3==a.anchorNode.nodeType&&!a.anchorNode.nodeValue&&a.anchorNode.previousElementSibling&&e.preventDefault(),(u||s)&&!i.backspace)return void e.preventDefault();if("Range"!=a.type&&!a.anchorOffset&&a.anchorNode==t.DOM.input&&"Delete"!=e.key)return void e.preventDefault();if("Range"!=a.type&&h&&h.hasAttribute("readonly"))return void _(c(h));"Delete"==e.key&&g&&x(a.anchorNode.nextSibling)&&t.removeTags(a.anchorNode.nextSibling),clearTimeout(P),P=setTimeout((function(){var e=document.getSelection();o(t.DOM.input.innerHTML),!s&&e.anchorNode.previousSibling,t.value=[].map.call(p,(function(e,i){var n=x(e);if(e.parentNode||n.readonly)return n;t.trigger("remove",{tag:e,index:i,data:n})})).filter((function(e){return e}))}),20)}return!0}var v="manual"==i.dropdown.position;switch(e.key){case"Backspace":"select"==i.mode&&i.enforceWhitelist&&t.value.length?t.removeTags():t.state.dropdown.visible&&"manual"!=i.dropdown.position||""!=e.target.textContent&&8203!=n.charCodeAt(0)||(!0===i.backspace?t.removeTags():"edit"==i.backspace&&setTimeout(t.editTag.bind(t),0));break;case"Esc":case"Escape":if(t.state.dropdown.visible)return;e.target.blur();break;case"Down":case"ArrowDown":t.state.dropdown.visible||t.dropdown.show();break;case"ArrowRight":var y=t.state.inputSuggestion||t.state.ddItemData;if(y&&i.autoComplete.rightKey)return void t.addTags([y],!0);break;case"Tab":var b="select"==i.mode;if(!n||b)return!0;e.preventDefault();case"Enter":if(t.state.dropdown.visible&&!v)return;e.preventDefault(),setTimeout((function(){t.state.dropdown.visible&&!v||t.state.actions.selectOption||!i.addTagOn.includes(e.key.toLowerCase())||t.addTags(n,!0)}))}})).catch((function(e){return e}))}},onInput:function(e){this.postUpdate();var t=this.settings;if("mix"==t.mode)return this.events.callbacks.onMixTagsInput.call(this,e);var i=this.input.normalize.call(this,void 0,{trim:!1}),n=i.length>=t.dropdown.enabled,r={value:i,inputElm:this.DOM.input},a=this.validateTag({value:i});"select"==t.mode&&this.toggleScopeValidation(a),r.isValid=a,this.state.inputText!=i&&(this.input.set.call(this,i,!1),-1!=i.search(t.delimiters)?this.addTags(i)&&this.input.set.call(this):t.dropdown.enabled>=0&&this.dropdown[n?"show":"hide"](i),this.trigger("input",r))},onMixTagsInput:function(e){var t,i,n,r,a,s,o,l,c=this,u=this.settings,d=this.value.length,f=this.getTagElms(),p=document.createDocumentFragment(),g=window.getSelection().getRangeAt(0),v=[].map.call(f,(function(e){return x(e).value}));if("deleteContentBackward"==e.inputType&&m()&&this.events.callbacks.onKeydown.call(this,{target:e.target,key:"Backspace"}),w(this.getTagElms()),this.value.slice().forEach((function(e){e.readonly&&!v.includes(e.value)&&p.appendChild(c.createTagElem(e))})),p.childNodes.length&&(g.insertNode(p),this.setRangeAtStartEnd(!1,p.lastChild)),f.length!=d)return this.value=[].map.call(this.getTagElms(),(function(e){return x(e)})),void this.update({withoutChangeEvent:!0});if(this.hasMaxTags())return!0;if(window.getSelection&&(s=window.getSelection()).rangeCount>0&&3==s.anchorNode.nodeType){if((g=s.getRangeAt(0).cloneRange()).collapse(!0),g.setStart(s.focusNode,0),n=(t=g.toString().slice(0,g.endOffset)).split(u.pattern).length-1,(i=t.match(u.pattern))&&(r=t.slice(t.lastIndexOf(i[i.length-1]))),r){if(this.state.actions.ArrowLeft=!1,this.state.tag={prefix:r.match(u.pattern)[0],value:r.replace(u.pattern,"")},this.state.tag.baseOffset=s.baseOffset-this.state.tag.value.length,l=this.state.tag.value.match(u.delimiters))return this.state.tag.value=this.state.tag.value.replace(u.delimiters,""),this.state.tag.delimiters=l[0],this.addTags(this.state.tag.value,u.dropdown.clearOnSelect),void this.dropdown.hide();a=this.state.tag.value.length>=u.dropdown.enabled;try{o=(o=this.state.flaggedTags[this.state.tag.baseOffset]).prefix==this.state.tag.prefix&&o.value[0]==this.state.tag.value[0],this.state.flaggedTags[this.state.tag.baseOffset]&&!this.state.tag.value&&delete this.state.flaggedTags[this.state.tag.baseOffset]}catch(e){}(o||n<this.state.mixMode.matchedPatternCount)&&(a=!1)}else this.state.flaggedTags={};this.state.mixMode.matchedPatternCount=n}setTimeout((function(){c.update({withoutChangeEvent:!0}),c.trigger("input",h({},c.state.tag,{textContent:c.DOM.input.textContent})),c.state.tag&&c.dropdown[a?"show":"hide"](c.state.tag.value)}),10)},onInputIE:function(e){var t=this;setTimeout((function(){t.events.callbacks.onInput.call(t,e)}))},observeOriginalInputValue:function(){this.DOM.originalInput.parentNode||this.destroy(),this.DOM.originalInput.value!=this.DOM.originalInput.tagifyValue&&this.loadOriginalValues()},onClickAnywhere:function(e){e.target==this.DOM.scope||this.DOM.scope.contains(e.target)||(this.toggleFocusClass(!1),this.state.hasFocus=!1,e.target.closest(".tagify__dropdown")&&e.target.closest(".tagify__dropdown").__tagify!=this&&this.dropdown.hide())},onClickScope:function(e){var t=this.settings,i=e.target.closest("."+t.classNames.tag),n=e.target===this.DOM.scope,r=+new Date-this.state.hasFocus;if(n&&"select"!=t.mode)this.DOM.input.focus();else{if(!e.target.classList.contains(t.classNames.tagX))return i&&!this.state.editing?(this.trigger("click",{tag:i,index:this.getNodeIndex(i),data:x(i),event:e}),void(1!==t.editTags&&1!==t.editTags.clicks&&"select"!=t.mode||this.events.callbacks.onDoubleClickScope.call(this,e))):void(e.target==this.DOM.input&&("mix"==t.mode&&this.fixFirefoxLastTagNoCaret(),r>500||!t.focusable)?this.state.dropdown.visible?this.dropdown.hide():0===t.dropdown.enabled&&"mix"!=t.mode&&this.dropdown.show(this.value.length?"":void 0):"select"!=t.mode||0!==t.dropdown.enabled||this.state.dropdown.visible||(this.events.callbacks.onDoubleClickScope.call(this,function(e,t){return t=null!=t?t:{},Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(t)):function(e,t){var i=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);i.push.apply(i,n)}return i}(Object(t)).forEach((function(i){Object.defineProperty(e,i,Object.getOwnPropertyDescriptor(t,i))})),e}(function(e){for(var t=1;t<arguments.length;t++){var i=null!=arguments[t]?arguments[t]:{},n=Object.keys(i);"function"==typeof Object.getOwnPropertySymbols&&(n=n.concat(Object.getOwnPropertySymbols(i).filter((function(e){return Object.getOwnPropertyDescriptor(i,e).enumerable})))),n.forEach((function(t){z(e,t,i[t])}))}return e}({},e),{target:this.getTagElms()[0]})),!t.userInput&&this.dropdown.show()));this.removeTags(e.target.parentNode)}},onPaste:function(e){var t=this;e.preventDefault();var i,n,r,a=this.settings;if("select"==a.mode&&a.enforceWhitelist||!a.userInput)return!1;a.readonly||(n=e.clipboardData||window.clipboardData,r=n.getData("Text"),a.hooks.beforePaste(e,{tagify:this,pastedText:r,clipboardData:n}).then((function(a){void 0===a&&(a=r),a&&(t.injectAtCaret(a,window.getSelection().getRangeAt(0)),"mix"==t.settings.mode?t.events.callbacks.onMixTagsInput.call(t,e):t.settings.pasteAsTags?i=t.addTags(t.state.inputText+a,!0):(t.state.inputText=a,t.dropdown.show(a))),t.trigger("paste",{event:e,pastedText:r,clipboardData:n,tagsElems:i})})).catch((function(e){return e})))},onDrop:function(e){e.preventDefault()},onEditTagInput:function(e,t){var i,n=e.closest("."+this.settings.classNames.tag),r=this.getNodeIndex(n),a=x(n),s=this.input.normalize.call(this,e),o=(z(i={},this.settings.tagTextProp,s),z(i,"__tagId",a.__tagId),i),l=this.validateTag(o);this.editTagChangeDetected(h(a,o))||!0!==e.originalIsValid||(l=!0),n.classList.toggle(this.settings.classNames.tagInvalid,!0!==l),a.__isValid=l,n.title=!0===l?a.title||a.value:l,s.length>=this.settings.dropdown.enabled&&(this.state.editing&&(this.state.editing.value=s),this.dropdown.show(s)),this.trigger("edit:input",{tag:n,index:r,data:h({},this.value[r],{newValue:s}),event:t})},onEditTagPaste:function(e,t){var i=(t.clipboardData||window.clipboardData).getData("Text");t.preventDefault();var n=b(i);this.setRangeAtStartEnd(!1,n)},onEditTagClick:function(e,t){this.events.callbacks.onClickScope.call(this,t)},onEditTagFocus:function(e){this.state.editing={scope:e,input:e.querySelector("[contenteditable]")}},onEditTagBlur:function(e,t){var i=v.call(this,t.relatedTarget);if("select"==this.settings.mode&&i&&t.relatedTarget.contains(t.target))this.dropdown.hide();else if(this.state.editing&&(this.state.hasFocus||this.toggleFocusClass(),this.DOM.scope.contains(e))){var n,r,a,s=this.settings,o=e.closest("."+s.classNames.tag),l=x(o),c=this.input.normalize.call(this,e),u=(z(n={},s.tagTextProp,c),z(n,"__tagId",l.__tagId),n),d=l.__originalData,f=this.editTagChangeDetected(h(l,u)),p=this.validateTag(u);if(c)if(f){var m;if(r=this.hasMaxTags(),a=h({},d,(z(m={},s.tagTextProp,this.trim(c)),z(m,"__isValid",p),m)),s.transformTag.call(this,a,d),!0!==(p=(!r||!0===d.__isValid)&&this.validateTag(a))){if(this.trigger("invalid",{data:a,tag:o,message:p}),s.editTags.keepInvalid)return;s.keepInvalidTags?a.__isValid=p:a=d}else s.keepInvalidTags&&(delete a.title,delete a["aria-invalid"],delete a.class);this.onEditTagDone(o,a)}else this.onEditTagDone(o,d);else this.onEditTagDone(o)}},onEditTagkeydown:function(e,t){if(!this.state.composing)switch(this.trigger("edit:keydown",{event:e}),e.key){case"Esc":case"Escape":this.state.editing=!1,t.__tagifyTagData.__originalData.value?t.parentNode.replaceChild(t.__tagifyTagData.__originalHTML,t):t.remove();break;case"Enter":case"Tab":e.preventDefault(),setTimeout((function(){return e.target.blur()}),0)}},onDoubleClickScope:function(e){var t,i,n=e.target.closest("."+this.settings.classNames.tag),r=x(n),a=this.settings;n&&!1!==r.editable&&(t=n.classList.contains(this.settings.classNames.tagEditing),i=n.hasAttribute("readonly"),a.readonly||t||i||!this.settings.editTags||!a.userInput||(this.events.callbacks.onEditTagFocus.call(this,n),this.editTag(n)),this.toggleFocusClass(!0),"select"!=a.mode&&this.trigger("dblclick",{tag:n,index:this.getNodeIndex(n),data:x(n)}))},onInputDOMChange:function(e){var t=this;e.forEach((function(e){e.addedNodes.forEach((function(e){if("<div><br></div>"==e.outerHTML)e.replaceWith(document.createElement("br"));else if(1==e.nodeType&&e.querySelector(t.settings.classNames.tagSelector)){var i,n=document.createTextNode("");3==e.childNodes[0].nodeType&&"BR"!=e.previousSibling.nodeName&&(n=document.createTextNode("\n")),(i=e).replaceWith.apply(i,V([n].concat(V(V(e.childNodes).slice(0,-1))))),_(n)}else if(v.call(t,e)){var r;if(3!=(null===(r=e.previousSibling)||void 0===r?void 0:r.nodeType)||e.previousSibling.textContent||e.previousSibling.remove(),e.previousSibling&&"BR"==e.previousSibling.nodeName){e.previousSibling.replaceWith("\n​");for(var a=e.nextSibling,s="";a;)s+=a.textContent,a=a.nextSibling;s.trim()&&_(e.previousSibling)}else e.previousSibling&&!x(e.previousSibling)||e.before("​")}})),e.removedNodes.forEach((function(e){e&&"BR"==e.nodeName&&v.call(t,i)&&(t.removeTags(i),t.fixFirefoxLastTagNoCaret())}))}));var i=this.DOM.input.lastChild;i&&""==i.nodeValue&&i.remove(),i&&"BR"==i.nodeName||this.DOM.input.appendChild(document.createElement("br"))}}};function U(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}function q(e,t,i){return t in e?Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}):e[t]=i,e}function $(e,t){return null!=t&&"undefined"!=typeof Symbol&&t[Symbol.hasInstance]?!!t[Symbol.hasInstance](e):e instanceof t}function X(e){for(var t=1;t<arguments.length;t++){var i=null!=arguments[t]?arguments[t]:{},n=Object.keys(i);"function"==typeof Object.getOwnPropertySymbols&&(n=n.concat(Object.getOwnPropertySymbols(i).filter((function(e){return Object.getOwnPropertyDescriptor(i,e).enumerable})))),n.forEach((function(t){q(e,t,i[t])}))}return e}function G(e){return function(e){if(Array.isArray(e))return U(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return U(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(i):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?U(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function Z(e,t){if(!e){n.warn("input element not found",e);var i=new Proxy(this,{get:function(){return function(){return i}}});return i}if(e.__tagify)return n.warn("input element is already Tagified - Same instance is returned.",e),e.__tagify;var r;h(this,function(e){var t=document.createTextNode(""),i={};function r(e,i,n){n&&i.split(/\s+/g).forEach((function(i){return t[e+"EventListener"].call(t,i,n)}))}return{removeAllCustomListeners:function(){Object.entries(i).forEach((function(e){var t=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var i=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=i){var n,r,a=[],s=!0,o=!1;try{for(i=i.call(e);!(s=(n=i.next()).done)&&(a.push(n.value),!t||a.length!==t);s=!0);}catch(e){o=!0,r=e}finally{try{s||null==i.return||i.return()}finally{if(o)throw r}}return a}}(e,t)||function(e,t){if(e){if("string"==typeof e)return H(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(i):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?H(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(e,2),i=t[0];t[1].forEach((function(e){return r("remove",i,e)}))})),i={}},off:function(e,t){return e&&(t?r("remove",e,t):e.split(/\s+/g).forEach((function(e){var t;null===(t=i[e])||void 0===t||t.forEach((function(t){return r("remove",e,t)})),delete i[e]}))),this},on:function(e,t){return t&&"function"==typeof t&&(e.split(/\s+/g).forEach((function(e){Array.isArray(i[e])?i[e].push(t):i[e]=[t]})),r("add",e,t)),this},trigger:function(i,r,a){var s;if(a=a||{cloneData:!0},i)if(e.settings.isJQueryPlugin)"remove"==i&&(i="removeTag"),jQuery(e.DOM.originalInput).triggerHandler(i,[r]);else{try{var o="object"==typeof r?r:{value:r};if((o=a.cloneData?h({},o):o).tagify=this,r.event&&(o.event=this.cloneEvent(r.event)),F(r,Object))for(var l in r)F(r[l],HTMLElement)&&(o[l]=r[l]);s=new CustomEvent(i,{detail:o})}catch(e){n.warn(e)}t.dispatchEvent(s)}}}}(this)),this.isFirefox=/firefox|fxios/i.test(navigator.userAgent)&&!/seamonkey/i.test(navigator.userAgent),this.isIE=window.document.documentMode,t=t||{},this.getPersistedData=(r=t.id,function(e){var t,i="/"+e;if(1==localStorage.getItem(I+r+"/v",1))try{t=JSON.parse(localStorage[I+r+i])}catch(e){}return t}),this.setPersistedData=function(e){return e?(localStorage.setItem(I+e+"/v",1),function(t,i){var n="/"+i,r=JSON.stringify(t);t&&i&&(localStorage.setItem(I+e+n,r),dispatchEvent(new Event("storage")))}):function(){}}(t.id),this.clearPersistedData=function(e){return function(t){var i=I+"/"+e+"/";if(t)localStorage.removeItem(i+t);else for(var n in localStorage)n.includes(i)&&localStorage.removeItem(n)}}(t.id),this.applySettings(e,t),this.state={inputText:"",editing:!1,composing:!1,actions:{},mixMode:{},dropdown:{},flaggedTags:{}},this.value=[],this.listeners={},this.DOM={},this.build(e),D.call(this),this.getCSSVars(),this.loadOriginalValues(),this.events.customBinding.call(this),this.events.binding.call(this),e.autofocus&&this.DOM.input.focus(),e.__tagify=this}return Z.prototype={_dropdown:Y,placeCaretAfterNode:_,getSetTagData:x,helpers:{sameStr:r,removeCollectionProp:a,omit:s,isObject:d,parseHTML:l,escapeHTML:u,extend:h,concatWithoutDups:f,getUID:g,isNodeTag:v},customEventsList:["change","add","remove","invalid","input","paste","click","keydown","focus","blur","edit:input","edit:beforeUpdate","edit:updated","edit:start","edit:keydown","dropdown:show","dropdown:hide","dropdown:select","dropdown:updated","dropdown:noMatch","dropdown:scroll"],dataProps:["__isValid","__removed","__originalData","__originalHTML","__tagId"],trim:function(e){return this.settings.trim&&e&&"string"==typeof e?e.trim():e},parseHTML:l,templates:j,parseTemplate:function(e,t){return l((e=this.settings.templates[e]||e).apply(this,t))},set whitelist(e){var t=e&&Array.isArray(e);this.settings.whitelist=t?e:[],this.setPersistedData(t?e:[],"whitelist")},get whitelist(){return this.settings.whitelist},set userInput(e){this.settings.userInput=!!e,this.setContentEditable(!!e)},get userInput(){return this.settings.userInput},generateClassSelectors:function(e){var t=function(t){var i=t;Object.defineProperty(e,i+"Selector",{get:function(){return"."+this[i].split(" ")[0]}})};for(var i in e)t(i)},applySettings:function(e,t){var i,n;k.templates=this.templates;var r=h({},k,"mix"==t.mode?{dropdown:{position:"text"}}:{}),a=this.settings=h({},r,t);if(a.disabled=e.hasAttribute("disabled"),a.readonly=a.readonly||e.hasAttribute("readonly"),a.placeholder=u(e.getAttribute("placeholder")||a.placeholder||""),a.required=e.hasAttribute("required"),this.generateClassSelectors(a.classNames),void 0===a.dropdown.includeSelectedTags&&(a.dropdown.includeSelectedTags=a.duplicates),this.isIE&&(a.autoComplete=!1),["whitelist","blacklist"].forEach((function(t){var i=e.getAttribute("data-"+t);i&&$(i=i.split(a.delimiters),Array)&&(a[t]=i)})),"autoComplete"in t&&!d(t.autoComplete)&&(a.autoComplete=k.autoComplete,a.autoComplete.enabled=t.autoComplete),"mix"==a.mode&&(a.pattern=a.pattern||/@/,a.autoComplete.rightKey=!0,a.delimiters=t.delimiters||null,a.tagTextProp&&!a.dropdown.searchKeys.includes(a.tagTextProp)&&a.dropdown.searchKeys.push(a.tagTextProp)),e.pattern)try{a.pattern=new RegExp(e.pattern)}catch(e){}if(a.delimiters){a._delimiters=a.delimiters;try{a.delimiters=new RegExp(this.settings.delimiters,"g")}catch(e){}}a.disabled&&(a.userInput=!1),this.TEXTS=X({},N,a.texts||{}),("select"!=a.mode||(null===(i=t.dropdown)||void 0===i?void 0:i.enabled))&&a.userInput||(a.dropdown.enabled=0),a.dropdown.appendTarget=(null===(n=t.dropdown)||void 0===n?void 0:n.appendTarget)||document.body;var s=this.getPersistedData("whitelist");Array.isArray(s)&&(this.whitelist=Array.isArray(a.whitelist)?f(a.whitelist,s):s)},getAttributes:function(e){var t,i=this.getCustomAttributes(e),n="";for(t in i)n+=" "+t+(void 0!==e[t]?'="'.concat(i[t],'"'):"");return n},getCustomAttributes:function(e){if(!d(e))return"";var t,i={};for(t in e)"__"!=t.slice(0,2)&&"class"!=t&&e.hasOwnProperty(t)&&void 0!==e[t]&&(i[t]=u(e[t]));return i},setStateSelection:function(){var e=window.getSelection(),t={anchorOffset:e.anchorOffset,anchorNode:e.anchorNode,range:e.getRangeAt&&e.rangeCount&&e.getRangeAt(0)};return this.state.selection=t,t},getCSSVars:function(){var e,t,i=getComputedStyle(this.DOM.scope,null);this.CSSVars={tagHideTransition:(e=function(e){if(!e)return{};var t=(e=e.trim().split(" ")[0]).split(/\d+/g).filter((function(e){return e})).pop().trim();return{value:+e.split(t).filter((function(e){return e}))[0].trim(),unit:t}}(i.getPropertyValue("--tag-hide-transition")),t=e.value,"s"==e.unit?1e3*t:t)}},build:function(e){var t=this.DOM,i=e.closest("label");this.settings.mixMode.integrated?(t.originalInput=null,t.scope=e,t.input=e):(t.originalInput=e,t.originalInput_tabIndex=e.tabIndex,t.scope=this.parseTemplate("wrapper",[e,this.settings]),t.input=t.scope.querySelector(this.settings.classNames.inputSelector),e.parentNode.insertBefore(t.scope,e),e.tabIndex=-1),i&&i.setAttribute("for","")},destroy:function(){this.events.unbindGlobal.call(this),this.DOM.scope.parentNode.removeChild(this.DOM.scope),this.DOM.originalInput.tabIndex=this.DOM.originalInput_tabIndex,delete this.DOM.originalInput.__tagify,this.dropdown.hide(!0),this.removeAllCustomListeners(),clearTimeout(this.dropdownHide__bindEventsTimeout),clearInterval(this.listeners.main.originalInputValueObserverInterval)},loadOriginalValues:function(e){var t,i=this.settings;if(this.state.blockChangeEvent=!0,void 0===e){var n=this.getPersistedData("value");e=n&&!this.DOM.originalInput.value?n:i.mixMode.integrated?this.DOM.input.textContent:this.DOM.originalInput.value}if(this.removeAllTags(),e)if("mix"==i.mode)this.parseMixTags(e),(t=this.DOM.input.lastChild)&&"BR"==t.tagName||this.DOM.input.insertAdjacentHTML("beforeend","<br>");else{try{$(JSON.parse(e),Array)&&(e=JSON.parse(e))}catch(e){}this.addTags(e,!0).forEach((function(e){return e&&e.classList.add(i.classNames.tagNoAnimation)}))}else this.postUpdate();this.state.lastOriginalValueReported=i.mixMode.integrated?"":this.DOM.originalInput.value},cloneEvent:function(e){var t={};for(var i in e)"path"!=i&&(t[i]=e[i]);return t},loading:function(e){return this.state.isLoading=e,this.DOM.scope.classList[e?"add":"remove"](this.settings.classNames.scopeLoading),this},tagLoading:function(e,t){return e&&e.classList[t?"add":"remove"](this.settings.classNames.tagLoading),this},toggleClass:function(e,t){"string"==typeof e&&this.DOM.scope.classList.toggle(e,t)},toggleScopeValidation:function(e){var t=!0===e||void 0===e;!this.settings.required&&e&&e===this.TEXTS.empty&&(t=!0),this.toggleClass(this.settings.classNames.tagInvalid,!t),this.DOM.scope.title=t?"":e},toggleFocusClass:function(e){this.toggleClass(this.settings.classNames.focus,!!e)},setPlaceholder:function(e){var t=this;["data","aria"].forEach((function(i){return t.DOM.input.setAttribute("".concat(i,"-placeholder"),e)}))},triggerChangeEvent:function(){if(!this.settings.mixMode.integrated){var e=this.DOM.originalInput,t=this.state.lastOriginalValueReported!==e.value,i=new CustomEvent("change",{bubbles:!0});t&&(this.state.lastOriginalValueReported=e.value,i.simulated=!0,e._valueTracker&&e._valueTracker.setValue(Math.random()),e.dispatchEvent(i),this.trigger("change",this.state.lastOriginalValueReported),e.value=this.state.lastOriginalValueReported)}},events:W,fixFirefoxLastTagNoCaret:function(){},setRangeAtStartEnd:function(e,t){if(t){e="number"==typeof e?e:!!e,t=t.lastChild||t;var i=document.getSelection();if($(i.focusNode,Element)&&!this.DOM.input.contains(i.focusNode))return!0;try{i.rangeCount>=1&&["Start","End"].forEach((function(n){return i.getRangeAt(0)["set"+n](t,e||t.length)}))}catch(e){console.warn(e)}}},insertAfterTag:function(e,t){if(t=t||this.settings.mixMode.insertAfterTag,e&&e.parentNode&&t)return t="string"==typeof t?document.createTextNode(t):t,e.parentNode.insertBefore(t,e.nextSibling),t},editTagChangeDetected:function(e){var t=e.__originalData;for(var i in t)if(!this.dataProps.includes(i)&&e[i]!=t[i])return!0;return!1},getTagTextNode:function(e){return e.querySelector(this.settings.classNames.tagTextSelector)},setTagTextNode:function(e,t){this.getTagTextNode(e).innerHTML=u(t)},editTag:function(e,t){var i=this;e=e||this.getLastTag(),t=t||{};var r=this.settings,a=this.getTagTextNode(e),s=this.getNodeIndex(e),o=x(e),l=this.events.callbacks,c=!0,u="select"==r.mode;if(!u&&this.dropdown.hide(),a){if(!$(o,Object)||!("editable"in o)||o.editable)return o=x(e,{__originalData:h({},o),__originalHTML:e.cloneNode(!0)}),x(o.__originalHTML,o.__originalData),a.setAttribute("contenteditable",!0),e.classList.add(r.classNames.tagEditing),a.addEventListener("click",l.onEditTagClick.bind(this,e)),a.addEventListener("blur",l.onEditTagBlur.bind(this,this.getTagTextNode(e))),a.addEventListener("input",l.onEditTagInput.bind(this,a)),a.addEventListener("paste",l.onEditTagPaste.bind(this,a)),a.addEventListener("keydown",(function(t){return l.onEditTagkeydown.call(i,t,e)})),a.addEventListener("compositionstart",l.onCompositionStart.bind(this)),a.addEventListener("compositionend",l.onCompositionEnd.bind(this)),t.skipValidation||(c=this.editTagToggleValidity(e)),a.originalIsValid=c,this.trigger("edit:start",{tag:e,index:s,data:o,isValid:c}),a.focus(),!u&&this.setRangeAtStartEnd(!1,a),0===r.dropdown.enabled&&!u&&this.dropdown.show(),this.state.hasFocus=!0,this}else n.warn("Cannot find element in Tag template: .",r.classNames.tagTextSelector)},editTagToggleValidity:function(e,t){var i;if(t=t||x(e))return(i=!("__isValid"in t)||!0===t.__isValid)||this.removeTagsFromValue(e),this.update(),e.classList.toggle(this.settings.classNames.tagNotAllowed,!i),t.__isValid=i,t.__isValid;n.warn("tag has no data: ",e,t)},onEditTagDone:function(e,t){t=t||{};var i,n,r={tag:e=e||this.state.editing.scope,index:this.getNodeIndex(e),previousData:x(e),data:t},a=this.settings;this.trigger("edit:beforeUpdate",r,{cloneData:!1}),this.state.editing=!1,delete t.__originalData,delete t.__originalHTML,e&&(void 0!==(n=t[a.tagTextProp])?null===(i=(n+="").trim)||void 0===i?void 0:i.call(n):a.tagTextProp in t?void 0:t.value)?(e=this.replaceTag(e,t),this.editTagToggleValidity(e,t),a.a11y.focusableTags?e.focus():"select"!=a.mode&&_(e)):e&&this.removeTags(e),this.trigger("edit:updated",r),this.dropdown.hide(),this.settings.keepInvalidTags&&this.reCheckInvalidTags()},replaceTag:function(e,t){t&&""!==t.value&&void 0!==t.value||(t=e.__tagifyTagData),t.__isValid&&1!=t.__isValid&&h(t,this.getInvalidTagAttrs(t,t.__isValid));var i=this.createTagElem(t);return e.parentNode.replaceChild(i,e),this.updateValueByDOMTags(),i},updateValueByDOMTags:function(){var e=this;this.value.length=0,[].forEach.call(this.getTagElms(),(function(t){t.classList.contains(e.settings.classNames.tagNotAllowed.split(" ")[0])||e.value.push(x(t))})),this.update()},injectAtCaret:function(e,t){var i;if(!(t=t||(null===(i=this.state.selection)||void 0===i?void 0:i.range))&&e)return this.appendMixTags(e),this;var n=b(e,t);return this.setRangeAtStartEnd(!1,n),this.updateValueByDOMTags(),this.update(),this},input:{set:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"",t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=this.settings,n=i.dropdown.closeOnSelect;this.state.inputText=e,t&&(this.DOM.input.innerHTML=u(""+e),e&&this.toggleClass(i.classNames.empty,!this.DOM.input.innerHTML)),!e&&n&&this.dropdown.hide.bind(this),this.input.autocomplete.suggest.call(this),this.input.validate.call(this)},raw:function(){return this.DOM.input.textContent},validate:function(){var e=!this.state.inputText||!0===this.validateTag({value:this.state.inputText});return this.DOM.input.classList.toggle(this.settings.classNames.inputInvalid,!e),e},normalize:function(e,t){var i=e||this.DOM.input,n=[];i.childNodes.forEach((function(e){return 3==e.nodeType&&n.push(e.nodeValue)})),n=n.join("\n");try{n=n.replace(/(?:\r\n|\r|\n)/g,this.settings.delimiters.source.charAt(0))}catch(e){}return n=n.replace(/\s/g," "),(null==t?void 0:t.trim)?this.trim(n):n},autocomplete:{suggest:function(e){if(this.settings.autoComplete.enabled){"object"!=typeof(e=e||{value:""})&&(e={value:e});var t=this.dropdown.getMappedValue(e);if("number"!=typeof t){var i=this.state.inputText.toLowerCase(),n=t.substr(0,this.state.inputText.length).toLowerCase(),r=t.substring(this.state.inputText.length);t&&this.state.inputText&&n==i?(this.DOM.input.setAttribute("data-suggest",r),this.state.inputSuggestion=e):(this.DOM.input.removeAttribute("data-suggest"),delete this.state.inputSuggestion)}}},set:function(e){var t=this.DOM.input.getAttribute("data-suggest"),i=e||(t?this.state.inputText+t:null);return!!i&&("mix"==this.settings.mode?this.replaceTextWithNode(document.createTextNode(this.state.tag.prefix+i)):(this.input.set.call(this,i),this.setRangeAtStartEnd(!1,this.DOM.input)),this.input.autocomplete.suggest.call(this),this.dropdown.hide(),!0)}}},getTagIdx:function(e){return this.value.findIndex((function(t){return t.__tagId==(e||{}).__tagId}))},getNodeIndex:function(e){var t=0;if(e)for(;e=e.previousElementSibling;)t++;return t},getTagElms:function(){for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];var n="."+G(this.settings.classNames.tag.split(" ")).concat(G(t)).join(".");return[].slice.call(this.DOM.scope.querySelectorAll(n))},getLastTag:function(){var e=this.settings.classNames,t=this.DOM.scope.querySelectorAll("".concat(e.tagSelector,":not(.").concat(e.tagHide,"):not([readonly])"));return t[t.length-1]},isTagDuplicate:function(e,t,i){var n=0;if("select"==this.settings.mode)return!1;var a=!0,s=!1,o=void 0;try{for(var l,c=this.value[Symbol.iterator]();!(a=(l=c.next()).done);a=!0){var u=l.value;r(this.trim(""+e),u.value,t)&&i!=u.__tagId&&n++}}catch(e){s=!0,o=e}finally{try{a||null==c.return||c.return()}finally{if(s)throw o}}return n},getTagIndexByValue:function(e){var t=this,i=[],n=this.settings.dropdown.caseSensitive;return this.getTagElms().forEach((function(a,s){a.__tagifyTagData&&r(t.trim(a.__tagifyTagData.value),e,n)&&i.push(s)})),i},getTagElmByValue:function(e){var t=this.getTagIndexByValue(e)[0];return this.getTagElms()[t]},flashTag:function(e){var t=this;e&&(e.classList.add(this.settings.classNames.tagFlash),setTimeout((function(){e.classList.remove(t.settings.classNames.tagFlash)}),100))},isTagBlacklisted:function(e){return e=this.trim(e.toLowerCase()),this.settings.blacklist.filter((function(t){return(""+t).toLowerCase()==e})).length},isTagWhitelisted:function(e){return!!this.getWhitelistItem(e)},getWhitelistItem:function(e,t,i){t=t||"value";var n,a=this.settings;return(i=i||a.whitelist).some((function(i){var s="object"==typeof i?i[t]||i.value:i;if(r(s,e,a.dropdown.caseSensitive,a.trim))return n="object"==typeof i?i:{value:i},!0})),n||"value"!=t||"value"==a.tagTextProp||(n=this.getWhitelistItem(e,a.tagTextProp,i)),n},validateTag:function(e){var t=this.settings,i="value"in e?"value":t.tagTextProp,n=this.trim(e[i]+"");return(e[i]+"").trim()?"mix"!=t.mode&&t.pattern&&$(t.pattern,RegExp)&&!t.pattern.test(n)?this.TEXTS.pattern:!t.duplicates&&this.isTagDuplicate(n,t.dropdown.caseSensitive,e.__tagId)?this.TEXTS.duplicate:this.isTagBlacklisted(n)||t.enforceWhitelist&&!this.isTagWhitelisted(n)?this.TEXTS.notAllowed:!t.validate||t.validate(e):this.TEXTS.empty},getInvalidTagAttrs:function(e,t){return{"aria-invalid":!0,class:"".concat(e.class||""," ").concat(this.settings.classNames.tagNotAllowed).trim(),title:t}},hasMaxTags:function(){return this.value.length>=this.settings.maxTags&&this.TEXTS.exceed},setReadonly:function(e,t){var i=this.settings;this.DOM.scope.contains(document.activeElement)&&document.activeElement.blur(),i[t||"readonly"]=e,this.DOM.scope[(e?"set":"remove")+"Attribute"](t||"readonly",!0),this.settings.userInput=!0,this.setContentEditable(!e)},setContentEditable:function(e){this.DOM.input.contentEditable=e,this.DOM.input.tabIndex=e?0:-1},setDisabled:function(e){this.setReadonly(e,"disabled")},normalizeTags:function(e){var t=this,i=this.settings,n=i.whitelist,r=i.delimiters,a=i.mode,s=i.tagTextProp,o=[],l=!!n&&$(n[0],Object),c=Array.isArray(e),u=c&&e[0].value,f=function(e){return(e+"").split(r).reduce((function(e,i){var n,r=t.trim(i);return r&&e.push((q(n={},s,r),q(n,"value",r),n)),e}),[])};if("number"==typeof e&&(e=e.toString()),"string"==typeof e){if(!e.trim())return[];e=f(e)}else c&&(e=e.reduce((function(e,i){if(d(i)){var n=h({},i);s in n||(s="value"),n[s]=t.trim(n[s]),n[s]&&e.push(n)}else if(i){var r;(r=e).push.apply(r,G(f(i)))}return e}),[]));return l&&!u&&(e.forEach((function(e){var i=o.map((function(e){return e.value})),n=t.dropdown.filterListItems.call(t,e[s],{exact:!0});t.settings.duplicates||(n=n.filter((function(e){return!i.includes(e.value)})));var r=n.length>1?t.getWhitelistItem(e[s],s,n):n[0];r&&$(r,Object)?o.push(r):"mix"!=a&&(null==e.value&&(e.value=e[s]),o.push(e))})),o.length&&(e=o)),e},parseMixTags:function(e){var t=this,i=this.settings,n=i.mixTagsInterpolator,r=i.duplicates,a=i.transformTag,s=i.enforceWhitelist,o=i.maxTags,l=i.tagTextProp,c=[];e=e.split(n[0]).map((function(e,i){var u,d,h,f=e.split(n[1]),p=f[0],m=c.length==o;try{if(p==+p)throw Error;d=JSON.parse(p)}catch(e){d=t.normalizeTags(p)[0]||{value:p}}if(a.call(t,d),m||!(f.length>1)||s&&!t.isTagWhitelisted(d.value)||!r&&t.isTagDuplicate(d.value)){if(e)return i?n[0]+e:e}else d[u=d[l]?l:"value"]=t.trim(d[u]),h=t.createTagElem(d),c.push(d),h.classList.add(t.settings.classNames.tagNoAnimation),f[0]=h.outerHTML,t.value.push(d);return f.join("")})).join(""),this.DOM.input.innerHTML=e,this.DOM.input.appendChild(document.createTextNode("")),this.DOM.input.normalize();var u=this.getTagElms();return u.forEach((function(e,t){return x(e,c[t])})),this.update({withoutChangeEvent:!0}),w(u,this.state.hasFocus),e},replaceTextWithNode:function(e,t){if(this.state.tag||t){t=t||this.state.tag.prefix+this.state.tag.value;var i,n,r=this.state.selection||window.getSelection(),a=r.anchorNode,s=this.state.tag.delimiters?this.state.tag.delimiters.length:0;return a.splitText(r.anchorOffset-s),-1==(i=a.nodeValue.lastIndexOf(t))||(n=a.splitText(i),e&&a.parentNode.replaceChild(e,n)),!0}},prepareNewTagNode:function(e,t){t=t||{};var i=this.settings,n=[],r={},a=Object.assign({},e,{value:e.value+""});if(e=Object.assign({},a),i.transformTag.call(this,e),e.__isValid=this.hasMaxTags()||this.validateTag(e),!0!==e.__isValid){if(t.skipInvalid)return;if(h(r,this.getInvalidTagAttrs(e,e.__isValid),{__preInvalidData:a}),e.__isValid==this.TEXTS.duplicate&&this.flashTag(this.getTagElmByValue(e.value)),!i.createInvalidTags)return void n.push(e.value)}return"readonly"in e&&(e.readonly?r["aria-readonly"]=!0:delete e.readonly),{tagElm:this.createTagElem(e,r),tagData:e,aggregatedInvalidInput:n}},postProcessNewTagNode:function(e,t){var i=this,n=this.settings,r=t.__isValid;r&&!0===r?(this.value.push(t),setTimeout((function(){i.trigger("add",{tag:e,index:i.value.length-1,data:t})}))):(this.trigger("invalid",{data:t,index:this.value.length,tag:e,message:r}),n.keepInvalidTags||setTimeout((function(){return i.removeTags(e,!0)}),1e3)),this.dropdown.position()},selectTag:function(e,t){var i=this;if(!this.settings.enforceWhitelist||this.isTagWhitelisted(t.value)){this.state.actions.selectOption&&setTimeout((function(){return i.setRangeAtStartEnd(!1,i.DOM.input)}));var n=this.getLastTag();return n?this.replaceTag(n,t):this.appendTag(e),this.value[0]=t,this.update(),this.trigger("add",{tag:e,data:t}),[e]}},addEmptyTag:function(e){var t=h({value:""},e||{}),i=this.createTagElem(t);x(i,t),this.appendTag(i),this.editTag(i,{skipValidation:!0}),this.toggleFocusClass(!0)},addTags:function(e,t,i){var n=this,r=[],a=this.settings,s=[],o=document.createDocumentFragment();if(!e||0==e.length)return r;switch(e=this.normalizeTags(e),a.mode){case"mix":return this.addMixTags(e);case"select":t=!1,this.removeAllTags()}return this.DOM.input.removeAttribute("style"),e.forEach((function(e){var t=n.prepareNewTagNode(e,{skipInvalid:i||a.skipInvalid});if(t){var l=t.tagElm;if(e=t.tagData,s=t.aggregatedInvalidInput,r.push(l),"select"==a.mode)return n.selectTag(l,e);o.appendChild(l),n.postProcessNewTagNode(l,e)}})),this.appendTag(o),this.update(),e.length&&t&&(this.input.set.call(this,a.createInvalidTags?"":s.join(a._delimiters)),this.setRangeAtStartEnd(!1,this.DOM.input)),a.dropdown.enabled&&this.dropdown.refilter(),r},addMixTags:function(e){var t=this;if((e=this.normalizeTags(e))[0].prefix||this.state.tag)return this.prefixedTextToTag(e[0]);var i=document.createDocumentFragment();return e.forEach((function(e){var n=t.prepareNewTagNode(e);i.appendChild(n.tagElm),t.insertAfterTag(n.tagElm),t.postProcessNewTagNode(n.tagElm,n.tagData)})),this.appendMixTags(i),i.children},appendMixTags:function(e){var t=!!this.state.selection;t?this.injectAtCaret(e):(this.DOM.input.focus(),(t=this.setStateSelection()).range.setStart(this.DOM.input,t.range.endOffset),t.range.setEnd(this.DOM.input,t.range.endOffset),this.DOM.input.appendChild(e),this.updateValueByDOMTags(),this.update())},prefixedTextToTag:function(e){var t,i,n,r=this,a=this.settings,s=null===(t=this.state.tag)||void 0===t?void 0:t.delimiters;if(e.prefix=e.prefix||this.state.tag?this.state.tag.prefix:(a.pattern.source||a.pattern)[0],n=this.prepareNewTagNode(e),i=n.tagElm,this.replaceTextWithNode(i)||this.DOM.input.appendChild(i),setTimeout((function(){return i.classList.add(r.settings.classNames.tagNoAnimation)}),300),this.value.push(n.tagData),this.update(),!s){var o=this.insertAfterTag(i)||i;setTimeout(_,0,o)}return this.state.tag=null,this.postProcessNewTagNode(i,n.tagData),i},appendTag:function(e){var t=this.DOM,i=t.input;t.scope.insertBefore(e,i)},createTagElem:function(e,t){e.__tagId=g();var i,n=h({},e,X({value:u(e.value+"")},t));return function(e){for(var t,i=document.createNodeIterator(e,NodeFilter.SHOW_TEXT,null,!1);t=i.nextNode();)t.textContent.trim()||t.parentNode.removeChild(t)}(i=this.parseTemplate("tag",[n,this])),x(i,e),i},reCheckInvalidTags:function(){var e=this,t=this.settings;this.getTagElms(t.classNames.tagNotAllowed).forEach((function(i,n){var r=x(i),a=e.hasMaxTags(),s=e.validateTag(r),o=!0===s&&!a;if("select"==t.mode&&e.toggleScopeValidation(s),o)return r=r.__preInvalidData?r.__preInvalidData:{value:r.value},e.replaceTag(i,r);i.title=a||s}))},removeTags:function(e,t,i){var n,r=this,a=this.settings;if(e=e&&$(e,HTMLElement)?[e]:$(e,Array)?e:e?[e]:[this.getLastTag()].filter((function(e){return e})),n=e.reduce((function(e,t){t&&"string"==typeof t&&(t=r.getTagElmByValue(t));var i=x(t);return t&&i&&!i.readonly&&e.push({node:t,idx:r.getTagIdx(i),data:x(t,{__removed:!0})}),e}),[]),i="number"==typeof i?i:this.CSSVars.tagHideTransition,"select"==a.mode&&(i=0,this.input.set.call(this)),1==n.length&&"select"!=a.mode&&n[0].node.classList.contains(a.classNames.tagNotAllowed)&&(t=!0),n.length)return a.hooks.beforeRemoveTag(n,{tagify:this}).then((function(){var e=function(e){e.node.parentNode&&(e.node.parentNode.removeChild(e.node),t?a.keepInvalidTags&&this.trigger("remove",{tag:e.node,index:e.idx}):(this.trigger("remove",{tag:e.node,index:e.idx,data:e.data}),this.dropdown.refilter(),this.dropdown.position(),this.DOM.input.normalize(),a.keepInvalidTags&&this.reCheckInvalidTags()))};i&&i>10&&1==n.length?function(t){t.node.style.width=parseFloat(window.getComputedStyle(t.node).width)+"px",document.body.clientTop,t.node.classList.add(a.classNames.tagHide),setTimeout(e.bind(this),i,t)}.call(r,n[0]):n.forEach(e.bind(r)),t||(r.removeTagsFromValue(n.map((function(e){return e.node}))),r.update(),"select"==a.mode&&a.userInput&&r.setContentEditable(!0))})).catch((function(e){}))},removeTagsFromDOM:function(){this.getTagElms().forEach((function(e){return e.remove()}))},removeTagsFromValue:function(e){var t=this;(e=Array.isArray(e)?e:[e]).forEach((function(e){var i=x(e),n=t.getTagIdx(i);n>-1&&t.value.splice(n,1)}))},removeAllTags:function(e){var t=this;e=e||{},this.value=[],"mix"==this.settings.mode?this.DOM.input.innerHTML="":this.removeTagsFromDOM(),this.dropdown.refilter(),this.dropdown.position(),this.state.dropdown.visible&&setTimeout((function(){t.DOM.input.focus()})),"select"==this.settings.mode&&(this.input.set.call(this),this.settings.userInput&&this.setContentEditable(!0)),this.update(e)},postUpdate:function(){this.state.blockChangeEvent=!1;var e,t,i=this.settings,n=i.classNames,r="mix"==i.mode?i.mixMode.integrated?this.DOM.input.textContent:this.DOM.originalInput.value.trim():this.value.length+this.input.raw.call(this).length;this.toggleClass(n.hasMaxTags,this.value.length>=i.maxTags),this.toggleClass(n.hasNoTags,!this.value.length),this.toggleClass(n.empty,!r),"select"==i.mode&&this.toggleScopeValidation(null===(t=this.value)||void 0===t||null===(e=t[0])||void 0===e?void 0:e.__isValid)},setOriginalInputValue:function(e){var t=this.DOM.originalInput;this.settings.mixMode.integrated||(t.value=e,t.tagifyValue=t.value,this.setPersistedData(e,"value"))},update:function(e){clearTimeout(this.debouncedUpdateTimeout),this.debouncedUpdateTimeout=setTimeout(function(){var t=this.getInputValue();this.setOriginalInputValue(t),this.settings.onChangeAfterBlur&&(e||{}).withoutChangeEvent||this.state.blockChangeEvent||this.triggerChangeEvent(),this.postUpdate()}.bind(this),100),this.events.bindOriginaInputListener.call(this,100)},getInputValue:function(){var e=this.getCleanValue();return"mix"==this.settings.mode?this.getMixedTagsAsString(e):e.length?this.settings.originalInputValueFormat?this.settings.originalInputValueFormat(e):JSON.stringify(e):""},getCleanValue:function(e){return a(e||this.value,this.dataProps)},getMixedTagsAsString:function(){var e="",t=this,i=this.settings,n=i.originalInputValueFormat||JSON.stringify,r=i.mixTagsInterpolator;return function i(a){a.childNodes.forEach((function(a){if(1==a.nodeType){var o=x(a);if("BR"==a.tagName&&(e+="\r\n"),o&&v.call(t,a)){if(o.__removed)return;e+=r[0]+n(s(o,t.dataProps))+r[1]}else a.getAttribute("style")||["B","I","U"].includes(a.tagName)?e+=a.textContent:"DIV"!=a.tagName&&"P"!=a.tagName||(e+="\r\n",i(a))}else e+=a.textContent}))}(this.DOM.input),e}},Z.prototype.removeTag=Z.prototype.removeTags,Z})),function(e){e(["jquery"],(function(e){return function(){function t(t,i){return t||(t=s()),(l=e("#"+t.containerId)).length||i&&(l=function(t){return l=e("<div/>").attr("id",t.containerId).addClass(t.positionClass),l.appendTo(e(t.target)),l}(t)),l}function i(t){for(var i=l.children(),r=i.length-1;r>=0;r--)n(e(i[r]),t)}function n(t,i,n){var r=!(!n||!n.force)&&n.force;return!(!t||!r&&0!==e(":focus",t).length||(t[i.hideMethod]({duration:i.hideDuration,easing:i.hideEasing,complete:function(){o(t)}}),0))}function r(e){c&&c(e)}function a(i){function n(e){return null==e&&(e=""),e.replace(/&/g,"&amp;").replace(/"/g,"&quot;").replace(/'/g,"&#39;").replace(/</g,"&lt;").replace(/>/g,"&gt;")}function a(t){var i=t&&!1!==p.closeMethod?p.closeMethod:p.hideMethod,n=t&&!1!==p.closeDuration?p.closeDuration:p.hideDuration,a=t&&!1!==p.closeEasing?p.closeEasing:p.hideEasing;if(!e(":focus",v).length||t)return clearTimeout(w.intervalId),v[i]({duration:n,easing:a,complete:function(){o(v),clearTimeout(g),p.onHidden&&"hidden"!==k.state&&p.onHidden(),k.state="hidden",k.endTime=new Date,r(k)}})}function c(){(p.timeOut>0||p.extendedTimeOut>0)&&(g=setTimeout(a,p.extendedTimeOut),w.maxHideTime=parseFloat(p.extendedTimeOut),w.hideEta=(new Date).getTime()+w.maxHideTime)}function h(){clearTimeout(g),w.hideEta=0,v.stop(!0,!0)[p.showMethod]({duration:p.showDuration,easing:p.showEasing})}function f(){var e=(w.hideEta-(new Date).getTime())/w.maxHideTime*100;x.width(e+"%")}var p=s(),m=i.iconClass||p.iconClass;if(void 0!==i.optionsOverride&&(p=e.extend(p,i.optionsOverride),m=i.optionsOverride.iconClass||m),!function(e,t){if(e.preventDuplicates){if(t.message===u)return!0;u=t.message}return!1}(p,i)){d++,l=t(p,!0);var g=null,v=e("<div/>"),y=e("<div/>"),b=e("<div/>"),x=e("<div/>"),_=e(p.closeHtml),w={intervalId:null,hideEta:null,maxHideTime:null},k={toastId:d,state:"visible",startTime:new Date,options:p,map:i};return i.iconClass&&v.addClass(p.toastClass).addClass(m),function(){if(i.title){var e=i.title;p.escapeHtml&&(e=n(i.title)),y.append(e).addClass(p.titleClass),v.append(y)}}(),function(){if(i.message){var e=i.message;p.escapeHtml&&(e=n(i.message)),b.append(e).addClass(p.messageClass),v.append(b)}}(),p.closeButton&&(_.addClass(p.closeClass).attr("role","button"),v.prepend(_)),p.progressBar&&(x.addClass(p.progressClass),v.prepend(x)),p.rtl&&v.addClass("rtl"),p.newestOnTop?l.prepend(v):l.append(v),function(){var e="";switch(i.iconClass){case"toastr-success":case"toastr-info":e="polite";break;default:e="assertive"}v.attr("aria-live",e)}(),v.hide(),v[p.showMethod]({duration:p.showDuration,easing:p.showEasing,complete:p.onShown}),p.timeOut>0&&(g=setTimeout(a,p.timeOut),w.maxHideTime=parseFloat(p.timeOut),w.hideEta=(new Date).getTime()+w.maxHideTime,p.progressBar&&(w.intervalId=setInterval(f,10))),p.closeOnHover&&v.hover(h,c),!p.onclick&&p.tapToDismiss&&v.click(a),p.closeButton&&_&&_.click((function(e){e.stopPropagation?e.stopPropagation():void 0!==e.cancelBubble&&!0!==e.cancelBubble&&(e.cancelBubble=!0),p.onCloseClick&&p.onCloseClick(e),a(!0)})),p.onclick&&v.click((function(e){p.onclick(e),a()})),r(k),p.debug&&console&&console.log(k),v}}function s(){return e.extend({},{tapToDismiss:!0,toastClass:"toastr",containerId:"toastr-container",debug:!1,showMethod:"fadeIn",showDuration:300,showEasing:"swing",onShown:void 0,hideMethod:"fadeOut",hideDuration:1e3,hideEasing:"swing",onHidden:void 0,closeMethod:!1,closeDuration:!1,closeEasing:!1,closeOnHover:!0,extendedTimeOut:1e3,iconClasses:{error:"toastr-error",info:"toastr-info",success:"toastr-success",warning:"toastr-warning"},iconClass:"toastr-info",positionClass:"toastr-top-right",timeOut:5e3,titleClass:"toastr-title",messageClass:"toastr-message",escapeHtml:!1,target:"body",closeHtml:'<button type="button">&times;</button>',closeClass:"toastr-close-button",newestOnTop:!0,preventDuplicates:!1,progressBar:!1,progressClass:"toastr-progress",rtl:!1},f.options)}function o(e){l||(l=t()),e.is(":visible")||(e.remove(),e=null,0===l.children().length&&(l.remove(),u=void 0))}var l,c,u,d=0,h={error:"error",info:"info",success:"success",warning:"warning"},f={clear:function(e,r){var a=s();l||t(a),n(e,a,r)||i(a)},remove:function(i){var n=s();return l||t(n),i&&0===e(":focus",i).length?void o(i):void(l.children().length&&l.remove())},error:function(e,t,i){return a({type:h.error,iconClass:s().iconClasses.error,message:e,optionsOverride:i,title:t})},getContainer:t,info:function(e,t,i){return a({type:h.info,iconClass:s().iconClasses.info,message:e,optionsOverride:i,title:t})},options:{},subscribe:function(e){c=e},success:function(e,t,i){return a({type:h.success,iconClass:s().iconClasses.success,message:e,optionsOverride:i,title:t})},version:"2.1.4",warning:function(e,t,i){return a({type:h.warning,iconClass:s().iconClasses.warning,message:e,optionsOverride:i,title:t})}};return f}()}))}("function"==typeof define&&define.amd?define:function(e,t){"undefined"!=typeof module&&module.exports?module.exports=t(require("jquery")):window.toastr=t(window.jQuery)}),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(e="undefined"!=typeof globalThis?globalThis:e||self).ApexCharts=t()}(this,(function(){"use strict";function e(e,t){var i=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),i.push.apply(i,n)}return i}function t(t){for(var i=1;i<arguments.length;i++){var n=null!=arguments[i]?arguments[i]:{};i%2?e(Object(n),!0).forEach((function(e){s(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):e(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function i(e){return i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},i(e)}function n(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function r(e,t){for(var i=0;i<t.length;i++){var n=t[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}function a(e,t,i){return t&&r(e.prototype,t),i&&r(e,i),e}function s(e,t,i){return t in e?Object.defineProperty(e,t,{value:i,enumerable:!0,configurable:!0,writable:!0}):e[t]=i,e}function o(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&c(e,t)}function l(e){return l=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)},l(e)}function c(e,t){return c=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e},c(e,t)}function u(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function d(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var i,n=l(e);if(t){var r=l(this).constructor;i=Reflect.construct(n,arguments,r)}else i=n.apply(this,arguments);return function(e,t){if(t&&("object"==typeof t||"function"==typeof t))return t;if(void 0!==t)throw new TypeError("Derived constructors may only return object or undefined");return u(e)}(this,i)}}function h(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var i=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=i){var n,r,a=[],s=!0,o=!1;try{for(i=i.call(e);!(s=(n=i.next()).done)&&(a.push(n.value),!t||a.length!==t);s=!0);}catch(e){o=!0,r=e}finally{try{s||null==i.return||i.return()}finally{if(o)throw r}}return a}}(e,t)||p(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function f(e){return function(e){if(Array.isArray(e))return m(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||p(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function p(e,t){if(e){if("string"==typeof e)return m(e,t);var i=Object.prototype.toString.call(e).slice(8,-1);return"Object"===i&&e.constructor&&(i=e.constructor.name),"Map"===i||"Set"===i?Array.from(e):"Arguments"===i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(i)?m(e,t):void 0}}function m(e,t){(null==t||t>e.length)&&(t=e.length);for(var i=0,n=new Array(t);i<t;i++)n[i]=e[i];return n}var g=function(){function e(){n(this,e)}return a(e,[{key:"shadeRGBColor",value:function(e,t){var i=t.split(","),n=e<0?0:255,r=e<0?-1*e:e,a=parseInt(i[0].slice(4),10),s=parseInt(i[1],10),o=parseInt(i[2],10);return"rgb("+(Math.round((n-a)*r)+a)+","+(Math.round((n-s)*r)+s)+","+(Math.round((n-o)*r)+o)+")"}},{key:"shadeHexColor",value:function(e,t){var i=parseInt(t.slice(1),16),n=e<0?0:255,r=e<0?-1*e:e,a=i>>16,s=i>>8&255,o=255&i;return"#"+(16777216+65536*(Math.round((n-a)*r)+a)+256*(Math.round((n-s)*r)+s)+(Math.round((n-o)*r)+o)).toString(16).slice(1)}},{key:"shadeColor",value:function(t,i){return e.isColorHex(i)?this.shadeHexColor(t,i):this.shadeRGBColor(t,i)}}],[{key:"bind",value:function(e,t){return function(){return e.apply(t,arguments)}}},{key:"isObject",value:function(e){return e&&"object"===i(e)&&!Array.isArray(e)&&null!=e}},{key:"is",value:function(e,t){return Object.prototype.toString.call(t)==="[object "+e+"]"}},{key:"listToArray",value:function(e){var t,i=[];for(t=0;t<e.length;t++)i[t]=e[t];return i}},{key:"extend",value:function(e,t){var i=this;"function"!=typeof Object.assign&&(Object.assign=function(e){if(null==e)throw new TypeError("Cannot convert undefined or null to object");for(var t=Object(e),i=1;i<arguments.length;i++){var n=arguments[i];if(null!=n)for(var r in n)n.hasOwnProperty(r)&&(t[r]=n[r])}return t});var n=Object.assign({},e);return this.isObject(e)&&this.isObject(t)&&Object.keys(t).forEach((function(r){i.isObject(t[r])&&r in e?n[r]=i.extend(e[r],t[r]):Object.assign(n,s({},r,t[r]))})),n}},{key:"extendArray",value:function(t,i){var n=[];return t.map((function(t){n.push(e.extend(i,t))})),n}},{key:"monthMod",value:function(e){return e%12}},{key:"clone",value:function(t){if(e.is("Array",t)){for(var n=[],r=0;r<t.length;r++)n[r]=this.clone(t[r]);return n}if(e.is("Null",t))return null;if(e.is("Date",t))return t;if("object"===i(t)){var a={};for(var s in t)t.hasOwnProperty(s)&&(a[s]=this.clone(t[s]));return a}return t}},{key:"log10",value:function(e){return Math.log(e)/Math.LN10}},{key:"roundToBase10",value:function(e){return Math.pow(10,Math.floor(Math.log10(e)))}},{key:"roundToBase",value:function(e,t){return Math.pow(t,Math.floor(Math.log(e)/Math.log(t)))}},{key:"parseNumber",value:function(e){return null===e?e:parseFloat(e)}},{key:"stripNumber",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:2;return Number.isInteger(e)?e:parseFloat(e.toPrecision(t))}},{key:"randomId",value:function(){return(Math.random()+1).toString(36).substring(4)}},{key:"noExponents",value:function(e){var t=String(e).split(/[eE]/);if(1===t.length)return t[0];var i="",n=e<0?"-":"",r=t[0].replace(".",""),a=Number(t[1])+1;if(a<0){for(i=n+"0.";a++;)i+="0";return i+r.replace(/^-/,"")}for(a-=r.length;a--;)i+="0";return r+i}},{key:"getDimensions",value:function(e){var t=getComputedStyle(e,null),i=e.clientHeight,n=e.clientWidth;return i-=parseFloat(t.paddingTop)+parseFloat(t.paddingBottom),[n-=parseFloat(t.paddingLeft)+parseFloat(t.paddingRight),i]}},{key:"getBoundingClientRect",value:function(e){var t=e.getBoundingClientRect();return{top:t.top,right:t.right,bottom:t.bottom,left:t.left,width:e.clientWidth,height:e.clientHeight,x:t.left,y:t.top}}},{key:"getLargestStringFromArr",value:function(e){return e.reduce((function(e,t){return Array.isArray(t)&&(t=t.reduce((function(e,t){return e.length>t.length?e:t}))),e.length>t.length?e:t}),0)}},{key:"hexToRgba",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"#999999",t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:.6;"#"!==e.substring(0,1)&&(e="#999999");var i=e.replace("#","");i=i.match(new RegExp("(.{"+i.length/3+"})","g"));for(var n=0;n<i.length;n++)i[n]=parseInt(1===i[n].length?i[n]+i[n]:i[n],16);return void 0!==t&&i.push(t),"rgba("+i.join(",")+")"}},{key:"getOpacityFromRGBA",value:function(e){return parseFloat(e.replace(/^.*,(.+)\)/,"$1"))}},{key:"rgb2hex",value:function(e){return(e=e.match(/^rgba?[\s+]?\([\s+]?(\d+)[\s+]?,[\s+]?(\d+)[\s+]?,[\s+]?(\d+)[\s+]?/i))&&4===e.length?"#"+("0"+parseInt(e[1],10).toString(16)).slice(-2)+("0"+parseInt(e[2],10).toString(16)).slice(-2)+("0"+parseInt(e[3],10).toString(16)).slice(-2):""}},{key:"isColorHex",value:function(e){return/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)|(^#[0-9A-F]{8}$)/i.test(e)}},{key:"getPolygonPos",value:function(e,t){for(var i=[],n=2*Math.PI/t,r=0;r<t;r++){var a={};a.x=e*Math.sin(r*n),a.y=-e*Math.cos(r*n),i.push(a)}return i}},{key:"polarToCartesian",value:function(e,t,i,n){var r=(n-90)*Math.PI/180;return{x:e+i*Math.cos(r),y:t+i*Math.sin(r)}}},{key:"escapeString",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"x",i=e.toString().slice();return i.replace(/[` ~!@#$%^&*()|+\=?;:'",.<>{}[\]\\/]/gi,t)}},{key:"negToZero",value:function(e){return e<0?0:e}},{key:"moveIndexInArray",value:function(e,t,i){if(i>=e.length)for(var n=i-e.length+1;n--;)e.push(void 0);return e.splice(i,0,e.splice(t,1)[0]),e}},{key:"extractNumber",value:function(e){return parseFloat(e.replace(/[^\d.]*/g,""))}},{key:"findAncestor",value:function(e,t){for(;(e=e.parentElement)&&!e.classList.contains(t););return e}},{key:"setELstyles",value:function(e,t){for(var i in t)t.hasOwnProperty(i)&&(e.style.key=t[i])}},{key:"isNumber",value:function(e){return!isNaN(e)&&parseFloat(Number(e))===e&&!isNaN(parseInt(e,10))}},{key:"isFloat",value:function(e){return Number(e)===e&&e%1!=0}},{key:"isSafari",value:function(){return/^((?!chrome|android).)*safari/i.test(navigator.userAgent)}},{key:"isFirefox",value:function(){return navigator.userAgent.toLowerCase().indexOf("firefox")>-1}},{key:"isIE11",value:function(){if(-1!==window.navigator.userAgent.indexOf("MSIE")||window.navigator.appVersion.indexOf("Trident/")>-1)return!0}},{key:"isIE",value:function(){var e=window.navigator.userAgent,t=e.indexOf("MSIE ");if(t>0)return parseInt(e.substring(t+5,e.indexOf(".",t)),10);if(e.indexOf("Trident/")>0){var i=e.indexOf("rv:");return parseInt(e.substring(i+3,e.indexOf(".",i)),10)}var n=e.indexOf("Edge/");return n>0&&parseInt(e.substring(n+5,e.indexOf(".",n)),10)}},{key:"getGCD",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:7,n=Math.pow(10,i-Math.floor(Math.log10(Math.max(e,t))));for(e=Math.round(Math.abs(e)*n),t=Math.round(Math.abs(t)*n);t;){var r=t;t=e%t,e=r}return e/n}},{key:"getPrimeFactors",value:function(e){for(var t=[],i=2;e>=2;)e%i==0?(t.push(i),e/=i):i++;return t}},{key:"mod",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:7,n=Math.pow(10,i-Math.floor(Math.log10(Math.max(e,t))));return(e=Math.round(Math.abs(e)*n))%(t=Math.round(Math.abs(t)*n))/n}}]),e}(),v=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.setEasingFunctions()}return a(e,[{key:"setEasingFunctions",value:function(){var e;if(!this.w.globals.easing){switch(this.w.config.chart.animations.easing){case"linear":e="-";break;case"easein":e="<";break;case"easeout":e=">";break;case"easeinout":default:e="<>";break;case"swing":e=function(e){var t=1.70158;return(e-=1)*e*((t+1)*e+t)+1};break;case"bounce":e=function(e){return e<1/2.75?7.5625*e*e:e<2/2.75?7.5625*(e-=1.5/2.75)*e+.75:e<2.5/2.75?7.5625*(e-=2.25/2.75)*e+.9375:7.5625*(e-=2.625/2.75)*e+.984375};break;case"elastic":e=function(e){return e===!!e?e:Math.pow(2,-10*e)*Math.sin((e-.075)*(2*Math.PI)/.3)+1}}this.w.globals.easing=e}}},{key:"animateLine",value:function(e,t,i,n){e.attr(t).animate(n).attr(i)}},{key:"animateMarker",value:function(e,t,i,n,r,a){t||(t=0),e.attr({r:t,width:t,height:t}).animate(n,r).attr({r:i,width:i.width,height:i.height}).afterAll((function(){a()}))}},{key:"animateCircle",value:function(e,t,i,n,r){e.attr({r:t.r,cx:t.cx,cy:t.cy}).animate(n,r).attr({r:i.r,cx:i.cx,cy:i.cy})}},{key:"animateRect",value:function(e,t,i,n,r){e.attr(t).animate(n).attr(i).afterAll((function(){return r()}))}},{key:"animatePathsGradually",value:function(e){var t=e.el,i=e.realIndex,n=e.j,r=e.fill,a=e.pathFrom,s=e.pathTo,o=e.speed,l=e.delay,c=this.w,u=0;c.config.chart.animations.animateGradually.enabled&&(u=c.config.chart.animations.animateGradually.delay),c.config.chart.animations.dynamicAnimation.enabled&&c.globals.dataChanged&&"bar"!==c.config.chart.type&&(u=0),this.morphSVG(t,i,n,"line"!==c.config.chart.type||c.globals.comboCharts?r:"stroke",a,s,o,l*u)}},{key:"showDelayedElements",value:function(){this.w.globals.delayedElements.forEach((function(e){var t=e.el;t.classList.remove("apexcharts-element-hidden"),t.classList.add("apexcharts-hidden-element-shown")}))}},{key:"animationCompleted",value:function(e){var t=this.w;t.globals.animationEnded||(t.globals.animationEnded=!0,this.showDelayedElements(),"function"==typeof t.config.chart.events.animationEnd&&t.config.chart.events.animationEnd(this.ctx,{el:e,w:t}))}},{key:"morphSVG",value:function(e,t,i,n,r,a,s,o){var l=this,c=this.w;r||(r=e.attr("pathFrom")),a||(a=e.attr("pathTo"));var u=function(e){return"radar"===c.config.chart.type&&(s=1),"M 0 ".concat(c.globals.gridHeight)};(!r||r.indexOf("undefined")>-1||r.indexOf("NaN")>-1)&&(r=u()),(!a||a.indexOf("undefined")>-1||a.indexOf("NaN")>-1)&&(a=u()),c.globals.shouldAnimate||(s=1),e.plot(r).animate(1,c.globals.easing,o).plot(r).animate(s,c.globals.easing,o).plot(a).afterAll((function(){g.isNumber(i)?i===c.globals.series[c.globals.maxValsInArrayIndex].length-2&&c.globals.shouldAnimate&&l.animationCompleted(e):"none"!==n&&c.globals.shouldAnimate&&(!c.globals.comboCharts&&t===c.globals.series.length-1||c.globals.comboCharts)&&l.animationCompleted(e),l.showDelayedElements()}))}}]),e}(),y=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"getDefaultFilter",value:function(e,t){var i=this.w;e.unfilter(!0),(new window.SVG.Filter).size("120%","180%","-5%","-40%"),"none"!==i.config.states.normal.filter?this.applyFilter(e,t,i.config.states.normal.filter.type,i.config.states.normal.filter.value):i.config.chart.dropShadow.enabled&&this.dropShadow(e,i.config.chart.dropShadow,t)}},{key:"addNormalFilter",value:function(e,t){var i=this.w;i.config.chart.dropShadow.enabled&&!e.node.classList.contains("apexcharts-marker")&&this.dropShadow(e,i.config.chart.dropShadow,t)}},{key:"addLightenFilter",value:function(e,t,i){var n=this,r=this.w,a=i.intensity;e.unfilter(!0),new window.SVG.Filter,e.filter((function(e){var i=r.config.chart.dropShadow;(i.enabled?n.addShadow(e,t,i):e).componentTransfer({rgb:{type:"linear",slope:1.5,intercept:a}})})),e.filterer.node.setAttribute("filterUnits","userSpaceOnUse"),this._scaleFilterSize(e.filterer.node)}},{key:"addDarkenFilter",value:function(e,t,i){var n=this,r=this.w,a=i.intensity;e.unfilter(!0),new window.SVG.Filter,e.filter((function(e){var i=r.config.chart.dropShadow;(i.enabled?n.addShadow(e,t,i):e).componentTransfer({rgb:{type:"linear",slope:a}})})),e.filterer.node.setAttribute("filterUnits","userSpaceOnUse"),this._scaleFilterSize(e.filterer.node)}},{key:"applyFilter",value:function(e,t,i){var n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:.5;switch(i){case"none":this.addNormalFilter(e,t);break;case"lighten":this.addLightenFilter(e,t,{intensity:n});break;case"darken":this.addDarkenFilter(e,t,{intensity:n})}}},{key:"addShadow",value:function(e,t,i){var n,r=this.w,a=i.blur,s=i.top,o=i.left,l=i.color,c=i.opacity;if((null===(n=r.config.chart.dropShadow.enabledOnSeries)||void 0===n?void 0:n.length)>0&&-1===r.config.chart.dropShadow.enabledOnSeries.indexOf(t))return e;var u=e.flood(Array.isArray(l)?l[t]:l,c).composite(e.sourceAlpha,"in").offset(o,s).gaussianBlur(a).merge(e.source);return e.blend(e.source,u)}},{key:"dropShadow",value:function(e,t){var i,n,r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:0,a=t.top,s=t.left,o=t.blur,l=t.color,c=t.opacity,u=t.noUserSpaceOnUse,d=this.w;return e.unfilter(!0),g.isIE()&&"radialBar"===d.config.chart.type||(null===(i=d.config.chart.dropShadow.enabledOnSeries)||void 0===i?void 0:i.length)>0&&-1===(null===(n=d.config.chart.dropShadow.enabledOnSeries)||void 0===n?void 0:n.indexOf(r))||(l=Array.isArray(l)?l[r]:l,e.filter((function(e){var t;t=g.isSafari()||g.isFirefox()||g.isIE()?e.flood(l,c).composite(e.sourceAlpha,"in").offset(s,a).gaussianBlur(o):e.flood(l,c).composite(e.sourceAlpha,"in").offset(s,a).gaussianBlur(o).merge(e.source),e.blend(e.source,t)})),u||e.filterer.node.setAttribute("filterUnits","userSpaceOnUse"),this._scaleFilterSize(e.filterer.node)),e}},{key:"setSelectionFilter",value:function(e,t,i){var n=this.w;if(void 0!==n.globals.selectedDataPoints[t]&&n.globals.selectedDataPoints[t].indexOf(i)>-1){e.node.setAttribute("selected",!0);var r=n.config.states.active.filter;"none"!==r&&this.applyFilter(e,t,r.type,r.value)}}},{key:"_scaleFilterSize",value:function(e){!function(t){for(var i in t)t.hasOwnProperty(i)&&e.setAttribute(i,t[i])}({width:"200%",height:"200%",x:"-50%",y:"-50%"})}}]),e}(),b=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"roundPathCorners",value:function(e,t){function i(e,t,i){var r=t.x-e.x,a=t.y-e.y,s=Math.sqrt(r*r+a*a);return n(e,t,Math.min(1,i/s))}function n(e,t,i){return{x:e.x+(t.x-e.x)*i,y:e.y+(t.y-e.y)*i}}function r(e,t){e.length>2&&(e[e.length-2]=t.x,e[e.length-1]=t.y)}function a(e){return{x:parseFloat(e[e.length-2]),y:parseFloat(e[e.length-1])}}e.indexOf("NaN")>-1&&(e="");var s=e.split(/[,\s]/).reduce((function(e,t){var i=t.match("([a-zA-Z])(.+)");return i?(e.push(i[1]),e.push(i[2])):e.push(t),e}),[]).reduce((function(e,t){return parseFloat(t)==t&&e.length?e[e.length-1].push(t):e.push([t]),e}),[]),o=[];if(s.length>1){var l=a(s[0]),c=null;"Z"==s[s.length-1][0]&&s[0].length>2&&(c=["L",l.x,l.y],s[s.length-1]=c),o.push(s[0]);for(var u=1;u<s.length;u++){var d=o[o.length-1],h=s[u],f=h==c?s[1]:s[u+1];if(f&&d&&d.length>2&&"L"==h[0]&&f.length>2&&"L"==f[0]){var p,m,g=a(d),v=a(h),y=a(f);p=i(v,g,t),m=i(v,y,t),r(h,p),h.origPoint=v,o.push(h);var b=n(p,v,.5),x=n(v,m,.5),_=["C",b.x,b.y,x.x,x.y,m.x,m.y];_.origPoint=v,o.push(_)}else o.push(h)}if(c){var w=a(o[o.length-1]);o.push(["Z"]),r(o[0],w)}}else o=s;return o.reduce((function(e,t){return e+t.join(" ")+" "}),"")}},{key:"drawLine",value:function(e,t,i,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:"#a8a8a8",a=arguments.length>5&&void 0!==arguments[5]?arguments[5]:0,s=arguments.length>6&&void 0!==arguments[6]?arguments[6]:null,o=arguments.length>7&&void 0!==arguments[7]?arguments[7]:"butt";return this.w.globals.dom.Paper.line().attr({x1:e,y1:t,x2:i,y2:n,stroke:r,"stroke-dasharray":a,"stroke-width":s,"stroke-linecap":o})}},{key:"drawRect",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0,t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:0,n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:0,r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:0,a=arguments.length>5&&void 0!==arguments[5]?arguments[5]:"#fefefe",s=arguments.length>6&&void 0!==arguments[6]?arguments[6]:1,o=arguments.length>7&&void 0!==arguments[7]?arguments[7]:null,l=arguments.length>8&&void 0!==arguments[8]?arguments[8]:null,c=arguments.length>9&&void 0!==arguments[9]?arguments[9]:0,u=this.w.globals.dom.Paper.rect();return u.attr({x:e,y:t,width:i>0?i:0,height:n>0?n:0,rx:r,ry:r,opacity:s,"stroke-width":null!==o?o:0,stroke:null!==l?l:"none","stroke-dasharray":c}),u.node.setAttribute("fill",a),u}},{key:"drawPolygon",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"#e1e1e1",i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:1,n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:"none";return this.w.globals.dom.Paper.polygon(e).attr({fill:n,stroke:t,"stroke-width":i})}},{key:"drawCircle",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;e<0&&(e=0);var i=this.w.globals.dom.Paper.circle(2*e);return null!==t&&i.attr(t),i}},{key:"drawPath",value:function(e){var t=e.d,i=void 0===t?"":t,n=e.stroke,r=void 0===n?"#a8a8a8":n,a=e.strokeWidth,s=void 0===a?1:a,o=e.fill,l=e.fillOpacity,c=void 0===l?1:l,u=e.strokeOpacity,d=void 0===u?1:u,h=e.classes,f=e.strokeLinecap,p=void 0===f?null:f,m=e.strokeDashArray,g=void 0===m?0:m,v=this.w;return null===p&&(p=v.config.stroke.lineCap),(i.indexOf("undefined")>-1||i.indexOf("NaN")>-1)&&(i="M 0 ".concat(v.globals.gridHeight)),v.globals.dom.Paper.path(i).attr({fill:o,"fill-opacity":c,stroke:r,"stroke-opacity":d,"stroke-linecap":p,"stroke-width":s,"stroke-dasharray":g,class:h})}},{key:"group",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null,t=this.w.globals.dom.Paper.group();return null!==e&&t.attr(e),t}},{key:"move",value:function(e,t){return["M",e,t].join(" ")}},{key:"line",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null,n=null;return null===i?n=[" L",e,t].join(" "):"H"===i?n=[" H",e].join(" "):"V"===i&&(n=[" V",t].join(" ")),n}},{key:"curve",value:function(e,t,i,n,r,a){return["C",e,t,i,n,r,a].join(" ")}},{key:"quadraticCurve",value:function(e,t,i,n){return["Q",e,t,i,n].join(" ")}},{key:"arc",value:function(e,t,i,n,r,a,s){var o="A";return arguments.length>7&&void 0!==arguments[7]&&arguments[7]&&(o="a"),[o,e,t,i,n,r,a,s].join(" ")}},{key:"renderPaths",value:function(e){var i,n=e.j,r=e.realIndex,a=e.pathFrom,s=e.pathTo,o=e.stroke,l=e.strokeWidth,c=e.strokeLinecap,u=e.fill,d=e.animationDelay,h=e.initialSpeed,f=e.dataChangeSpeed,p=e.className,m=e.shouldClipToGrid,g=void 0===m||m,b=e.bindEventsOnPaths,x=void 0===b||b,_=e.drawShadow,w=void 0===_||_,k=this.w,M=new y(this.ctx),S=new v(this.ctx),A=this.w.config.chart.animations.enabled,L=A&&this.w.config.chart.animations.dynamicAnimation.enabled,T=!!(A&&!k.globals.resized||L&&k.globals.dataChanged&&k.globals.shouldAnimate);T?i=a:(i=s,k.globals.animationEnded=!0);var C,D=k.config.stroke.dashArray;C=Array.isArray(D)?D[r]:k.config.stroke.dashArray;var E=this.drawPath({d:i,stroke:o,strokeWidth:l,fill:u,fillOpacity:1,classes:p,strokeLinecap:c,strokeDashArray:C});if(E.attr("index",r),g&&E.attr({"clip-path":"url(#gridRectMask".concat(k.globals.cuid,")")}),"none"!==k.config.states.normal.filter.type)M.getDefaultFilter(E,r);else if(k.config.chart.dropShadow.enabled&&w){var O=k.config.chart.dropShadow;M.dropShadow(E,O,r)}x&&(E.node.addEventListener("mouseenter",this.pathMouseEnter.bind(this,E)),E.node.addEventListener("mouseleave",this.pathMouseLeave.bind(this,E)),E.node.addEventListener("mousedown",this.pathMouseDown.bind(this,E))),E.attr({pathTo:s,pathFrom:a});var P={el:E,j:n,realIndex:r,pathFrom:a,pathTo:s,fill:u,strokeWidth:l,delay:d};return!A||k.globals.resized||k.globals.dataChanged?!k.globals.resized&&k.globals.dataChanged||S.showDelayedElements():S.animatePathsGradually(t(t({},P),{},{speed:h})),k.globals.dataChanged&&L&&T&&S.animatePathsGradually(t(t({},P),{},{speed:f})),E}},{key:"drawPattern",value:function(e,t,i){var n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:"#a8a8a8",r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:0;return this.w.globals.dom.Paper.pattern(t,i,(function(a){"horizontalLines"===e?a.line(0,0,i,0).stroke({color:n,width:r+1}):"verticalLines"===e?a.line(0,0,0,t).stroke({color:n,width:r+1}):"slantedLines"===e?a.line(0,0,t,i).stroke({color:n,width:r}):"squares"===e?a.rect(t,i).fill("none").stroke({color:n,width:r}):"circles"===e&&a.circle(t).fill("none").stroke({color:n,width:r})}))}},{key:"drawGradient",value:function(e,t,i,n,r){var a,s=arguments.length>5&&void 0!==arguments[5]?arguments[5]:null,o=arguments.length>6&&void 0!==arguments[6]?arguments[6]:null,l=arguments.length>7&&void 0!==arguments[7]?arguments[7]:null,c=arguments.length>8&&void 0!==arguments[8]?arguments[8]:0,u=this.w;t.length<9&&0===t.indexOf("#")&&(t=g.hexToRgba(t,n)),i.length<9&&0===i.indexOf("#")&&(i=g.hexToRgba(i,r));var d=0,h=1,f=1,p=null;null!==o&&(d=void 0!==o[0]?o[0]/100:0,h=void 0!==o[1]?o[1]/100:1,f=void 0!==o[2]?o[2]/100:1,p=void 0!==o[3]?o[3]/100:null);var m=!("donut"!==u.config.chart.type&&"pie"!==u.config.chart.type&&"polarArea"!==u.config.chart.type&&"bubble"!==u.config.chart.type);if(a=null===l||0===l.length?u.globals.dom.Paper.gradient(m?"radial":"linear",(function(e){e.at(d,t,n),e.at(h,i,r),e.at(f,i,r),null!==p&&e.at(p,t,n)})):u.globals.dom.Paper.gradient(m?"radial":"linear",(function(e){(Array.isArray(l[c])?l[c]:l).forEach((function(t){e.at(t.offset/100,t.color,t.opacity)}))})),m){var v=u.globals.gridWidth/2,y=u.globals.gridHeight/2;"bubble"!==u.config.chart.type?a.attr({gradientUnits:"userSpaceOnUse",cx:v,cy:y,r:s}):a.attr({cx:.5,cy:.5,r:.8,fx:.2,fy:.2})}else"vertical"===e?a.from(0,0).to(0,1):"diagonal"===e?a.from(0,0).to(1,1):"horizontal"===e?a.from(0,1).to(1,1):"diagonal2"===e&&a.from(1,0).to(0,1);return a}},{key:"getTextBasedOnMaxWidth",value:function(e){var t=e.text,i=e.maxWidth,n=e.fontSize,r=e.fontFamily,a=this.getTextRects(t,n,r),s=a.width/t.length,o=Math.floor(i/s);return i<a.width?t.slice(0,o-3)+"...":t}},{key:"drawText",value:function(e){var i=this,n=e.x,r=e.y,a=e.text,s=e.textAnchor,o=e.fontSize,l=e.fontFamily,c=e.fontWeight,u=e.foreColor,d=e.opacity,h=e.maxWidth,f=e.cssClass,p=void 0===f?"":f,m=e.isPlainText,g=void 0===m||m,v=e.dominantBaseline,y=void 0===v?"auto":v,b=this.w;void 0===a&&(a="");var x=a;s||(s="start"),u&&u.length||(u=b.config.chart.foreColor),l=l||b.config.chart.fontFamily,c=c||"regular";var _,w={maxWidth:h,fontSize:o=o||"11px",fontFamily:l};return Array.isArray(a)?_=b.globals.dom.Paper.text((function(e){for(var n=0;n<a.length;n++)x=a[n],h&&(x=i.getTextBasedOnMaxWidth(t({text:a[n]},w))),0===n?e.tspan(x):e.tspan(x).newLine()})):(h&&(x=this.getTextBasedOnMaxWidth(t({text:a},w))),_=g?b.globals.dom.Paper.plain(a):b.globals.dom.Paper.text((function(e){return e.tspan(x)}))),_.attr({x:n,y:r,"text-anchor":s,"dominant-baseline":y,"font-size":o,"font-family":l,"font-weight":c,fill:u,class:"apexcharts-text "+p}),_.node.style.fontFamily=l,_.node.style.opacity=d,_}},{key:"createGroupWithAttributes",value:function(e,t,i,n){var r=this.group();return i.forEach((function(e){return r.add(e)})),r.attr({class:n.class?n.class:"",cy:t,cx:e}),r}},{key:"drawPlus",value:function(e,t,i,n){var r=i/2,a=this.drawLine(e,t-r,e,t+r,n.pointStrokeColor,n.pointStrokeDashArray,n.pointStrokeWidth,n.pointStrokeLineCap),s=this.drawLine(e-r,t,e+r,t,n.pointStrokeColor,n.pointStrokeDashArray,n.pointStrokeWidth,n.pointStrokeLineCap);return this.createGroupWithAttributes(e,t,[a,s],n)}},{key:"drawX",value:function(e,t,i,n){var r=i/2,a=this.drawLine(e-r,t-r,e+r,t+r,n.pointStrokeColor,n.pointStrokeDashArray,n.pointStrokeWidth,n.pointStrokeLineCap),s=this.drawLine(e-r,t+r,e+r,t-r,n.pointStrokeColor,n.pointStrokeDashArray,n.pointStrokeWidth,n.pointStrokeLineCap);return this.createGroupWithAttributes(e,t,[a,s],n)}},{key:"drawMarker",value:function(e,t,i){e=e||0;var n=i.pSize||0,r=null;if("X"===(null==i?void 0:i.shape)||"x"===(null==i?void 0:i.shape))r=this.drawX(e,t,n,i);else if("plus"===(null==i?void 0:i.shape)||"+"===(null==i?void 0:i.shape))r=this.drawPlus(e,t,n,i);else if("square"===i.shape||"rect"===i.shape){var a=void 0===i.pRadius?n/2:i.pRadius;null!==t&&n||(n=0,a=0);var s=1.2*n+a,o=this.drawRect(s,s,s,s,a);o.attr({x:e-s/2,y:t-s/2,cx:e,cy:t,class:i.class?i.class:"",fill:i.pointFillColor,"fill-opacity":i.pointFillOpacity?i.pointFillOpacity:1,stroke:i.pointStrokeColor,"stroke-width":i.pointStrokeWidth?i.pointStrokeWidth:0,"stroke-opacity":i.pointStrokeOpacity?i.pointStrokeOpacity:1}),r=o}else"circle"!==i.shape&&i.shape||(g.isNumber(t)||(n=0,t=0),r=this.drawCircle(n,{cx:e,cy:t,class:i.class?i.class:"",stroke:i.pointStrokeColor,fill:i.pointFillColor,"fill-opacity":i.pointFillOpacity?i.pointFillOpacity:1,"stroke-width":i.pointStrokeWidth?i.pointStrokeWidth:0,"stroke-opacity":i.pointStrokeOpacity?i.pointStrokeOpacity:1}));return r}},{key:"pathMouseEnter",value:function(e,t){var i=this.w,n=new y(this.ctx),r=parseInt(e.node.getAttribute("index"),10),a=parseInt(e.node.getAttribute("j"),10);if("function"==typeof i.config.chart.events.dataPointMouseEnter&&i.config.chart.events.dataPointMouseEnter(t,this.ctx,{seriesIndex:r,dataPointIndex:a,w:i}),this.ctx.events.fireEvent("dataPointMouseEnter",[t,this.ctx,{seriesIndex:r,dataPointIndex:a,w:i}]),("none"===i.config.states.active.filter.type||"true"!==e.node.getAttribute("selected"))&&"none"!==i.config.states.hover.filter.type&&!i.globals.isTouchDevice){var s=i.config.states.hover.filter;n.applyFilter(e,r,s.type,s.value)}}},{key:"pathMouseLeave",value:function(e,t){var i=this.w,n=new y(this.ctx),r=parseInt(e.node.getAttribute("index"),10),a=parseInt(e.node.getAttribute("j"),10);"function"==typeof i.config.chart.events.dataPointMouseLeave&&i.config.chart.events.dataPointMouseLeave(t,this.ctx,{seriesIndex:r,dataPointIndex:a,w:i}),this.ctx.events.fireEvent("dataPointMouseLeave",[t,this.ctx,{seriesIndex:r,dataPointIndex:a,w:i}]),"none"!==i.config.states.active.filter.type&&"true"===e.node.getAttribute("selected")||"none"!==i.config.states.hover.filter.type&&n.getDefaultFilter(e,r)}},{key:"pathMouseDown",value:function(e,t){var i=this.w,n=new y(this.ctx),r=parseInt(e.node.getAttribute("index"),10),a=parseInt(e.node.getAttribute("j"),10),s="false";if("true"===e.node.getAttribute("selected")){if(e.node.setAttribute("selected","false"),i.globals.selectedDataPoints[r].indexOf(a)>-1){var o=i.globals.selectedDataPoints[r].indexOf(a);i.globals.selectedDataPoints[r].splice(o,1)}}else{if(!i.config.states.active.allowMultipleDataPointsSelection&&i.globals.selectedDataPoints.length>0){i.globals.selectedDataPoints=[];var l=i.globals.dom.Paper.select(".apexcharts-series path").members,c=i.globals.dom.Paper.select(".apexcharts-series circle, .apexcharts-series rect").members,u=function(e){Array.prototype.forEach.call(e,(function(e){e.node.setAttribute("selected","false"),n.getDefaultFilter(e,r)}))};u(l),u(c)}e.node.setAttribute("selected","true"),s="true",void 0===i.globals.selectedDataPoints[r]&&(i.globals.selectedDataPoints[r]=[]),i.globals.selectedDataPoints[r].push(a)}if("true"===s){var d=i.config.states.active.filter;if("none"!==d)n.applyFilter(e,r,d.type,d.value);else if("none"!==i.config.states.hover.filter&&!i.globals.isTouchDevice){var h=i.config.states.hover.filter;n.applyFilter(e,r,h.type,h.value)}}else"none"!==i.config.states.active.filter.type&&("none"===i.config.states.hover.filter.type||i.globals.isTouchDevice?n.getDefaultFilter(e,r):(h=i.config.states.hover.filter,n.applyFilter(e,r,h.type,h.value)));"function"==typeof i.config.chart.events.dataPointSelection&&i.config.chart.events.dataPointSelection(t,this.ctx,{selectedDataPoints:i.globals.selectedDataPoints,seriesIndex:r,dataPointIndex:a,w:i}),t&&this.ctx.events.fireEvent("dataPointSelection",[t,this.ctx,{selectedDataPoints:i.globals.selectedDataPoints,seriesIndex:r,dataPointIndex:a,w:i}])}},{key:"rotateAroundCenter",value:function(e){var t={};return e&&"function"==typeof e.getBBox&&(t=e.getBBox()),{x:t.x+t.width/2,y:t.y+t.height/2}}},{key:"getTextRects",value:function(e,t,i,n){var r=!(arguments.length>4&&void 0!==arguments[4])||arguments[4],a=this.w,s=this.drawText({x:-200,y:-200,text:e,textAnchor:"start",fontSize:t,fontFamily:i,foreColor:"#fff",opacity:0});n&&s.attr("transform",n),a.globals.dom.Paper.add(s);var o=s.bbox();return r||(o=s.node.getBoundingClientRect()),s.remove(),{width:o.width,height:o.height}}},{key:"placeTextWithEllipsis",value:function(e,t,i){if("function"==typeof e.getComputedTextLength&&(e.textContent=t,t.length>0&&e.getComputedTextLength()>=i/1.1)){for(var n=t.length-3;n>0;n-=3)if(e.getSubStringLength(0,n)<=i/1.1)return void(e.textContent=t.substring(0,n)+"...");e.textContent="."}}}],[{key:"setAttrs",value:function(e,t){for(var i in t)t.hasOwnProperty(i)&&e.setAttribute(i,t[i])}}]),e}(),x=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"getStackedSeriesTotals",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=this.w,i=[];if(0===t.globals.series.length)return i;for(var n=0;n<t.globals.series[t.globals.maxValsInArrayIndex].length;n++){for(var r=0,a=0;a<t.globals.series.length;a++)void 0!==t.globals.series[a][n]&&-1===e.indexOf(a)&&(r+=t.globals.series[a][n]);i.push(r)}return i}},{key:"getSeriesTotalByIndex",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null;return null===e?this.w.config.series.reduce((function(e,t){return e+t}),0):this.w.globals.series[e].reduce((function(e,t){return e+t}),0)}},{key:"getStackedSeriesTotalsByGroups",value:function(){var e=this,t=this.w,i=[];return t.globals.seriesGroups.forEach((function(n){var r=[];t.config.series.forEach((function(e,i){n.indexOf(t.globals.seriesNames[i])>-1&&r.push(i)}));var a=t.globals.series.map((function(e,t){return-1===r.indexOf(t)?t:-1})).filter((function(e){return-1!==e}));i.push(e.getStackedSeriesTotals(a))})),i}},{key:"setSeriesYAxisMappings",value:function(){var e=this.w.globals,t=this.w.config,i=[],n=[],r=[],a=e.series.length>t.yaxis.length||t.yaxis.some((function(e){return Array.isArray(e.seriesName)}));t.series.forEach((function(e,t){r.push(t),n.push(null)})),t.yaxis.forEach((function(e,t){i[t]=[]}));var s=[];t.yaxis.forEach((function(e,n){var o=!1;if(e.seriesName){var l=[];Array.isArray(e.seriesName)?l=e.seriesName:l.push(e.seriesName),l.forEach((function(e){t.series.forEach((function(t,s){if(t.name===e){var l=s;n===s||a?!a||r.indexOf(s)>-1?i[n].push([n,s]):console.warn("Series '"+t.name+"' referenced more than once in what looks like the new style. That is, when using either seriesName: [], or when there are more series than yaxes."):(i[s].push([s,n]),l=n),o=!0,-1!==(l=r.indexOf(l))&&r.splice(l,1)}}))}))}o||s.push(n)})),i=i.map((function(e,t){var i=[];return e.forEach((function(e){n[e[1]]=e[0],i.push(e[1])})),i}));for(var o=t.yaxis.length-1,l=0;l<s.length&&(o=s[l],i[o]=[],r);l++){var c=r[0];r.shift(),i[o].push(c),n[c]=o}r.forEach((function(e){i[o].push(e),n[e]=o})),e.seriesYAxisMap=i.map((function(e){return e})),e.seriesYAxisReverseMap=n.map((function(e){return e})),e.seriesYAxisMap.forEach((function(e,i){e.forEach((function(e){t.series[e]&&void 0===t.series[e].group&&(t.series[e].group="apexcharts-axis-".concat(i.toString()))}))}))}},{key:"isSeriesNull",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null;return 0===(null===e?this.w.config.series.filter((function(e){return null!==e})):this.w.config.series[e].data.filter((function(e){return null!==e}))).length}},{key:"seriesHaveSameValues",value:function(e){return this.w.globals.series[e].every((function(e,t,i){return e===i[0]}))}},{key:"getCategoryLabels",value:function(e){var t=this.w,i=e.slice();return t.config.xaxis.convertedCatToNumeric&&(i=e.map((function(e,i){return t.config.xaxis.labels.formatter(e-t.globals.minX+1)}))),i}},{key:"getLargestSeries",value:function(){var e=this.w;e.globals.maxValsInArrayIndex=e.globals.series.map((function(e){return e.length})).indexOf(Math.max.apply(Math,e.globals.series.map((function(e){return e.length}))))}},{key:"getLargestMarkerSize",value:function(){var e=this.w,t=0;return e.globals.markers.size.forEach((function(e){t=Math.max(t,e)})),e.config.markers.discrete&&e.config.markers.discrete.length&&e.config.markers.discrete.forEach((function(e){t=Math.max(t,e.size)})),t>0&&(t+=e.config.markers.hover.sizeOffset+1),e.globals.markers.largestSize=t,t}},{key:"getSeriesTotals",value:function(){var e=this.w;e.globals.seriesTotals=e.globals.series.map((function(e,t){var i=0;if(Array.isArray(e))for(var n=0;n<e.length;n++)i+=e[n];else i+=e;return i}))}},{key:"getSeriesTotalsXRange",value:function(e,t){var i=this.w;return i.globals.series.map((function(n,r){for(var a=0,s=0;s<n.length;s++)i.globals.seriesX[r][s]>e&&i.globals.seriesX[r][s]<t&&(a+=n[s]);return a}))}},{key:"getPercentSeries",value:function(){var e=this.w;e.globals.seriesPercent=e.globals.series.map((function(t,i){var n=[];if(Array.isArray(t))for(var r=0;r<t.length;r++){var a=e.globals.stackedSeriesTotals[r],s=0;a&&(s=100*t[r]/a),n.push(s)}else{var o=100*t/e.globals.seriesTotals.reduce((function(e,t){return e+t}),0);n.push(o)}return n}))}},{key:"getCalculatedRatios",value:function(){var e,t,i,n=this,r=this.w,a=r.globals,s=[],o=0,l=[],c=.1,u=0;if(a.yRange=[],a.isMultipleYAxis)for(var d=0;d<a.minYArr.length;d++)a.yRange.push(Math.abs(a.minYArr[d]-a.maxYArr[d])),l.push(0);else a.yRange.push(Math.abs(a.minY-a.maxY));a.xRange=Math.abs(a.maxX-a.minX),a.zRange=Math.abs(a.maxZ-a.minZ);for(var h=0;h<a.yRange.length;h++)s.push(a.yRange[h]/a.gridHeight);if(t=a.xRange/a.gridWidth,e=a.yRange/a.gridWidth,i=a.xRange/a.gridHeight,(o=a.zRange/a.gridHeight*16)||(o=1),a.minY!==Number.MIN_VALUE&&0!==Math.abs(a.minY)&&(a.hasNegs=!0),r.globals.seriesYAxisReverseMap.length>0){var f=function(e,t){var i=r.config.yaxis[r.globals.seriesYAxisReverseMap[t]],a=e<0?-1:1;return e=Math.abs(e),i.logarithmic&&(e=n.getBaseLog(i.logBase,e)),-a*e/s[t]};if(a.isMultipleYAxis){l=[];for(var p=0;p<s.length;p++)l.push(f(a.minYArr[p],p))}else(l=[]).push(f(a.minY,0)),a.minY!==Number.MIN_VALUE&&0!==Math.abs(a.minY)&&(c=-a.minY/e,u=a.minX/t)}else(l=[]).push(0),c=0,u=0;return{yRatio:s,invertedYRatio:e,zRatio:o,xRatio:t,invertedXRatio:i,baseLineInvertedY:c,baseLineY:l,baseLineX:u}}},{key:"getLogSeries",value:function(e){var t=this,i=this.w;return i.globals.seriesLog=e.map((function(e,n){var r=i.globals.seriesYAxisReverseMap[n];return i.config.yaxis[r]&&i.config.yaxis[r].logarithmic?e.map((function(e){return null===e?null:t.getLogVal(i.config.yaxis[r].logBase,e,n)})):e})),i.globals.invalidLogScale?e:i.globals.seriesLog}},{key:"getBaseLog",value:function(e,t){return Math.log(t)/Math.log(e)}},{key:"getLogVal",value:function(e,t,i){if(t<=0)return 0;var n=this.w,r=0===n.globals.minYArr[i]?-1:this.getBaseLog(e,n.globals.minYArr[i]),a=(0===n.globals.maxYArr[i]?0:this.getBaseLog(e,n.globals.maxYArr[i]))-r;return t<1?t/a:(this.getBaseLog(e,t)-r)/a}},{key:"getLogYRatios",value:function(e){var t=this,i=this.w,n=this.w.globals;return n.yLogRatio=e.slice(),n.logYRange=n.yRange.map((function(e,r){var a=i.globals.seriesYAxisReverseMap[r];if(i.config.yaxis[a]&&t.w.config.yaxis[a].logarithmic){var s,o=-Number.MAX_VALUE,l=Number.MIN_VALUE;return n.seriesLog.forEach((function(e,t){e.forEach((function(e){i.config.yaxis[t]&&i.config.yaxis[t].logarithmic&&(o=Math.max(e,o),l=Math.min(e,l))}))})),s=Math.pow(n.yRange[r],Math.abs(l-o)/n.yRange[r]),n.yLogRatio[r]=s/n.gridHeight,s}})),n.invalidLogScale?e.slice():n.yLogRatio}},{key:"drawSeriesByGroup",value:function(e,t,i,n){var r=this.w,a=[];return e.series.length>0&&t.forEach((function(t){var s=[],o=[];e.i.forEach((function(i,n){r.config.series[i].group===t&&(s.push(e.series[n]),o.push(i))})),s.length>0&&a.push(n.draw(s,i,o))})),a}}],[{key:"checkComboSeries",value:function(e,t){var i=!1,n=0,r=0;return void 0===t&&(t="line"),e.length&&void 0!==e[0].type&&e.forEach((function(e){"bar"!==e.type&&"column"!==e.type&&"candlestick"!==e.type&&"boxPlot"!==e.type||n++,void 0!==e.type&&e.type!==t&&r++})),r>0&&(i=!0),{comboBarCount:n,comboCharts:i}}},{key:"extendArrayProps",value:function(e,t,i){var n,r,a,s,o,l;return null!==(n=t)&&void 0!==n&&n.yaxis&&(t=e.extendYAxis(t,i)),null!==(r=t)&&void 0!==r&&r.annotations&&(t.annotations.yaxis&&(t=e.extendYAxisAnnotations(t)),null!==(a=t)&&void 0!==a&&null!==(s=a.annotations)&&void 0!==s&&s.xaxis&&(t=e.extendXAxisAnnotations(t)),null!==(o=t)&&void 0!==o&&null!==(l=o.annotations)&&void 0!==l&&l.points&&(t=e.extendPointAnnotations(t))),t}}]),e}(),_=function(){function e(t){n(this,e),this.w=t.w,this.annoCtx=t}return a(e,[{key:"setOrientations",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null,i=this.w;if("vertical"===e.label.orientation){var n=null!==t?t:0,r=i.globals.dom.baseEl.querySelector(".apexcharts-xaxis-annotations .apexcharts-xaxis-annotation-label[rel='".concat(n,"']"));if(null!==r){var a=r.getBoundingClientRect();r.setAttribute("x",parseFloat(r.getAttribute("x"))-a.height+4),"top"===e.label.position?r.setAttribute("y",parseFloat(r.getAttribute("y"))+a.width):r.setAttribute("y",parseFloat(r.getAttribute("y"))-a.width);var s=this.annoCtx.graphics.rotateAroundCenter(r),o=s.x,l=s.y;r.setAttribute("transform","rotate(-90 ".concat(o," ").concat(l,")"))}}}},{key:"addBackgroundToAnno",value:function(e,t){var i=this.w;if(!e||void 0===t.label.text||void 0!==t.label.text&&!String(t.label.text).trim())return null;var n=i.globals.dom.baseEl.querySelector(".apexcharts-grid").getBoundingClientRect(),r=e.getBoundingClientRect(),a=t.label.style.padding.left,s=t.label.style.padding.right,o=t.label.style.padding.top,l=t.label.style.padding.bottom;"vertical"===t.label.orientation&&(o=t.label.style.padding.left,l=t.label.style.padding.right,a=t.label.style.padding.top,s=t.label.style.padding.bottom);var c=r.left-n.left-a,u=r.top-n.top-o,d=this.annoCtx.graphics.drawRect(c-i.globals.barPadForNumericAxis,u,r.width+a+s,r.height+o+l,t.label.borderRadius,t.label.style.background,1,t.label.borderWidth,t.label.borderColor,0);return t.id&&d.node.classList.add(t.id),d}},{key:"annotationsBackground",value:function(){var e=this,t=this.w,i=function(i,n,r){var a=t.globals.dom.baseEl.querySelector(".apexcharts-".concat(r,"-annotations .apexcharts-").concat(r,"-annotation-label[rel='").concat(n,"']"));if(a){var s=a.parentNode,o=e.addBackgroundToAnno(a,i);o&&(s.insertBefore(o.node,a),i.label.mouseEnter&&o.node.addEventListener("mouseenter",i.label.mouseEnter.bind(e,i)),i.label.mouseLeave&&o.node.addEventListener("mouseleave",i.label.mouseLeave.bind(e,i)),i.label.click&&o.node.addEventListener("click",i.label.click.bind(e,i)))}};t.config.annotations.xaxis.map((function(e,t){i(e,t,"xaxis")})),t.config.annotations.yaxis.map((function(e,t){i(e,t,"yaxis")})),t.config.annotations.points.map((function(e,t){i(e,t,"point")}))}},{key:"getY1Y2",value:function(e,t){var i,n="y1"===e?t.y:t.y2,r=!1,a=this.w;if(this.annoCtx.invertAxis){var s=a.globals.labels;a.config.xaxis.convertedCatToNumeric&&(s=a.globals.categoryLabels);var o=s.indexOf(n),l=a.globals.dom.baseEl.querySelector(".apexcharts-yaxis-texts-g text:nth-child("+(o+1)+")");i=l?parseFloat(l.getAttribute("y")):(a.globals.gridHeight/s.length-1)*(o+1)-a.globals.barHeight,void 0!==t.seriesIndex&&a.globals.barHeight&&(i=i-a.globals.barHeight/2*(a.globals.series.length-1)+a.globals.barHeight*t.seriesIndex)}else{var c,u=a.globals.seriesYAxisMap[t.yAxisIndex][0];(c=a.config.yaxis[t.yAxisIndex].logarithmic?(n=new x(this.annoCtx.ctx).getLogVal(a.config.yaxis[t.yAxisIndex].logBase,n,u))/a.globals.yLogRatio[u]:(n-a.globals.minYArr[u])/(a.globals.yRange[u]/a.globals.gridHeight))>a.globals.gridHeight?(c=a.globals.gridHeight,r=!0):c<0&&(c=0,r=!0),i=a.globals.gridHeight-c,!t.marker||void 0!==t.y&&null!==t.y||(i=0),a.config.yaxis[t.yAxisIndex]&&a.config.yaxis[t.yAxisIndex].reversed&&(i=c)}return"string"==typeof n&&n.indexOf("px")>-1&&(i=parseFloat(n)),{yP:i,clipped:r}}},{key:"getX1X2",value:function(e,t){var i,n="x1"===e?t.x:t.x2,r=this.w,a=this.annoCtx.invertAxis?r.globals.minY:r.globals.minX,s=this.annoCtx.invertAxis?r.globals.maxY:r.globals.maxX,o=this.annoCtx.invertAxis?r.globals.yRange[0]:r.globals.xRange,l=!1;return i=this.annoCtx.inversedReversedAxis?(s-n)/(o/r.globals.gridWidth):(n-a)/(o/r.globals.gridWidth),"category"!==r.config.xaxis.type&&!r.config.xaxis.convertedCatToNumeric||this.annoCtx.invertAxis||r.globals.dataFormatXNumeric||r.config.chart.sparkline.enabled||(i=this.getStringX(n)),"string"==typeof n&&n.indexOf("px")>-1&&(i=parseFloat(n)),null==n&&t.marker&&(i=r.globals.gridWidth),void 0!==t.seriesIndex&&r.globals.barWidth&&!this.annoCtx.invertAxis&&(i=i-r.globals.barWidth/2*(r.globals.series.length-1)+r.globals.barWidth*t.seriesIndex),i>r.globals.gridWidth?(i=r.globals.gridWidth,l=!0):i<0&&(i=0,l=!0),{x:i,clipped:l}}},{key:"getStringX",value:function(e){var t=this.w,i=e;t.config.xaxis.convertedCatToNumeric&&t.globals.categoryLabels.length&&(e=t.globals.categoryLabels.indexOf(e)+1);var n=t.globals.labels.indexOf(e),r=t.globals.dom.baseEl.querySelector(".apexcharts-xaxis-texts-g text:nth-child("+(n+1)+")");return r&&(i=parseFloat(r.getAttribute("x"))),i}}]),e}(),w=function(){function e(t){n(this,e),this.w=t.w,this.annoCtx=t,this.invertAxis=this.annoCtx.invertAxis,this.helpers=new _(this.annoCtx)}return a(e,[{key:"addXaxisAnnotation",value:function(e,t,i){var n,r=this.w,a=this.helpers.getX1X2("x1",e),s=a.x,o=a.clipped,l=!0,c=e.label.text,u=e.strokeDashArray;if(g.isNumber(s)){if(null===e.x2||void 0===e.x2){if(!o){var d=this.annoCtx.graphics.drawLine(s+e.offsetX,0+e.offsetY,s+e.offsetX,r.globals.gridHeight+e.offsetY,e.borderColor,u,e.borderWidth);t.appendChild(d.node),e.id&&d.node.classList.add(e.id)}}else{var h=this.helpers.getX1X2("x2",e);if(n=h.x,l=h.clipped,!o||!l){if(n<s){var f=s;s=n,n=f}var p=this.annoCtx.graphics.drawRect(s+e.offsetX,0+e.offsetY,n-s,r.globals.gridHeight+e.offsetY,0,e.fillColor,e.opacity,1,e.borderColor,u);p.node.classList.add("apexcharts-annotation-rect"),p.attr("clip-path","url(#gridRectMask".concat(r.globals.cuid,")")),t.appendChild(p.node),e.id&&p.node.classList.add(e.id)}}if(!o||!l){var m=this.annoCtx.graphics.getTextRects(c,parseFloat(e.label.style.fontSize)),v="top"===e.label.position?4:"center"===e.label.position?r.globals.gridHeight/2+("vertical"===e.label.orientation?m.width/2:0):r.globals.gridHeight,y=this.annoCtx.graphics.drawText({x:s+e.label.offsetX,y:v+e.label.offsetY-("vertical"===e.label.orientation?"top"===e.label.position?m.width/2-12:-m.width/2:0),text:c,textAnchor:e.label.textAnchor,fontSize:e.label.style.fontSize,fontFamily:e.label.style.fontFamily,fontWeight:e.label.style.fontWeight,foreColor:e.label.style.color,cssClass:"apexcharts-xaxis-annotation-label ".concat(e.label.style.cssClass," ").concat(e.id?e.id:"")});y.attr({rel:i}),t.appendChild(y.node),this.annoCtx.helpers.setOrientations(e,i)}}}},{key:"drawXAxisAnnotations",value:function(){var e=this,t=this.w,i=this.annoCtx.graphics.group({class:"apexcharts-xaxis-annotations"});return t.config.annotations.xaxis.map((function(t,n){e.addXaxisAnnotation(t,i.node,n)})),i}}]),e}(),k=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.months31=[1,3,5,7,8,10,12],this.months30=[2,4,6,9,11],this.daysCntOfYear=[0,31,59,90,120,151,181,212,243,273,304,334]}return a(e,[{key:"isValidDate",value:function(e){return"number"!=typeof e&&!isNaN(this.parseDate(e))}},{key:"getTimeStamp",value:function(e){return Date.parse(e)?this.w.config.xaxis.labels.datetimeUTC?new Date(new Date(e).toISOString().substr(0,25)).getTime():new Date(e).getTime():e}},{key:"getDate",value:function(e){return this.w.config.xaxis.labels.datetimeUTC?new Date(new Date(e).toUTCString()):new Date(e)}},{key:"parseDate",value:function(e){var t=Date.parse(e);if(!isNaN(t))return this.getTimeStamp(e);var i=Date.parse(e.replace(/-/g,"/").replace(/[a-z]+/gi," "));return this.getTimeStamp(i)}},{key:"parseDateWithTimezone",value:function(e){return Date.parse(e.replace(/-/g,"/").replace(/[a-z]+/gi," "))}},{key:"formatDate",value:function(e,t){var i=this.w.globals.locale,n=this.w.config.xaxis.labels.datetimeUTC,r=["\0"].concat(f(i.months)),a=[""].concat(f(i.shortMonths)),s=[""].concat(f(i.days)),o=[""].concat(f(i.shortDays));function l(e,t){var i=e+"";for(t=t||2;i.length<t;)i="0"+i;return i}var c=n?e.getUTCFullYear():e.getFullYear();t=(t=(t=t.replace(/(^|[^\\])yyyy+/g,"$1"+c)).replace(/(^|[^\\])yy/g,"$1"+c.toString().substr(2,2))).replace(/(^|[^\\])y/g,"$1"+c);var u=(n?e.getUTCMonth():e.getMonth())+1;t=(t=(t=(t=t.replace(/(^|[^\\])MMMM+/g,"$1"+r[0])).replace(/(^|[^\\])MMM/g,"$1"+a[0])).replace(/(^|[^\\])MM/g,"$1"+l(u))).replace(/(^|[^\\])M/g,"$1"+u);var d=n?e.getUTCDate():e.getDate();t=(t=(t=(t=t.replace(/(^|[^\\])dddd+/g,"$1"+s[0])).replace(/(^|[^\\])ddd/g,"$1"+o[0])).replace(/(^|[^\\])dd/g,"$1"+l(d))).replace(/(^|[^\\])d/g,"$1"+d);var h=n?e.getUTCHours():e.getHours(),p=h>12?h-12:0===h?12:h;t=(t=(t=(t=t.replace(/(^|[^\\])HH+/g,"$1"+l(h))).replace(/(^|[^\\])H/g,"$1"+h)).replace(/(^|[^\\])hh+/g,"$1"+l(p))).replace(/(^|[^\\])h/g,"$1"+p);var m=n?e.getUTCMinutes():e.getMinutes();t=(t=t.replace(/(^|[^\\])mm+/g,"$1"+l(m))).replace(/(^|[^\\])m/g,"$1"+m);var g=n?e.getUTCSeconds():e.getSeconds();t=(t=t.replace(/(^|[^\\])ss+/g,"$1"+l(g))).replace(/(^|[^\\])s/g,"$1"+g);var v=n?e.getUTCMilliseconds():e.getMilliseconds();t=t.replace(/(^|[^\\])fff+/g,"$1"+l(v,3)),v=Math.round(v/10),t=t.replace(/(^|[^\\])ff/g,"$1"+l(v)),v=Math.round(v/10);var y=h<12?"AM":"PM";t=(t=(t=t.replace(/(^|[^\\])f/g,"$1"+v)).replace(/(^|[^\\])TT+/g,"$1"+y)).replace(/(^|[^\\])T/g,"$1"+y.charAt(0));var b=y.toLowerCase();t=(t=t.replace(/(^|[^\\])tt+/g,"$1"+b)).replace(/(^|[^\\])t/g,"$1"+b.charAt(0));var x=-e.getTimezoneOffset(),_=n||!x?"Z":x>0?"+":"-";if(!n){var w=(x=Math.abs(x))%60;_+=l(Math.floor(x/60))+":"+l(w)}t=t.replace(/(^|[^\\])K/g,"$1"+_);var k=(n?e.getUTCDay():e.getDay())+1;return(t=(t=(t=(t=t.replace(new RegExp(s[0],"g"),s[k])).replace(new RegExp(o[0],"g"),o[k])).replace(new RegExp(r[0],"g"),r[u])).replace(new RegExp(a[0],"g"),a[u])).replace(/\\(.)/g,"$1")}},{key:"getTimeUnitsfromTimestamp",value:function(e,t,i){var n=this.w;void 0!==n.config.xaxis.min&&(e=n.config.xaxis.min),void 0!==n.config.xaxis.max&&(t=n.config.xaxis.max);var r=this.getDate(e),a=this.getDate(t),s=this.formatDate(r,"yyyy MM dd HH mm ss fff").split(" "),o=this.formatDate(a,"yyyy MM dd HH mm ss fff").split(" ");return{minMillisecond:parseInt(s[6],10),maxMillisecond:parseInt(o[6],10),minSecond:parseInt(s[5],10),maxSecond:parseInt(o[5],10),minMinute:parseInt(s[4],10),maxMinute:parseInt(o[4],10),minHour:parseInt(s[3],10),maxHour:parseInt(o[3],10),minDate:parseInt(s[2],10),maxDate:parseInt(o[2],10),minMonth:parseInt(s[1],10)-1,maxMonth:parseInt(o[1],10)-1,minYear:parseInt(s[0],10),maxYear:parseInt(o[0],10)}}},{key:"isLeapYear",value:function(e){return e%4==0&&e%100!=0||e%400==0}},{key:"calculcateLastDaysOfMonth",value:function(e,t,i){return this.determineDaysOfMonths(e,t)-i}},{key:"determineDaysOfYear",value:function(e){var t=365;return this.isLeapYear(e)&&(t=366),t}},{key:"determineRemainingDaysOfYear",value:function(e,t,i){var n=this.daysCntOfYear[t]+i;return t>1&&this.isLeapYear()&&n++,n}},{key:"determineDaysOfMonths",value:function(e,t){var i=30;switch(e=g.monthMod(e),!0){case this.months30.indexOf(e)>-1:2===e&&(i=this.isLeapYear(t)?29:28);break;case this.months31.indexOf(e)>-1:default:i=31}return i}}]),e}(),M=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.tooltipKeyFormat="dd MMM"}return a(e,[{key:"xLabelFormat",value:function(e,t,i,n){var r=this.w;if("datetime"===r.config.xaxis.type&&void 0===r.config.xaxis.labels.formatter&&void 0===r.config.tooltip.x.formatter){var a=new k(this.ctx);return a.formatDate(a.getDate(t),r.config.tooltip.x.format)}return e(t,i,n)}},{key:"defaultGeneralFormatter",value:function(e){return Array.isArray(e)?e.map((function(e){return e})):e}},{key:"defaultYFormatter",value:function(e,t,i){var n=this.w;if(g.isNumber(e))if(0!==n.globals.yValueDecimal)e=e.toFixed(void 0!==t.decimalsInFloat?t.decimalsInFloat:n.globals.yValueDecimal);else{var r=e.toFixed(0);e=e==r?r:e.toFixed(1)}return e}},{key:"setLabelFormatters",value:function(){var e=this,t=this.w;return t.globals.xaxisTooltipFormatter=function(t){return e.defaultGeneralFormatter(t)},t.globals.ttKeyFormatter=function(t){return e.defaultGeneralFormatter(t)},t.globals.ttZFormatter=function(e){return e},t.globals.legendFormatter=function(t){return e.defaultGeneralFormatter(t)},void 0!==t.config.xaxis.labels.formatter?t.globals.xLabelFormatter=t.config.xaxis.labels.formatter:t.globals.xLabelFormatter=function(e){if(g.isNumber(e)){if(!t.config.xaxis.convertedCatToNumeric&&"numeric"===t.config.xaxis.type){if(g.isNumber(t.config.xaxis.decimalsInFloat))return e.toFixed(t.config.xaxis.decimalsInFloat);var i=t.globals.maxX-t.globals.minX;return i>0&&i<100?e.toFixed(1):e.toFixed(0)}return t.globals.isBarHorizontal&&t.globals.maxY-t.globals.minYArr<4?e.toFixed(1):e.toFixed(0)}return e},"function"==typeof t.config.tooltip.x.formatter?t.globals.ttKeyFormatter=t.config.tooltip.x.formatter:t.globals.ttKeyFormatter=t.globals.xLabelFormatter,"function"==typeof t.config.xaxis.tooltip.formatter&&(t.globals.xaxisTooltipFormatter=t.config.xaxis.tooltip.formatter),(Array.isArray(t.config.tooltip.y)||void 0!==t.config.tooltip.y.formatter)&&(t.globals.ttVal=t.config.tooltip.y),void 0!==t.config.tooltip.z.formatter&&(t.globals.ttZFormatter=t.config.tooltip.z.formatter),void 0!==t.config.legend.formatter&&(t.globals.legendFormatter=t.config.legend.formatter),t.config.yaxis.forEach((function(i,n){void 0!==i.labels.formatter?t.globals.yLabelFormatters[n]=i.labels.formatter:t.globals.yLabelFormatters[n]=function(r){return t.globals.xyCharts?Array.isArray(r)?r.map((function(t){return e.defaultYFormatter(t,i,n)})):e.defaultYFormatter(r,i,n):r}})),t.globals}},{key:"heatmapLabelFormatters",value:function(){var e=this.w;if("heatmap"===e.config.chart.type){e.globals.yAxisScale[0].result=e.globals.seriesNames.slice();var t=e.globals.seriesNames.reduce((function(e,t){return e.length>t.length?e:t}),0);e.globals.yAxisScale[0].niceMax=t,e.globals.yAxisScale[0].niceMin=t}}}]),e}(),S=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"getLabel",value:function(e,t,i,n){var r,a,s=arguments.length>4&&void 0!==arguments[4]?arguments[4]:[],o=arguments.length>5&&void 0!==arguments[5]?arguments[5]:"12px",l=!(arguments.length>6&&void 0!==arguments[6])||arguments[6],c=this.w,u=void 0===e[n]?"":e[n],d=u,h=c.globals.xLabelFormatter,f=c.config.xaxis.labels.formatter,p=!1,m=new M(this.ctx),g=u;l&&(d=m.xLabelFormat(h,u,g,{i:n,dateFormatter:new k(this.ctx).formatDate,w:c}),void 0!==f&&(d=f(u,e[n],{i:n,dateFormatter:new k(this.ctx).formatDate,w:c}))),t.length>0?(r=t[n].unit,a=null,t.forEach((function(e){"month"===e.unit?a="year":"day"===e.unit?a="month":"hour"===e.unit?a="day":"minute"===e.unit&&(a="hour")})),p=a===r,i=t[n].position,d=t[n].value):"datetime"===c.config.xaxis.type&&void 0===f&&(d=""),void 0===d&&(d=""),d=Array.isArray(d)?d:d.toString();var v,y=new b(this.ctx);v=c.globals.rotateXLabels&&l?y.getTextRects(d,parseInt(o,10),null,"rotate(".concat(c.config.xaxis.labels.rotate," 0 0)"),!1):y.getTextRects(d,parseInt(o,10));var x=!c.config.xaxis.labels.showDuplicates&&this.ctx.timeScale;return!Array.isArray(d)&&("NaN"===String(d)||s.indexOf(d)>=0&&x)&&(d=""),{x:i,text:d,textRect:v,isBold:p}}},{key:"checkLabelBasedOnTickamount",value:function(e,t,i){var n=this.w,r=n.config.xaxis.tickAmount;return"dataPoints"===r&&(r=Math.round(n.globals.gridWidth/120)),r>i||e%Math.round(i/(r+1))==0||(t.text=""),t}},{key:"checkForOverflowingLabels",value:function(e,t,i,n,r){var a=this.w;if(0===e&&a.globals.skipFirstTimelinelabel&&(t.text=""),e===i-1&&a.globals.skipLastTimelinelabel&&(t.text=""),a.config.xaxis.labels.hideOverlappingLabels&&n.length>0){var s=r[r.length-1];t.x<s.textRect.width/(a.globals.rotateXLabels?Math.abs(a.config.xaxis.labels.rotate)/12:1.01)+s.x&&(t.text="")}return t}},{key:"checkForReversedLabels",value:function(e,t){var i=this.w;return i.config.yaxis[e]&&i.config.yaxis[e].reversed&&t.reverse(),t}},{key:"yAxisAllSeriesCollapsed",value:function(e){var t=this.w.globals;return!t.seriesYAxisMap[e].some((function(e){return-1===t.collapsedSeriesIndices.indexOf(e)}))}},{key:"translateYAxisIndex",value:function(e){var t=this.w,i=t.globals,n=t.config.yaxis;return i.series.length>n.length||n.some((function(e){return Array.isArray(e.seriesName)}))?e:i.seriesYAxisReverseMap[e]}},{key:"isYAxisHidden",value:function(e){var t=this.w,i=t.config.yaxis[e];if(!i.show||this.yAxisAllSeriesCollapsed(e))return!0;if(!i.showForNullSeries){var n=t.globals.seriesYAxisMap[e],r=new x(this.ctx);return n.every((function(e){return r.isSeriesNull(e)}))}return!1}},{key:"getYAxisForeColor",value:function(e,t){var i=this.w;return Array.isArray(e)&&i.globals.yAxisScale[t]&&this.ctx.theme.pushExtraColors(e,i.globals.yAxisScale[t].result.length,!1),e}},{key:"drawYAxisTicks",value:function(e,t,i,n,r,a,s){var o=this.w,l=new b(this.ctx),c=o.globals.translateY+o.config.yaxis[r].labels.offsetY;if(o.globals.isBarHorizontal?c=0:"heatmap"===o.config.chart.type&&(c+=a/2),n.show&&t>0){!0===o.config.yaxis[r].opposite&&(e+=n.width);for(var u=t;u>=0;u--){var d=l.drawLine(e+i.offsetX-n.width+n.offsetX,c+n.offsetY,e+i.offsetX+n.offsetX,c+n.offsetY,n.color);s.add(d),c+=a}}}}]),e}(),A=function(){function e(t){n(this,e),this.w=t.w,this.annoCtx=t,this.helpers=new _(this.annoCtx),this.axesUtils=new S(this.annoCtx)}return a(e,[{key:"addYaxisAnnotation",value:function(e,t,i){var n,r=this.w,a=e.strokeDashArray,s=this.helpers.getY1Y2("y1",e),o=s.yP,l=s.clipped,c=!0,u=!1,d=e.label.text;if(null===e.y2||void 0===e.y2){if(!l){u=!0;var h=this.annoCtx.graphics.drawLine(0+e.offsetX,o+e.offsetY,this._getYAxisAnnotationWidth(e),o+e.offsetY,e.borderColor,a,e.borderWidth);t.appendChild(h.node),e.id&&h.node.classList.add(e.id)}}else{if(n=(s=this.helpers.getY1Y2("y2",e)).yP,c=s.clipped,n>o){var f=o;o=n,n=f}if(!l||!c){u=!0;var p=this.annoCtx.graphics.drawRect(0+e.offsetX,n+e.offsetY,this._getYAxisAnnotationWidth(e),o-n,0,e.fillColor,e.opacity,1,e.borderColor,a);p.node.classList.add("apexcharts-annotation-rect"),p.attr("clip-path","url(#gridRectMask".concat(r.globals.cuid,")")),t.appendChild(p.node),e.id&&p.node.classList.add(e.id)}}if(u){var m="right"===e.label.position?r.globals.gridWidth:"center"===e.label.position?r.globals.gridWidth/2:0,g=this.annoCtx.graphics.drawText({x:m+e.label.offsetX,y:(null!=n?n:o)+e.label.offsetY-3,text:d,textAnchor:e.label.textAnchor,fontSize:e.label.style.fontSize,fontFamily:e.label.style.fontFamily,fontWeight:e.label.style.fontWeight,foreColor:e.label.style.color,cssClass:"apexcharts-yaxis-annotation-label ".concat(e.label.style.cssClass," ").concat(e.id?e.id:"")});g.attr({rel:i}),t.appendChild(g.node)}}},{key:"_getYAxisAnnotationWidth",value:function(e){var t=this.w;return t.globals.gridWidth,(e.width.indexOf("%")>-1?t.globals.gridWidth*parseInt(e.width,10)/100:parseInt(e.width,10))+e.offsetX}},{key:"drawYAxisAnnotations",value:function(){var e=this,t=this.w,i=this.annoCtx.graphics.group({class:"apexcharts-yaxis-annotations"});return t.config.annotations.yaxis.forEach((function(t,n){t.yAxisIndex=e.axesUtils.translateYAxisIndex(t.yAxisIndex),e.axesUtils.isYAxisHidden(t.yAxisIndex)&&e.axesUtils.yAxisAllSeriesCollapsed(t.yAxisIndex)||e.addYaxisAnnotation(t,i.node,n)})),i}}]),e}(),L=function(){function e(t){n(this,e),this.w=t.w,this.annoCtx=t,this.helpers=new _(this.annoCtx)}return a(e,[{key:"addPointAnnotation",value:function(e,t,i){if(!(this.w.globals.collapsedSeriesIndices.indexOf(e.seriesIndex)>-1)){var n=this.helpers.getX1X2("x1",e),r=n.x,a=n.clipped,s=(n=this.helpers.getY1Y2("y1",e)).yP,o=n.clipped;if(g.isNumber(r)&&!o&&!a){var l={pSize:e.marker.size,pointStrokeWidth:e.marker.strokeWidth,pointFillColor:e.marker.fillColor,pointStrokeColor:e.marker.strokeColor,shape:e.marker.shape,pRadius:e.marker.radius,class:"apexcharts-point-annotation-marker ".concat(e.marker.cssClass," ").concat(e.id?e.id:"")},c=this.annoCtx.graphics.drawMarker(r+e.marker.offsetX,s+e.marker.offsetY,l);t.appendChild(c.node);var u=e.label.text?e.label.text:"",d=this.annoCtx.graphics.drawText({x:r+e.label.offsetX,y:s+e.label.offsetY-e.marker.size-parseFloat(e.label.style.fontSize)/1.6,text:u,textAnchor:e.label.textAnchor,fontSize:e.label.style.fontSize,fontFamily:e.label.style.fontFamily,fontWeight:e.label.style.fontWeight,foreColor:e.label.style.color,cssClass:"apexcharts-point-annotation-label ".concat(e.label.style.cssClass," ").concat(e.id?e.id:"")});if(d.attr({rel:i}),t.appendChild(d.node),e.customSVG.SVG){var h=this.annoCtx.graphics.group({class:"apexcharts-point-annotations-custom-svg "+e.customSVG.cssClass});h.attr({transform:"translate(".concat(r+e.customSVG.offsetX,", ").concat(s+e.customSVG.offsetY,")")}),h.node.innerHTML=e.customSVG.SVG,t.appendChild(h.node)}if(e.image.path){var f=e.image.width?e.image.width:20,p=e.image.height?e.image.height:20;c=this.annoCtx.addImage({x:r+e.image.offsetX-f/2,y:s+e.image.offsetY-p/2,width:f,height:p,path:e.image.path,appendTo:".apexcharts-point-annotations"})}e.mouseEnter&&c.node.addEventListener("mouseenter",e.mouseEnter.bind(this,e)),e.mouseLeave&&c.node.addEventListener("mouseleave",e.mouseLeave.bind(this,e)),e.click&&c.node.addEventListener("click",e.click.bind(this,e))}}}},{key:"drawPointAnnotations",value:function(){var e=this,t=this.w,i=this.annoCtx.graphics.group({class:"apexcharts-point-annotations"});return t.config.annotations.points.map((function(t,n){e.addPointAnnotation(t,i.node,n)})),i}}]),e}(),T={name:"en",options:{months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],toolbar:{exportToSVG:"Download SVG",exportToPNG:"Download PNG",exportToCSV:"Download CSV",menu:"Menu",selection:"Selection",selectionZoom:"Selection Zoom",zoomIn:"Zoom In",zoomOut:"Zoom Out",pan:"Panning",reset:"Reset Zoom"}}},C=function(){function e(){n(this,e),this.yAxis={show:!0,showAlways:!1,showForNullSeries:!0,seriesName:void 0,opposite:!1,reversed:!1,logarithmic:!1,logBase:10,tickAmount:void 0,stepSize:void 0,forceNiceScale:!1,max:void 0,min:void 0,floating:!1,decimalsInFloat:void 0,labels:{show:!0,minWidth:0,maxWidth:160,offsetX:0,offsetY:0,align:void 0,rotate:0,padding:20,style:{colors:[],fontSize:"11px",fontWeight:400,fontFamily:void 0,cssClass:""},formatter:void 0},axisBorder:{show:!1,color:"#e0e0e0",width:1,offsetX:0,offsetY:0},axisTicks:{show:!1,color:"#e0e0e0",width:6,offsetX:0,offsetY:0},title:{text:void 0,rotate:-90,offsetY:0,offsetX:0,style:{color:void 0,fontSize:"11px",fontWeight:900,fontFamily:void 0,cssClass:""}},tooltip:{enabled:!1,offsetX:0},crosshairs:{show:!0,position:"front",stroke:{color:"#b6b6b6",width:1,dashArray:0}}},this.pointAnnotation={id:void 0,x:0,y:null,yAxisIndex:0,seriesIndex:void 0,mouseEnter:void 0,mouseLeave:void 0,click:void 0,marker:{size:4,fillColor:"#fff",strokeWidth:2,strokeColor:"#333",shape:"circle",offsetX:0,offsetY:0,radius:2,cssClass:""},label:{borderColor:"#c2c2c2",borderWidth:1,borderRadius:2,text:void 0,textAnchor:"middle",offsetX:0,offsetY:0,mouseEnter:void 0,mouseLeave:void 0,click:void 0,style:{background:"#fff",color:void 0,fontSize:"11px",fontFamily:void 0,fontWeight:400,cssClass:"",padding:{left:5,right:5,top:2,bottom:2}}},customSVG:{SVG:void 0,cssClass:void 0,offsetX:0,offsetY:0},image:{path:void 0,width:20,height:20,offsetX:0,offsetY:0}},this.yAxisAnnotation={id:void 0,y:0,y2:null,strokeDashArray:1,fillColor:"#c2c2c2",borderColor:"#c2c2c2",borderWidth:1,opacity:.3,offsetX:0,offsetY:0,width:"100%",yAxisIndex:0,label:{borderColor:"#c2c2c2",borderWidth:1,borderRadius:2,text:void 0,textAnchor:"end",position:"right",offsetX:0,offsetY:-3,mouseEnter:void 0,mouseLeave:void 0,click:void 0,style:{background:"#fff",color:void 0,fontSize:"11px",fontFamily:void 0,fontWeight:400,cssClass:"",padding:{left:5,right:5,top:2,bottom:2}}}},this.xAxisAnnotation={id:void 0,x:0,x2:null,strokeDashArray:1,fillColor:"#c2c2c2",borderColor:"#c2c2c2",borderWidth:1,opacity:.3,offsetX:0,offsetY:0,label:{borderColor:"#c2c2c2",borderWidth:1,borderRadius:2,text:void 0,textAnchor:"middle",orientation:"vertical",position:"top",offsetX:0,offsetY:0,mouseEnter:void 0,mouseLeave:void 0,click:void 0,style:{background:"#fff",color:void 0,fontSize:"11px",fontFamily:void 0,fontWeight:400,cssClass:"",padding:{left:5,right:5,top:2,bottom:2}}}},this.text={x:0,y:0,text:"",textAnchor:"start",foreColor:void 0,fontSize:"13px",fontFamily:void 0,fontWeight:400,appendTo:".apexcharts-annotations",backgroundColor:"transparent",borderColor:"#c2c2c2",borderRadius:0,borderWidth:0,paddingLeft:4,paddingRight:4,paddingTop:2,paddingBottom:2}}return a(e,[{key:"init",value:function(){return{annotations:{yaxis:[this.yAxisAnnotation],xaxis:[this.xAxisAnnotation],points:[this.pointAnnotation],texts:[],images:[],shapes:[]},chart:{animations:{enabled:!0,easing:"easeinout",speed:800,animateGradually:{delay:150,enabled:!0},dynamicAnimation:{enabled:!0,speed:350}},background:"transparent",locales:[T],defaultLocale:"en",dropShadow:{enabled:!1,enabledOnSeries:void 0,top:2,left:2,blur:4,color:"#000",opacity:.35},events:{animationEnd:void 0,beforeMount:void 0,mounted:void 0,updated:void 0,click:void 0,mouseMove:void 0,mouseLeave:void 0,xAxisLabelClick:void 0,legendClick:void 0,markerClick:void 0,selection:void 0,dataPointSelection:void 0,dataPointMouseEnter:void 0,dataPointMouseLeave:void 0,beforeZoom:void 0,beforeResetZoom:void 0,zoomed:void 0,scrolled:void 0,brushScrolled:void 0},foreColor:"#373d3f",fontFamily:"Helvetica, Arial, sans-serif",height:"auto",parentHeightOffset:15,redrawOnParentResize:!0,redrawOnWindowResize:!0,id:void 0,group:void 0,nonce:void 0,offsetX:0,offsetY:0,selection:{enabled:!1,type:"x",fill:{color:"#24292e",opacity:.1},stroke:{width:1,color:"#24292e",opacity:.4,dashArray:3},xaxis:{min:void 0,max:void 0},yaxis:{min:void 0,max:void 0}},sparkline:{enabled:!1},brush:{enabled:!1,autoScaleYaxis:!0,target:void 0,targets:void 0},stacked:!1,stackOnlyBar:!0,stackType:"normal",toolbar:{show:!0,offsetX:0,offsetY:0,tools:{download:!0,selection:!0,zoom:!0,zoomin:!0,zoomout:!0,pan:!0,reset:!0,customIcons:[]},export:{csv:{filename:void 0,columnDelimiter:",",headerCategory:"category",headerValue:"value",dateFormatter:function(e){return new Date(e).toDateString()}},png:{filename:void 0},svg:{filename:void 0}},autoSelected:"zoom"},type:"line",width:"100%",zoom:{enabled:!0,type:"x",autoScaleYaxis:!1,zoomedArea:{fill:{color:"#90CAF9",opacity:.4},stroke:{color:"#0D47A1",opacity:.4,width:1}}}},plotOptions:{line:{isSlopeChart:!1},area:{fillTo:"origin"},bar:{horizontal:!1,columnWidth:"70%",barHeight:"70%",distributed:!1,borderRadius:0,borderRadiusApplication:"around",borderRadiusWhenStacked:"last",rangeBarOverlap:!0,rangeBarGroupRows:!1,hideZeroBarsWhenGrouped:!1,isDumbbell:!1,dumbbellColors:void 0,isFunnel:!1,isFunnel3d:!0,colors:{ranges:[],backgroundBarColors:[],backgroundBarOpacity:1,backgroundBarRadius:0},dataLabels:{position:"top",maxItems:100,hideOverflowingLabels:!0,orientation:"horizontal",total:{enabled:!1,formatter:void 0,offsetX:0,offsetY:0,style:{color:"#373d3f",fontSize:"12px",fontFamily:void 0,fontWeight:600}}}},bubble:{zScaling:!0,minBubbleRadius:void 0,maxBubbleRadius:void 0},candlestick:{colors:{upward:"#00B746",downward:"#EF403C"},wick:{useFillColor:!0}},boxPlot:{colors:{upper:"#00E396",lower:"#008FFB"}},heatmap:{radius:2,enableShades:!0,shadeIntensity:.5,reverseNegativeShade:!1,distributed:!1,useFillColorAsStroke:!1,colorScale:{inverse:!1,ranges:[],min:void 0,max:void 0}},treemap:{enableShades:!0,shadeIntensity:.5,distributed:!1,reverseNegativeShade:!1,useFillColorAsStroke:!1,borderRadius:4,dataLabels:{format:"scale"},colorScale:{inverse:!1,ranges:[],min:void 0,max:void 0}},radialBar:{inverseOrder:!1,startAngle:0,endAngle:360,offsetX:0,offsetY:0,hollow:{margin:5,size:"50%",background:"transparent",image:void 0,imageWidth:150,imageHeight:150,imageOffsetX:0,imageOffsetY:0,imageClipped:!0,position:"front",dropShadow:{enabled:!1,top:0,left:0,blur:3,color:"#000",opacity:.5}},track:{show:!0,startAngle:void 0,endAngle:void 0,background:"#f2f2f2",strokeWidth:"97%",opacity:1,margin:5,dropShadow:{enabled:!1,top:0,left:0,blur:3,color:"#000",opacity:.5}},dataLabels:{show:!0,name:{show:!0,fontSize:"16px",fontFamily:void 0,fontWeight:600,color:void 0,offsetY:0,formatter:function(e){return e}},value:{show:!0,fontSize:"14px",fontFamily:void 0,fontWeight:400,color:void 0,offsetY:16,formatter:function(e){return e+"%"}},total:{show:!1,label:"Total",fontSize:"16px",fontWeight:600,fontFamily:void 0,color:void 0,formatter:function(e){return e.globals.seriesTotals.reduce((function(e,t){return e+t}),0)/e.globals.series.length+"%"}}},barLabels:{enabled:!1,margin:5,useSeriesColors:!0,fontFamily:void 0,fontWeight:600,fontSize:"16px",formatter:function(e){return e},onClick:void 0}},pie:{customScale:1,offsetX:0,offsetY:0,startAngle:0,endAngle:360,expandOnClick:!0,dataLabels:{offset:0,minAngleToShowLabel:10},donut:{size:"65%",background:"transparent",labels:{show:!1,name:{show:!0,fontSize:"16px",fontFamily:void 0,fontWeight:600,color:void 0,offsetY:-10,formatter:function(e){return e}},value:{show:!0,fontSize:"20px",fontFamily:void 0,fontWeight:400,color:void 0,offsetY:10,formatter:function(e){return e}},total:{show:!1,showAlways:!1,label:"Total",fontSize:"16px",fontWeight:400,fontFamily:void 0,color:void 0,formatter:function(e){return e.globals.seriesTotals.reduce((function(e,t){return e+t}),0)}}}}},polarArea:{rings:{strokeWidth:1,strokeColor:"#e8e8e8"},spokes:{strokeWidth:1,connectorColors:"#e8e8e8"}},radar:{size:void 0,offsetX:0,offsetY:0,polygons:{strokeWidth:1,strokeColors:"#e8e8e8",connectorColors:"#e8e8e8",fill:{colors:void 0}}}},colors:void 0,dataLabels:{enabled:!0,enabledOnSeries:void 0,formatter:function(e){return null!==e?e:""},textAnchor:"middle",distributed:!1,offsetX:0,offsetY:0,style:{fontSize:"12px",fontFamily:void 0,fontWeight:600,colors:void 0},background:{enabled:!0,foreColor:"#fff",borderRadius:2,padding:4,opacity:.9,borderWidth:1,borderColor:"#fff",dropShadow:{enabled:!1,top:1,left:1,blur:1,color:"#000",opacity:.45}},dropShadow:{enabled:!1,top:1,left:1,blur:1,color:"#000",opacity:.45}},fill:{type:"solid",colors:void 0,opacity:.85,gradient:{shade:"dark",type:"horizontal",shadeIntensity:.5,gradientToColors:void 0,inverseColors:!0,opacityFrom:1,opacityTo:1,stops:[0,50,100],colorStops:[]},image:{src:[],width:void 0,height:void 0},pattern:{style:"squares",width:6,height:6,strokeWidth:2}},forecastDataPoints:{count:0,fillOpacity:.5,strokeWidth:void 0,dashArray:4},grid:{show:!0,borderColor:"#e0e0e0",strokeDashArray:0,position:"back",xaxis:{lines:{show:!1}},yaxis:{lines:{show:!0}},row:{colors:void 0,opacity:.5},column:{colors:void 0,opacity:.5},padding:{top:0,right:10,bottom:0,left:12}},labels:[],legend:{show:!0,showForSingleSeries:!1,showForNullSeries:!0,showForZeroSeries:!0,floating:!1,position:"bottom",horizontalAlign:"center",inverseOrder:!1,fontSize:"12px",fontFamily:void 0,fontWeight:400,width:void 0,height:void 0,formatter:void 0,tooltipHoverFormatter:void 0,offsetX:-20,offsetY:4,customLegendItems:[],labels:{colors:void 0,useSeriesColors:!1},markers:{width:12,height:12,strokeWidth:0,fillColors:void 0,strokeColor:"#fff",radius:12,customHTML:void 0,offsetX:0,offsetY:0,onClick:void 0},itemMargin:{horizontal:5,vertical:2},onItemClick:{toggleDataSeries:!0},onItemHover:{highlightDataSeries:!0}},markers:{discrete:[],size:0,colors:void 0,strokeColors:"#fff",strokeWidth:2,strokeOpacity:.9,strokeDashArray:0,fillOpacity:1,shape:"circle",width:8,height:8,radius:2,offsetX:0,offsetY:0,onClick:void 0,onDblClick:void 0,showNullDataPoints:!0,hover:{size:void 0,sizeOffset:3}},noData:{text:void 0,align:"center",verticalAlign:"middle",offsetX:0,offsetY:0,style:{color:void 0,fontSize:"14px",fontFamily:void 0}},responsive:[],series:void 0,states:{normal:{filter:{type:"none",value:0}},hover:{filter:{type:"lighten",value:.1}},active:{allowMultipleDataPointsSelection:!1,filter:{type:"darken",value:.5}}},title:{text:void 0,align:"left",margin:5,offsetX:0,offsetY:0,floating:!1,style:{fontSize:"14px",fontWeight:900,fontFamily:void 0,color:void 0}},subtitle:{text:void 0,align:"left",margin:5,offsetX:0,offsetY:30,floating:!1,style:{fontSize:"12px",fontWeight:400,fontFamily:void 0,color:void 0}},stroke:{show:!0,curve:"smooth",lineCap:"butt",width:2,colors:void 0,dashArray:0,fill:{type:"solid",colors:void 0,opacity:.85,gradient:{shade:"dark",type:"horizontal",shadeIntensity:.5,gradientToColors:void 0,inverseColors:!0,opacityFrom:1,opacityTo:1,stops:[0,50,100],colorStops:[]}}},tooltip:{enabled:!0,enabledOnSeries:void 0,shared:!0,hideEmptySeries:!1,followCursor:!1,intersect:!1,inverseOrder:!1,custom:void 0,fillSeriesColor:!1,theme:"light",cssClass:"",style:{fontSize:"12px",fontFamily:void 0},onDatasetHover:{highlightDataSeries:!1},x:{show:!0,format:"dd MMM",formatter:void 0},y:{formatter:void 0,title:{formatter:function(e){return e?e+": ":""}}},z:{formatter:void 0,title:"Size: "},marker:{show:!0,fillColors:void 0},items:{display:"flex"},fixed:{enabled:!1,position:"topRight",offsetX:0,offsetY:0}},xaxis:{type:"category",categories:[],convertedCatToNumeric:!1,offsetX:0,offsetY:0,overwriteCategories:void 0,labels:{show:!0,rotate:-45,rotateAlways:!1,hideOverlappingLabels:!0,trim:!1,minHeight:void 0,maxHeight:120,showDuplicates:!0,style:{colors:[],fontSize:"12px",fontWeight:400,fontFamily:void 0,cssClass:""},offsetX:0,offsetY:0,format:void 0,formatter:void 0,datetimeUTC:!0,datetimeFormatter:{year:"yyyy",month:"MMM 'yy",day:"dd MMM",hour:"HH:mm",minute:"HH:mm:ss",second:"HH:mm:ss"}},group:{groups:[],style:{colors:[],fontSize:"12px",fontWeight:400,fontFamily:void 0,cssClass:""}},axisBorder:{show:!0,color:"#e0e0e0",width:"100%",height:1,offsetX:0,offsetY:0},axisTicks:{show:!0,color:"#e0e0e0",height:6,offsetX:0,offsetY:0},stepSize:void 0,tickAmount:void 0,tickPlacement:"on",min:void 0,max:void 0,range:void 0,floating:!1,decimalsInFloat:void 0,position:"bottom",title:{text:void 0,offsetX:0,offsetY:0,style:{color:void 0,fontSize:"12px",fontWeight:900,fontFamily:void 0,cssClass:""}},crosshairs:{show:!0,width:1,position:"back",opacity:.9,stroke:{color:"#b6b6b6",width:1,dashArray:3},fill:{type:"solid",color:"#B1B9C4",gradient:{colorFrom:"#D8E3F0",colorTo:"#BED1E6",stops:[0,100],opacityFrom:.4,opacityTo:.5}},dropShadow:{enabled:!1,left:0,top:0,blur:1,opacity:.4}},tooltip:{enabled:!0,offsetY:0,formatter:void 0,style:{fontSize:"12px",fontFamily:void 0}}},yaxis:this.yAxis,theme:{mode:"light",palette:"palette1",monochrome:{enabled:!1,color:"#008FFB",shadeTo:"light",shadeIntensity:.65}}}}}]),e}(),D=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.graphics=new b(this.ctx),this.w.globals.isBarHorizontal&&(this.invertAxis=!0),this.helpers=new _(this),this.xAxisAnnotations=new w(this),this.yAxisAnnotations=new A(this),this.pointsAnnotations=new L(this),this.w.globals.isBarHorizontal&&this.w.config.yaxis[0].reversed&&(this.inversedReversedAxis=!0),this.xDivision=this.w.globals.gridWidth/this.w.globals.dataPoints}return a(e,[{key:"drawAxesAnnotations",value:function(){var e=this.w;if(e.globals.axisCharts){for(var t=this.yAxisAnnotations.drawYAxisAnnotations(),i=this.xAxisAnnotations.drawXAxisAnnotations(),n=this.pointsAnnotations.drawPointAnnotations(),r=e.config.chart.animations.enabled,a=[t,i,n],s=[i.node,t.node,n.node],o=0;o<3;o++)e.globals.dom.elGraphical.add(a[o]),!r||e.globals.resized||e.globals.dataChanged||"scatter"!==e.config.chart.type&&"bubble"!==e.config.chart.type&&e.globals.dataPoints>1&&s[o].classList.add("apexcharts-element-hidden"),e.globals.delayedElements.push({el:s[o],index:0});this.helpers.annotationsBackground()}}},{key:"drawImageAnnos",value:function(){var e=this;this.w.config.annotations.images.map((function(t,i){e.addImage(t,i)}))}},{key:"drawTextAnnos",value:function(){var e=this;this.w.config.annotations.texts.map((function(t,i){e.addText(t,i)}))}},{key:"addXaxisAnnotation",value:function(e,t,i){this.xAxisAnnotations.addXaxisAnnotation(e,t,i)}},{key:"addYaxisAnnotation",value:function(e,t,i){this.yAxisAnnotations.addYaxisAnnotation(e,t,i)}},{key:"addPointAnnotation",value:function(e,t,i){this.pointsAnnotations.addPointAnnotation(e,t,i)}},{key:"addText",value:function(e,t){var i=e.x,n=e.y,r=e.text,a=e.textAnchor,s=e.foreColor,o=e.fontSize,l=e.fontFamily,c=e.fontWeight,u=e.cssClass,d=e.backgroundColor,h=e.borderWidth,f=e.strokeDashArray,p=e.borderRadius,m=e.borderColor,g=e.appendTo,v=void 0===g?".apexcharts-svg":g,y=e.paddingLeft,b=void 0===y?4:y,x=e.paddingRight,_=void 0===x?4:x,w=e.paddingBottom,k=void 0===w?2:w,M=e.paddingTop,S=void 0===M?2:M,A=this.w,L=this.graphics.drawText({x:i,y:n,text:r,textAnchor:a||"start",fontSize:o||"12px",fontWeight:c||"regular",fontFamily:l||A.config.chart.fontFamily,foreColor:s||A.config.chart.foreColor,cssClass:u}),T=A.globals.dom.baseEl.querySelector(v);T&&T.appendChild(L.node);var C=L.bbox();if(r){var D=this.graphics.drawRect(C.x-b,C.y-S,C.width+b+_,C.height+k+S,p,d||"transparent",1,h,m,f);T.insertBefore(D.node,L.node)}}},{key:"addImage",value:function(e,t){var i=this.w,n=e.path,r=e.x,a=void 0===r?0:r,s=e.y,o=void 0===s?0:s,l=e.width,c=void 0===l?20:l,u=e.height,d=void 0===u?20:u,h=e.appendTo,f=void 0===h?".apexcharts-svg":h,p=i.globals.dom.Paper.image(n);p.size(c,d).move(a,o);var m=i.globals.dom.baseEl.querySelector(f);return m&&m.appendChild(p.node),p}},{key:"addXaxisAnnotationExternal",value:function(e,t,i){return this.addAnnotationExternal({params:e,pushToMemory:t,context:i,type:"xaxis",contextMethod:i.addXaxisAnnotation}),i}},{key:"addYaxisAnnotationExternal",value:function(e,t,i){return this.addAnnotationExternal({params:e,pushToMemory:t,context:i,type:"yaxis",contextMethod:i.addYaxisAnnotation}),i}},{key:"addPointAnnotationExternal",value:function(e,t,i){return void 0===this.invertAxis&&(this.invertAxis=i.w.globals.isBarHorizontal),this.addAnnotationExternal({params:e,pushToMemory:t,context:i,type:"point",contextMethod:i.addPointAnnotation}),i}},{key:"addAnnotationExternal",value:function(e){var t=e.params,i=e.pushToMemory,n=e.context,r=e.type,a=e.contextMethod,s=n,o=s.w,l=o.globals.dom.baseEl.querySelector(".apexcharts-".concat(r,"-annotations")),c=l.childNodes.length+1,u=new C,d=Object.assign({},"xaxis"===r?u.xAxisAnnotation:"yaxis"===r?u.yAxisAnnotation:u.pointAnnotation),h=g.extend(d,t);switch(r){case"xaxis":this.addXaxisAnnotation(h,l,c);break;case"yaxis":this.addYaxisAnnotation(h,l,c);break;case"point":this.addPointAnnotation(h,l,c)}var f=o.globals.dom.baseEl.querySelector(".apexcharts-".concat(r,"-annotations .apexcharts-").concat(r,"-annotation-label[rel='").concat(c,"']")),p=this.helpers.addBackgroundToAnno(f,h);return p&&l.insertBefore(p.node,f),i&&o.globals.memory.methodsToExec.push({context:s,id:h.id?h.id:g.randomId(),method:a,label:"addAnnotation",params:t}),n}},{key:"clearAnnotations",value:function(e){var t=e.w,i=t.globals.dom.baseEl.querySelectorAll(".apexcharts-yaxis-annotations, .apexcharts-xaxis-annotations, .apexcharts-point-annotations");t.globals.memory.methodsToExec.map((function(e,i){"addText"!==e.label&&"addAnnotation"!==e.label||t.globals.memory.methodsToExec.splice(i,1)})),i=g.listToArray(i),Array.prototype.forEach.call(i,(function(e){for(;e.firstChild;)e.removeChild(e.firstChild)}))}},{key:"removeAnnotation",value:function(e,t){var i=e.w,n=i.globals.dom.baseEl.querySelectorAll(".".concat(t));n&&(i.globals.memory.methodsToExec.map((function(e,n){e.id===t&&i.globals.memory.methodsToExec.splice(n,1)})),Array.prototype.forEach.call(n,(function(e){e.parentElement.removeChild(e)})))}}]),e}(),E=function(e){var t,i=e.isTimeline,n=e.ctx,r=e.seriesIndex,a=e.dataPointIndex,s=e.y1,o=e.y2,l=e.w,c=l.globals.seriesRangeStart[r][a],u=l.globals.seriesRangeEnd[r][a],d=l.globals.labels[a],h=l.config.series[r].name?l.config.series[r].name:"",f=l.globals.ttKeyFormatter,p=l.config.tooltip.y.title.formatter,m={w:l,seriesIndex:r,dataPointIndex:a,start:c,end:u};"function"==typeof p&&(h=p(h,m)),null!==(t=l.config.series[r].data[a])&&void 0!==t&&t.x&&(d=l.config.series[r].data[a].x),i||"datetime"===l.config.xaxis.type&&(d=new M(n).xLabelFormat(l.globals.ttKeyFormatter,d,d,{i:void 0,dateFormatter:new k(n).formatDate,w:l})),"function"==typeof f&&(d=f(d,m)),Number.isFinite(s)&&Number.isFinite(o)&&(c=s,u=o);var g="",v="",y=l.globals.colors[r];if(void 0===l.config.tooltip.x.formatter)if("datetime"===l.config.xaxis.type){var b=new k(n);g=b.formatDate(b.getDate(c),l.config.tooltip.x.format),v=b.formatDate(b.getDate(u),l.config.tooltip.x.format)}else g=c,v=u;else g=l.config.tooltip.x.formatter(c),v=l.config.tooltip.x.formatter(u);return{start:c,end:u,startVal:g,endVal:v,ylabel:d,color:y,seriesName:h}},O=function(e){var t=e.color,i=e.seriesName,n=e.ylabel,r=e.start,a=e.end,s=e.seriesIndex,o=e.dataPointIndex,l=e.ctx.tooltip.tooltipLabels.getFormatters(s);r=l.yLbFormatter(r),a=l.yLbFormatter(a);var c=l.yLbFormatter(e.w.globals.series[s][o]),u='<span class="value start-value">\n  '.concat(r,'\n  </span> <span class="separator">-</span> <span class="value end-value">\n  ').concat(a,"\n  </span>");return'<div class="apexcharts-tooltip-rangebar"><div> <span class="series-name" style="color: '+t+'">'+(i||"")+'</span></div><div> <span class="category">'+n+": </span> "+(e.w.globals.comboCharts?"rangeArea"===e.w.config.series[s].type||"rangeBar"===e.w.config.series[s].type?u:"<span>".concat(c,"</span>"):u)+" </div></div>"},P=function(){function e(t){n(this,e),this.opts=t}return a(e,[{key:"hideYAxis",value:function(){this.opts.yaxis[0].show=!1,this.opts.yaxis[0].title.text="",this.opts.yaxis[0].axisBorder.show=!1,this.opts.yaxis[0].axisTicks.show=!1,this.opts.yaxis[0].floating=!0}},{key:"line",value:function(){return{chart:{animations:{easing:"swing"}},dataLabels:{enabled:!1},stroke:{width:5,curve:"straight"},markers:{size:0,hover:{sizeOffset:6}},xaxis:{crosshairs:{width:1}}}}},{key:"sparkline",value:function(e){return this.hideYAxis(),g.extend(e,{grid:{show:!1,padding:{left:0,right:0,top:0,bottom:0}},legend:{show:!1},xaxis:{labels:{show:!1},tooltip:{enabled:!1},axisBorder:{show:!1},axisTicks:{show:!1}},chart:{toolbar:{show:!1},zoom:{enabled:!1}},dataLabels:{enabled:!1}})}},{key:"slope",value:function(){return this.hideYAxis(),{chart:{toolbar:{show:!1},zoom:{enabled:!1}},dataLabels:{enabled:!0,formatter:function(e,t){var i=t.w.config.series[t.seriesIndex].name;return null!==e?i+": "+e:""},background:{enabled:!1},offsetX:-5},grid:{xaxis:{lines:{show:!0}},yaxis:{lines:{show:!1}}},xaxis:{position:"top",labels:{style:{fontSize:14,fontWeight:900}},tooltip:{enabled:!1},crosshairs:{show:!1}},markers:{size:8,hover:{sizeOffset:1}},legend:{show:!1},tooltip:{shared:!1,intersect:!0,followCursor:!0},stroke:{width:5,curve:"straight"}}}},{key:"bar",value:function(){return{chart:{stacked:!1,animations:{easing:"swing"}},plotOptions:{bar:{dataLabels:{position:"center"}}},dataLabels:{style:{colors:["#fff"]},background:{enabled:!1}},stroke:{width:0,lineCap:"round"},fill:{opacity:.85},legend:{markers:{shape:"square",radius:2,size:8}},tooltip:{shared:!1,intersect:!0},xaxis:{tooltip:{enabled:!1},tickPlacement:"between",crosshairs:{width:"barWidth",position:"back",fill:{type:"gradient"},dropShadow:{enabled:!1},stroke:{width:0}}}}}},{key:"funnel",value:function(){return this.hideYAxis(),t(t({},this.bar()),{},{chart:{animations:{easing:"linear",speed:800,animateGradually:{enabled:!1}}},plotOptions:{bar:{horizontal:!0,borderRadiusApplication:"around",borderRadius:0,dataLabels:{position:"center"}}},grid:{show:!1,padding:{left:0,right:0}},xaxis:{labels:{show:!1},tooltip:{enabled:!1},axisBorder:{show:!1},axisTicks:{show:!1}}})}},{key:"candlestick",value:function(){var e=this;return{stroke:{width:1,colors:["#333"]},fill:{opacity:1},dataLabels:{enabled:!1},tooltip:{shared:!0,custom:function(t){var i=t.seriesIndex,n=t.dataPointIndex,r=t.w;return e._getBoxTooltip(r,i,n,["Open","High","","Low","Close"],"candlestick")}},states:{active:{filter:{type:"none"}}},xaxis:{crosshairs:{width:1}}}}},{key:"boxPlot",value:function(){var e=this;return{chart:{animations:{dynamicAnimation:{enabled:!1}}},stroke:{width:1,colors:["#24292e"]},dataLabels:{enabled:!1},tooltip:{shared:!0,custom:function(t){var i=t.seriesIndex,n=t.dataPointIndex,r=t.w;return e._getBoxTooltip(r,i,n,["Minimum","Q1","Median","Q3","Maximum"],"boxPlot")}},markers:{size:5,strokeWidth:1,strokeColors:"#111"},xaxis:{crosshairs:{width:1}}}}},{key:"rangeBar",value:function(){return{chart:{animations:{animateGradually:!1}},stroke:{width:0,lineCap:"square"},plotOptions:{bar:{borderRadius:0,dataLabels:{position:"center"}}},dataLabels:{enabled:!1,formatter:function(e,t){t.ctx;var i=t.seriesIndex,n=t.dataPointIndex,r=t.w,a=function(){var e=r.globals.seriesRangeStart[i][n];return r.globals.seriesRangeEnd[i][n]-e};return r.globals.comboCharts?"rangeBar"===r.config.series[i].type||"rangeArea"===r.config.series[i].type?a():e:a()},background:{enabled:!1},style:{colors:["#fff"]}},markers:{size:10},tooltip:{shared:!1,followCursor:!0,custom:function(e){return e.w.config.plotOptions&&e.w.config.plotOptions.bar&&e.w.config.plotOptions.bar.horizontal?function(e){var i=E(t(t({},e),{},{isTimeline:!0})),n=i.color,r=i.seriesName,a=i.ylabel,s=i.startVal,o=i.endVal;return O(t(t({},e),{},{color:n,seriesName:r,ylabel:a,start:s,end:o}))}(e):function(e){var i=E(e),n=i.color,r=i.seriesName,a=i.ylabel,s=i.start,o=i.end;return O(t(t({},e),{},{color:n,seriesName:r,ylabel:a,start:s,end:o}))}(e)}},xaxis:{tickPlacement:"between",tooltip:{enabled:!1},crosshairs:{stroke:{width:0}}}}}},{key:"dumbbell",value:function(e){var t,i;return null!==(t=e.plotOptions.bar)&&void 0!==t&&t.barHeight||(e.plotOptions.bar.barHeight=2),null!==(i=e.plotOptions.bar)&&void 0!==i&&i.columnWidth||(e.plotOptions.bar.columnWidth=2),e}},{key:"area",value:function(){return{stroke:{width:4,fill:{type:"solid",gradient:{inverseColors:!1,shade:"light",type:"vertical",opacityFrom:.65,opacityTo:.5,stops:[0,100,100]}}},fill:{type:"gradient",gradient:{inverseColors:!1,shade:"light",type:"vertical",opacityFrom:.65,opacityTo:.5,stops:[0,100,100]}},markers:{size:0,hover:{sizeOffset:6}},tooltip:{followCursor:!1}}}},{key:"rangeArea",value:function(){return{stroke:{curve:"straight",width:0},fill:{type:"solid",opacity:.6},markers:{size:0},states:{hover:{filter:{type:"none"}},active:{filter:{type:"none"}}},tooltip:{intersect:!1,shared:!0,followCursor:!0,custom:function(e){return function(e){var i=E(e),n=i.color,r=i.seriesName,a=i.ylabel,s=i.start,o=i.end;return O(t(t({},e),{},{color:n,seriesName:r,ylabel:a,start:s,end:o}))}(e)}}}}},{key:"brush",value:function(e){return g.extend(e,{chart:{toolbar:{autoSelected:"selection",show:!1},zoom:{enabled:!1}},dataLabels:{enabled:!1},stroke:{width:1},tooltip:{enabled:!1},xaxis:{tooltip:{enabled:!1}}})}},{key:"stacked100",value:function(e){e.dataLabels=e.dataLabels||{},e.dataLabels.formatter=e.dataLabels.formatter||void 0;var t=e.dataLabels.formatter;return e.yaxis.forEach((function(t,i){e.yaxis[i].min=0,e.yaxis[i].max=100})),"bar"===e.chart.type&&(e.dataLabels.formatter=t||function(e){return"number"==typeof e&&e?e.toFixed(0)+"%":e}),e}},{key:"stackedBars",value:function(){var e=this.bar();return t(t({},e),{},{plotOptions:t(t({},e.plotOptions),{},{bar:t(t({},e.plotOptions.bar),{},{borderRadiusApplication:"end",borderRadiusWhenStacked:"last"})})})}},{key:"convertCatToNumeric",value:function(e){return e.xaxis.convertedCatToNumeric=!0,e}},{key:"convertCatToNumericXaxis",value:function(e,t,i){e.xaxis.type="numeric",e.xaxis.labels=e.xaxis.labels||{},e.xaxis.labels.formatter=e.xaxis.labels.formatter||function(e){return g.isNumber(e)?Math.floor(e):e};var n=e.xaxis.labels.formatter,r=e.xaxis.categories&&e.xaxis.categories.length?e.xaxis.categories:e.labels;return i&&i.length&&(r=i.map((function(e){return Array.isArray(e)?e:String(e)}))),r&&r.length&&(e.xaxis.labels.formatter=function(e){return g.isNumber(e)?n(r[Math.floor(e)-1]):n(e)}),e.xaxis.categories=[],e.labels=[],e.xaxis.tickAmount=e.xaxis.tickAmount||"dataPoints",e}},{key:"bubble",value:function(){return{dataLabels:{style:{colors:["#fff"]}},tooltip:{shared:!1,intersect:!0},xaxis:{crosshairs:{width:0}},fill:{type:"solid",gradient:{shade:"light",inverse:!0,shadeIntensity:.55,opacityFrom:.4,opacityTo:.8}}}}},{key:"scatter",value:function(){return{dataLabels:{enabled:!1},tooltip:{shared:!1,intersect:!0},markers:{size:6,strokeWidth:1,hover:{sizeOffset:2}}}}},{key:"heatmap",value:function(){return{chart:{stacked:!1},fill:{opacity:1},dataLabels:{style:{colors:["#fff"]}},stroke:{colors:["#fff"]},tooltip:{followCursor:!0,marker:{show:!1},x:{show:!1}},legend:{position:"top",markers:{shape:"square",size:10,offsetY:2}},grid:{padding:{right:20}}}}},{key:"treemap",value:function(){return{chart:{zoom:{enabled:!1}},dataLabels:{style:{fontSize:14,fontWeight:600,colors:["#fff"]}},stroke:{show:!0,width:2,colors:["#fff"]},legend:{show:!1},fill:{gradient:{stops:[0,100]}},tooltip:{followCursor:!0,x:{show:!1}},grid:{padding:{left:0,right:0}},xaxis:{crosshairs:{show:!1},tooltip:{enabled:!1}}}}},{key:"pie",value:function(){return{chart:{toolbar:{show:!1}},plotOptions:{pie:{donut:{labels:{show:!1}}}},dataLabels:{formatter:function(e){return e.toFixed(1)+"%"},style:{colors:["#fff"]},background:{enabled:!1},dropShadow:{enabled:!0}},stroke:{colors:["#fff"]},fill:{opacity:1,gradient:{shade:"light",stops:[0,100]}},tooltip:{theme:"dark",fillSeriesColor:!0},legend:{position:"right"}}}},{key:"donut",value:function(){return{chart:{toolbar:{show:!1}},dataLabels:{formatter:function(e){return e.toFixed(1)+"%"},style:{colors:["#fff"]},background:{enabled:!1},dropShadow:{enabled:!0}},stroke:{colors:["#fff"]},fill:{opacity:1,gradient:{shade:"light",shadeIntensity:.35,stops:[80,100],opacityFrom:1,opacityTo:1}},tooltip:{theme:"dark",fillSeriesColor:!0},legend:{position:"right"}}}},{key:"polarArea",value:function(){return{chart:{toolbar:{show:!1}},dataLabels:{formatter:function(e){return e.toFixed(1)+"%"},enabled:!1},stroke:{show:!0,width:2},fill:{opacity:.7},tooltip:{theme:"dark",fillSeriesColor:!0},legend:{position:"right"}}}},{key:"radar",value:function(){return this.opts.yaxis[0].labels.offsetY=this.opts.yaxis[0].labels.offsetY?this.opts.yaxis[0].labels.offsetY:6,{dataLabels:{enabled:!1,style:{fontSize:"11px"}},stroke:{width:2},markers:{size:3,strokeWidth:1,strokeOpacity:1},fill:{opacity:.2},tooltip:{shared:!1,intersect:!0,followCursor:!0},grid:{show:!1},xaxis:{labels:{formatter:function(e){return e},style:{colors:["#a8a8a8"],fontSize:"11px"}},tooltip:{enabled:!1},crosshairs:{show:!1}}}}},{key:"radialBar",value:function(){return{chart:{animations:{dynamicAnimation:{enabled:!0,speed:800}},toolbar:{show:!1}},fill:{gradient:{shade:"dark",shadeIntensity:.4,inverseColors:!1,type:"diagonal2",opacityFrom:1,opacityTo:1,stops:[70,98,100]}},legend:{show:!1,position:"right"},tooltip:{enabled:!1,fillSeriesColor:!0}}}},{key:"_getBoxTooltip",value:function(e,t,i,n,r){var a=e.globals.seriesCandleO[t][i],s=e.globals.seriesCandleH[t][i],o=e.globals.seriesCandleM[t][i],l=e.globals.seriesCandleL[t][i],c=e.globals.seriesCandleC[t][i];return e.config.series[t].type&&e.config.series[t].type!==r?'<div class="apexcharts-custom-tooltip">\n          '.concat(e.config.series[t].name?e.config.series[t].name:"series-"+(t+1),": <strong>").concat(e.globals.series[t][i],"</strong>\n        </div>"):'<div class="apexcharts-tooltip-box apexcharts-tooltip-'.concat(e.config.chart.type,'">')+"<div>".concat(n[0],': <span class="value">')+a+"</span></div>"+"<div>".concat(n[1],': <span class="value">')+s+"</span></div>"+(o?"<div>".concat(n[2],': <span class="value">')+o+"</span></div>":"")+"<div>".concat(n[3],': <span class="value">')+l+"</span></div>"+"<div>".concat(n[4],': <span class="value">')+c+"</span></div></div>"}}]),e}(),Y=function(){function e(t){n(this,e),this.opts=t}return a(e,[{key:"init",value:function(e){var t=e.responsiveOverride,n=this.opts,r=new C,a=new P(n);this.chartType=n.chart.type,n=this.extendYAxis(n),n=this.extendAnnotations(n);var s=r.init(),o={};if(n&&"object"===i(n)){var l,c,u,d,h,f,p,m,v,y,b={};b=-1!==["line","area","bar","candlestick","boxPlot","rangeBar","rangeArea","bubble","scatter","heatmap","treemap","pie","polarArea","donut","radar","radialBar"].indexOf(n.chart.type)?a[n.chart.type]():a.line(),null!==(l=n.plotOptions)&&void 0!==l&&null!==(c=l.bar)&&void 0!==c&&c.isFunnel&&(b=a.funnel()),n.chart.stacked&&"bar"===n.chart.type&&(b=a.stackedBars()),null!==(u=n.chart.brush)&&void 0!==u&&u.enabled&&(b=a.brush(b)),null!==(d=n.plotOptions)&&void 0!==d&&null!==(h=d.line)&&void 0!==h&&h.isSlopeChart&&(b=a.slope()),n.chart.stacked&&"100%"===n.chart.stackType&&(n=a.stacked100(n)),null!==(f=n.plotOptions)&&void 0!==f&&null!==(p=f.bar)&&void 0!==p&&p.isDumbbell&&(n=a.dumbbell(n)),this.checkForDarkTheme(window.Apex),this.checkForDarkTheme(n),n.xaxis=n.xaxis||window.Apex.xaxis||{},t||(n.xaxis.convertedCatToNumeric=!1),(null!==(m=(n=this.checkForCatToNumericXAxis(this.chartType,b,n)).chart.sparkline)&&void 0!==m&&m.enabled||null!==(v=window.Apex.chart)&&void 0!==v&&null!==(y=v.sparkline)&&void 0!==y&&y.enabled)&&(b=a.sparkline(b)),o=g.extend(s,b)}var x=g.extend(o,window.Apex);return s=g.extend(x,n),this.handleUserInputErrors(s)}},{key:"checkForCatToNumericXAxis",value:function(e,t,i){var n,r,a=new P(i),s=("bar"===e||"boxPlot"===e)&&(null===(n=i.plotOptions)||void 0===n||null===(r=n.bar)||void 0===r?void 0:r.horizontal),o="pie"===e||"polarArea"===e||"donut"===e||"radar"===e||"radialBar"===e||"heatmap"===e,l="datetime"!==i.xaxis.type&&"numeric"!==i.xaxis.type,c=i.xaxis.tickPlacement?i.xaxis.tickPlacement:t.xaxis&&t.xaxis.tickPlacement;return s||o||!l||"between"===c||(i=a.convertCatToNumeric(i)),i}},{key:"extendYAxis",value:function(e,t){var i=new C;(void 0===e.yaxis||!e.yaxis||Array.isArray(e.yaxis)&&0===e.yaxis.length)&&(e.yaxis={}),e.yaxis.constructor!==Array&&window.Apex.yaxis&&window.Apex.yaxis.constructor!==Array&&(e.yaxis=g.extend(e.yaxis,window.Apex.yaxis)),e.yaxis.constructor!==Array?e.yaxis=[g.extend(i.yAxis,e.yaxis)]:e.yaxis=g.extendArray(e.yaxis,i.yAxis);var n=!1;e.yaxis.forEach((function(e){e.logarithmic&&(n=!0)}));var r=e.series;return t&&!r&&(r=t.config.series),n&&r.length!==e.yaxis.length&&r.length&&(e.yaxis=r.map((function(t,n){if(t.name||(r[n].name="series-".concat(n+1)),e.yaxis[n])return e.yaxis[n].seriesName=r[n].name,e.yaxis[n];var a=g.extend(i.yAxis,e.yaxis[0]);return a.show=!1,a}))),n&&r.length>1&&r.length!==e.yaxis.length&&console.warn("A multi-series logarithmic chart should have equal number of series and y-axes"),e}},{key:"extendAnnotations",value:function(e){return void 0===e.annotations&&(e.annotations={},e.annotations.yaxis=[],e.annotations.xaxis=[],e.annotations.points=[]),e=this.extendYAxisAnnotations(e),e=this.extendXAxisAnnotations(e),this.extendPointAnnotations(e)}},{key:"extendYAxisAnnotations",value:function(e){var t=new C;return e.annotations.yaxis=g.extendArray(void 0!==e.annotations.yaxis?e.annotations.yaxis:[],t.yAxisAnnotation),e}},{key:"extendXAxisAnnotations",value:function(e){var t=new C;return e.annotations.xaxis=g.extendArray(void 0!==e.annotations.xaxis?e.annotations.xaxis:[],t.xAxisAnnotation),e}},{key:"extendPointAnnotations",value:function(e){var t=new C;return e.annotations.points=g.extendArray(void 0!==e.annotations.points?e.annotations.points:[],t.pointAnnotation),e}},{key:"checkForDarkTheme",value:function(e){e.theme&&"dark"===e.theme.mode&&(e.tooltip||(e.tooltip={}),"light"!==e.tooltip.theme&&(e.tooltip.theme="dark"),e.chart.foreColor||(e.chart.foreColor="#f6f7f8"),e.chart.background||(e.chart.background="#424242"),e.theme.palette||(e.theme.palette="palette4"))}},{key:"handleUserInputErrors",value:function(e){var t=e;if(t.tooltip.shared&&t.tooltip.intersect)throw new Error("tooltip.shared cannot be enabled when tooltip.intersect is true. Turn off any other option by setting it to false.");if("bar"===t.chart.type&&t.plotOptions.bar.horizontal){if(t.yaxis.length>1)throw new Error("Multiple Y Axis for bars are not supported. Switch to column chart by setting plotOptions.bar.horizontal=false");t.yaxis[0].reversed&&(t.yaxis[0].opposite=!0),t.xaxis.tooltip.enabled=!1,t.yaxis[0].tooltip.enabled=!1,t.chart.zoom.enabled=!1}return"bar"!==t.chart.type&&"rangeBar"!==t.chart.type||t.tooltip.shared&&"barWidth"===t.xaxis.crosshairs.width&&t.series.length>1&&(t.xaxis.crosshairs.width="tickWidth"),"candlestick"!==t.chart.type&&"boxPlot"!==t.chart.type||t.yaxis[0].reversed&&(console.warn("Reversed y-axis in ".concat(t.chart.type," chart is not supported.")),t.yaxis[0].reversed=!1),t}}]),e}(),I=function(){function e(){n(this,e)}return a(e,[{key:"initGlobalVars",value:function(e){e.series=[],e.seriesCandleO=[],e.seriesCandleH=[],e.seriesCandleM=[],e.seriesCandleL=[],e.seriesCandleC=[],e.seriesRangeStart=[],e.seriesRangeEnd=[],e.seriesRange=[],e.seriesPercent=[],e.seriesGoals=[],e.seriesX=[],e.seriesZ=[],e.seriesNames=[],e.seriesTotals=[],e.seriesLog=[],e.seriesColors=[],e.stackedSeriesTotals=[],e.seriesXvalues=[],e.seriesYvalues=[],e.labels=[],e.hasXaxisGroups=!1,e.groups=[],e.barGroups=[],e.lineGroups=[],e.areaGroups=[],e.hasSeriesGroups=!1,e.seriesGroups=[],e.categoryLabels=[],e.timescaleLabels=[],e.noLabelsProvided=!1,e.resizeTimer=null,e.selectionResizeTimer=null,e.delayedElements=[],e.pointsArray=[],e.dataLabelsRects=[],e.isXNumeric=!1,e.skipLastTimelinelabel=!1,e.skipFirstTimelinelabel=!1,e.isDataXYZ=!1,e.isMultiLineX=!1,e.isMultipleYAxis=!1,e.maxY=-Number.MAX_VALUE,e.minY=Number.MIN_VALUE,e.minYArr=[],e.maxYArr=[],e.maxX=-Number.MAX_VALUE,e.minX=Number.MAX_VALUE,e.initialMaxX=-Number.MAX_VALUE,e.initialMinX=Number.MAX_VALUE,e.maxDate=0,e.minDate=Number.MAX_VALUE,e.minZ=Number.MAX_VALUE,e.maxZ=-Number.MAX_VALUE,e.minXDiff=Number.MAX_VALUE,e.yAxisScale=[],e.xAxisScale=null,e.xAxisTicksPositions=[],e.yLabelsCoords=[],e.yTitleCoords=[],e.barPadForNumericAxis=0,e.padHorizontal=0,e.xRange=0,e.yRange=[],e.zRange=0,e.dataPoints=0,e.xTickAmount=0,e.multiAxisTickAmount=0}},{key:"globalVars",value:function(e){return{chartID:null,cuid:null,events:{beforeMount:[],mounted:[],updated:[],clicked:[],selection:[],dataPointSelection:[],zoomed:[],scrolled:[]},colors:[],clientX:null,clientY:null,fill:{colors:[]},stroke:{colors:[]},dataLabels:{style:{colors:[]}},radarPolygons:{fill:{colors:[]}},markers:{colors:[],size:e.markers.size,largestSize:0},animationEnded:!1,isTouchDevice:"ontouchstart"in window||navigator.msMaxTouchPoints,isDirty:!1,isExecCalled:!1,initialConfig:null,initialSeries:[],lastXAxis:[],lastYAxis:[],columnSeries:null,labels:[],timescaleLabels:[],noLabelsProvided:!1,allSeriesCollapsed:!1,collapsedSeries:[],collapsedSeriesIndices:[],ancillaryCollapsedSeries:[],ancillaryCollapsedSeriesIndices:[],risingSeries:[],dataFormatXNumeric:!1,capturedSeriesIndex:-1,capturedDataPointIndex:-1,selectedDataPoints:[],goldenPadding:35,invalidLogScale:!1,ignoreYAxisIndexes:[],maxValsInArrayIndex:0,radialSize:0,selection:void 0,zoomEnabled:"zoom"===e.chart.toolbar.autoSelected&&e.chart.toolbar.tools.zoom&&e.chart.zoom.enabled,panEnabled:"pan"===e.chart.toolbar.autoSelected&&e.chart.toolbar.tools.pan,selectionEnabled:"selection"===e.chart.toolbar.autoSelected&&e.chart.toolbar.tools.selection,yaxis:null,mousedown:!1,lastClientPosition:{},visibleXRange:void 0,yValueDecimal:0,total:0,SVGNS:"http://www.w3.org/2000/svg",svgWidth:0,svgHeight:0,noData:!1,locale:{},dom:{},memory:{methodsToExec:[]},shouldAnimate:!0,skipLastTimelinelabel:!1,skipFirstTimelinelabel:!1,delayedElements:[],axisCharts:!0,isDataXYZ:!1,isSlopeChart:e.plotOptions.line.isSlopeChart,resized:!1,resizeTimer:null,comboCharts:!1,dataChanged:!1,previousPaths:[],allSeriesHasEqualX:!0,pointsArray:[],dataLabelsRects:[],lastDrawnDataLabelsIndexes:[],hasNullValues:!1,easing:null,zoomed:!1,gridWidth:0,gridHeight:0,rotateXLabels:!1,defaultLabels:!1,xLabelFormatter:void 0,yLabelFormatters:[],xaxisTooltipFormatter:void 0,ttKeyFormatter:void 0,ttVal:void 0,ttZFormatter:void 0,LINE_HEIGHT_RATIO:1.618,xAxisLabelsHeight:0,xAxisGroupLabelsHeight:0,xAxisLabelsWidth:0,yAxisLabelsWidth:0,scaleX:1,scaleY:1,translateX:0,translateY:0,translateYAxisX:[],yAxisWidths:[],translateXAxisY:0,translateXAxisX:0,tooltip:null,niceScaleAllowedMagMsd:[[1,1,2,5,5,5,10,10,10,10,10],[1,1,2,5,5,5,10,10,10,10,10]],niceScaleDefaultTicks:[1,2,4,4,6,6,6,6,6,6,6,6,6,6,6,6,6,6,12,12,12,12,12,12,12,12,12,24],seriesYAxisMap:[],seriesYAxisReverseMap:[]}}},{key:"init",value:function(e){var t=this.globalVars(e);return this.initGlobalVars(t),t.initialConfig=g.extend({},e),t.initialSeries=g.clone(e.series),t.lastXAxis=g.clone(t.initialConfig.xaxis),t.lastYAxis=g.clone(t.initialConfig.yaxis),t}}]),e}(),N=function(){function e(t){n(this,e),this.opts=t}return a(e,[{key:"init",value:function(){var e=new Y(this.opts).init({responsiveOverride:!1});return{config:e,globals:(new I).init(e)}}}]),e}(),j=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.opts=null,this.seriesIndex=0}return a(e,[{key:"clippedImgArea",value:function(e){var t=this.w,i=t.config,n=parseInt(t.globals.gridWidth,10),r=parseInt(t.globals.gridHeight,10),a=n>r?n:r,s=e.image,o=0,l=0;void 0===e.width&&void 0===e.height?void 0!==i.fill.image.width&&void 0!==i.fill.image.height?(o=i.fill.image.width+1,l=i.fill.image.height):(o=a+1,l=a):(o=e.width,l=e.height);var c=document.createElementNS(t.globals.SVGNS,"pattern");b.setAttrs(c,{id:e.patternID,patternUnits:e.patternUnits?e.patternUnits:"userSpaceOnUse",width:o+"px",height:l+"px"});var u=document.createElementNS(t.globals.SVGNS,"image");c.appendChild(u),u.setAttributeNS(window.SVG.xlink,"href",s),b.setAttrs(u,{x:0,y:0,preserveAspectRatio:"none",width:o+"px",height:l+"px"}),u.style.opacity=e.opacity,t.globals.dom.elDefs.node.appendChild(c)}},{key:"getSeriesIndex",value:function(e){var t=this.w,i=t.config.chart.type;return("bar"===i||"rangeBar"===i)&&t.config.plotOptions.bar.distributed||"heatmap"===i||"treemap"===i?this.seriesIndex=e.seriesNumber:this.seriesIndex=e.seriesNumber%t.globals.series.length,this.seriesIndex}},{key:"fillPath",value:function(e){var t=this.w;this.opts=e;var i,n,r,a=this.w.config;this.seriesIndex=this.getSeriesIndex(e);var s=this.getFillColors()[this.seriesIndex];void 0!==t.globals.seriesColors[this.seriesIndex]&&(s=t.globals.seriesColors[this.seriesIndex]),"function"==typeof s&&(s=s({seriesIndex:this.seriesIndex,dataPointIndex:e.dataPointIndex,value:e.value,w:t}));var o=e.fillType?e.fillType:this.getFillType(this.seriesIndex),l=Array.isArray(a.fill.opacity)?a.fill.opacity[this.seriesIndex]:a.fill.opacity;e.color&&(s=e.color),s||(s="#fff",console.warn("undefined color - ApexCharts"));var c=s;if(-1===s.indexOf("rgb")?s.length<9&&(c=g.hexToRgba(s,l)):s.indexOf("rgba")>-1&&(l=g.getOpacityFromRGBA(s)),e.opacity&&(l=e.opacity),"pattern"===o&&(n=this.handlePatternFill({fillConfig:e.fillConfig,patternFill:n,fillColor:s,fillOpacity:l,defaultColor:c})),"gradient"===o&&(r=this.handleGradientFill({fillConfig:e.fillConfig,fillColor:s,fillOpacity:l,i:this.seriesIndex})),"image"===o){var u=a.fill.image.src,d=e.patternID?e.patternID:"";this.clippedImgArea({opacity:l,image:Array.isArray(u)?e.seriesNumber<u.length?u[e.seriesNumber]:u[0]:u,width:e.width?e.width:void 0,height:e.height?e.height:void 0,patternUnits:e.patternUnits,patternID:"pattern".concat(t.globals.cuid).concat(e.seriesNumber+1).concat(d)}),i="url(#pattern".concat(t.globals.cuid).concat(e.seriesNumber+1).concat(d,")")}else i="gradient"===o?r:"pattern"===o?n:c;return e.solid&&(i=c),i}},{key:"getFillType",value:function(e){var t=this.w;return Array.isArray(t.config.fill.type)?t.config.fill.type[e]:t.config.fill.type}},{key:"getFillColors",value:function(){var e=this.w,t=e.config,i=this.opts,n=[];return e.globals.comboCharts?"line"===e.config.series[this.seriesIndex].type?Array.isArray(e.globals.stroke.colors)?n=e.globals.stroke.colors:n.push(e.globals.stroke.colors):Array.isArray(e.globals.fill.colors)?n=e.globals.fill.colors:n.push(e.globals.fill.colors):"line"===t.chart.type?Array.isArray(e.globals.stroke.colors)?n=e.globals.stroke.colors:n.push(e.globals.stroke.colors):Array.isArray(e.globals.fill.colors)?n=e.globals.fill.colors:n.push(e.globals.fill.colors),void 0!==i.fillColors&&(n=[],Array.isArray(i.fillColors)?n=i.fillColors.slice():n.push(i.fillColors)),n}},{key:"handlePatternFill",value:function(e){var t=e.fillConfig,i=(e.patternFill,e.fillColor),n=e.fillOpacity,r=e.defaultColor,a=this.w.config.fill;t&&(a=t);var s=this.opts,o=new b(this.ctx),l=Array.isArray(a.pattern.strokeWidth)?a.pattern.strokeWidth[this.seriesIndex]:a.pattern.strokeWidth,c=i;return Array.isArray(a.pattern.style)?void 0!==a.pattern.style[s.seriesNumber]?o.drawPattern(a.pattern.style[s.seriesNumber],a.pattern.width,a.pattern.height,c,l,n):r:o.drawPattern(a.pattern.style,a.pattern.width,a.pattern.height,c,l,n)}},{key:"handleGradientFill",value:function(e){var i=e.fillColor,n=e.fillOpacity,r=e.fillConfig,a=e.i,s=this.w.config.fill;r&&(s=t(t({},s),r));var o,l=this.opts,c=new b(this.ctx),u=new g,d=s.gradient.type,h=i,f=void 0===s.gradient.opacityFrom?n:Array.isArray(s.gradient.opacityFrom)?s.gradient.opacityFrom[a]:s.gradient.opacityFrom;h.indexOf("rgba")>-1&&(f=g.getOpacityFromRGBA(h));var p=void 0===s.gradient.opacityTo?n:Array.isArray(s.gradient.opacityTo)?s.gradient.opacityTo[a]:s.gradient.opacityTo;if(void 0===s.gradient.gradientToColors||0===s.gradient.gradientToColors.length)o="dark"===s.gradient.shade?u.shadeColor(-1*parseFloat(s.gradient.shadeIntensity),i.indexOf("rgb")>-1?g.rgb2hex(i):i):u.shadeColor(parseFloat(s.gradient.shadeIntensity),i.indexOf("rgb")>-1?g.rgb2hex(i):i);else if(s.gradient.gradientToColors[l.seriesNumber]){var m=s.gradient.gradientToColors[l.seriesNumber];o=m,m.indexOf("rgba")>-1&&(p=g.getOpacityFromRGBA(m))}else o=i;if(s.gradient.gradientFrom&&(h=s.gradient.gradientFrom),s.gradient.gradientTo&&(o=s.gradient.gradientTo),s.gradient.inverseColors){var v=h;h=o,o=v}return h.indexOf("rgb")>-1&&(h=g.rgb2hex(h)),o.indexOf("rgb")>-1&&(o=g.rgb2hex(o)),c.drawGradient(d,h,o,f,p,l.size,s.gradient.stops,s.gradient.colorStops,a)}}]),e}(),H=function(){function e(t,i){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"setGlobalMarkerSize",value:function(){var e=this.w;if(e.globals.markers.size=Array.isArray(e.config.markers.size)?e.config.markers.size:[e.config.markers.size],e.globals.markers.size.length>0){if(e.globals.markers.size.length<e.globals.series.length+1)for(var t=0;t<=e.globals.series.length;t++)void 0===e.globals.markers.size[t]&&e.globals.markers.size.push(e.globals.markers.size[0])}else e.globals.markers.size=e.config.series.map((function(t){return e.config.markers.size}))}},{key:"plotChartMarkers",value:function(e,t,i,n){var r,a=arguments.length>4&&void 0!==arguments[4]&&arguments[4],s=this.w,o=t,l=e,c=null,u=new b(this.ctx),d=s.config.markers.discrete&&s.config.markers.discrete.length;if((s.globals.markers.size[t]>0||a||d)&&(c=u.group({class:a||d?"":"apexcharts-series-markers"})).attr("clip-path","url(#gridRectMarkerMask".concat(s.globals.cuid,")")),Array.isArray(l.x))for(var h=0;h<l.x.length;h++){var f=i;1===i&&0===h&&(f=0),1===i&&1===h&&(f=1);var p="apexcharts-marker";if("line"!==s.config.chart.type&&"area"!==s.config.chart.type||s.globals.comboCharts||s.config.tooltip.intersect||(p+=" no-pointer-events"),(Array.isArray(s.config.markers.size)?s.globals.markers.size[t]>0:s.config.markers.size>0)||a||d){g.isNumber(l.y[h])?p+=" w".concat(g.randomId()):p="apexcharts-nullpoint";var m=this.getMarkerConfig({cssClass:p,seriesIndex:t,dataPointIndex:f});s.config.series[o].data[f]&&(s.config.series[o].data[f].fillColor&&(m.pointFillColor=s.config.series[o].data[f].fillColor),s.config.series[o].data[f].strokeColor&&(m.pointStrokeColor=s.config.series[o].data[f].strokeColor)),n&&(m.pSize=n),(l.x[h]<-s.globals.markers.largestSize||l.x[h]>s.globals.gridWidth+s.globals.markers.largestSize||l.y[h]<-s.globals.markers.largestSize||l.y[h]>s.globals.gridHeight+s.globals.markers.largestSize)&&(m.pSize=0),(r=u.drawMarker(l.x[h],l.y[h],m)).attr("rel",f),r.attr("j",f),r.attr("index",t),r.node.setAttribute("default-marker-size",m.pSize),new y(this.ctx).setSelectionFilter(r,t,f),this.addEvents(r),c&&c.add(r)}else void 0===s.globals.pointsArray[t]&&(s.globals.pointsArray[t]=[]),s.globals.pointsArray[t].push([l.x[h],l.y[h]])}return c}},{key:"getMarkerConfig",value:function(e){var t=e.cssClass,i=e.seriesIndex,n=e.dataPointIndex,r=void 0===n?null:n,a=e.finishRadius,s=void 0===a?null:a,o=this.w,l=this.getMarkerStyle(i),c=o.globals.markers.size[i],u=o.config.markers;return null!==r&&u.discrete.length&&u.discrete.map((function(e){e.seriesIndex===i&&e.dataPointIndex===r&&(l.pointStrokeColor=e.strokeColor,l.pointFillColor=e.fillColor,c=e.size,l.pointShape=e.shape)})),{pSize:null===s?c:s,pRadius:u.radius,width:Array.isArray(u.width)?u.width[i]:u.width,height:Array.isArray(u.height)?u.height[i]:u.height,pointStrokeWidth:Array.isArray(u.strokeWidth)?u.strokeWidth[i]:u.strokeWidth,pointStrokeColor:l.pointStrokeColor,pointFillColor:l.pointFillColor,shape:l.pointShape||(Array.isArray(u.shape)?u.shape[i]:u.shape),class:t,pointStrokeOpacity:Array.isArray(u.strokeOpacity)?u.strokeOpacity[i]:u.strokeOpacity,pointStrokeDashArray:Array.isArray(u.strokeDashArray)?u.strokeDashArray[i]:u.strokeDashArray,pointFillOpacity:Array.isArray(u.fillOpacity)?u.fillOpacity[i]:u.fillOpacity,seriesIndex:i}}},{key:"addEvents",value:function(e){var t=this.w,i=new b(this.ctx);e.node.addEventListener("mouseenter",i.pathMouseEnter.bind(this.ctx,e)),e.node.addEventListener("mouseleave",i.pathMouseLeave.bind(this.ctx,e)),e.node.addEventListener("mousedown",i.pathMouseDown.bind(this.ctx,e)),e.node.addEventListener("click",t.config.markers.onClick),e.node.addEventListener("dblclick",t.config.markers.onDblClick),e.node.addEventListener("touchstart",i.pathMouseDown.bind(this.ctx,e),{passive:!0})}},{key:"getMarkerStyle",value:function(e){var t=this.w,i=t.globals.markers.colors,n=t.config.markers.strokeColor||t.config.markers.strokeColors;return{pointStrokeColor:Array.isArray(n)?n[e]:n,pointFillColor:Array.isArray(i)?i[e]:i}}}]),e}(),F=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.initialAnim=this.w.config.chart.animations.enabled,this.dynamicAnim=this.initialAnim&&this.w.config.chart.animations.dynamicAnimation.enabled}return a(e,[{key:"draw",value:function(e,t,i){var n=this.w,r=new b(this.ctx),a=i.realIndex,s=i.pointsPos,o=i.zRatio,l=i.elParent,c=r.group({class:"apexcharts-series-markers apexcharts-series-".concat(n.config.chart.type)});if(c.attr("clip-path","url(#gridRectMarkerMask".concat(n.globals.cuid,")")),Array.isArray(s.x))for(var u=0;u<s.x.length;u++){var d=t+1,h=!0;0===t&&0===u&&(d=0),0===t&&1===u&&(d=1);var f=0,p=n.globals.markers.size[a];if(o!==1/0){var m=n.config.plotOptions.bubble;p=n.globals.seriesZ[a][d],m.zScaling&&(p/=o),m.minBubbleRadius&&p<m.minBubbleRadius&&(p=m.minBubbleRadius),m.maxBubbleRadius&&p>m.maxBubbleRadius&&(p=m.maxBubbleRadius)}n.config.chart.animations.enabled||(f=p);var g=s.x[u],v=s.y[u];if(f=f||0,null!==v&&void 0!==n.globals.series[a][d]||(h=!1),h){var y=this.drawPoint(g,v,f,p,a,d,t);c.add(y)}l.add(c)}}},{key:"drawPoint",value:function(e,t,i,n,r,a,s){var o=this.w,l=r,c=new v(this.ctx),u=new y(this.ctx),d=new j(this.ctx),h=new H(this.ctx),f=new b(this.ctx),p=h.getMarkerConfig({cssClass:"apexcharts-marker",seriesIndex:l,dataPointIndex:a,finishRadius:"bubble"===o.config.chart.type||o.globals.comboCharts&&o.config.series[r]&&"bubble"===o.config.series[r].type?n:null});n=p.pSize;var m,g=d.fillPath({seriesNumber:r,dataPointIndex:a,color:p.pointFillColor,patternUnits:"objectBoundingBox",value:o.globals.series[r][s]});if("circle"===p.shape?m=f.drawCircle(i):"square"!==p.shape&&"rect"!==p.shape||(m=f.drawRect(0,0,p.width-p.pointStrokeWidth/2,p.height-p.pointStrokeWidth/2,p.pRadius)),o.config.series[l].data[a]&&o.config.series[l].data[a].fillColor&&(g=o.config.series[l].data[a].fillColor),m.attr({x:e-p.width/2-p.pointStrokeWidth/2,y:t-p.height/2-p.pointStrokeWidth/2,cx:e,cy:t,fill:g,"fill-opacity":p.pointFillOpacity,stroke:p.pointStrokeColor,r:n,"stroke-width":p.pointStrokeWidth,"stroke-dasharray":p.pointStrokeDashArray,"stroke-opacity":p.pointStrokeOpacity}),o.config.chart.dropShadow.enabled){var x=o.config.chart.dropShadow;u.dropShadow(m,x,r)}if(!this.initialAnim||o.globals.dataChanged||o.globals.resized)o.globals.animationEnded=!0;else{var _=o.config.chart.animations.speed;c.animateMarker(m,0,"circle"===p.shape?n:{width:p.width,height:p.height},_,o.globals.easing,(function(){window.setTimeout((function(){c.animationCompleted(m)}),100)}))}if(o.globals.dataChanged&&"circle"===p.shape)if(this.dynamicAnim){var w,k,M,S,A=o.config.chart.animations.dynamicAnimation.speed;null!=(S=o.globals.previousPaths[r]&&o.globals.previousPaths[r][s])&&(w=S.x,k=S.y,M=void 0!==S.r?S.r:n);for(var L=0;L<o.globals.collapsedSeries.length;L++)o.globals.collapsedSeries[L].index===r&&(A=1,n=0);0===e&&0===t&&(n=0),c.animateCircle(m,{cx:w,cy:k,r:M},{cx:e,cy:t,r:n},A,o.globals.easing)}else m.attr({r:n});return m.attr({rel:a,j:a,index:r,"default-marker-size":n}),u.setSelectionFilter(m,r,a),h.addEvents(m),m.node.classList.add("apexcharts-marker"),m}},{key:"centerTextInBubble",value:function(e){var t=this.w;return{y:e+=parseInt(t.config.dataLabels.style.fontSize,10)/4}}}]),e}(),R=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"dataLabelsCorrection",value:function(e,t,i,n,r,a,s){var o=this.w,l=!1,c=new b(this.ctx).getTextRects(i,s),u=c.width,d=c.height;t<0&&(t=0),t>o.globals.gridHeight+d&&(t=o.globals.gridHeight+d/2),void 0===o.globals.dataLabelsRects[n]&&(o.globals.dataLabelsRects[n]=[]),o.globals.dataLabelsRects[n].push({x:e,y:t,width:u,height:d});var h=o.globals.dataLabelsRects[n].length-2,f=void 0!==o.globals.lastDrawnDataLabelsIndexes[n]?o.globals.lastDrawnDataLabelsIndexes[n][o.globals.lastDrawnDataLabelsIndexes[n].length-1]:0;if(void 0!==o.globals.dataLabelsRects[n][h]){var p=o.globals.dataLabelsRects[n][f];(e>p.x+p.width||t>p.y+p.height||t+d<p.y||e+u<p.x)&&(l=!0)}return(0===r||a)&&(l=!0),{x:e,y:t,textRects:c,drawnextLabel:l}}},{key:"drawDataLabel",value:function(e){var t=this,i=e.type,n=e.pos,r=e.i,a=e.j,s=e.isRangeStart,o=e.strokeWidth,l=void 0===o?2:o,c=this.w,u=new b(this.ctx),d=c.config.dataLabels,h=0,f=0,p=a,m=null;if(-1!==c.globals.collapsedSeriesIndices.indexOf(r)||!d.enabled||!Array.isArray(n.x))return m;m=u.group({class:"apexcharts-data-labels"});for(var g=0;g<n.x.length;g++)if(h=n.x[g]+d.offsetX,f=n.y[g]+d.offsetY+l,!isNaN(h)){1===a&&0===g&&(p=0),1===a&&1===g&&(p=1);var v=c.globals.series[r][p];"rangeArea"===i&&(v=s?c.globals.seriesRangeStart[r][p]:c.globals.seriesRangeEnd[r][p]);var y="",x=function(e){return c.config.dataLabels.formatter(e,{ctx:t.ctx,seriesIndex:r,dataPointIndex:p,w:c})};"bubble"===c.config.chart.type?(y=x(v=c.globals.seriesZ[r][p]),f=n.y[g],f=new F(this.ctx).centerTextInBubble(f,r,p).y):void 0!==v&&(y=x(v));var _=c.config.dataLabels.textAnchor;c.globals.isSlopeChart&&(_=0===p?"end":p===c.config.series[r].data.length-1?"start":"middle"),this.plotDataLabelsText({x:h,y:f,text:y,i:r,j:p,parent:m,offsetCorrection:!0,dataLabelsConfig:c.config.dataLabels,textAnchor:_})}return m}},{key:"plotDataLabelsText",value:function(e){var t=this.w,i=new b(this.ctx),n=e.x,r=e.y,a=e.i,s=e.j,o=e.text,l=e.textAnchor,c=e.fontSize,u=e.parent,d=e.dataLabelsConfig,h=e.color,f=e.alwaysDrawDataLabel,p=e.offsetCorrection;if(!(Array.isArray(t.config.dataLabels.enabledOnSeries)&&t.config.dataLabels.enabledOnSeries.indexOf(a)<0)){var m={x:n,y:r,drawnextLabel:!0,textRects:null};p&&(m=this.dataLabelsCorrection(n,r,o,a,s,f,parseInt(d.style.fontSize,10))),t.globals.zoomed||(n=m.x,r=m.y),m.textRects&&(n<-20-m.textRects.width||n>t.globals.gridWidth+m.textRects.width+30)&&(o="");var g=t.globals.dataLabels.style.colors[a];(("bar"===t.config.chart.type||"rangeBar"===t.config.chart.type)&&t.config.plotOptions.bar.distributed||t.config.dataLabels.distributed)&&(g=t.globals.dataLabels.style.colors[s]),"function"==typeof g&&(g=g({series:t.globals.series,seriesIndex:a,dataPointIndex:s,w:t})),h&&(g=h);var v=d.offsetX,x=d.offsetY;if("bar"!==t.config.chart.type&&"rangeBar"!==t.config.chart.type||(v=0,x=0),t.globals.isSlopeChart&&(0!==s&&(v=-2*d.offsetX+5),0!==s&&s!==t.config.series[a].data.length-1&&(v=0)),m.drawnextLabel){var _=i.drawText({width:100,height:parseInt(d.style.fontSize,10),x:n+v,y:r+x,foreColor:g,textAnchor:l||d.textAnchor,text:o,fontSize:c||d.style.fontSize,fontFamily:d.style.fontFamily,fontWeight:d.style.fontWeight||"normal"});if(_.attr({class:"apexcharts-datalabel",cx:n,cy:r}),d.dropShadow.enabled){var w=d.dropShadow;new y(this.ctx).dropShadow(_,w)}u.add(_),void 0===t.globals.lastDrawnDataLabelsIndexes[a]&&(t.globals.lastDrawnDataLabelsIndexes[a]=[]),t.globals.lastDrawnDataLabelsIndexes[a].push(s)}}}},{key:"addBackgroundToDataLabel",value:function(e,t){var i=this.w,n=i.config.dataLabels.background,r=n.padding,a=n.padding/2,s=t.width,o=t.height,l=new b(this.ctx).drawRect(t.x-r,t.y-a/2,s+2*r,o+a,n.borderRadius,"transparent"===i.config.chart.background?"#fff":i.config.chart.background,n.opacity,n.borderWidth,n.borderColor);return n.dropShadow.enabled&&new y(this.ctx).dropShadow(l,n.dropShadow),l}},{key:"dataLabelsBackground",value:function(){var e=this.w;if("bubble"!==e.config.chart.type)for(var t=e.globals.dom.baseEl.querySelectorAll(".apexcharts-datalabels text"),i=0;i<t.length;i++){var n=t[i],r=n.getBBox(),a=null;if(r.width&&r.height&&(a=this.addBackgroundToDataLabel(n,r)),a){n.parentNode.insertBefore(a.node,n);var s=n.getAttribute("fill");!e.config.chart.animations.enabled||e.globals.resized||e.globals.dataChanged?a.attr({fill:s}):a.animate().attr({fill:s}),n.setAttribute("fill",e.config.dataLabels.background.foreColor)}}}},{key:"bringForward",value:function(){for(var e=this.w,t=e.globals.dom.baseEl.querySelectorAll(".apexcharts-datalabels"),i=e.globals.dom.baseEl.querySelector(".apexcharts-plot-series:last-child"),n=0;n<t.length;n++)i&&i.insertBefore(t[n],i.nextSibling)}}]),e}(),z=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.legendInactiveClass="legend-mouseover-inactive"}return a(e,[{key:"getAllSeriesEls",value:function(){return this.w.globals.dom.baseEl.getElementsByClassName("apexcharts-series")}},{key:"getSeriesByName",value:function(e){return this.w.globals.dom.baseEl.querySelector(".apexcharts-inner .apexcharts-series[seriesName='".concat(g.escapeString(e),"']"))}},{key:"isSeriesHidden",value:function(e){var t=this.getSeriesByName(e),i=parseInt(t.getAttribute("data:realIndex"),10);return{isHidden:t.classList.contains("apexcharts-series-collapsed"),realIndex:i}}},{key:"addCollapsedClassToSeries",value:function(e,t){var i=this.w;function n(i){for(var n=0;n<i.length;n++)i[n].index===t&&e.node.classList.add("apexcharts-series-collapsed")}n(i.globals.collapsedSeries),n(i.globals.ancillaryCollapsedSeries)}},{key:"toggleSeries",value:function(e){var t=this.isSeriesHidden(e);return this.ctx.legend.legendHelpers.toggleDataSeries(t.realIndex,t.isHidden),t.isHidden}},{key:"showSeries",value:function(e){var t=this.isSeriesHidden(e);t.isHidden&&this.ctx.legend.legendHelpers.toggleDataSeries(t.realIndex,!0)}},{key:"hideSeries",value:function(e){var t=this.isSeriesHidden(e);t.isHidden||this.ctx.legend.legendHelpers.toggleDataSeries(t.realIndex,!1)}},{key:"resetSeries",value:function(){var e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0],t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=!(arguments.length>2&&void 0!==arguments[2])||arguments[2],n=this.w,r=g.clone(n.globals.initialSeries);n.globals.previousPaths=[],i?(n.globals.collapsedSeries=[],n.globals.ancillaryCollapsedSeries=[],n.globals.collapsedSeriesIndices=[],n.globals.ancillaryCollapsedSeriesIndices=[]):r=this.emptyCollapsedSeries(r),n.config.series=r,e&&(t&&(n.globals.zoomed=!1,this.ctx.updateHelpers.revertDefaultAxisMinMax()),this.ctx.updateHelpers._updateSeries(r,n.config.chart.animations.dynamicAnimation.enabled))}},{key:"emptyCollapsedSeries",value:function(e){for(var t=this.w,i=0;i<e.length;i++)t.globals.collapsedSeriesIndices.indexOf(i)>-1&&(e[i].data=[]);return e}},{key:"toggleSeriesOnHover",value:function(e,t){var i=this.w;t||(t=e.target);var n=i.globals.dom.baseEl.querySelectorAll(".apexcharts-series, .apexcharts-datalabels, .apexcharts-yaxis");if("mousemove"===e.type){var r=parseInt(t.getAttribute("rel"),10)-1,a=null,s=null,o=null;if(i.globals.axisCharts||"radialBar"===i.config.chart.type)if(i.globals.axisCharts){a=i.globals.dom.baseEl.querySelector(".apexcharts-series[data\\:realIndex='".concat(r,"']")),s=i.globals.dom.baseEl.querySelector(".apexcharts-datalabels[data\\:realIndex='".concat(r,"']"));var l=i.globals.seriesYAxisReverseMap[r];o=i.globals.dom.baseEl.querySelector(".apexcharts-yaxis[rel='".concat(l,"']"))}else a=i.globals.dom.baseEl.querySelector(".apexcharts-series[rel='".concat(r+1,"']"));else a=i.globals.dom.baseEl.querySelector(".apexcharts-series[rel='".concat(r+1,"'] path"));for(var c=0;c<n.length;c++)n[c].classList.add(this.legendInactiveClass);null!==a&&(i.globals.axisCharts||a.parentNode.classList.remove(this.legendInactiveClass),a.classList.remove(this.legendInactiveClass),null!==s&&s.classList.remove(this.legendInactiveClass),null!==o&&o.classList.remove(this.legendInactiveClass))}else if("mouseout"===e.type)for(var u=0;u<n.length;u++)n[u].classList.remove(this.legendInactiveClass)}},{key:"highlightRangeInSeries",value:function(e,t){var i=this,n=this.w,r=n.globals.dom.baseEl.getElementsByClassName("apexcharts-heatmap-rect"),a=function(e){for(var t=0;t<r.length;t++)r[t].classList[e](i.legendInactiveClass)};if("mousemove"===e.type){var s=parseInt(t.getAttribute("rel"),10)-1;a("add"),function(e){for(var t=0;t<r.length;t++){var n=parseInt(r[t].getAttribute("val"),10);n>=e.from&&n<=e.to&&r[t].classList.remove(i.legendInactiveClass)}}(n.config.plotOptions.heatmap.colorScale.ranges[s])}else"mouseout"===e.type&&a("remove")}},{key:"getActiveConfigSeriesIndex",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"asc",t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:[],i=this.w,n=0;if(i.config.series.length>1)for(var r=i.config.series.map((function(e,n){return e.data&&e.data.length>0&&-1===i.globals.collapsedSeriesIndices.indexOf(n)&&(!i.globals.comboCharts||0===t.length||t.length&&t.indexOf(i.config.series[n].type)>-1)?n:-1})),a="asc"===e?0:r.length-1;"asc"===e?a<r.length:a>=0;"asc"===e?a++:a--)if(-1!==r[a]){n=r[a];break}return n}},{key:"getBarSeriesIndices",value:function(){return this.w.globals.comboCharts?this.w.config.series.map((function(e,t){return"bar"===e.type||"column"===e.type?t:-1})).filter((function(e){return-1!==e})):this.w.config.series.map((function(e,t){return t}))}},{key:"getPreviousPaths",value:function(){var e=this.w;function t(t,i,n){for(var r=t[i].childNodes,a={type:n,paths:[],realIndex:t[i].getAttribute("data:realIndex")},s=0;s<r.length;s++)if(r[s].hasAttribute("pathTo")){var o=r[s].getAttribute("pathTo");a.paths.push({d:o})}e.globals.previousPaths.push(a)}e.globals.previousPaths=[],["line","area","bar","rangebar","rangeArea","candlestick","radar"].forEach((function(i){for(var n,r=(n=i,e.globals.dom.baseEl.querySelectorAll(".apexcharts-".concat(n,"-series .apexcharts-series"))),a=0;a<r.length;a++)t(r,a,i)})),this.handlePrevBubbleScatterPaths("bubble"),this.handlePrevBubbleScatterPaths("scatter");var i=e.globals.dom.baseEl.querySelectorAll(".apexcharts-".concat(e.config.chart.type," .apexcharts-series"));if(i.length>0)for(var n=function(t){for(var i=e.globals.dom.baseEl.querySelectorAll(".apexcharts-".concat(e.config.chart.type," .apexcharts-series[data\\:realIndex='").concat(t,"'] rect")),n=[],r=function(e){var t=function(t){return i[e].getAttribute(t)},r={x:parseFloat(t("x")),y:parseFloat(t("y")),width:parseFloat(t("width")),height:parseFloat(t("height"))};n.push({rect:r,color:i[e].getAttribute("color")})},a=0;a<i.length;a++)r(a);e.globals.previousPaths.push(n)},r=0;r<i.length;r++)n(r);e.globals.axisCharts||(e.globals.previousPaths=e.globals.series)}},{key:"handlePrevBubbleScatterPaths",value:function(e){var t=this.w,i=t.globals.dom.baseEl.querySelectorAll(".apexcharts-".concat(e,"-series .apexcharts-series"));if(i.length>0)for(var n=0;n<i.length;n++){for(var r=t.globals.dom.baseEl.querySelectorAll(".apexcharts-".concat(e,"-series .apexcharts-series[data\\:realIndex='").concat(n,"'] circle")),a=[],s=0;s<r.length;s++)a.push({x:r[s].getAttribute("cx"),y:r[s].getAttribute("cy"),r:r[s].getAttribute("r")});t.globals.previousPaths.push(a)}}},{key:"clearPreviousPaths",value:function(){var e=this.w;e.globals.previousPaths=[],e.globals.allSeriesCollapsed=!1}},{key:"handleNoData",value:function(){var e=this.w,t=e.config.noData,i=new b(this.ctx),n=e.globals.svgWidth/2,r=e.globals.svgHeight/2,a="middle";if(e.globals.noData=!0,e.globals.animationEnded=!0,"left"===t.align?(n=10,a="start"):"right"===t.align&&(n=e.globals.svgWidth-10,a="end"),"top"===t.verticalAlign?r=50:"bottom"===t.verticalAlign&&(r=e.globals.svgHeight-50),n+=t.offsetX,r=r+parseInt(t.style.fontSize,10)+2+t.offsetY,void 0!==t.text&&""!==t.text){var s=i.drawText({x:n,y:r,text:t.text,textAnchor:a,fontSize:t.style.fontSize,fontFamily:t.style.fontFamily,foreColor:t.style.color,opacity:1,class:"apexcharts-text-nodata"});e.globals.dom.Paper.add(s)}}},{key:"setNullSeriesToZeroValues",value:function(e){for(var t=this.w,i=0;i<e.length;i++)if(0===e[i].length)for(var n=0;n<e[t.globals.maxValsInArrayIndex].length;n++)e[i].push(0);return e}},{key:"hasAllSeriesEqualX",value:function(){for(var e=!0,t=this.w,i=this.filteredSeriesX(),n=0;n<i.length-1;n++)if(i[n][0]!==i[n+1][0]){e=!1;break}return t.globals.allSeriesHasEqualX=e,e}},{key:"filteredSeriesX",value:function(){return this.w.globals.seriesX.map((function(e){return e.length>0?e:[]}))}}]),e}(),B=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.twoDSeries=[],this.threeDSeries=[],this.twoDSeriesX=[],this.seriesGoals=[],this.coreUtils=new x(this.ctx)}return a(e,[{key:"isMultiFormat",value:function(){return this.isFormatXY()||this.isFormat2DArray()}},{key:"isFormatXY",value:function(){var e=this.w.config.series.slice(),t=new z(this.ctx);if(this.activeSeriesIndex=t.getActiveConfigSeriesIndex(),void 0!==e[this.activeSeriesIndex].data&&e[this.activeSeriesIndex].data.length>0&&null!==e[this.activeSeriesIndex].data[0]&&void 0!==e[this.activeSeriesIndex].data[0].x&&null!==e[this.activeSeriesIndex].data[0])return!0}},{key:"isFormat2DArray",value:function(){var e=this.w.config.series.slice(),t=new z(this.ctx);if(this.activeSeriesIndex=t.getActiveConfigSeriesIndex(),void 0!==e[this.activeSeriesIndex].data&&e[this.activeSeriesIndex].data.length>0&&void 0!==e[this.activeSeriesIndex].data[0]&&null!==e[this.activeSeriesIndex].data[0]&&e[this.activeSeriesIndex].data[0].constructor===Array)return!0}},{key:"handleFormat2DArray",value:function(e,t){for(var i=this.w.config,n=this.w.globals,r="boxPlot"===i.chart.type||"boxPlot"===i.series[t].type,a=0;a<e[t].data.length;a++)if(void 0!==e[t].data[a][1]&&(Array.isArray(e[t].data[a][1])&&4===e[t].data[a][1].length&&!r?this.twoDSeries.push(g.parseNumber(e[t].data[a][1][3])):e[t].data[a].length>=5?this.twoDSeries.push(g.parseNumber(e[t].data[a][4])):this.twoDSeries.push(g.parseNumber(e[t].data[a][1])),n.dataFormatXNumeric=!0),"datetime"===i.xaxis.type){var s=new Date(e[t].data[a][0]);s=new Date(s).getTime(),this.twoDSeriesX.push(s)}else this.twoDSeriesX.push(e[t].data[a][0]);for(var o=0;o<e[t].data.length;o++)void 0!==e[t].data[o][2]&&(this.threeDSeries.push(e[t].data[o][2]),n.isDataXYZ=!0)}},{key:"handleFormatXY",value:function(e,t){var i=this.w.config,n=this.w.globals,r=new k(this.ctx),a=t;n.collapsedSeriesIndices.indexOf(t)>-1&&(a=this.activeSeriesIndex);for(var s=0;s<e[t].data.length;s++)void 0!==e[t].data[s].y&&(Array.isArray(e[t].data[s].y)?this.twoDSeries.push(g.parseNumber(e[t].data[s].y[e[t].data[s].y.length-1])):this.twoDSeries.push(g.parseNumber(e[t].data[s].y))),void 0!==e[t].data[s].goals&&Array.isArray(e[t].data[s].goals)?(void 0===this.seriesGoals[t]&&(this.seriesGoals[t]=[]),this.seriesGoals[t].push(e[t].data[s].goals)):(void 0===this.seriesGoals[t]&&(this.seriesGoals[t]=[]),this.seriesGoals[t].push(null));for(var o=0;o<e[a].data.length;o++){var l="string"==typeof e[a].data[o].x,c=Array.isArray(e[a].data[o].x),u=!c&&!!r.isValidDate(e[a].data[o].x);if(l||u)if(l||i.xaxis.convertedCatToNumeric){var d=n.isBarHorizontal&&n.isRangeData;"datetime"!==i.xaxis.type||d?(this.fallbackToCategory=!0,this.twoDSeriesX.push(e[a].data[o].x),isNaN(e[a].data[o].x)||"category"===this.w.config.xaxis.type||"string"==typeof e[a].data[o].x||(n.isXNumeric=!0)):this.twoDSeriesX.push(r.parseDate(e[a].data[o].x))}else"datetime"===i.xaxis.type?this.twoDSeriesX.push(r.parseDate(e[a].data[o].x.toString())):(n.dataFormatXNumeric=!0,n.isXNumeric=!0,this.twoDSeriesX.push(parseFloat(e[a].data[o].x)));else c?(this.fallbackToCategory=!0,this.twoDSeriesX.push(e[a].data[o].x)):(n.isXNumeric=!0,n.dataFormatXNumeric=!0,this.twoDSeriesX.push(e[a].data[o].x))}if(e[t].data[0]&&void 0!==e[t].data[0].z){for(var h=0;h<e[t].data.length;h++)this.threeDSeries.push(e[t].data[h].z);n.isDataXYZ=!0}}},{key:"handleRangeData",value:function(e,t){var i=this.w.globals,n={};return this.isFormat2DArray()?n=this.handleRangeDataFormat("array",e,t):this.isFormatXY()&&(n=this.handleRangeDataFormat("xy",e,t)),i.seriesRangeStart.push(void 0===n.start?[]:n.start),i.seriesRangeEnd.push(void 0===n.end?[]:n.end),i.seriesRange.push(n.rangeUniques),i.seriesRange.forEach((function(e,t){e&&e.forEach((function(e,t){e.y.forEach((function(t,i){for(var n=0;n<e.y.length;n++)if(i!==n){var r=t.y1,a=t.y2,s=e.y[n].y1;r<=e.y[n].y2&&s<=a&&(e.overlaps.indexOf(t.rangeName)<0&&e.overlaps.push(t.rangeName),e.overlaps.indexOf(e.y[n].rangeName)<0&&e.overlaps.push(e.y[n].rangeName))}}))}))})),n}},{key:"handleCandleStickBoxData",value:function(e,t){var i=this.w.globals,n={};return this.isFormat2DArray()?n=this.handleCandleStickBoxDataFormat("array",e,t):this.isFormatXY()&&(n=this.handleCandleStickBoxDataFormat("xy",e,t)),i.seriesCandleO[t]=n.o,i.seriesCandleH[t]=n.h,i.seriesCandleM[t]=n.m,i.seriesCandleL[t]=n.l,i.seriesCandleC[t]=n.c,n}},{key:"handleRangeDataFormat",value:function(e,t,i){var n=[],r=[],a=t[i].data.filter((function(e,t,i){return t===i.findIndex((function(t){return t.x===e.x}))})).map((function(e,t){return{x:e.x,overlaps:[],y:[]}}));if("array"===e)for(var s=0;s<t[i].data.length;s++)Array.isArray(t[i].data[s])?(n.push(t[i].data[s][1][0]),r.push(t[i].data[s][1][1])):(n.push(t[i].data[s]),r.push(t[i].data[s]));else if("xy"===e)for(var o=function(e){var s=Array.isArray(t[i].data[e].y),o=g.randomId(),l=t[i].data[e].x,c={y1:s?t[i].data[e].y[0]:t[i].data[e].y,y2:s?t[i].data[e].y[1]:t[i].data[e].y,rangeName:o};t[i].data[e].rangeName=o;var u=a.findIndex((function(e){return e.x===l}));a[u].y.push(c),n.push(c.y1),r.push(c.y2)},l=0;l<t[i].data.length;l++)o(l);return{start:n,end:r,rangeUniques:a}}},{key:"handleCandleStickBoxDataFormat",value:function(e,t,i){var n=this.w,r="boxPlot"===n.config.chart.type||"boxPlot"===n.config.series[i].type,a=[],s=[],o=[],l=[],c=[];if("array"===e)if(r&&6===t[i].data[0].length||!r&&5===t[i].data[0].length)for(var u=0;u<t[i].data.length;u++)a.push(t[i].data[u][1]),s.push(t[i].data[u][2]),r?(o.push(t[i].data[u][3]),l.push(t[i].data[u][4]),c.push(t[i].data[u][5])):(l.push(t[i].data[u][3]),c.push(t[i].data[u][4]));else for(var d=0;d<t[i].data.length;d++)Array.isArray(t[i].data[d][1])&&(a.push(t[i].data[d][1][0]),s.push(t[i].data[d][1][1]),r?(o.push(t[i].data[d][1][2]),l.push(t[i].data[d][1][3]),c.push(t[i].data[d][1][4])):(l.push(t[i].data[d][1][2]),c.push(t[i].data[d][1][3])));else if("xy"===e)for(var h=0;h<t[i].data.length;h++)Array.isArray(t[i].data[h].y)&&(a.push(t[i].data[h].y[0]),s.push(t[i].data[h].y[1]),r?(o.push(t[i].data[h].y[2]),l.push(t[i].data[h].y[3]),c.push(t[i].data[h].y[4])):(l.push(t[i].data[h].y[2]),c.push(t[i].data[h].y[3])));return{o:a,h:s,m:o,l:l,c:c}}},{key:"parseDataAxisCharts",value:function(e){var t=this,i=arguments.length>1&&void 0!==arguments[1]?arguments[1]:this.ctx,n=this.w.config,r=this.w.globals,a=new k(i),s=n.labels.length>0?n.labels.slice():n.xaxis.categories.slice();r.isRangeBar="rangeBar"===n.chart.type&&r.isBarHorizontal,r.hasXaxisGroups="category"===n.xaxis.type&&n.xaxis.group.groups.length>0,r.hasXaxisGroups&&(r.groups=n.xaxis.group.groups),e.forEach((function(e,t){void 0!==e.name?r.seriesNames.push(e.name):r.seriesNames.push("series-"+parseInt(t+1,10))})),this.coreUtils.setSeriesYAxisMappings();var o=[],l=f(new Set(n.series.map((function(e){return e.group}))));n.series.forEach((function(e,t){var i=l.indexOf(e.group);o[i]||(o[i]=[]),o[i].push(r.seriesNames[t])})),r.seriesGroups=o;for(var c=function(){for(var e=0;e<s.length;e++)if("string"==typeof s[e]){if(!a.isValidDate(s[e]))throw new Error("You have provided invalid Date format. Please provide a valid JavaScript Date");t.twoDSeriesX.push(a.parseDate(s[e]))}else t.twoDSeriesX.push(s[e])},u=0;u<e.length;u++){if(this.twoDSeries=[],this.twoDSeriesX=[],this.threeDSeries=[],void 0===e[u].data)return void console.error("It is a possibility that you may have not included 'data' property in series.");if("rangeBar"!==n.chart.type&&"rangeArea"!==n.chart.type&&"rangeBar"!==e[u].type&&"rangeArea"!==e[u].type||(r.isRangeData=!0,"rangeBar"!==n.chart.type&&"rangeArea"!==n.chart.type||this.handleRangeData(e,u)),this.isMultiFormat())this.isFormat2DArray()?this.handleFormat2DArray(e,u):this.isFormatXY()&&this.handleFormatXY(e,u),"candlestick"!==n.chart.type&&"candlestick"!==e[u].type&&"boxPlot"!==n.chart.type&&"boxPlot"!==e[u].type||this.handleCandleStickBoxData(e,u),r.series.push(this.twoDSeries),r.labels.push(this.twoDSeriesX),r.seriesX.push(this.twoDSeriesX),r.seriesGoals=this.seriesGoals,u!==this.activeSeriesIndex||this.fallbackToCategory||(r.isXNumeric=!0);else{"datetime"===n.xaxis.type?(r.isXNumeric=!0,c(),r.seriesX.push(this.twoDSeriesX)):"numeric"===n.xaxis.type&&(r.isXNumeric=!0,s.length>0&&(this.twoDSeriesX=s,r.seriesX.push(this.twoDSeriesX))),r.labels.push(this.twoDSeriesX);var d=e[u].data.map((function(e){return g.parseNumber(e)}));r.series.push(d)}r.seriesZ.push(this.threeDSeries),void 0!==e[u].color?r.seriesColors.push(e[u].color):r.seriesColors.push(void 0)}return this.w}},{key:"parseDataNonAxisCharts",value:function(e){var t=this.w.globals,i=this.w.config;t.series=e.slice(),t.seriesNames=i.labels.slice();for(var n=0;n<t.series.length;n++)void 0===t.seriesNames[n]&&t.seriesNames.push("series-"+(n+1));return this.w}},{key:"handleExternalLabelsData",value:function(e){var t=this.w.config,i=this.w.globals;t.xaxis.categories.length>0?i.labels=t.xaxis.categories:t.labels.length>0?i.labels=t.labels.slice():this.fallbackToCategory?(i.labels=i.labels[0],i.seriesRange.length&&(i.seriesRange.map((function(e){e.forEach((function(e){i.labels.indexOf(e.x)<0&&e.x&&i.labels.push(e.x)}))})),i.labels=Array.from(new Set(i.labels.map(JSON.stringify)),JSON.parse)),t.xaxis.convertedCatToNumeric&&(new P(t).convertCatToNumericXaxis(t,this.ctx,i.seriesX[0]),this._generateExternalLabels(e))):this._generateExternalLabels(e)}},{key:"_generateExternalLabels",value:function(e){var t=this.w.globals,i=this.w.config,n=[];if(t.axisCharts){if(t.series.length>0)if(this.isFormatXY())for(var r=i.series.map((function(e,t){return e.data.filter((function(e,t,i){return i.findIndex((function(t){return t.x===e.x}))===t}))})),a=r.reduce((function(e,t,i,n){return n[e].length>t.length?e:i}),0),s=0;s<r[a].length;s++)n.push(s+1);else for(var o=0;o<t.series[t.maxValsInArrayIndex].length;o++)n.push(o+1);t.seriesX=[];for(var l=0;l<e.length;l++)t.seriesX.push(n);this.w.globals.isBarHorizontal||(t.isXNumeric=!0)}if(0===n.length){n=t.axisCharts?[]:t.series.map((function(e,t){return t+1}));for(var c=0;c<e.length;c++)t.seriesX.push(n)}t.labels=n,i.xaxis.convertedCatToNumeric&&(t.categoryLabels=n.map((function(e){return i.xaxis.labels.formatter(e)}))),t.noLabelsProvided=!0}},{key:"parseData",value:function(e){var t=this.w,i=t.config,n=t.globals;if(this.excludeCollapsedSeriesInYAxis(),this.fallbackToCategory=!1,this.ctx.core.resetGlobals(),this.ctx.core.isMultipleY(),n.axisCharts?(this.parseDataAxisCharts(e),this.coreUtils.getLargestSeries()):this.parseDataNonAxisCharts(e),i.chart.stacked){var r=new z(this.ctx);n.series=r.setNullSeriesToZeroValues(n.series)}this.coreUtils.getSeriesTotals(),n.axisCharts&&(n.stackedSeriesTotals=this.coreUtils.getStackedSeriesTotals(),n.stackedSeriesTotalsByGroups=this.coreUtils.getStackedSeriesTotalsByGroups()),this.coreUtils.getPercentSeries(),n.dataFormatXNumeric||n.isXNumeric&&("numeric"!==i.xaxis.type||0!==i.labels.length||0!==i.xaxis.categories.length)||this.handleExternalLabelsData(e);for(var a=this.coreUtils.getCategoryLabels(n.labels),s=0;s<a.length;s++)if(Array.isArray(a[s])){n.isMultiLineX=!0;break}}},{key:"excludeCollapsedSeriesInYAxis",value:function(){var e=this.w,t=[];e.globals.seriesYAxisMap.forEach((function(i,n){var r=0;i.forEach((function(t){-1!==e.globals.collapsedSeriesIndices.indexOf(t)&&r++})),r>0&&r==i.length&&t.push(n)})),e.globals.ignoreYAxisIndexes=t.map((function(e){return e}))}}]),e}(),V=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"scaleSvgNode",value:function(e,t){var i=parseFloat(e.getAttributeNS(null,"width")),n=parseFloat(e.getAttributeNS(null,"height"));e.setAttributeNS(null,"width",i*t),e.setAttributeNS(null,"height",n*t),e.setAttributeNS(null,"viewBox","0 0 "+i+" "+n)}},{key:"fixSvgStringForIe11",value:function(e){if(!g.isIE11())return e.replace(/&nbsp;/g,"&#160;");var t=0,i=e.replace(/xmlns="http:\/\/www.w3.org\/2000\/svg"/g,(function(e){return 2==++t?'xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.dev"':e}));return(i=i.replace(/xmlns:NS\d+=""/g,"")).replace(/NS\d+:(\w+:\w+=")/g,"$1")}},{key:"getSvgString",value:function(e){null==e&&(e=1);var t=this.w.globals.dom.Paper.svg();if(1!==e){var i=this.w.globals.dom.Paper.node.cloneNode(!0);this.scaleSvgNode(i,e),t=(new XMLSerializer).serializeToString(i)}return this.fixSvgStringForIe11(t)}},{key:"cleanup",value:function(){var e=this.w,t=e.globals.dom.baseEl.getElementsByClassName("apexcharts-xcrosshairs"),i=e.globals.dom.baseEl.getElementsByClassName("apexcharts-ycrosshairs"),n=e.globals.dom.baseEl.querySelectorAll(".apexcharts-zoom-rect, .apexcharts-selection-rect");Array.prototype.forEach.call(n,(function(e){e.setAttribute("width",0)})),t&&t[0]&&(t[0].setAttribute("x",-500),t[0].setAttribute("x1",-500),t[0].setAttribute("x2",-500)),i&&i[0]&&(i[0].setAttribute("y",-100),i[0].setAttribute("y1",-100),i[0].setAttribute("y2",-100))}},{key:"svgUrl",value:function(){this.cleanup();var e=this.getSvgString(),t=new Blob([e],{type:"image/svg+xml;charset=utf-8"});return URL.createObjectURL(t)}},{key:"dataURI",value:function(e){var t=this;return new Promise((function(i){var n=t.w,r=e?e.scale||e.width/n.globals.svgWidth:1;t.cleanup();var a=document.createElement("canvas");a.width=n.globals.svgWidth*r,a.height=parseInt(n.globals.dom.elWrap.style.height,10)*r;var s="transparent"===n.config.chart.background?"#fff":n.config.chart.background,o=a.getContext("2d");o.fillStyle=s,o.fillRect(0,0,a.width*r,a.height*r);var l=t.getSvgString(r);if(window.canvg&&g.isIE11()){var c=window.canvg.Canvg.fromString(o,l,{ignoreClear:!0,ignoreDimensions:!0});c.start();var u=a.msToBlob();c.stop(),i({blob:u})}else{var d="data:image/svg+xml,"+encodeURIComponent(l),h=new Image;h.crossOrigin="anonymous",h.onload=function(){if(o.drawImage(h,0,0),a.msToBlob){var e=a.msToBlob();i({blob:e})}else{var t=a.toDataURL("image/png");i({imgURI:t})}},h.src=d}}))}},{key:"exportToSVG",value:function(){this.triggerDownload(this.svgUrl(),this.w.config.chart.toolbar.export.svg.filename,".svg")}},{key:"exportToPng",value:function(){var e=this;this.dataURI().then((function(t){var i=t.imgURI,n=t.blob;n?navigator.msSaveOrOpenBlob(n,e.w.globals.chartID+".png"):e.triggerDownload(i,e.w.config.chart.toolbar.export.png.filename,".png")}))}},{key:"exportToCSV",value:function(e){var t=this,i=e.series,n=e.fileName,r=e.columnDelimiter,a=void 0===r?",":r,s=e.lineDelimiter,o=void 0===s?"\n":s,l=this.w;i||(i=l.config.series);var c,u,d=[],h=[],p="",m=l.globals.series.map((function(e,t){return-1===l.globals.collapsedSeriesIndices.indexOf(t)?e:[]})),v=function(e){return"datetime"===l.config.xaxis.type&&String(e).length>=10},y=Math.max.apply(Math,f(i.map((function(e){return e.data?e.data.length:0})))),b=new B(this.ctx),x=new S(this.ctx),_=function(e){var i="";if(l.globals.axisCharts){if("category"===l.config.xaxis.type||l.config.xaxis.convertedCatToNumeric)if(l.globals.isBarHorizontal){var n=l.globals.yLabelFormatters[0],r=new z(t.ctx).getActiveConfigSeriesIndex();i=n(l.globals.labels[e],{seriesIndex:r,dataPointIndex:e,w:l})}else i=x.getLabel(l.globals.labels,l.globals.timescaleLabels,0,e).text;"datetime"===l.config.xaxis.type&&(l.config.xaxis.categories.length?i=l.config.xaxis.categories[e]:l.config.labels.length&&(i=l.config.labels[e]))}else i=l.config.labels[e];return null===i?"nullvalue":(Array.isArray(i)&&(i=i.join(" ")),g.isNumber(i)?i:i.split(a).join(""))};d.push(l.config.chart.toolbar.export.csv.headerCategory),"boxPlot"===l.config.chart.type?(d.push("minimum"),d.push("q1"),d.push("median"),d.push("q3"),d.push("maximum")):"candlestick"===l.config.chart.type?(d.push("open"),d.push("high"),d.push("low"),d.push("close")):"rangeBar"===l.config.chart.type?(d.push("minimum"),d.push("maximum")):i.map((function(e,t){var i=(e.name?e.name:"series-".concat(t))+"";l.globals.axisCharts&&d.push(i.split(a).join("")?i.split(a).join(""):"series-".concat(t))})),l.globals.axisCharts||(d.push(l.config.chart.toolbar.export.csv.headerValue),h.push(d.join(a))),l.globals.allSeriesHasEqualX||!l.globals.axisCharts||l.config.xaxis.categories.length||l.config.labels.length?i.map((function(e,t){l.globals.axisCharts?function(e,t){if(d.length&&0===t&&h.push(d.join(a)),e.data){e.data=e.data.length&&e.data||f(Array(y)).map((function(){return""}));for(var n=0;n<e.data.length;n++){d=[];var r=_(n);if("nullvalue"!==r){if(r||(b.isFormatXY()?r=i[t].data[n].x:b.isFormat2DArray()&&(r=i[t].data[n]?i[t].data[n][0]:"")),0===t){d.push(v(r)?l.config.chart.toolbar.export.csv.dateFormatter(r):g.isNumber(r)?r:r.split(a).join(""));for(var s=0;s<l.globals.series.length;s++){var o;b.isFormatXY()?d.push(null===(o=i[s].data[n])||void 0===o?void 0:o.y):d.push(m[s][n])}}("candlestick"===l.config.chart.type||e.type&&"candlestick"===e.type)&&(d.pop(),d.push(l.globals.seriesCandleO[t][n]),d.push(l.globals.seriesCandleH[t][n]),d.push(l.globals.seriesCandleL[t][n]),d.push(l.globals.seriesCandleC[t][n])),("boxPlot"===l.config.chart.type||e.type&&"boxPlot"===e.type)&&(d.pop(),d.push(l.globals.seriesCandleO[t][n]),d.push(l.globals.seriesCandleH[t][n]),d.push(l.globals.seriesCandleM[t][n]),d.push(l.globals.seriesCandleL[t][n]),d.push(l.globals.seriesCandleC[t][n])),"rangeBar"===l.config.chart.type&&(d.pop(),d.push(l.globals.seriesRangeStart[t][n]),d.push(l.globals.seriesRangeEnd[t][n])),d.length&&h.push(d.join(a))}}}}(e,t):((d=[]).push(l.globals.labels[t].split(a).join("")),d.push(m[t]),h.push(d.join(a)))})):(c=new Set,u={},i.forEach((function(e,t){null==e||e.data.forEach((function(e){var n,r;if(b.isFormatXY())n=e.x,r=e.y;else{if(!b.isFormat2DArray())return;n=e[0],r=e[1]}u[n]||(u[n]=Array(i.length).fill("")),u[n][t]=r,c.add(n)}))})),d.length&&h.push(d.join(a)),Array.from(c).sort().forEach((function(e){h.push([v(e)&&"datetime"===l.config.xaxis.type?l.config.chart.toolbar.export.csv.dateFormatter(e):g.isNumber(e)?e:e.split(a).join(""),u[e].join(a)])}))),p+=h.join(o),this.triggerDownload("data:text/csv; charset=utf-8,"+encodeURIComponent("\ufeff"+p),n||l.config.chart.toolbar.export.csv.filename,".csv")}},{key:"triggerDownload",value:function(e,t,i){var n=document.createElement("a");n.href=e,n.download=(t||this.w.globals.chartID)+i,document.body.appendChild(n),n.click(),document.body.removeChild(n)}}]),e}(),W=function(){function e(t,i){n(this,e),this.ctx=t,this.elgrid=i,this.w=t.w;var r=this.w;this.axesUtils=new S(t),this.xaxisLabels=r.globals.labels.slice(),r.globals.timescaleLabels.length>0&&!r.globals.isBarHorizontal&&(this.xaxisLabels=r.globals.timescaleLabels.slice()),r.config.xaxis.overwriteCategories&&(this.xaxisLabels=r.config.xaxis.overwriteCategories),this.drawnLabels=[],this.drawnLabelsRects=[],"top"===r.config.xaxis.position?this.offY=0:this.offY=r.globals.gridHeight,this.offY=this.offY+r.config.xaxis.axisBorder.offsetY,this.isCategoryBarHorizontal="bar"===r.config.chart.type&&r.config.plotOptions.bar.horizontal,this.xaxisFontSize=r.config.xaxis.labels.style.fontSize,this.xaxisFontFamily=r.config.xaxis.labels.style.fontFamily,this.xaxisForeColors=r.config.xaxis.labels.style.colors,this.xaxisBorderWidth=r.config.xaxis.axisBorder.width,this.isCategoryBarHorizontal&&(this.xaxisBorderWidth=r.config.yaxis[0].axisBorder.width.toString()),this.xaxisBorderWidth.indexOf("%")>-1?this.xaxisBorderWidth=r.globals.gridWidth*parseInt(this.xaxisBorderWidth,10)/100:this.xaxisBorderWidth=parseInt(this.xaxisBorderWidth,10),this.xaxisBorderHeight=r.config.xaxis.axisBorder.height,this.yaxis=r.config.yaxis[0]}return a(e,[{key:"drawXaxis",value:function(){var e=this.w,t=new b(this.ctx),i=t.group({class:"apexcharts-xaxis",transform:"translate(".concat(e.config.xaxis.offsetX,", ").concat(e.config.xaxis.offsetY,")")}),n=t.group({class:"apexcharts-xaxis-texts-g",transform:"translate(".concat(e.globals.translateXAxisX,", ").concat(e.globals.translateXAxisY,")")});i.add(n);for(var r=[],a=0;a<this.xaxisLabels.length;a++)r.push(this.xaxisLabels[a]);if(this.drawXAxisLabelAndGroup(!0,t,n,r,e.globals.isXNumeric,(function(e,t){return t})),e.globals.hasXaxisGroups){var s=e.globals.groups;r=[];for(var o=0;o<s.length;o++)r.push(s[o].title);var l={};e.config.xaxis.group.style&&(l.xaxisFontSize=e.config.xaxis.group.style.fontSize,l.xaxisFontFamily=e.config.xaxis.group.style.fontFamily,l.xaxisForeColors=e.config.xaxis.group.style.colors,l.fontWeight=e.config.xaxis.group.style.fontWeight,l.cssClass=e.config.xaxis.group.style.cssClass),this.drawXAxisLabelAndGroup(!1,t,n,r,!1,(function(e,t){return s[e].cols*t}),l)}if(void 0!==e.config.xaxis.title.text){var c=t.group({class:"apexcharts-xaxis-title"}),u=t.drawText({x:e.globals.gridWidth/2+e.config.xaxis.title.offsetX,y:this.offY+parseFloat(this.xaxisFontSize)+("bottom"===e.config.xaxis.position?e.globals.xAxisLabelsHeight:-e.globals.xAxisLabelsHeight-10)+e.config.xaxis.title.offsetY,text:e.config.xaxis.title.text,textAnchor:"middle",fontSize:e.config.xaxis.title.style.fontSize,fontFamily:e.config.xaxis.title.style.fontFamily,fontWeight:e.config.xaxis.title.style.fontWeight,foreColor:e.config.xaxis.title.style.color,cssClass:"apexcharts-xaxis-title-text "+e.config.xaxis.title.style.cssClass});c.add(u),i.add(c)}if(e.config.xaxis.axisBorder.show){var d=e.globals.barPadForNumericAxis,h=t.drawLine(e.globals.padHorizontal+e.config.xaxis.axisBorder.offsetX-d,this.offY,this.xaxisBorderWidth+d,this.offY,e.config.xaxis.axisBorder.color,0,this.xaxisBorderHeight);this.elgrid&&this.elgrid.elGridBorders&&e.config.grid.show?this.elgrid.elGridBorders.add(h):i.add(h)}return i}},{key:"drawXAxisLabelAndGroup",value:function(e,t,i,n,r,a){var s,o=this,l=arguments.length>6&&void 0!==arguments[6]?arguments[6]:{},c=[],u=[],d=this.w,h=l.xaxisFontSize||this.xaxisFontSize,f=l.xaxisFontFamily||this.xaxisFontFamily,p=l.xaxisForeColors||this.xaxisForeColors,m=l.fontWeight||d.config.xaxis.labels.style.fontWeight,g=l.cssClass||d.config.xaxis.labels.style.cssClass,v=d.globals.padHorizontal,y=n.length,b="category"===d.config.xaxis.type?d.globals.dataPoints:y;if(0===b&&y>b&&(b=y),r){var x=b>1?b-1:b;s=d.globals.gridWidth/Math.min(x,y-1),v=v+a(0,s)/2+d.config.xaxis.labels.offsetX}else s=d.globals.gridWidth/b,v=v+a(0,s)+d.config.xaxis.labels.offsetX;for(var _=function(r){var l=v-a(r,s)/2+d.config.xaxis.labels.offsetX;0===r&&1===y&&s/2===v&&1===b&&(l=d.globals.gridWidth/2);var x=o.axesUtils.getLabel(n,d.globals.timescaleLabels,l,r,c,h,e),_=28;if(d.globals.rotateXLabels&&e&&(_=22),d.config.xaxis.title.text&&"top"===d.config.xaxis.position&&(_+=parseFloat(d.config.xaxis.title.style.fontSize)+2),e||(_=_+parseFloat(h)+(d.globals.xAxisLabelsHeight-d.globals.xAxisGroupLabelsHeight)+(d.globals.rotateXLabels?10:0)),x=void 0!==d.config.xaxis.tickAmount&&"dataPoints"!==d.config.xaxis.tickAmount&&"datetime"!==d.config.xaxis.type?o.axesUtils.checkLabelBasedOnTickamount(r,x,y):o.axesUtils.checkForOverflowingLabels(r,x,y,c,u),d.config.xaxis.labels.show){var w=t.drawText({x:x.x,y:o.offY+d.config.xaxis.labels.offsetY+_-("top"===d.config.xaxis.position?d.globals.xAxisHeight+d.config.xaxis.axisTicks.height-2:0),text:x.text,textAnchor:"middle",fontWeight:x.isBold?600:m,fontSize:h,fontFamily:f,foreColor:Array.isArray(p)?e&&d.config.xaxis.convertedCatToNumeric?p[d.globals.minX+r-1]:p[r]:p,isPlainText:!1,cssClass:(e?"apexcharts-xaxis-label ":"apexcharts-xaxis-group-label ")+g});if(i.add(w),w.on("click",(function(e){if("function"==typeof d.config.chart.events.xAxisLabelClick){var t=Object.assign({},d,{labelIndex:r});d.config.chart.events.xAxisLabelClick(e,o.ctx,t)}})),e){var k=document.createElementNS(d.globals.SVGNS,"title");k.textContent=Array.isArray(x.text)?x.text.join(" "):x.text,w.node.appendChild(k),""!==x.text&&(c.push(x.text),u.push(x))}}r<y-1&&(v+=a(r+1,s))},w=0;w<=y-1;w++)_(w)}},{key:"drawXaxisInversed",value:function(e){var t,i,n=this,r=this.w,a=new b(this.ctx),s=r.config.yaxis[0].opposite?r.globals.translateYAxisX[e]:0,o=a.group({class:"apexcharts-yaxis apexcharts-xaxis-inversed",rel:e}),l=a.group({class:"apexcharts-yaxis-texts-g apexcharts-xaxis-inversed-texts-g",transform:"translate("+s+", 0)"});o.add(l);var c=[];if(r.config.yaxis[e].show)for(var u=0;u<this.xaxisLabels.length;u++)c.push(this.xaxisLabels[u]);t=r.globals.gridHeight/c.length,i=-t/2.2;var d=r.globals.yLabelFormatters[0],h=r.config.yaxis[0].labels;if(h.show)for(var f=function(s){var o=void 0===c[s]?"":c[s];o=d(o,{seriesIndex:e,dataPointIndex:s,w:r});var u=n.axesUtils.getYAxisForeColor(h.style.colors,e),f=0;Array.isArray(o)&&(f=o.length/2*parseInt(h.style.fontSize,10));var p=h.offsetX-15,m="end";n.yaxis.opposite&&(m="start"),"left"===r.config.yaxis[0].labels.align?(p=h.offsetX,m="start"):"center"===r.config.yaxis[0].labels.align?(p=h.offsetX,m="middle"):"right"===r.config.yaxis[0].labels.align&&(m="end");var g=a.drawText({x:p,y:i+t+h.offsetY-f,text:o,textAnchor:m,foreColor:Array.isArray(u)?u[s]:u,fontSize:h.style.fontSize,fontFamily:h.style.fontFamily,fontWeight:h.style.fontWeight,isPlainText:!1,cssClass:"apexcharts-yaxis-label "+h.style.cssClass,maxWidth:h.maxWidth});l.add(g),g.on("click",(function(e){if("function"==typeof r.config.chart.events.xAxisLabelClick){var t=Object.assign({},r,{labelIndex:s});r.config.chart.events.xAxisLabelClick(e,n.ctx,t)}}));var v=document.createElementNS(r.globals.SVGNS,"title");if(v.textContent=Array.isArray(o)?o.join(" "):o,g.node.appendChild(v),0!==r.config.yaxis[e].labels.rotate){var y=a.rotateAroundCenter(g.node);g.node.setAttribute("transform","rotate(".concat(r.config.yaxis[e].labels.rotate," 0 ").concat(y.y,")"))}i+=t},p=0;p<=c.length-1;p++)f(p);if(void 0!==r.config.yaxis[0].title.text){var m=a.group({class:"apexcharts-yaxis-title apexcharts-xaxis-title-inversed",transform:"translate("+s+", 0)"}),g=a.drawText({x:r.config.yaxis[0].title.offsetX,y:r.globals.gridHeight/2+r.config.yaxis[0].title.offsetY,text:r.config.yaxis[0].title.text,textAnchor:"middle",foreColor:r.config.yaxis[0].title.style.color,fontSize:r.config.yaxis[0].title.style.fontSize,fontWeight:r.config.yaxis[0].title.style.fontWeight,fontFamily:r.config.yaxis[0].title.style.fontFamily,cssClass:"apexcharts-yaxis-title-text "+r.config.yaxis[0].title.style.cssClass});m.add(g),o.add(m)}var v=0;this.isCategoryBarHorizontal&&r.config.yaxis[0].opposite&&(v=r.globals.gridWidth);var y=r.config.xaxis.axisBorder;if(y.show){var x=a.drawLine(r.globals.padHorizontal+y.offsetX+v,1+y.offsetY,r.globals.padHorizontal+y.offsetX+v,r.globals.gridHeight+y.offsetY,y.color,0);this.elgrid&&this.elgrid.elGridBorders&&r.config.grid.show?this.elgrid.elGridBorders.add(x):o.add(x)}return r.config.yaxis[0].axisTicks.show&&this.axesUtils.drawYAxisTicks(v,c.length,r.config.yaxis[0].axisBorder,r.config.yaxis[0].axisTicks,0,t,o),o}},{key:"drawXaxisTicks",value:function(e,t,i){var n=this.w,r=e;if(!(e<0||e-2>n.globals.gridWidth)){var a=this.offY+n.config.xaxis.axisTicks.offsetY;if(t=t+a+n.config.xaxis.axisTicks.height,"top"===n.config.xaxis.position&&(t=a-n.config.xaxis.axisTicks.height),n.config.xaxis.axisTicks.show){var s=new b(this.ctx).drawLine(e+n.config.xaxis.axisTicks.offsetX,a+n.config.xaxis.offsetY,r+n.config.xaxis.axisTicks.offsetX,t+n.config.xaxis.offsetY,n.config.xaxis.axisTicks.color);i.add(s),s.node.classList.add("apexcharts-xaxis-tick")}}}},{key:"getXAxisTicksPositions",value:function(){var e=this.w,t=[],i=this.xaxisLabels.length,n=e.globals.padHorizontal;if(e.globals.timescaleLabels.length>0)for(var r=0;r<i;r++)n=this.xaxisLabels[r].position,t.push(n);else for(var a=i,s=0;s<a;s++){var o=a;e.globals.isXNumeric&&"bar"!==e.config.chart.type&&(o-=1),n+=e.globals.gridWidth/o,t.push(n)}return t}},{key:"xAxisLabelCorrections",value:function(){var e=this.w,t=new b(this.ctx),i=e.globals.dom.baseEl.querySelector(".apexcharts-xaxis-texts-g"),n=e.globals.dom.baseEl.querySelectorAll(".apexcharts-xaxis-texts-g text:not(.apexcharts-xaxis-group-label)"),r=e.globals.dom.baseEl.querySelectorAll(".apexcharts-yaxis-inversed text"),a=e.globals.dom.baseEl.querySelectorAll(".apexcharts-xaxis-inversed-texts-g text tspan");if(e.globals.rotateXLabels||e.config.xaxis.labels.rotateAlways)for(var s=0;s<n.length;s++){var o=t.rotateAroundCenter(n[s]);o.y=o.y-1,o.x=o.x+1,n[s].setAttribute("transform","rotate(".concat(e.config.xaxis.labels.rotate," ").concat(o.x," ").concat(o.y,")")),n[s].setAttribute("text-anchor","end"),i.setAttribute("transform","translate(0, ".concat(-10,")"));var l=n[s].childNodes;e.config.xaxis.labels.trim&&Array.prototype.forEach.call(l,(function(i){t.placeTextWithEllipsis(i,i.textContent,e.globals.xAxisLabelsHeight-("bottom"===e.config.legend.position?20:10))}))}else!function(){for(var i=e.globals.gridWidth/(e.globals.labels.length+1),r=0;r<n.length;r++){var a=n[r].childNodes;e.config.xaxis.labels.trim&&"datetime"!==e.config.xaxis.type&&Array.prototype.forEach.call(a,(function(e){t.placeTextWithEllipsis(e,e.textContent,i)}))}}();if(r.length>0){var c=r[r.length-1].getBBox(),u=r[0].getBBox();c.x<-20&&r[r.length-1].parentNode.removeChild(r[r.length-1]),u.x+u.width>e.globals.gridWidth&&!e.globals.isBarHorizontal&&r[0].parentNode.removeChild(r[0]);for(var d=0;d<a.length;d++)t.placeTextWithEllipsis(a[d],a[d].textContent,e.config.yaxis[0].labels.maxWidth-(e.config.yaxis[0].title.text?2*parseFloat(e.config.yaxis[0].title.style.fontSize):0)-15)}}}]),e}(),U=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w;var i=this.w;this.xaxisLabels=i.globals.labels.slice(),this.axesUtils=new S(t),this.isRangeBar=i.globals.seriesRange.length&&i.globals.isBarHorizontal,i.globals.timescaleLabels.length>0&&(this.xaxisLabels=i.globals.timescaleLabels.slice())}return a(e,[{key:"drawGridArea",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null,t=this.w,i=new b(this.ctx);null===e&&(e=i.group({class:"apexcharts-grid"}));var n=i.drawLine(t.globals.padHorizontal,1,t.globals.padHorizontal,t.globals.gridHeight,"transparent"),r=i.drawLine(t.globals.padHorizontal,t.globals.gridHeight,t.globals.gridWidth,t.globals.gridHeight,"transparent");return e.add(r),e.add(n),e}},{key:"drawGrid",value:function(){var e=null;return this.w.globals.axisCharts&&(e=this.renderGrid(),this.drawGridArea(e.el)),e}},{key:"createGridMask",value:function(){var e=this.w,t=e.globals,i=new b(this.ctx),n=Array.isArray(e.config.stroke.width)?0:e.config.stroke.width;if(Array.isArray(e.config.stroke.width)){var r=0;e.config.stroke.width.forEach((function(e){r=Math.max(r,e)})),n=r}t.dom.elGridRectMask=document.createElementNS(t.SVGNS,"clipPath"),t.dom.elGridRectMask.setAttribute("id","gridRectMask".concat(t.cuid)),t.dom.elGridRectMarkerMask=document.createElementNS(t.SVGNS,"clipPath"),t.dom.elGridRectMarkerMask.setAttribute("id","gridRectMarkerMask".concat(t.cuid)),t.dom.elForecastMask=document.createElementNS(t.SVGNS,"clipPath"),t.dom.elForecastMask.setAttribute("id","forecastMask".concat(t.cuid)),t.dom.elNonForecastMask=document.createElementNS(t.SVGNS,"clipPath"),t.dom.elNonForecastMask.setAttribute("id","nonForecastMask".concat(t.cuid));var a=e.config.chart.type,s=0,o=0;("bar"===a||"rangeBar"===a||"candlestick"===a||"boxPlot"===a||e.globals.comboBarCount>0)&&e.globals.isXNumeric&&!e.globals.isBarHorizontal&&(s=e.config.grid.padding.left,o=e.config.grid.padding.right,t.barPadForNumericAxis>s&&(s=t.barPadForNumericAxis,o=t.barPadForNumericAxis)),t.dom.elGridRect=i.drawRect(-n/2-s-2,-n/2-2,t.gridWidth+n+o+s+4,t.gridHeight+n+4,0,"#fff");var l=e.globals.markers.largestSize+1;t.dom.elGridRectMarker=i.drawRect(2*-l,2*-l,t.gridWidth+4*l,t.gridHeight+4*l,0,"#fff"),t.dom.elGridRectMask.appendChild(t.dom.elGridRect.node),t.dom.elGridRectMarkerMask.appendChild(t.dom.elGridRectMarker.node);var c=t.dom.baseEl.querySelector("defs");c.appendChild(t.dom.elGridRectMask),c.appendChild(t.dom.elForecastMask),c.appendChild(t.dom.elNonForecastMask),c.appendChild(t.dom.elGridRectMarkerMask)}},{key:"_drawGridLines",value:function(e){var t=e.i,i=e.x1,n=e.y1,r=e.x2,a=e.y2,s=e.xCount,o=e.parent,l=this.w;if(!(0===t&&l.globals.skipFirstTimelinelabel||t===s-1&&l.globals.skipLastTimelinelabel&&!l.config.xaxis.labels.formatter||"radar"===l.config.chart.type)){l.config.grid.xaxis.lines.show&&this._drawGridLine({i:t,x1:i,y1:n,x2:r,y2:a,xCount:s,parent:o});var c=0;if(l.globals.hasXaxisGroups&&"between"===l.config.xaxis.tickPlacement){var u=l.globals.groups;if(u){for(var d=0,h=0;d<t&&h<u.length;h++)d+=u[h].cols;d===t&&(c=.6*l.globals.xAxisLabelsHeight)}}new W(this.ctx).drawXaxisTicks(i,c,l.globals.dom.elGraphical)}}},{key:"_drawGridLine",value:function(e){var t=e.i,i=e.x1,n=e.y1,r=e.x2,a=e.y2,s=e.xCount,o=e.parent,l=this.w,c=!1,u=o.node.classList.contains("apexcharts-gridlines-horizontal"),d=l.config.grid.strokeDashArray,h=l.globals.barPadForNumericAxis;(0===n&&0===a||0===i&&0===r)&&(c=!0),n===l.globals.gridHeight&&a===l.globals.gridHeight&&(c=!0),!l.globals.isBarHorizontal||0!==t&&t!==s-1||(c=!0);var f=new b(this).drawLine(i-(u?h:0),n,r+(u?h:0),a,l.config.grid.borderColor,d);f.node.classList.add("apexcharts-gridline"),c&&l.config.grid.show?this.elGridBorders.add(f):o.add(f)}},{key:"_drawGridBandRect",value:function(e){var t=e.c,i=e.x1,n=e.y1,r=e.x2,a=e.y2,s=e.type,o=this.w,l=new b(this.ctx),c=o.globals.barPadForNumericAxis;if("column"!==s||"datetime"!==o.config.xaxis.type){var u=o.config.grid[s].colors[t],d=l.drawRect(i-("row"===s?c:0),n,r+("row"===s?2*c:0),a,0,u,o.config.grid[s].opacity);this.elg.add(d),d.attr("clip-path","url(#gridRectMask".concat(o.globals.cuid,")")),d.node.classList.add("apexcharts-grid-".concat(s))}}},{key:"_drawXYLines",value:function(e){var t=this,i=e.xCount,n=e.tickAmount,r=this.w;if(r.config.grid.xaxis.lines.show||r.config.xaxis.axisTicks.show){var a,s=r.globals.padHorizontal,o=r.globals.gridHeight;r.globals.timescaleLabels.length?function(e){for(var n=e.xC,r=e.x1,a=e.y1,s=e.x2,o=e.y2,l=0;l<n;l++)r=t.xaxisLabels[l].position,s=t.xaxisLabels[l].position,t._drawGridLines({i:l,x1:r,y1:a,x2:s,y2:o,xCount:i,parent:t.elgridLinesV})}({xC:i,x1:s,y1:0,x2:a,y2:o}):(r.globals.isXNumeric&&(i=r.globals.xAxisScale.result.length),function(e){for(var n=e.xC,a=e.x1,s=e.y1,o=e.x2,l=e.y2,c=0;c<n+(r.globals.isXNumeric?0:1);c++)0===c&&1===n&&1===r.globals.dataPoints&&(o=a=r.globals.gridWidth/2),t._drawGridLines({i:c,x1:a,y1:s,x2:o,y2:l,xCount:i,parent:t.elgridLinesV}),o=a+=r.globals.gridWidth/(r.globals.isXNumeric?n-1:n)}({xC:i,x1:s,y1:0,x2:a,y2:o}))}if(r.config.grid.yaxis.lines.show){var l=0,c=0,u=r.globals.gridWidth,d=n+1;this.isRangeBar&&(d=r.globals.labels.length);for(var h=0;h<d+(this.isRangeBar?1:0);h++)this._drawGridLine({i:h,xCount:d+(this.isRangeBar?1:0),x1:0,y1:l,x2:u,y2:c,parent:this.elgridLinesH}),c=l+=r.globals.gridHeight/(this.isRangeBar?d:n)}}},{key:"_drawInvertedXYLines",value:function(e){var t=e.xCount,i=this.w;if(i.config.grid.xaxis.lines.show||i.config.xaxis.axisTicks.show)for(var n,r=i.globals.padHorizontal,a=i.globals.gridHeight,s=0;s<t+1;s++)i.config.grid.xaxis.lines.show&&this._drawGridLine({i:s,xCount:t+1,x1:r,y1:0,x2:n,y2:a,parent:this.elgridLinesV}),new W(this.ctx).drawXaxisTicks(r,0,i.globals.dom.elGraphical),n=r+=i.globals.gridWidth/t;if(i.config.grid.yaxis.lines.show)for(var o=0,l=0,c=i.globals.gridWidth,u=0;u<i.globals.dataPoints+1;u++)this._drawGridLine({i:u,xCount:i.globals.dataPoints+1,x1:0,y1:o,x2:c,y2:l,parent:this.elgridLinesH}),l=o+=i.globals.gridHeight/i.globals.dataPoints}},{key:"renderGrid",value:function(){var e=this.w,t=e.globals,i=new b(this.ctx);this.elg=i.group({class:"apexcharts-grid"}),this.elgridLinesH=i.group({class:"apexcharts-gridlines-horizontal"}),this.elgridLinesV=i.group({class:"apexcharts-gridlines-vertical"}),this.elGridBorders=i.group({class:"apexcharts-grid-borders"}),this.elg.add(this.elgridLinesH),this.elg.add(this.elgridLinesV),e.config.grid.show||(this.elgridLinesV.hide(),this.elgridLinesH.hide(),this.elGridBorders.hide());for(var n=0;n<t.seriesYAxisMap.length&&-1!==t.ignoreYAxisIndexes.indexOf(n);)n++;n===t.seriesYAxisMap.length&&(n=0);var r,a,s,o,l=t.yAxisScale[n].result.length-1;!t.isBarHorizontal||this.isRangeBar?(r=this.xaxisLabels.length,this.isRangeBar&&(l=t.labels.length,e.config.xaxis.tickAmount&&e.config.xaxis.labels.formatter&&(r=e.config.xaxis.tickAmount),(null===(a=t.yAxisScale)||void 0===a||null===(s=a[n])||void 0===s||null===(o=s.result)||void 0===o?void 0:o.length)>0&&"datetime"!==e.config.xaxis.type&&(r=t.yAxisScale[n].result.length-1)),this._drawXYLines({xCount:r,tickAmount:l})):(r=l,l=t.xTickAmount,this._drawInvertedXYLines({xCount:r,tickAmount:l}));return this.drawGridBands(r,l),{el:this.elg,elGridBorders:this.elGridBorders,xAxisTickWidth:t.gridWidth/r}}},{key:"drawGridBands",value:function(e,t){var i=this.w;if(void 0!==i.config.grid.row.colors&&i.config.grid.row.colors.length>0)for(var n=0,r=i.globals.gridHeight/t,a=i.globals.gridWidth,s=0,o=0;s<t;s++,o++)o>=i.config.grid.row.colors.length&&(o=0),this._drawGridBandRect({c:o,x1:0,y1:n,x2:a,y2:r,type:"row"}),n+=i.globals.gridHeight/t;if(void 0!==i.config.grid.column.colors&&i.config.grid.column.colors.length>0)for(var l=i.globals.isBarHorizontal||"on"!==i.config.xaxis.tickPlacement||"category"!==i.config.xaxis.type&&!i.config.xaxis.convertedCatToNumeric?e:e-1,c=i.globals.padHorizontal,u=i.globals.padHorizontal+i.globals.gridWidth/l,d=i.globals.gridHeight,h=0,f=0;h<e;h++,f++)f>=i.config.grid.column.colors.length&&(f=0),this._drawGridBandRect({c:f,x1:c,y1:0,x2:u,y2:d,type:"column"}),c+=i.globals.gridWidth/l}}]),e}(),q=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"niceScale",value:function(e,t){var i,n,r,a,s=arguments.length>2&&void 0!==arguments[2]?arguments[2]:0,o=1e-11,l=this.w,c=l.globals;c.isBarHorizontal?(i=l.config.xaxis,n=Math.max((c.svgWidth-100)/25,2)):(i=l.config.yaxis[s],n=Math.max((c.svgHeight-100)/15,2)),r=void 0!==i.min&&null!==i.min,a=void 0!==i.max&&null!==i.min;var u=void 0!==i.stepSize&&null!==i.stepSize,d=void 0!==i.tickAmount&&null!==i.tickAmount,h=d?i.tickAmount:i.forceNiceScale?c.niceScaleDefaultTicks[Math.min(Math.round(n/2),c.niceScaleDefaultTicks.length-1)]:10;if(c.isMultipleYAxis&&!d&&c.multiAxisTickAmount>0&&(h=c.multiAxisTickAmount,d=!0),h="dataPoints"===h?c.dataPoints-1:Math.abs(Math.round(h)),(e===Number.MIN_VALUE&&0===t||!g.isNumber(e)&&!g.isNumber(t)||e===Number.MIN_VALUE&&t===-Number.MAX_VALUE)&&(e=g.isNumber(i.min)?i.min:0,t=g.isNumber(i.max)?i.max:e+h,c.allSeriesCollapsed=!1),e>t){console.warn("axis.min cannot be greater than axis.max: swapping min and max");var f=t;t=e,e=f}else e===t&&(e=0===e?0:e-1,t=0===t?2:t+1);var p=[];h<1&&(h=1);var m=h,v=Math.abs(t-e);i.forceNiceScale&&(!r&&e>0&&e/v<.15&&(e=0,r=!0),!a&&t<0&&-t/v<.15&&(t=0,a=!0),v=Math.abs(t-e));var y=v/m,b=y,x=Math.floor(Math.log10(b)),_=Math.pow(10,x),w=Math.ceil(b/_);if(y=b=(w=c.niceScaleAllowedMagMsd[0===c.yValueDecimal?0:1][w])*_,c.isBarHorizontal&&i.stepSize&&"datetime"!==i.type?(y=i.stepSize,u=!0):u&&(y=i.stepSize),u&&i.forceNiceScale){var k=Math.floor(Math.log10(y));y*=Math.pow(10,x-k)}if(r&&a){var M=v/m;if(d)if(u)if(0!=g.mod(v,y)){var S=g.getGCD(y,M);y=M/S<10?S:M}else 0==g.mod(y,M)?y=M:(M=y,d=!1);else y=M;else if(u)0==g.mod(v,y)?M=y:y=M;else if(0==g.mod(v,y))M=y;else{M=v/(m=Math.ceil(v/y));var A=g.getGCD(v,y);v/A<n&&(M=A),y=M}m=Math.round(v/y)}else{if(r||a){if(a)if(d)e=t-y*m;else{var L=e;e=y*Math.floor(e/y),Math.abs(t-e)/g.getGCD(v,y)>n&&(e=t-y*h,e+=y*Math.floor((L-e)/y))}else if(r)if(d)t=e+y*m;else{var T=t;t=y*Math.ceil(t/y),Math.abs(t-e)/g.getGCD(v,y)>n&&(t=e+y*h,t+=y*Math.ceil((T-t)/y))}}else if(d){var C=y/(t-e>t?1:2),D=C*Math.floor(e/C);Math.abs(D-e)<=C/2?t=(e=D)+y*m:e=(t=C*Math.ceil(t/C))-y*m}else e=y*Math.floor(e/y),t=y*Math.ceil(t/y);v=Math.abs(t-e),y=g.getGCD(v,y),m=Math.round(v/y)}if(d||r||a||(m=Math.ceil((v-o)/(y+o)))>16&&g.getPrimeFactors(m).length<2&&m++,!d&&i.forceNiceScale&&0===c.yValueDecimal&&m>v&&(m=v,y=Math.round(v/m)),m>n&&(!d&&!u||i.forceNiceScale)){var E=g.getPrimeFactors(m),O=E.length-1,P=m;e:for(var Y=0;Y<O;Y++)for(var I=0;I<=O-Y;I++){for(var N=Math.min(I+Y,O),j=P,H=1,F=I;F<=N;F++)H*=E[F];if((j/=H)<n){P=j;break e}}y=P===m?v:v/P,m=Math.round(v/y)}c.isMultipleYAxis&&0==c.multiAxisTickAmount&&c.ignoreYAxisIndexes.indexOf(s)<0&&(c.multiAxisTickAmount=m);var R=e-y,z=y*o;do{R+=y,p.push(g.stripNumber(R,7))}while(t-R>z);return{result:p,niceMin:p[0],niceMax:p[p.length-1]}}},{key:"linearScale",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:10,n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:0,r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:void 0,a=Math.abs(t-e);"dataPoints"===(i=this._adjustTicksForSmallRange(i,n,a))&&(i=this.w.globals.dataPoints-1),r||(r=a/i),i===Number.MAX_VALUE&&(i=5,r=1);for(var s=[],o=e;i>=0;)s.push(o),o+=r,i-=1;return{result:s,niceMin:s[0],niceMax:s[s.length-1]}}},{key:"logarithmicScaleNice",value:function(e,t,i){t<=0&&(t=Math.max(e,i)),e<=0&&(e=Math.min(t,i));for(var n=[],r=Math.ceil(Math.log(t)/Math.log(i)+1),a=Math.floor(Math.log(e)/Math.log(i));a<r;a++)n.push(Math.pow(i,a));return{result:n,niceMin:n[0],niceMax:n[n.length-1]}}},{key:"logarithmicScale",value:function(e,t,i){t<=0&&(t=Math.max(e,i)),e<=0&&(e=Math.min(t,i));for(var n=[],r=Math.log(t)/Math.log(i),a=Math.log(e)/Math.log(i),s=r-a,o=Math.round(s),l=s/o,c=0,u=a;c<o;c++,u+=l)n.push(Math.pow(i,u));return n.push(Math.pow(i,r)),{result:n,niceMin:e,niceMax:t}}},{key:"_adjustTicksForSmallRange",value:function(e,t,i){var n=e;if(void 0!==t&&this.w.config.yaxis[t].labels.formatter&&void 0===this.w.config.yaxis[t].tickAmount){var r=Number(this.w.config.yaxis[t].labels.formatter(1));g.isNumber(r)&&0===this.w.globals.yValueDecimal&&(n=Math.ceil(i))}return n<e?n:e}},{key:"setYScaleForIndex",value:function(e,t,i){var n=this.w.globals,r=this.w.config,a=n.isBarHorizontal?r.xaxis:r.yaxis[e];void 0===n.yAxisScale[e]&&(n.yAxisScale[e]=[]);var s=Math.abs(i-t);a.logarithmic&&s<=5&&(n.invalidLogScale=!0),a.logarithmic&&s>5?(n.allSeriesCollapsed=!1,n.yAxisScale[e]=a.forceNiceScale?this.logarithmicScaleNice(t,i,a.logBase):this.logarithmicScale(t,i,a.logBase)):i!==-Number.MAX_VALUE&&g.isNumber(i)&&t!==Number.MAX_VALUE&&g.isNumber(t)?(n.allSeriesCollapsed=!1,n.yAxisScale[e]=this.niceScale(t,i,e)):n.yAxisScale[e]=this.niceScale(Number.MIN_VALUE,0,e)}},{key:"setXScale",value:function(e,t){var i=this.w,n=i.globals,r=Math.abs(t-e);return t!==-Number.MAX_VALUE&&g.isNumber(t)?n.xAxisScale=this.linearScale(e,t,i.config.xaxis.tickAmount?i.config.xaxis.tickAmount:r<10&&r>1?r+1:10,0,i.config.xaxis.stepSize):n.xAxisScale=this.linearScale(0,10,10),n.xAxisScale}},{key:"setSeriesYAxisMappings",value:function(){var e=this.w.globals,t=this.w.config;e.minYArr,e.maxYArr;var i=[],n=[],r=[],a=e.series.length>t.yaxis.length||t.yaxis.some((function(e){return Array.isArray(e.seriesName)}));t.series.forEach((function(e,t){r.push(t),n.push(null)})),t.yaxis.forEach((function(e,t){i[t]=[]}));var s=[];t.yaxis.forEach((function(e,n){var o=!1;if(e.seriesName){var l=[];Array.isArray(e.seriesName)?l=e.seriesName:l.push(e.seriesName),l.forEach((function(e){t.series.forEach((function(t,s){if(t.name===e){var l=s;n===s||a?!a||r.indexOf(s)>-1?i[n].push([n,s]):console.warn("Series '"+t.name+"' referenced more than once in what looks like the new style. That is, when using either seriesName: [], or when there are more series than yaxes."):(i[s].push([s,n]),l=n),o=!0,-1!==(l=r.indexOf(l))&&r.splice(l,1)}}))}))}o||s.push(n)})),i=i.map((function(e,t){var i=[];return e.forEach((function(e){n[e[1]]=e[0],i.push(e[1])})),i}));for(var o=t.yaxis.length-1,l=0;l<s.length&&(o=s[l],i[o]=[],r);l++){var c=r[0];r.shift(),i[o].push(c),n[c]=o}r.forEach((function(e){i[o].push(e),n[e]=o})),e.seriesYAxisMap=i.map((function(e){return e})),e.seriesYAxisReverseMap=n.map((function(e){return e}))}},{key:"scaleMultipleYAxes",value:function(){var e=this,t=this.w.config,i=this.w.globals;this.setSeriesYAxisMappings();var n=i.seriesYAxisMap,r=i.minYArr,a=i.maxYArr;i.allSeriesCollapsed=!0,i.barGroups=[],n.forEach((function(n,s){var o=[];n.forEach((function(e){var i=t.series[e].group;o.indexOf(i)<0&&o.push(i)})),n.length>0?function(){var l,c,u=Number.MAX_VALUE,d=-Number.MAX_VALUE,h=u,f=d;if(t.chart.stacked)!function(){var e=i.seriesX[n[0]],r=[],a=[],p=[];o.forEach((function(){r.push(e.map((function(){return Number.MIN_VALUE}))),a.push(e.map((function(){return Number.MIN_VALUE}))),p.push(e.map((function(){return Number.MIN_VALUE})))}));for(var m=function(e){!l&&t.series[n[e]].type&&(l=t.series[n[e]].type);var u=n[e];c=t.series[u].group?t.series[u].group:"axis-".concat(s),!(i.collapsedSeriesIndices.indexOf(u)<0&&i.ancillaryCollapsedSeriesIndices.indexOf(u)<0)||(i.allSeriesCollapsed=!1,o.forEach((function(e,n){if(t.series[u].group===e)for(var s=0;s<i.series[u].length;s++){var o=i.series[u][s];o>=0?a[n][s]+=o:p[n][s]+=o,r[n][s]+=o,h=Math.min(h,o),f=Math.max(f,o)}}))),"bar"!==l&&"column"!==l||i.barGroups.push(c)},g=0;g<n.length;g++)m(g);l||(l=t.chart.type),"bar"===l||"column"===l?o.forEach((function(e,t){u=Math.min(u,Math.min.apply(null,p[t])),d=Math.max(d,Math.max.apply(null,a[t]))})):(o.forEach((function(e,t){h=Math.min(h,Math.min.apply(null,r[t])),f=Math.max(f,Math.max.apply(null,r[t]))})),u=h,d=f),u===Number.MIN_VALUE&&d===Number.MIN_VALUE&&(d=-Number.MAX_VALUE)}();else for(var p=0;p<n.length;p++){var m=n[p];u=Math.min(u,r[m]),d=Math.max(d,a[m]),!(i.collapsedSeriesIndices.indexOf(m)<0&&i.ancillaryCollapsedSeriesIndices.indexOf(m)<0)||(i.allSeriesCollapsed=!1)}void 0!==t.yaxis[s].min&&(u="function"==typeof t.yaxis[s].min?t.yaxis[s].min(u):t.yaxis[s].min),void 0!==t.yaxis[s].max&&(d="function"==typeof t.yaxis[s].max?t.yaxis[s].max(d):t.yaxis[s].max),i.barGroups=i.barGroups.filter((function(e,t,i){return i.indexOf(e)===t})),e.setYScaleForIndex(s,u,d),n.forEach((function(e){r[e]=i.yAxisScale[s].niceMin,a[e]=i.yAxisScale[s].niceMax}))}():e.setYScaleForIndex(s,0,-Number.MAX_VALUE)}))}}]),e}(),$=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.scales=new q(t)}return a(e,[{key:"init",value:function(){this.setYRange(),this.setXRange(),this.setZRange()}},{key:"getMinYMaxY",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Number.MAX_VALUE,i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:-Number.MAX_VALUE,n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:null,r=this.w.config,a=this.w.globals,s=-Number.MAX_VALUE,o=Number.MIN_VALUE;null===n&&(n=e+1);var l=0,c=0,u=void 0;if(a.seriesX.length>=n){var d,h;l=0,c=(u=f(new Set((d=[]).concat.apply(d,f(a.seriesX.slice(e,n)))))).length-1;var p=null===(h=a.brushSource)||void 0===h?void 0:h.w.config.chart.brush;if(r.chart.zoom.enabled&&r.chart.zoom.autoScaleYaxis||null!=p&&p.enabled&&null!=p&&p.autoScaleYaxis){if(r.xaxis.min)for(l=0;l<c&&u[l]<r.xaxis.min;l++);if(r.xaxis.max)for(;c>l&&u[c]>r.xaxis.max;c--);}}var m=a.series,v=m,y=m;"candlestick"===r.chart.type?(v=a.seriesCandleL,y=a.seriesCandleH):"boxPlot"===r.chart.type?(v=a.seriesCandleO,y=a.seriesCandleC):a.isRangeData&&(v=a.seriesRangeStart,y=a.seriesRangeEnd);for(var b=e;b<n;b++){a.dataPoints=Math.max(a.dataPoints,m[b].length);var x=r.series[b].type;a.categoryLabels.length&&(a.dataPoints=a.categoryLabels.filter((function(e){return void 0!==e})).length),a.labels.length&&"datetime"!==r.xaxis.type&&0!==a.series.reduce((function(e,t){return e+t.length}),0)&&(a.dataPoints=Math.max(a.dataPoints,a.labels.length)),u||(l=0,c=a.series[b].length);for(var _=l;_<=c&&_<a.series[b].length;_++){var w=m[b][_];if(null!==w&&g.isNumber(w)){switch(void 0!==y[b][_]&&(s=Math.max(s,y[b][_]),t=Math.min(t,y[b][_])),void 0!==v[b][_]&&(t=Math.min(t,v[b][_]),i=Math.max(i,v[b][_])),x){case"candlestick":void 0!==a.seriesCandleC[b][_]&&(s=Math.max(s,a.seriesCandleH[b][_]),t=Math.min(t,a.seriesCandleL[b][_]));break;case"boxPlot":void 0!==a.seriesCandleC[b][_]&&(s=Math.max(s,a.seriesCandleC[b][_]),t=Math.min(t,a.seriesCandleO[b][_]))}x&&"candlestick"!==x&&"boxPlot"!==x&&"rangeArea"!==x&&"rangeBar"!==x&&(s=Math.max(s,a.series[b][_]),t=Math.min(t,a.series[b][_])),i=s,a.seriesGoals[b]&&a.seriesGoals[b][_]&&Array.isArray(a.seriesGoals[b][_])&&a.seriesGoals[b][_].forEach((function(e){o!==Number.MIN_VALUE&&(o=Math.min(o,e.value),t=o),s=Math.max(s,e.value),i=s})),g.isFloat(w)&&(w=g.noExponents(w),a.yValueDecimal=Math.max(a.yValueDecimal,w.toString().split(".")[1].length)),o>v[b][_]&&v[b][_]<0&&(o=v[b][_])}else a.hasNullValues=!0}"bar"!==x&&"column"!==x||(o<0&&s<0&&(s=0,i=Math.max(i,0)),o===Number.MIN_VALUE&&(o=0,t=Math.min(t,0)))}return"rangeBar"===r.chart.type&&a.seriesRangeStart.length&&a.isBarHorizontal&&(o=t),"bar"===r.chart.type&&(o<0&&s<0&&(s=0),o===Number.MIN_VALUE&&(o=0)),{minY:o,maxY:s,lowestY:t,highestY:i}}},{key:"setYRange",value:function(){var e=this.w.globals,t=this.w.config;e.maxY=-Number.MAX_VALUE,e.minY=Number.MIN_VALUE;var i,n=Number.MAX_VALUE;if(e.isMultipleYAxis){n=Number.MAX_VALUE;for(var r=0;r<e.series.length;r++)i=this.getMinYMaxY(r),e.minYArr[r]=i.lowestY,e.maxYArr[r]=i.highestY,n=Math.min(n,i.lowestY)}return i=this.getMinYMaxY(0,n,null,e.series.length),"bar"===t.chart.type?(e.minY=i.minY,e.maxY=i.maxY):(e.minY=i.lowestY,e.maxY=i.highestY),n=i.lowestY,t.chart.stacked&&this._setStackedMinMax(),"line"===t.chart.type||"area"===t.chart.type||"scatter"===t.chart.type||"candlestick"===t.chart.type||"boxPlot"===t.chart.type||"rangeBar"===t.chart.type&&!e.isBarHorizontal?e.minY===Number.MIN_VALUE&&n!==-Number.MAX_VALUE&&n!==e.maxY&&(e.minY=n):e.minY=i.minY,t.yaxis.forEach((function(t,i){void 0!==t.max&&("number"==typeof t.max?e.maxYArr[i]=t.max:"function"==typeof t.max&&(e.maxYArr[i]=t.max(e.isMultipleYAxis?e.maxYArr[i]:e.maxY)),e.maxY=e.maxYArr[i]),void 0!==t.min&&("number"==typeof t.min?e.minYArr[i]=t.min:"function"==typeof t.min&&(e.minYArr[i]=t.min(e.isMultipleYAxis?e.minYArr[i]===Number.MIN_VALUE?0:e.minYArr[i]:e.minY)),e.minY=e.minYArr[i])})),e.isBarHorizontal&&["min","max"].forEach((function(i){void 0!==t.xaxis[i]&&"number"==typeof t.xaxis[i]&&("min"===i?e.minY=t.xaxis[i]:e.maxY=t.xaxis[i])})),e.isMultipleYAxis?(this.scales.scaleMultipleYAxes(),e.minY=n):(this.scales.setYScaleForIndex(0,e.minY,e.maxY),e.minY=e.yAxisScale[0].niceMin,e.maxY=e.yAxisScale[0].niceMax,e.minYArr[0]=e.minY,e.maxYArr[0]=e.maxY),e.barGroups=[],e.lineGroups=[],e.areaGroups=[],t.series.forEach((function(i){switch(i.type||t.chart.type){case"bar":case"column":e.barGroups.push(i.group);break;case"line":e.lineGroups.push(i.group);break;case"area":e.areaGroups.push(i.group)}})),e.barGroups=e.barGroups.filter((function(e,t,i){return i.indexOf(e)===t})),e.lineGroups=e.lineGroups.filter((function(e,t,i){return i.indexOf(e)===t})),e.areaGroups=e.areaGroups.filter((function(e,t,i){return i.indexOf(e)===t})),{minY:e.minY,maxY:e.maxY,minYArr:e.minYArr,maxYArr:e.maxYArr,yAxisScale:e.yAxisScale}}},{key:"setXRange",value:function(){var e=this.w.globals,t=this.w.config,i="numeric"===t.xaxis.type||"datetime"===t.xaxis.type||"category"===t.xaxis.type&&!e.noLabelsProvided||e.noLabelsProvided||e.isXNumeric;if(e.isXNumeric&&function(){for(var t=0;t<e.series.length;t++)if(e.labels[t])for(var i=0;i<e.labels[t].length;i++)null!==e.labels[t][i]&&g.isNumber(e.labels[t][i])&&(e.maxX=Math.max(e.maxX,e.labels[t][i]),e.initialMaxX=Math.max(e.maxX,e.labels[t][i]),e.minX=Math.min(e.minX,e.labels[t][i]),e.initialMinX=Math.min(e.minX,e.labels[t][i]))}(),e.noLabelsProvided&&0===t.xaxis.categories.length&&(e.maxX=e.labels[e.labels.length-1],e.initialMaxX=e.labels[e.labels.length-1],e.minX=1,e.initialMinX=1),e.isXNumeric||e.noLabelsProvided||e.dataFormatXNumeric){var n;if(void 0===t.xaxis.tickAmount?(n=Math.round(e.svgWidth/150),"numeric"===t.xaxis.type&&e.dataPoints<30&&(n=e.dataPoints-1),n>e.dataPoints&&0!==e.dataPoints&&(n=e.dataPoints-1)):"dataPoints"===t.xaxis.tickAmount?(e.series.length>1&&(n=e.series[e.maxValsInArrayIndex].length-1),e.isXNumeric&&(n=e.maxX-e.minX-1)):n=t.xaxis.tickAmount,e.xTickAmount=n,void 0!==t.xaxis.max&&"number"==typeof t.xaxis.max&&(e.maxX=t.xaxis.max),void 0!==t.xaxis.min&&"number"==typeof t.xaxis.min&&(e.minX=t.xaxis.min),void 0!==t.xaxis.range&&(e.minX=e.maxX-t.xaxis.range),e.minX!==Number.MAX_VALUE&&e.maxX!==-Number.MAX_VALUE)if(t.xaxis.convertedCatToNumeric&&!e.dataFormatXNumeric){for(var r=[],a=e.minX-1;a<e.maxX;a++)r.push(a+1);e.xAxisScale={result:r,niceMin:r[0],niceMax:r[r.length-1]}}else e.xAxisScale=this.scales.setXScale(e.minX,e.maxX);else e.xAxisScale=this.scales.linearScale(0,n,n,0,t.xaxis.stepSize),e.noLabelsProvided&&e.labels.length>0&&(e.xAxisScale=this.scales.linearScale(1,e.labels.length,n-1,0,t.xaxis.stepSize),e.seriesX=e.labels.slice());i&&(e.labels=e.xAxisScale.result.slice())}return e.isBarHorizontal&&e.labels.length&&(e.xTickAmount=e.labels.length),this._handleSingleDataPoint(),this._getMinXDiff(),{minX:e.minX,maxX:e.maxX}}},{key:"setZRange",value:function(){var e=this.w.globals;if(e.isDataXYZ)for(var t=0;t<e.series.length;t++)if(void 0!==e.seriesZ[t])for(var i=0;i<e.seriesZ[t].length;i++)null!==e.seriesZ[t][i]&&g.isNumber(e.seriesZ[t][i])&&(e.maxZ=Math.max(e.maxZ,e.seriesZ[t][i]),e.minZ=Math.min(e.minZ,e.seriesZ[t][i]))}},{key:"_handleSingleDataPoint",value:function(){var e=this.w.globals,t=this.w.config;if(e.minX===e.maxX){var i=new k(this.ctx);if("datetime"===t.xaxis.type){var n=i.getDate(e.minX);t.xaxis.labels.datetimeUTC?n.setUTCDate(n.getUTCDate()-2):n.setDate(n.getDate()-2),e.minX=new Date(n).getTime();var r=i.getDate(e.maxX);t.xaxis.labels.datetimeUTC?r.setUTCDate(r.getUTCDate()+2):r.setDate(r.getDate()+2),e.maxX=new Date(r).getTime()}else("numeric"===t.xaxis.type||"category"===t.xaxis.type&&!e.noLabelsProvided)&&(e.minX=e.minX-2,e.initialMinX=e.minX,e.maxX=e.maxX+2,e.initialMaxX=e.maxX)}}},{key:"_getMinXDiff",value:function(){var e=this.w.globals;e.isXNumeric&&e.seriesX.forEach((function(t,i){1===t.length&&t.push(e.seriesX[e.maxValsInArrayIndex][e.seriesX[e.maxValsInArrayIndex].length-1]);var n=t.slice();n.sort((function(e,t){return e-t})),n.forEach((function(t,i){if(i>0){var r=t-n[i-1];r>0&&(e.minXDiff=Math.min(r,e.minXDiff))}})),1!==e.dataPoints&&e.minXDiff!==Number.MAX_VALUE||(e.minXDiff=.5)}))}},{key:"_setStackedMinMax",value:function(){var e=this,t=this.w.globals;if(t.series.length){var i=t.seriesGroups;i.length||(i=[this.w.globals.seriesNames.map((function(e){return e}))]);var n={},r={};i.forEach((function(i){n[i]=[],r[i]=[],e.w.config.series.map((function(e,n){return i.indexOf(t.seriesNames[n])>-1?n:null})).filter((function(e){return null!==e})).forEach((function(a){for(var s=0;s<t.series[t.maxValsInArrayIndex].length;s++){var o,l,c,u;void 0===n[i][s]&&(n[i][s]=0,r[i][s]=0),(e.w.config.chart.stacked&&!t.comboCharts||e.w.config.chart.stacked&&t.comboCharts&&(!e.w.config.chart.stackOnlyBar||"bar"===(null===(o=e.w.config.series)||void 0===o||null===(l=o[a])||void 0===l?void 0:l.type)||"column"===(null===(c=e.w.config.series)||void 0===c||null===(u=c[a])||void 0===u?void 0:u.type)))&&null!==t.series[a][s]&&g.isNumber(t.series[a][s])&&(t.series[a][s]>0?n[i][s]+=parseFloat(t.series[a][s])+1e-4:r[i][s]+=parseFloat(t.series[a][s]))}}))})),Object.entries(n).forEach((function(e){var i=h(e,1)[0];n[i].forEach((function(e,a){t.maxY=Math.max(t.maxY,n[i][a]),t.minY=Math.min(t.minY,r[i][a])}))}))}}}]),e}(),X=function(){function e(t,i){n(this,e),this.ctx=t,this.elgrid=i,this.w=t.w;var r=this.w;this.xaxisFontSize=r.config.xaxis.labels.style.fontSize,this.axisFontFamily=r.config.xaxis.labels.style.fontFamily,this.xaxisForeColors=r.config.xaxis.labels.style.colors,this.isCategoryBarHorizontal="bar"===r.config.chart.type&&r.config.plotOptions.bar.horizontal,this.xAxisoffX=0,"bottom"===r.config.xaxis.position&&(this.xAxisoffX=r.globals.gridHeight),this.drawnLabels=[],this.axesUtils=new S(t)}return a(e,[{key:"drawYaxis",value:function(e){var t=this,i=this.w,n=new b(this.ctx),r=i.config.yaxis[e].labels.style,a=r.fontSize,s=r.fontFamily,o=r.fontWeight,l=n.group({class:"apexcharts-yaxis",rel:e,transform:"translate("+i.globals.translateYAxisX[e]+", 0)"});if(this.axesUtils.isYAxisHidden(e))return l;var c=n.group({class:"apexcharts-yaxis-texts-g"});l.add(c);var u=i.globals.yAxisScale[e].result.length-1,d=i.globals.gridHeight/u,h=i.globals.yLabelFormatters[e],f=i.globals.yAxisScale[e].result.slice();f=this.axesUtils.checkForReversedLabels(e,f);var p="";if(i.config.yaxis[e].labels.show){var m=i.globals.translateY+i.config.yaxis[e].labels.offsetY;i.globals.isBarHorizontal?m=0:"heatmap"===i.config.chart.type&&(m-=d/2),m+=parseInt(i.config.yaxis[e].labels.style.fontSize,10)/3;for(var g=function(l){var g=f[l];g=h(g,l,i);var v=i.config.yaxis[e].labels.padding;i.config.yaxis[e].opposite&&0!==i.config.yaxis.length&&(v*=-1);var y="end";i.config.yaxis[e].opposite&&(y="start"),"left"===i.config.yaxis[e].labels.align?y="start":"center"===i.config.yaxis[e].labels.align?y="middle":"right"===i.config.yaxis[e].labels.align&&(y="end");var b=t.axesUtils.getYAxisForeColor(r.colors,e),x=n.drawText({x:v,y:m,text:g,textAnchor:y,fontSize:a,fontFamily:s,fontWeight:o,maxWidth:i.config.yaxis[e].labels.maxWidth,foreColor:Array.isArray(b)?b[l]:b,isPlainText:!1,cssClass:"apexcharts-yaxis-label "+r.cssClass});l===u&&(p=x),c.add(x);var _=document.createElementNS(i.globals.SVGNS,"title");if(_.textContent=Array.isArray(g)?g.join(" "):g,x.node.appendChild(_),0!==i.config.yaxis[e].labels.rotate){var w=n.rotateAroundCenter(p.node),k=n.rotateAroundCenter(x.node);x.node.setAttribute("transform","rotate(".concat(i.config.yaxis[e].labels.rotate," ").concat(w.x," ").concat(k.y,")"))}m+=d},v=u;v>=0;v--)g(v)}if(void 0!==i.config.yaxis[e].title.text){var y=n.group({class:"apexcharts-yaxis-title"}),x=0;i.config.yaxis[e].opposite&&(x=i.globals.translateYAxisX[e]);var _=n.drawText({x:x,y:i.globals.gridHeight/2+i.globals.translateY+i.config.yaxis[e].title.offsetY,text:i.config.yaxis[e].title.text,textAnchor:"end",foreColor:i.config.yaxis[e].title.style.color,fontSize:i.config.yaxis[e].title.style.fontSize,fontWeight:i.config.yaxis[e].title.style.fontWeight,fontFamily:i.config.yaxis[e].title.style.fontFamily,cssClass:"apexcharts-yaxis-title-text "+i.config.yaxis[e].title.style.cssClass});y.add(_),l.add(y)}var w=i.config.yaxis[e].axisBorder,k=31+w.offsetX;if(i.config.yaxis[e].opposite&&(k=-31-w.offsetX),w.show){var M=n.drawLine(k,i.globals.translateY+w.offsetY-2,k,i.globals.gridHeight+i.globals.translateY+w.offsetY+2,w.color,0,w.width);l.add(M)}return i.config.yaxis[e].axisTicks.show&&this.axesUtils.drawYAxisTicks(k,u,w,i.config.yaxis[e].axisTicks,e,d,l),l}},{key:"drawYaxisInversed",value:function(e){var t=this.w,i=new b(this.ctx),n=i.group({class:"apexcharts-xaxis apexcharts-yaxis-inversed"}),r=i.group({class:"apexcharts-xaxis-texts-g",transform:"translate(".concat(t.globals.translateXAxisX,", ").concat(t.globals.translateXAxisY,")")});n.add(r);var a=t.globals.yAxisScale[e].result.length-1,s=t.globals.gridWidth/a+.1,o=s+t.config.xaxis.labels.offsetX,l=t.globals.xLabelFormatter,c=t.globals.yAxisScale[e].result.slice(),u=t.globals.timescaleLabels;u.length>0&&(this.xaxisLabels=u.slice(),a=(c=u.slice()).length),c=this.axesUtils.checkForReversedLabels(e,c);var d=u.length;if(t.config.xaxis.labels.show)for(var h=d?0:a;d?h<d:h>=0;d?h++:h--){var f=c[h];f=l(f,h,t);var p=t.globals.gridWidth+t.globals.padHorizontal-(o-s+t.config.xaxis.labels.offsetX);if(u.length){var m=this.axesUtils.getLabel(c,u,p,h,this.drawnLabels,this.xaxisFontSize);p=m.x,f=m.text,this.drawnLabels.push(m.text),0===h&&t.globals.skipFirstTimelinelabel&&(f=""),h===c.length-1&&t.globals.skipLastTimelinelabel&&(f="")}var g=i.drawText({x:p,y:this.xAxisoffX+t.config.xaxis.labels.offsetY+30-("top"===t.config.xaxis.position?t.globals.xAxisHeight+t.config.xaxis.axisTicks.height-2:0),text:f,textAnchor:"middle",foreColor:Array.isArray(this.xaxisForeColors)?this.xaxisForeColors[e]:this.xaxisForeColors,fontSize:this.xaxisFontSize,fontFamily:this.xaxisFontFamily,fontWeight:t.config.xaxis.labels.style.fontWeight,isPlainText:!1,cssClass:"apexcharts-xaxis-label "+t.config.xaxis.labels.style.cssClass});r.add(g),g.tspan(f);var v=document.createElementNS(t.globals.SVGNS,"title");v.textContent=f,g.node.appendChild(v),o+=s}return this.inversedYAxisTitleText(n),this.inversedYAxisBorder(n),n}},{key:"inversedYAxisBorder",value:function(e){var t=this.w,i=new b(this.ctx),n=t.config.xaxis.axisBorder;if(n.show){var r=0;"bar"===t.config.chart.type&&t.globals.isXNumeric&&(r-=15);var a=i.drawLine(t.globals.padHorizontal+r+n.offsetX,this.xAxisoffX,t.globals.gridWidth,this.xAxisoffX,n.color,0,n.height);this.elgrid&&this.elgrid.elGridBorders&&t.config.grid.show?this.elgrid.elGridBorders.add(a):e.add(a)}}},{key:"inversedYAxisTitleText",value:function(e){var t=this.w,i=new b(this.ctx);if(void 0!==t.config.xaxis.title.text){var n=i.group({class:"apexcharts-xaxis-title apexcharts-yaxis-title-inversed"}),r=i.drawText({x:t.globals.gridWidth/2+t.config.xaxis.title.offsetX,y:this.xAxisoffX+parseFloat(this.xaxisFontSize)+parseFloat(t.config.xaxis.title.style.fontSize)+t.config.xaxis.title.offsetY+20,text:t.config.xaxis.title.text,textAnchor:"middle",fontSize:t.config.xaxis.title.style.fontSize,fontFamily:t.config.xaxis.title.style.fontFamily,fontWeight:t.config.xaxis.title.style.fontWeight,foreColor:t.config.xaxis.title.style.color,cssClass:"apexcharts-xaxis-title-text "+t.config.xaxis.title.style.cssClass});n.add(r),e.add(n)}}},{key:"yAxisTitleRotate",value:function(e,t){var i=this.w,n=new b(this.ctx),r={width:0,height:0},a={width:0,height:0},s=i.globals.dom.baseEl.querySelector(" .apexcharts-yaxis[rel='".concat(e,"'] .apexcharts-yaxis-texts-g"));null!==s&&(r=s.getBoundingClientRect());var o=i.globals.dom.baseEl.querySelector(".apexcharts-yaxis[rel='".concat(e,"'] .apexcharts-yaxis-title text"));if(null!==o&&(a=o.getBoundingClientRect()),null!==o){var l=this.xPaddingForYAxisTitle(e,r,a,t);o.setAttribute("x",l.xPos-(t?10:0))}if(null!==o){var c=n.rotateAroundCenter(o);o.setAttribute("transform","rotate(".concat(t?-1*i.config.yaxis[e].title.rotate:i.config.yaxis[e].title.rotate," ").concat(c.x," ").concat(c.y,")"))}}},{key:"xPaddingForYAxisTitle",value:function(e,t,i,n){var r=this.w,a=0,s=0,o=10;return void 0===r.config.yaxis[e].title.text||e<0?{xPos:s,padd:0}:(n?(s=t.width+r.config.yaxis[e].title.offsetX+i.width/2+o/2,0===(a+=1)&&(s-=o/2)):(s=-1*t.width+r.config.yaxis[e].title.offsetX+o/2+i.width/2,r.globals.isBarHorizontal&&(o=25,s=-1*t.width-r.config.yaxis[e].title.offsetX-o)),{xPos:s,padd:o})}},{key:"setYAxisXPosition",value:function(e,t){var i=this.w,n=0,r=0,a=18,s=1;i.config.yaxis.length>1&&(this.multipleYs=!0),i.config.yaxis.map((function(o,l){var c=i.globals.ignoreYAxisIndexes.indexOf(l)>-1||!o.show||o.floating||0===e[l].width,u=e[l].width+t[l].width;o.opposite?i.globals.isBarHorizontal?(r=i.globals.gridWidth+i.globals.translateX-1,i.globals.translateYAxisX[l]=r-o.labels.offsetX):(r=i.globals.gridWidth+i.globals.translateX+s,c||(s=s+u+20),i.globals.translateYAxisX[l]=r-o.labels.offsetX+20):(n=i.globals.translateX-a,c||(a=a+u+20),i.globals.translateYAxisX[l]=n+o.labels.offsetX)}))}},{key:"setYAxisTextAlignments",value:function(){var e=this.w,t=e.globals.dom.baseEl.getElementsByClassName("apexcharts-yaxis");(t=g.listToArray(t)).forEach((function(t,i){var n=e.config.yaxis[i];if(n&&!n.floating&&void 0!==n.labels.align){var r=e.globals.dom.baseEl.querySelector(".apexcharts-yaxis[rel='".concat(i,"'] .apexcharts-yaxis-texts-g")),a=e.globals.dom.baseEl.querySelectorAll(".apexcharts-yaxis[rel='".concat(i,"'] .apexcharts-yaxis-label"));a=g.listToArray(a);var s=r.getBoundingClientRect();"left"===n.labels.align?(a.forEach((function(e,t){e.setAttribute("text-anchor","start")})),n.opposite||r.setAttribute("transform","translate(-".concat(s.width,", 0)"))):"center"===n.labels.align?(a.forEach((function(e,t){e.setAttribute("text-anchor","middle")})),r.setAttribute("transform","translate(".concat(s.width/2*(n.opposite?1:-1),", 0)"))):"right"===n.labels.align&&(a.forEach((function(e,t){e.setAttribute("text-anchor","end")})),n.opposite&&r.setAttribute("transform","translate(".concat(s.width,", 0)")))}}))}}]),e}(),G=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.documentEvent=g.bind(this.documentEvent,this)}return a(e,[{key:"addEventListener",value:function(e,t){var i=this.w;i.globals.events.hasOwnProperty(e)?i.globals.events[e].push(t):i.globals.events[e]=[t]}},{key:"removeEventListener",value:function(e,t){var i=this.w;if(i.globals.events.hasOwnProperty(e)){var n=i.globals.events[e].indexOf(t);-1!==n&&i.globals.events[e].splice(n,1)}}},{key:"fireEvent",value:function(e,t){var i=this.w;if(i.globals.events.hasOwnProperty(e)){t&&t.length||(t=[]);for(var n=i.globals.events[e],r=n.length,a=0;a<r;a++)n[a].apply(null,t)}}},{key:"setupEventHandlers",value:function(){var e=this,t=this.w,i=this.ctx,n=t.globals.dom.baseEl.querySelector(t.globals.chartClass);this.ctx.eventList.forEach((function(e){n.addEventListener(e,(function(e){var n=Object.assign({},t,{seriesIndex:t.globals.axisCharts?t.globals.capturedSeriesIndex:0,dataPointIndex:t.globals.capturedDataPointIndex});"mousemove"===e.type||"touchmove"===e.type?"function"==typeof t.config.chart.events.mouseMove&&t.config.chart.events.mouseMove(e,i,n):"mouseleave"===e.type||"touchleave"===e.type?"function"==typeof t.config.chart.events.mouseLeave&&t.config.chart.events.mouseLeave(e,i,n):("mouseup"===e.type&&1===e.which||"touchend"===e.type)&&("function"==typeof t.config.chart.events.click&&t.config.chart.events.click(e,i,n),i.ctx.events.fireEvent("click",[e,i,n]))}),{capture:!1,passive:!0})})),this.ctx.eventList.forEach((function(i){t.globals.dom.baseEl.addEventListener(i,e.documentEvent,{passive:!0})})),this.ctx.core.setupBrushHandler()}},{key:"documentEvent",value:function(e){var t=this.w,i=e.target.className;if("click"===e.type){var n=t.globals.dom.baseEl.querySelector(".apexcharts-menu");n&&n.classList.contains("apexcharts-menu-open")&&"apexcharts-menu-icon"!==i&&n.classList.remove("apexcharts-menu-open")}t.globals.clientX="touchmove"===e.type?e.touches[0].clientX:e.clientX,t.globals.clientY="touchmove"===e.type?e.touches[0].clientY:e.clientY}}]),e}(),Z=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"setCurrentLocaleValues",value:function(e){var t=this.w.config.chart.locales;window.Apex.chart&&window.Apex.chart.locales&&window.Apex.chart.locales.length>0&&(t=this.w.config.chart.locales.concat(window.Apex.chart.locales));var i=t.filter((function(t){return t.name===e}))[0];if(!i)throw new Error("Wrong locale name provided. Please make sure you set the correct locale name in options");var n=g.extend(T,i);this.w.globals.locale=n.options}}]),e}(),K=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"drawAxis",value:function(e,t){var i,n,r=this,a=this.w.globals,s=this.w.config,o=new W(this.ctx,t),l=new X(this.ctx,t);a.axisCharts&&"radar"!==e&&(a.isBarHorizontal?(n=l.drawYaxisInversed(0),i=o.drawXaxisInversed(0),a.dom.elGraphical.add(i),a.dom.elGraphical.add(n)):(i=o.drawXaxis(),a.dom.elGraphical.add(i),s.yaxis.map((function(e,t){if(-1===a.ignoreYAxisIndexes.indexOf(t)&&(n=l.drawYaxis(t),a.dom.Paper.add(n),"back"===r.w.config.grid.position)){var i=a.dom.Paper.children()[1];i.remove(),a.dom.Paper.add(i)}}))))}}]),e}(),J=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"drawXCrosshairs",value:function(){var e=this.w,t=new b(this.ctx),i=new y(this.ctx),n=e.config.xaxis.crosshairs.fill.gradient,r=e.config.xaxis.crosshairs.dropShadow,a=e.config.xaxis.crosshairs.fill.type,s=n.colorFrom,o=n.colorTo,l=n.opacityFrom,c=n.opacityTo,u=n.stops,d=r.enabled,h=r.left,f=r.top,p=r.blur,m=r.color,v=r.opacity,x=e.config.xaxis.crosshairs.fill.color;if(e.config.xaxis.crosshairs.show){"gradient"===a&&(x=t.drawGradient("vertical",s,o,l,c,null,u,null));var _=t.drawRect();1===e.config.xaxis.crosshairs.width&&(_=t.drawLine());var w=e.globals.gridHeight;(!g.isNumber(w)||w<0)&&(w=0);var k=e.config.xaxis.crosshairs.width;(!g.isNumber(k)||k<0)&&(k=0),_.attr({class:"apexcharts-xcrosshairs",x:0,y:0,y2:w,width:k,height:w,fill:x,filter:"none","fill-opacity":e.config.xaxis.crosshairs.opacity,stroke:e.config.xaxis.crosshairs.stroke.color,"stroke-width":e.config.xaxis.crosshairs.stroke.width,"stroke-dasharray":e.config.xaxis.crosshairs.stroke.dashArray}),d&&(_=i.dropShadow(_,{left:h,top:f,blur:p,color:m,opacity:v})),e.globals.dom.elGraphical.add(_)}}},{key:"drawYCrosshairs",value:function(){var e=this.w,t=new b(this.ctx),i=e.config.yaxis[0].crosshairs,n=e.globals.barPadForNumericAxis;if(e.config.yaxis[0].crosshairs.show){var r=t.drawLine(-n,0,e.globals.gridWidth+n,0,i.stroke.color,i.stroke.dashArray,i.stroke.width);r.attr({class:"apexcharts-ycrosshairs"}),e.globals.dom.elGraphical.add(r)}var a=t.drawLine(-n,0,e.globals.gridWidth+n,0,i.stroke.color,0,0);a.attr({class:"apexcharts-ycrosshairs-hidden"}),e.globals.dom.elGraphical.add(a)}}]),e}(),Q=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"checkResponsiveConfig",value:function(e){var t=this,i=this.w,n=i.config;if(0!==n.responsive.length){var r=n.responsive.slice();r.sort((function(e,t){return e.breakpoint>t.breakpoint?1:t.breakpoint>e.breakpoint?-1:0})).reverse();var a=new Y({}),s=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},n=r[0].breakpoint,s=window.innerWidth>0?window.innerWidth:screen.width;if(s>n){var o=g.clone(i.globals.initialConfig);o.series=g.clone(i.config.series);var l=x.extendArrayProps(a,o,i);e=g.extend(l,e),e=g.extend(i.config,e),t.overrideResponsiveOptions(e)}else for(var c=0;c<r.length;c++)if(s<r[c].breakpoint){var u=x.extendArrayProps(a,r[c].options,i);e=g.extend(u,e),e=g.extend(i.config,e),t.overrideResponsiveOptions(e)}};if(e){var o=x.extendArrayProps(a,e,i);o=g.extend(i.config,o),s(o=g.extend(o,e))}else s({})}}},{key:"overrideResponsiveOptions",value:function(e){var t=new Y(e).init({responsiveOverride:!0});this.w.config=t}}]),e}(),ee=function(){function e(t){n(this,e),this.ctx=t,this.colors=[],this.w=t.w;var i=this.w;this.isColorFn=!1,this.isHeatmapDistributed="treemap"===i.config.chart.type&&i.config.plotOptions.treemap.distributed||"heatmap"===i.config.chart.type&&i.config.plotOptions.heatmap.distributed,this.isBarDistributed=i.config.plotOptions.bar.distributed&&("bar"===i.config.chart.type||"rangeBar"===i.config.chart.type)}return a(e,[{key:"init",value:function(){this.setDefaultColors()}},{key:"setDefaultColors",value:function(){var e,t=this,i=this.w,n=new g;if(i.globals.dom.elWrap.classList.add("apexcharts-theme-".concat(i.config.theme.mode)),void 0===i.config.colors||0===(null===(e=i.config.colors)||void 0===e?void 0:e.length)?i.globals.colors=this.predefined():(i.globals.colors=i.config.colors,Array.isArray(i.config.colors)&&i.config.colors.length>0&&"function"==typeof i.config.colors[0]&&(i.globals.colors=i.config.series.map((function(e,n){var r=i.config.colors[n];return r||(r=i.config.colors[0]),"function"==typeof r?(t.isColorFn=!0,r({value:i.globals.axisCharts?i.globals.series[n][0]?i.globals.series[n][0]:0:i.globals.series[n],seriesIndex:n,dataPointIndex:n,w:i})):r})))),i.globals.seriesColors.map((function(e,t){e&&(i.globals.colors[t]=e)})),i.config.theme.monochrome.enabled){var r=[],a=i.globals.series.length;(this.isBarDistributed||this.isHeatmapDistributed)&&(a=i.globals.series[0].length*i.globals.series.length);for(var s=i.config.theme.monochrome.color,o=1/(a/i.config.theme.monochrome.shadeIntensity),l=i.config.theme.monochrome.shadeTo,c=0,u=0;u<a;u++){var d=void 0;"dark"===l?(d=n.shadeColor(-1*c,s),c+=o):(d=n.shadeColor(c,s),c+=o),r.push(d)}i.globals.colors=r.slice()}var h=i.globals.colors.slice();this.pushExtraColors(i.globals.colors),["fill","stroke"].forEach((function(e){void 0===i.config[e].colors?i.globals[e].colors=t.isColorFn?i.config.colors:h:i.globals[e].colors=i.config[e].colors.slice(),t.pushExtraColors(i.globals[e].colors)})),void 0===i.config.dataLabels.style.colors?i.globals.dataLabels.style.colors=h:i.globals.dataLabels.style.colors=i.config.dataLabels.style.colors.slice(),this.pushExtraColors(i.globals.dataLabels.style.colors,50),void 0===i.config.plotOptions.radar.polygons.fill.colors?i.globals.radarPolygons.fill.colors=["dark"===i.config.theme.mode?"#424242":"none"]:i.globals.radarPolygons.fill.colors=i.config.plotOptions.radar.polygons.fill.colors.slice(),this.pushExtraColors(i.globals.radarPolygons.fill.colors,20),void 0===i.config.markers.colors?i.globals.markers.colors=h:i.globals.markers.colors=i.config.markers.colors.slice(),this.pushExtraColors(i.globals.markers.colors)}},{key:"pushExtraColors",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null,n=this.w,r=t||n.globals.series.length;if(null===i&&(i=this.isBarDistributed||this.isHeatmapDistributed||"heatmap"===n.config.chart.type&&n.config.plotOptions.heatmap.colorScale.inverse),i&&n.globals.series.length&&(r=n.globals.series[n.globals.maxValsInArrayIndex].length*n.globals.series.length),e.length<r)for(var a=r-e.length,s=0;s<a;s++)e.push(e[s])}},{key:"updateThemeOptions",value:function(e){e.chart=e.chart||{},e.tooltip=e.tooltip||{};var t=e.theme.mode||"light",i=e.theme.palette?e.theme.palette:"dark"===t?"palette4":"palette1",n=e.chart.foreColor?e.chart.foreColor:"dark"===t?"#f6f7f8":"#373d3f";return e.tooltip.theme=t,e.chart.foreColor=n,e.theme.palette=i,e}},{key:"predefined",value:function(){switch(this.w.config.theme.palette){case"palette1":default:this.colors=["#008FFB","#00E396","#FEB019","#FF4560","#775DD0"];break;case"palette2":this.colors=["#3f51b5","#03a9f4","#4caf50","#f9ce1d","#FF9800"];break;case"palette3":this.colors=["#33b2df","#546E7A","#d4526e","#13d8aa","#A5978B"];break;case"palette4":this.colors=["#4ecdc4","#c7f464","#81D4FA","#fd6a6a","#546E7A"];break;case"palette5":this.colors=["#2b908f","#f9a3a4","#90ee7e","#fa4443","#69d2e7"];break;case"palette6":this.colors=["#449DD1","#F86624","#EA3546","#662E9B","#C5D86D"];break;case"palette7":this.colors=["#D7263D","#1B998B","#2E294E","#F46036","#E2C044"];break;case"palette8":this.colors=["#662E9B","#F86624","#F9C80E","#EA3546","#43BCCD"];break;case"palette9":this.colors=["#5C4742","#A5978B","#8D5B4C","#5A2A27","#C4BBAF"];break;case"palette10":this.colors=["#A300D6","#7D02EB","#5653FE","#2983FF","#00B1F2"]}return this.colors}}]),e}(),te=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"draw",value:function(){this.drawTitleSubtitle("title"),this.drawTitleSubtitle("subtitle")}},{key:"drawTitleSubtitle",value:function(e){var t=this.w,i="title"===e?t.config.title:t.config.subtitle,n=t.globals.svgWidth/2,r=i.offsetY,a="middle";if("left"===i.align?(n=10,a="start"):"right"===i.align&&(n=t.globals.svgWidth-10,a="end"),n+=i.offsetX,r=r+parseInt(i.style.fontSize,10)+i.margin/2,void 0!==i.text){var s=new b(this.ctx).drawText({x:n,y:r,text:i.text,textAnchor:a,fontSize:i.style.fontSize,fontFamily:i.style.fontFamily,fontWeight:i.style.fontWeight,foreColor:i.style.color,opacity:1});s.node.setAttribute("class","apexcharts-".concat(e,"-text")),t.globals.dom.Paper.add(s)}}}]),e}(),ie=function(){function e(t){n(this,e),this.w=t.w,this.dCtx=t}return a(e,[{key:"getTitleSubtitleCoords",value:function(e){var t=this.w,i=0,n=0,r="title"===e?t.config.title.floating:t.config.subtitle.floating,a=t.globals.dom.baseEl.querySelector(".apexcharts-".concat(e,"-text"));if(null!==a&&!r){var s=a.getBoundingClientRect();i=s.width,n=t.globals.axisCharts?s.height+5:s.height}return{width:i,height:n}}},{key:"getLegendsRect",value:function(){var e=this.w,t=e.globals.dom.elLegendWrap;e.config.legend.height||"top"!==e.config.legend.position&&"bottom"!==e.config.legend.position||(t.style.maxHeight=e.globals.svgHeight/2+"px");var i=Object.assign({},g.getBoundingClientRect(t));return null!==t&&!e.config.legend.floating&&e.config.legend.show?this.dCtx.lgRect={x:i.x,y:i.y,height:i.height,width:0===i.height?0:i.width}:this.dCtx.lgRect={x:0,y:0,height:0,width:0},"left"!==e.config.legend.position&&"right"!==e.config.legend.position||1.5*this.dCtx.lgRect.width>e.globals.svgWidth&&(this.dCtx.lgRect.width=e.globals.svgWidth/1.5),this.dCtx.lgRect}},{key:"getDatalabelsRect",value:function(){var e=this,t=this.w,i=[];t.config.series.forEach((function(r,a){r.data.forEach((function(r,s){var o;o=t.globals.series[a][s],n=t.config.dataLabels.formatter(o,{ctx:e.dCtx.ctx,seriesIndex:a,dataPointIndex:s,w:t}),i.push(n)}))}));var n=g.getLargestStringFromArr(i),r=new b(this.dCtx.ctx),a=t.config.dataLabels.style,s=r.getTextRects(n,parseInt(a.fontSize),a.fontFamily);return{width:1.05*s.width,height:s.height}}},{key:"getLargestStringFromMultiArr",value:function(e,t){var i=e;if(this.w.globals.isMultiLineX){var n=t.map((function(e,t){return Array.isArray(e)?e.length:1})),r=Math.max.apply(Math,f(n));i=t[n.indexOf(r)]}return i}}]),e}(),ne=function(){function e(t){n(this,e),this.w=t.w,this.dCtx=t}return a(e,[{key:"getxAxisLabelsCoords",value:function(){var e,t=this.w,i=t.globals.labels.slice();if(t.config.xaxis.convertedCatToNumeric&&0===i.length&&(i=t.globals.categoryLabels),t.globals.timescaleLabels.length>0){var n=this.getxAxisTimeScaleLabelsCoords();e={width:n.width,height:n.height},t.globals.rotateXLabels=!1}else{this.dCtx.lgWidthForSideLegends="left"!==t.config.legend.position&&"right"!==t.config.legend.position||t.config.legend.floating?0:this.dCtx.lgRect.width;var r=t.globals.xLabelFormatter,a=g.getLargestStringFromArr(i),s=this.dCtx.dimHelpers.getLargestStringFromMultiArr(a,i);t.globals.isBarHorizontal&&(s=a=t.globals.yAxisScale[0].result.reduce((function(e,t){return e.length>t.length?e:t}),0));var o=new M(this.dCtx.ctx),l=a;a=o.xLabelFormat(r,a,l,{i:void 0,dateFormatter:new k(this.dCtx.ctx).formatDate,w:t}),s=o.xLabelFormat(r,s,l,{i:void 0,dateFormatter:new k(this.dCtx.ctx).formatDate,w:t}),(t.config.xaxis.convertedCatToNumeric&&void 0===a||""===String(a).trim())&&(s=a="1");var c=new b(this.dCtx.ctx),u=c.getTextRects(a,t.config.xaxis.labels.style.fontSize),d=u;if(a!==s&&(d=c.getTextRects(s,t.config.xaxis.labels.style.fontSize)),(e={width:u.width>=d.width?u.width:d.width,height:u.height>=d.height?u.height:d.height}).width*i.length>t.globals.svgWidth-this.dCtx.lgWidthForSideLegends-this.dCtx.yAxisWidth-this.dCtx.gridPad.left-this.dCtx.gridPad.right&&0!==t.config.xaxis.labels.rotate||t.config.xaxis.labels.rotateAlways){if(!t.globals.isBarHorizontal){t.globals.rotateXLabels=!0;var h=function(e){return c.getTextRects(e,t.config.xaxis.labels.style.fontSize,t.config.xaxis.labels.style.fontFamily,"rotate(".concat(t.config.xaxis.labels.rotate," 0 0)"),!1)};u=h(a),a!==s&&(d=h(s)),e.height=(u.height>d.height?u.height:d.height)/1.5,e.width=u.width>d.width?u.width:d.width}}else t.globals.rotateXLabels=!1}return t.config.xaxis.labels.show||(e={width:0,height:0}),{width:e.width,height:e.height}}},{key:"getxAxisGroupLabelsCoords",value:function(){var e,t=this.w;if(!t.globals.hasXaxisGroups)return{width:0,height:0};var i,n=(null===(e=t.config.xaxis.group.style)||void 0===e?void 0:e.fontSize)||t.config.xaxis.labels.style.fontSize,r=t.globals.groups.map((function(e){return e.title})),a=g.getLargestStringFromArr(r),s=this.dCtx.dimHelpers.getLargestStringFromMultiArr(a,r),o=new b(this.dCtx.ctx),l=o.getTextRects(a,n),c=l;return a!==s&&(c=o.getTextRects(s,n)),i={width:l.width>=c.width?l.width:c.width,height:l.height>=c.height?l.height:c.height},t.config.xaxis.labels.show||(i={width:0,height:0}),{width:i.width,height:i.height}}},{key:"getxAxisTitleCoords",value:function(){var e=this.w,t=0,i=0;if(void 0!==e.config.xaxis.title.text){var n=new b(this.dCtx.ctx).getTextRects(e.config.xaxis.title.text,e.config.xaxis.title.style.fontSize);t=n.width,i=n.height}return{width:t,height:i}}},{key:"getxAxisTimeScaleLabelsCoords",value:function(){var e,t=this.w;this.dCtx.timescaleLabels=t.globals.timescaleLabels.slice();var i=this.dCtx.timescaleLabels.map((function(e){return e.value})),n=i.reduce((function(e,t){return void 0===e?(console.error("You have possibly supplied invalid Date format. Please supply a valid JavaScript Date"),0):e.length>t.length?e:t}),0);return 1.05*(e=new b(this.dCtx.ctx).getTextRects(n,t.config.xaxis.labels.style.fontSize)).width*i.length>t.globals.gridWidth&&0!==t.config.xaxis.labels.rotate&&(t.globals.overlappingXLabels=!0),e}},{key:"additionalPaddingXLabels",value:function(e){var t=this,i=this.w,n=i.globals,r=i.config,a=r.xaxis.type,s=e.width;n.skipLastTimelinelabel=!1,n.skipFirstTimelinelabel=!1;var o=i.config.yaxis[0].opposite&&i.globals.isBarHorizontal,l=function(e,o){r.yaxis.length>1&&function(e){return-1!==n.collapsedSeriesIndices.indexOf(e)}(o)||function(e){if(t.dCtx.timescaleLabels&&t.dCtx.timescaleLabels.length){var o=t.dCtx.timescaleLabels[0],l=t.dCtx.timescaleLabels[t.dCtx.timescaleLabels.length-1].position+s/1.75-t.dCtx.yAxisWidthRight,c=o.position-s/1.75+t.dCtx.yAxisWidthLeft,u="right"===i.config.legend.position&&t.dCtx.lgRect.width>0?t.dCtx.lgRect.width:0;l>n.svgWidth-n.translateX-u&&(n.skipLastTimelinelabel=!0),c<-(e.show&&!e.floating||"bar"!==r.chart.type&&"candlestick"!==r.chart.type&&"rangeBar"!==r.chart.type&&"boxPlot"!==r.chart.type?10:s/1.75)&&(n.skipFirstTimelinelabel=!0)}else"datetime"===a?t.dCtx.gridPad.right<s&&!n.rotateXLabels&&(n.skipLastTimelinelabel=!0):"datetime"!==a&&t.dCtx.gridPad.right<s/2-t.dCtx.yAxisWidthRight&&!n.rotateXLabels&&!i.config.xaxis.labels.trim&&("between"!==i.config.xaxis.tickPlacement||i.globals.isBarHorizontal)&&(t.dCtx.xPadRight=s/2+1)}(e)};r.yaxis.forEach((function(e,i){o?(t.dCtx.gridPad.left<s&&(t.dCtx.xPadLeft=s/2+1),t.dCtx.xPadRight=s/2+1):l(e,i)}))}}]),e}(),re=function(){function e(t){n(this,e),this.w=t.w,this.dCtx=t}return a(e,[{key:"getyAxisLabelsCoords",value:function(){var e=this,t=this.w,i=[],n=10,r=new S(this.dCtx.ctx);return t.config.yaxis.map((function(a,s){var o={seriesIndex:s,dataPointIndex:-1,w:t},l=t.globals.yAxisScale[s],c=0;if(!r.isYAxisHidden(s)&&a.labels.show&&void 0!==a.labels.minWidth&&(c=a.labels.minWidth),!r.isYAxisHidden(s)&&a.labels.show&&l.result.length){var u=t.globals.yLabelFormatters[s],d=l.niceMin===Number.MIN_VALUE?0:l.niceMin,h=l.result.reduce((function(e,t){var i,n;return(null===(i=String(u(e,o)))||void 0===i?void 0:i.length)>(null===(n=String(u(t,o)))||void 0===n?void 0:n.length)?e:t}),d),f=h=u(h,o);if(void 0!==h&&0!==h.length||(h=l.niceMax),t.globals.isBarHorizontal){n=0;var p=t.globals.labels.slice();h=g.getLargestStringFromArr(p),h=u(h,{seriesIndex:s,dataPointIndex:-1,w:t}),f=e.dCtx.dimHelpers.getLargestStringFromMultiArr(h,p)}var m=new b(e.dCtx.ctx),v="rotate(".concat(a.labels.rotate," 0 0)"),y=m.getTextRects(h,a.labels.style.fontSize,a.labels.style.fontFamily,v,!1),x=y;h!==f&&(x=m.getTextRects(f,a.labels.style.fontSize,a.labels.style.fontFamily,v,!1)),i.push({width:(c>x.width||c>y.width?c:x.width>y.width?x.width:y.width)+n,height:x.height>y.height?x.height:y.height})}else i.push({width:0,height:0})})),i}},{key:"getyAxisTitleCoords",value:function(){var e=this,t=this.w,i=[];return t.config.yaxis.map((function(t,n){if(t.show&&void 0!==t.title.text){var r=new b(e.dCtx.ctx),a="rotate(".concat(t.title.rotate," 0 0)"),s=r.getTextRects(t.title.text,t.title.style.fontSize,t.title.style.fontFamily,a,!1);i.push({width:s.width,height:s.height})}else i.push({width:0,height:0})})),i}},{key:"getTotalYAxisWidth",value:function(){var e=this.w,t=0,i=0,n=0,r=e.globals.yAxisScale.length>1?10:0,a=new S(this.dCtx.ctx),s=function(s,o){var l=e.config.yaxis[o].floating,c=0;s.width>0&&!l?(c=s.width+r,function(t){return e.globals.ignoreYAxisIndexes.indexOf(t)>-1}(o)&&(c=c-s.width-r)):c=l||a.isYAxisHidden(o)?0:5,e.config.yaxis[o].opposite?n+=c:i+=c,t+=c};return e.globals.yLabelsCoords.map((function(e,t){s(e,t)})),e.globals.yTitleCoords.map((function(e,t){s(e,t)})),e.globals.isBarHorizontal&&!e.config.yaxis[0].floating&&(t=e.globals.yLabelsCoords[0].width+e.globals.yTitleCoords[0].width+15),this.dCtx.yAxisWidthLeft=i,this.dCtx.yAxisWidthRight=n,t}}]),e}(),ae=function(){function e(t){n(this,e),this.w=t.w,this.dCtx=t}return a(e,[{key:"gridPadForColumnsInNumericAxis",value:function(e){var t=this.w,i=t.config,n=t.globals;if(n.noData||n.collapsedSeries.length+n.ancillaryCollapsedSeries.length===i.series.length)return 0;var r=function(e){return"bar"===e||"rangeBar"===e||"candlestick"===e||"boxPlot"===e},a=i.chart.type,s=0,o=r(a)?i.series.length:1;if(n.comboBarCount>0&&(o=n.comboBarCount),n.collapsedSeries.forEach((function(e){r(e.type)&&(o-=1)})),i.chart.stacked&&(o=1),(r(a)||n.comboBarCount>0)&&n.isXNumeric&&!n.isBarHorizontal&&o>0){var l,c,u=Math.abs(n.initialMaxX-n.initialMinX);u<=3&&(u=n.dataPoints),l=u/e,n.minXDiff&&n.minXDiff/l>0&&(c=n.minXDiff/l),c>e/2&&(c/=2),(s=c*parseInt(i.plotOptions.bar.columnWidth,10)/100)<1&&(s=1),n.barPadForNumericAxis=s}return s}},{key:"gridPadFortitleSubtitle",value:function(){var e=this,t=this.w,i=t.globals,n=this.dCtx.isSparkline||!t.globals.axisCharts?0:10;["title","subtitle"].forEach((function(i){void 0!==t.config[i].text?n+=t.config[i].margin:n+=e.dCtx.isSparkline||!t.globals.axisCharts?0:5})),!t.config.legend.show||"bottom"!==t.config.legend.position||t.config.legend.floating||t.globals.axisCharts||(n+=10);var r=this.dCtx.dimHelpers.getTitleSubtitleCoords("title"),a=this.dCtx.dimHelpers.getTitleSubtitleCoords("subtitle");i.gridHeight=i.gridHeight-r.height-a.height-n,i.translateY=i.translateY+r.height+a.height+n}},{key:"setGridXPosForDualYAxis",value:function(e,t){var i=this.w,n=new S(this.dCtx.ctx);i.config.yaxis.map((function(r,a){-1!==i.globals.ignoreYAxisIndexes.indexOf(a)||r.floating||n.isYAxisHidden(a)||(r.opposite&&(i.globals.translateX=i.globals.translateX-(t[a].width+e[a].width)-parseInt(i.config.yaxis[a].labels.style.fontSize,10)/1.2-12),i.globals.translateX<2&&(i.globals.translateX=2))}))}}]),e}(),se=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.lgRect={},this.yAxisWidth=0,this.yAxisWidthLeft=0,this.yAxisWidthRight=0,this.xAxisHeight=0,this.isSparkline=this.w.config.chart.sparkline.enabled,this.dimHelpers=new ie(this),this.dimYAxis=new re(this),this.dimXAxis=new ne(this),this.dimGrid=new ae(this),this.lgWidthForSideLegends=0,this.gridPad=this.w.config.grid.padding,this.xPadRight=0,this.xPadLeft=0}return a(e,[{key:"plotCoords",value:function(){var e=this,t=this.w,i=t.globals;this.lgRect=this.dimHelpers.getLegendsRect(),this.datalabelsCoords={width:0,height:0};var n=Array.isArray(t.config.stroke.width)?Math.max.apply(Math,f(t.config.stroke.width)):t.config.stroke.width;this.isSparkline&&((t.config.markers.discrete.length>0||t.config.markers.size>0)&&Object.entries(this.gridPad).forEach((function(t){var i=h(t,2),n=i[0],r=i[1];e.gridPad[n]=Math.max(r,e.w.globals.markers.largestSize/1.5)})),this.gridPad.top=Math.max(n/2,this.gridPad.top),this.gridPad.bottom=Math.max(n/2,this.gridPad.bottom)),i.axisCharts?this.setDimensionsForAxisCharts():this.setDimensionsForNonAxisCharts(),this.dimGrid.gridPadFortitleSubtitle(),i.gridHeight=i.gridHeight-this.gridPad.top-this.gridPad.bottom,i.gridWidth=i.gridWidth-this.gridPad.left-this.gridPad.right-this.xPadRight-this.xPadLeft;var r=this.dimGrid.gridPadForColumnsInNumericAxis(i.gridWidth);i.gridWidth=i.gridWidth-2*r,i.translateX=i.translateX+this.gridPad.left+this.xPadLeft+(r>0?r:0),i.translateY=i.translateY+this.gridPad.top}},{key:"setDimensionsForAxisCharts",value:function(){var e=this,t=this.w,i=t.globals,n=this.dimYAxis.getyAxisLabelsCoords(),r=this.dimYAxis.getyAxisTitleCoords();i.isSlopeChart&&(this.datalabelsCoords=this.dimHelpers.getDatalabelsRect()),t.globals.yLabelsCoords=[],t.globals.yTitleCoords=[],t.config.yaxis.map((function(e,i){t.globals.yLabelsCoords.push({width:n[i].width,index:i}),t.globals.yTitleCoords.push({width:r[i].width,index:i})})),this.yAxisWidth=this.dimYAxis.getTotalYAxisWidth();var a=this.dimXAxis.getxAxisLabelsCoords(),s=this.dimXAxis.getxAxisGroupLabelsCoords(),o=this.dimXAxis.getxAxisTitleCoords();this.conditionalChecksForAxisCoords(a,o,s),i.translateXAxisY=t.globals.rotateXLabels?this.xAxisHeight/8:-4,i.translateXAxisX=t.globals.rotateXLabels&&t.globals.isXNumeric&&t.config.xaxis.labels.rotate<=-45?-this.xAxisWidth/4:0,t.globals.isBarHorizontal&&(i.rotateXLabels=!1,i.translateXAxisY=parseInt(t.config.xaxis.labels.style.fontSize,10)/1.5*-1),i.translateXAxisY=i.translateXAxisY+t.config.xaxis.labels.offsetY,i.translateXAxisX=i.translateXAxisX+t.config.xaxis.labels.offsetX;var l=this.yAxisWidth,c=this.xAxisHeight;i.xAxisLabelsHeight=this.xAxisHeight-o.height,i.xAxisGroupLabelsHeight=i.xAxisLabelsHeight-a.height,i.xAxisLabelsWidth=this.xAxisWidth,i.xAxisHeight=this.xAxisHeight;var u=10;("radar"===t.config.chart.type||this.isSparkline)&&(l=0,c=i.goldenPadding),this.isSparkline&&(this.lgRect={height:0,width:0}),(this.isSparkline||"treemap"===t.config.chart.type)&&(l=0,c=0,u=0),this.isSparkline||this.dimXAxis.additionalPaddingXLabels(a);var d=function(){i.translateX=l+e.datalabelsCoords.width,i.gridHeight=i.svgHeight-e.lgRect.height-c-(e.isSparkline||"treemap"===t.config.chart.type?0:t.globals.rotateXLabels?10:15),i.gridWidth=i.svgWidth-l-2*e.datalabelsCoords.width};switch("top"===t.config.xaxis.position&&(u=i.xAxisHeight-t.config.xaxis.axisTicks.height-5),t.config.legend.position){case"bottom":i.translateY=u,d();break;case"top":i.translateY=this.lgRect.height+u,d();break;case"left":i.translateY=u,i.translateX=this.lgRect.width+l+this.datalabelsCoords.width,i.gridHeight=i.svgHeight-c-12,i.gridWidth=i.svgWidth-this.lgRect.width-l-2*this.datalabelsCoords.width;break;case"right":i.translateY=u,i.translateX=l+this.datalabelsCoords.width,i.gridHeight=i.svgHeight-c-12,i.gridWidth=i.svgWidth-this.lgRect.width-l-2*this.datalabelsCoords.width-5;break;default:throw new Error("Legend position not supported")}this.dimGrid.setGridXPosForDualYAxis(r,n),new X(this.ctx).setYAxisXPosition(n,r)}},{key:"setDimensionsForNonAxisCharts",value:function(){var e=this.w,t=e.globals,i=e.config,n=0;e.config.legend.show&&!e.config.legend.floating&&(n=20);var r="pie"===i.chart.type||"polarArea"===i.chart.type||"donut"===i.chart.type?"pie":"radialBar",a=i.plotOptions[r].offsetY,s=i.plotOptions[r].offsetX;if(!i.legend.show||i.legend.floating)return t.gridHeight=t.svgHeight-i.grid.padding.left+i.grid.padding.right,t.gridWidth=Math.min(t.svgWidth,t.gridHeight),t.translateY=a,void(t.translateX=s+(t.svgWidth-t.gridWidth)/2);switch(i.legend.position){case"bottom":t.gridHeight=t.svgHeight-this.lgRect.height-t.goldenPadding,t.gridWidth=t.svgWidth,t.translateY=a-10,t.translateX=s+(t.svgWidth-t.gridWidth)/2;break;case"top":t.gridHeight=t.svgHeight-this.lgRect.height-t.goldenPadding,t.gridWidth=t.svgWidth,t.translateY=this.lgRect.height+a+10,t.translateX=s+(t.svgWidth-t.gridWidth)/2;break;case"left":t.gridWidth=t.svgWidth-this.lgRect.width-n,t.gridHeight="auto"!==i.chart.height?t.svgHeight:t.gridWidth,t.translateY=a,t.translateX=s+this.lgRect.width+n;break;case"right":t.gridWidth=t.svgWidth-this.lgRect.width-n-5,t.gridHeight="auto"!==i.chart.height?t.svgHeight:t.gridWidth,t.translateY=a,t.translateX=s+10;break;default:throw new Error("Legend position not supported")}}},{key:"conditionalChecksForAxisCoords",value:function(e,t,i){var n=this.w,r=n.globals.hasXaxisGroups?2:1,a=i.height+e.height+t.height,s=n.globals.isMultiLineX?1.2:n.globals.LINE_HEIGHT_RATIO,o=n.globals.rotateXLabels?22:10,l=n.globals.rotateXLabels&&"bottom"===n.config.legend.position?10:0;this.xAxisHeight=a*s+r*o+l,this.xAxisWidth=e.width,this.xAxisHeight-t.height>n.config.xaxis.labels.maxHeight&&(this.xAxisHeight=n.config.xaxis.labels.maxHeight),n.config.xaxis.labels.minHeight&&this.xAxisHeight<n.config.xaxis.labels.minHeight&&(this.xAxisHeight=n.config.xaxis.labels.minHeight),n.config.xaxis.floating&&(this.xAxisHeight=0);var c=0,u=0;n.config.yaxis.forEach((function(e){c+=e.labels.minWidth,u+=e.labels.maxWidth})),this.yAxisWidth<c&&(this.yAxisWidth=c),this.yAxisWidth>u&&(this.yAxisWidth=u)}}]),e}(),oe=function(){function e(t){n(this,e),this.w=t.w,this.lgCtx=t}return a(e,[{key:"getLegendStyles",value:function(){var e,t,i,n=document.createElement("style");n.setAttribute("type","text/css");var r=(null===(e=this.lgCtx.ctx)||void 0===e||null===(t=e.opts)||void 0===t||null===(i=t.chart)||void 0===i?void 0:i.nonce)||this.w.config.chart.nonce;r&&n.setAttribute("nonce",r);var a=document.createTextNode("\n      .apexcharts-legend {\n        display: flex;\n        overflow: auto;\n        padding: 0 10px;\n      }\n      .apexcharts-legend.apx-legend-position-bottom, .apexcharts-legend.apx-legend-position-top {\n        flex-wrap: wrap\n      }\n      .apexcharts-legend.apx-legend-position-right, .apexcharts-legend.apx-legend-position-left {\n        flex-direction: column;\n        bottom: 0;\n      }\n      .apexcharts-legend.apx-legend-position-bottom.apexcharts-align-left, .apexcharts-legend.apx-legend-position-top.apexcharts-align-left, .apexcharts-legend.apx-legend-position-right, .apexcharts-legend.apx-legend-position-left {\n        justify-content: flex-start;\n      }\n      .apexcharts-legend.apx-legend-position-bottom.apexcharts-align-center, .apexcharts-legend.apx-legend-position-top.apexcharts-align-center {\n        justify-content: center;\n      }\n      .apexcharts-legend.apx-legend-position-bottom.apexcharts-align-right, .apexcharts-legend.apx-legend-position-top.apexcharts-align-right {\n        justify-content: flex-end;\n      }\n      .apexcharts-legend-series {\n        cursor: pointer;\n        line-height: normal;\n      }\n      .apexcharts-legend.apx-legend-position-bottom .apexcharts-legend-series, .apexcharts-legend.apx-legend-position-top .apexcharts-legend-series{\n        display: flex;\n        align-items: center;\n      }\n      .apexcharts-legend-text {\n        position: relative;\n        font-size: 14px;\n      }\n      .apexcharts-legend-text *, .apexcharts-legend-marker * {\n        pointer-events: none;\n      }\n      .apexcharts-legend-marker {\n        position: relative;\n        display: inline-block;\n        cursor: pointer;\n        margin-right: 3px;\n        border-style: solid;\n      }\n\n      .apexcharts-legend.apexcharts-align-right .apexcharts-legend-series, .apexcharts-legend.apexcharts-align-left .apexcharts-legend-series{\n        display: inline-block;\n      }\n      .apexcharts-legend-series.apexcharts-no-click {\n        cursor: auto;\n      }\n      .apexcharts-legend .apexcharts-hidden-zero-series, .apexcharts-legend .apexcharts-hidden-null-series {\n        display: none !important;\n      }\n      .apexcharts-inactive-legend {\n        opacity: 0.45;\n      }");return n.appendChild(a),n}},{key:"getLegendBBox",value:function(){var e=this.w.globals.dom.baseEl.querySelector(".apexcharts-legend").getBoundingClientRect(),t=e.width;return{clwh:e.height,clww:t}}},{key:"appendToForeignObject",value:function(){this.w.globals.dom.elLegendForeign.appendChild(this.getLegendStyles())}},{key:"toggleDataSeries",value:function(e,t){var i=this,n=this.w;if(n.globals.axisCharts||"radialBar"===n.config.chart.type){n.globals.resized=!0;var r=null,a=null;n.globals.risingSeries=[],n.globals.axisCharts?(r=n.globals.dom.baseEl.querySelector(".apexcharts-series[data\\:realIndex='".concat(e,"']")),a=parseInt(r.getAttribute("data:realIndex"),10)):(r=n.globals.dom.baseEl.querySelector(".apexcharts-series[rel='".concat(e+1,"']")),a=parseInt(r.getAttribute("rel"),10)-1),t?[{cs:n.globals.collapsedSeries,csi:n.globals.collapsedSeriesIndices},{cs:n.globals.ancillaryCollapsedSeries,csi:n.globals.ancillaryCollapsedSeriesIndices}].forEach((function(e){i.riseCollapsedSeries(e.cs,e.csi,a)})):this.hideSeries({seriesEl:r,realIndex:a})}else{var s=n.globals.dom.Paper.select(" .apexcharts-series[rel='".concat(e+1,"'] path")),o=n.config.chart.type;if("pie"===o||"polarArea"===o||"donut"===o){var l=n.config.plotOptions.pie.donut.labels;new b(this.lgCtx.ctx).pathMouseDown(s.members[0],null),this.lgCtx.ctx.pie.printDataLabelsInner(s.members[0].node,l)}s.fire("click")}}},{key:"hideSeries",value:function(e){var t=e.seriesEl,i=e.realIndex,n=this.w,r=n.globals,a=g.clone(n.config.series);if(r.axisCharts){var s=n.config.yaxis[r.seriesYAxisReverseMap[i]];if(s&&s.show&&s.showAlways)r.ancillaryCollapsedSeriesIndices.indexOf(i)<0&&(r.ancillaryCollapsedSeries.push({index:i,data:a[i].data.slice(),type:t.parentNode.className.baseVal.split("-")[1]}),r.ancillaryCollapsedSeriesIndices.push(i));else if(r.collapsedSeriesIndices.indexOf(i)<0){r.collapsedSeries.push({index:i,data:a[i].data.slice(),type:t.parentNode.className.baseVal.split("-")[1]}),r.collapsedSeriesIndices.push(i);var o=r.risingSeries.indexOf(i);r.risingSeries.splice(o,1)}}else r.collapsedSeries.push({index:i,data:a[i]}),r.collapsedSeriesIndices.push(i);for(var l=t.childNodes,c=0;c<l.length;c++)l[c].classList.contains("apexcharts-series-markers-wrap")&&(l[c].classList.contains("apexcharts-hide")?l[c].classList.remove("apexcharts-hide"):l[c].classList.add("apexcharts-hide"));r.allSeriesCollapsed=r.collapsedSeries.length+r.ancillaryCollapsedSeries.length===n.config.series.length,a=this._getSeriesBasedOnCollapsedState(a),this.lgCtx.ctx.updateHelpers._updateSeries(a,n.config.chart.animations.dynamicAnimation.enabled)}},{key:"riseCollapsedSeries",value:function(e,t,i){var n=this.w,r=g.clone(n.config.series);if(e.length>0){for(var a=0;a<e.length;a++)e[a].index===i&&(n.globals.axisCharts?(r[i].data=e[a].data.slice(),e.splice(a,1),t.splice(a,1),n.globals.risingSeries.push(i)):(r[i]=e[a].data,e.splice(a,1),t.splice(a,1),n.globals.risingSeries.push(i)));r=this._getSeriesBasedOnCollapsedState(r),this.lgCtx.ctx.updateHelpers._updateSeries(r,n.config.chart.animations.dynamicAnimation.enabled)}}},{key:"_getSeriesBasedOnCollapsedState",value:function(e){var t=this.w,i=0;return t.globals.axisCharts?e.forEach((function(n,r){t.globals.collapsedSeriesIndices.indexOf(r)<0&&t.globals.ancillaryCollapsedSeriesIndices.indexOf(r)<0||(e[r].data=[],i++)})):e.forEach((function(n,r){!t.globals.collapsedSeriesIndices.indexOf(r)<0&&(e[r]=0,i++)})),t.globals.allSeriesCollapsed=i===e.length,e}}]),e}(),le=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.onLegendClick=this.onLegendClick.bind(this),this.onLegendHovered=this.onLegendHovered.bind(this),this.isBarsDistributed="bar"===this.w.config.chart.type&&this.w.config.plotOptions.bar.distributed&&1===this.w.config.series.length,this.legendHelpers=new oe(this)}return a(e,[{key:"init",value:function(){var e=this.w,t=e.globals,i=e.config;if((i.legend.showForSingleSeries&&1===t.series.length||this.isBarsDistributed||t.series.length>1||!t.axisCharts)&&i.legend.show){for(;t.dom.elLegendWrap.firstChild;)t.dom.elLegendWrap.removeChild(t.dom.elLegendWrap.firstChild);this.drawLegends(),g.isIE11()?document.getElementsByTagName("head")[0].appendChild(this.legendHelpers.getLegendStyles()):this.legendHelpers.appendToForeignObject(),"bottom"===i.legend.position||"top"===i.legend.position?this.legendAlignHorizontal():"right"!==i.legend.position&&"left"!==i.legend.position||this.legendAlignVertical()}}},{key:"drawLegends",value:function(){var e=this,t=this.w,i=t.config.legend.fontFamily,n=t.globals.seriesNames,r=t.globals.colors.slice();if("heatmap"===t.config.chart.type){var a=t.config.plotOptions.heatmap.colorScale.ranges;n=a.map((function(e){return e.name?e.name:e.from+" - "+e.to})),r=a.map((function(e){return e.color}))}else this.isBarsDistributed&&(n=t.globals.labels.slice());t.config.legend.customLegendItems.length&&(n=t.config.legend.customLegendItems);for(var s=t.globals.legendFormatter,o=t.config.legend.inverseOrder,l=o?n.length-1:0;o?l>=0:l<=n.length-1;o?l--:l++){var c,u=s(n[l],{seriesIndex:l,w:t}),d=!1,h=!1;if(t.globals.collapsedSeries.length>0)for(var f=0;f<t.globals.collapsedSeries.length;f++)t.globals.collapsedSeries[f].index===l&&(d=!0);if(t.globals.ancillaryCollapsedSeriesIndices.length>0)for(var p=0;p<t.globals.ancillaryCollapsedSeriesIndices.length;p++)t.globals.ancillaryCollapsedSeriesIndices[p]===l&&(h=!0);var m=document.createElement("span");m.classList.add("apexcharts-legend-marker");var v=t.config.legend.markers.offsetX,y=t.config.legend.markers.offsetY,_=t.config.legend.markers.height,w=t.config.legend.markers.width,k=t.config.legend.markers.strokeWidth,M=t.config.legend.markers.strokeColor,S=t.config.legend.markers.radius,A=m.style;A.background=r[l],A.color=r[l],A.setProperty("background",r[l],"important"),t.config.legend.markers.fillColors&&t.config.legend.markers.fillColors[l]&&(A.background=t.config.legend.markers.fillColors[l]),void 0!==t.globals.seriesColors[l]&&(A.background=t.globals.seriesColors[l],A.color=t.globals.seriesColors[l]),A.height=Array.isArray(_)?parseFloat(_[l])+"px":parseFloat(_)+"px",A.width=Array.isArray(w)?parseFloat(w[l])+"px":parseFloat(w)+"px",A.left=(Array.isArray(v)?parseFloat(v[l]):parseFloat(v))+"px",A.top=(Array.isArray(y)?parseFloat(y[l]):parseFloat(y))+"px",A.borderWidth=Array.isArray(k)?k[l]:k,A.borderColor=Array.isArray(M)?M[l]:M,A.borderRadius=Array.isArray(S)?parseFloat(S[l])+"px":parseFloat(S)+"px",t.config.legend.markers.customHTML&&(Array.isArray(t.config.legend.markers.customHTML)?t.config.legend.markers.customHTML[l]&&(m.innerHTML=t.config.legend.markers.customHTML[l]()):m.innerHTML=t.config.legend.markers.customHTML()),b.setAttrs(m,{rel:l+1,"data:collapsed":d||h}),(d||h)&&m.classList.add("apexcharts-inactive-legend");var L=document.createElement("div"),T=document.createElement("span");T.classList.add("apexcharts-legend-text"),T.innerHTML=Array.isArray(u)?u.join(" "):u;var C=t.config.legend.labels.useSeriesColors?t.globals.colors[l]:Array.isArray(t.config.legend.labels.colors)?null===(c=t.config.legend.labels.colors)||void 0===c?void 0:c[l]:t.config.legend.labels.colors;C||(C=t.config.chart.foreColor),T.style.color=C,T.style.fontSize=parseFloat(t.config.legend.fontSize)+"px",T.style.fontWeight=t.config.legend.fontWeight,T.style.fontFamily=i||t.config.chart.fontFamily,b.setAttrs(T,{rel:l+1,i:l,"data:default-text":encodeURIComponent(u),"data:collapsed":d||h}),L.appendChild(m),L.appendChild(T);var D=new x(this.ctx);t.config.legend.showForZeroSeries||0===D.getSeriesTotalByIndex(l)&&D.seriesHaveSameValues(l)&&!D.isSeriesNull(l)&&-1===t.globals.collapsedSeriesIndices.indexOf(l)&&-1===t.globals.ancillaryCollapsedSeriesIndices.indexOf(l)&&L.classList.add("apexcharts-hidden-zero-series"),t.config.legend.showForNullSeries||D.isSeriesNull(l)&&-1===t.globals.collapsedSeriesIndices.indexOf(l)&&-1===t.globals.ancillaryCollapsedSeriesIndices.indexOf(l)&&L.classList.add("apexcharts-hidden-null-series"),t.globals.dom.elLegendWrap.appendChild(L),t.globals.dom.elLegendWrap.classList.add("apexcharts-align-".concat(t.config.legend.horizontalAlign)),t.globals.dom.elLegendWrap.classList.add("apx-legend-position-"+t.config.legend.position),L.classList.add("apexcharts-legend-series"),L.style.margin="".concat(t.config.legend.itemMargin.vertical,"px ").concat(t.config.legend.itemMargin.horizontal,"px"),t.globals.dom.elLegendWrap.style.width=t.config.legend.width?t.config.legend.width+"px":"",t.globals.dom.elLegendWrap.style.height=t.config.legend.height?t.config.legend.height+"px":"",b.setAttrs(L,{rel:l+1,seriesName:g.escapeString(n[l]),"data:collapsed":d||h}),(d||h)&&L.classList.add("apexcharts-inactive-legend"),t.config.legend.onItemClick.toggleDataSeries||L.classList.add("apexcharts-no-click")}t.globals.dom.elWrap.addEventListener("click",e.onLegendClick,!0),t.config.legend.onItemHover.highlightDataSeries&&0===t.config.legend.customLegendItems.length&&(t.globals.dom.elWrap.addEventListener("mousemove",e.onLegendHovered,!0),t.globals.dom.elWrap.addEventListener("mouseout",e.onLegendHovered,!0))}},{key:"setLegendWrapXY",value:function(e,t){var i=this.w,n=i.globals.dom.elLegendWrap,r=n.getBoundingClientRect(),a=0,s=0;if("bottom"===i.config.legend.position)s+=i.globals.svgHeight-r.height/2;else if("top"===i.config.legend.position){var o=new se(this.ctx),l=o.dimHelpers.getTitleSubtitleCoords("title").height,c=o.dimHelpers.getTitleSubtitleCoords("subtitle").height;s=s+(l>0?l-10:0)+(c>0?c-10:0)}n.style.position="absolute",a=a+e+i.config.legend.offsetX,s=s+t+i.config.legend.offsetY,n.style.left=a+"px",n.style.top=s+"px","bottom"===i.config.legend.position?(n.style.top="auto",n.style.bottom=5-i.config.legend.offsetY+"px"):"right"===i.config.legend.position&&(n.style.left="auto",n.style.right=25+i.config.legend.offsetX+"px"),["width","height"].forEach((function(e){n.style[e]&&(n.style[e]=parseInt(i.config.legend[e],10)+"px")}))}},{key:"legendAlignHorizontal",value:function(){var e=this.w;e.globals.dom.elLegendWrap.style.right=0;var t=this.legendHelpers.getLegendBBox(),i=new se(this.ctx),n=i.dimHelpers.getTitleSubtitleCoords("title"),r=i.dimHelpers.getTitleSubtitleCoords("subtitle"),a=0;"bottom"===e.config.legend.position?a=-t.clwh/1.8:"top"===e.config.legend.position&&(a=n.height+r.height+e.config.title.margin+e.config.subtitle.margin-10),this.setLegendWrapXY(20,a)}},{key:"legendAlignVertical",value:function(){var e=this.w,t=this.legendHelpers.getLegendBBox(),i=0;"left"===e.config.legend.position&&(i=20),"right"===e.config.legend.position&&(i=e.globals.svgWidth-t.clww-10),this.setLegendWrapXY(i,20)}},{key:"onLegendHovered",value:function(e){var t=this.w,i=e.target.classList.contains("apexcharts-legend-series")||e.target.classList.contains("apexcharts-legend-text")||e.target.classList.contains("apexcharts-legend-marker");if("heatmap"===t.config.chart.type||this.isBarsDistributed){if(i){var n=parseInt(e.target.getAttribute("rel"),10)-1;this.ctx.events.fireEvent("legendHover",[this.ctx,n,this.w]),new z(this.ctx).highlightRangeInSeries(e,e.target)}}else!e.target.classList.contains("apexcharts-inactive-legend")&&i&&new z(this.ctx).toggleSeriesOnHover(e,e.target)}},{key:"onLegendClick",value:function(e){var t=this.w;if(!t.config.legend.customLegendItems.length&&(e.target.classList.contains("apexcharts-legend-series")||e.target.classList.contains("apexcharts-legend-text")||e.target.classList.contains("apexcharts-legend-marker"))){var i=parseInt(e.target.getAttribute("rel"),10)-1,n="true"===e.target.getAttribute("data:collapsed"),r=this.w.config.chart.events.legendClick;"function"==typeof r&&r(this.ctx,i,this.w),this.ctx.events.fireEvent("legendClick",[this.ctx,i,this.w]);var a=this.w.config.legend.markers.onClick;"function"==typeof a&&e.target.classList.contains("apexcharts-legend-marker")&&(a(this.ctx,i,this.w),this.ctx.events.fireEvent("legendMarkerClick",[this.ctx,i,this.w])),"treemap"!==t.config.chart.type&&"heatmap"!==t.config.chart.type&&!this.isBarsDistributed&&t.config.legend.onItemClick.toggleDataSeries&&this.legendHelpers.toggleDataSeries(i,n)}}}]),e}(),ce=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w;var i=this.w;this.ev=this.w.config.chart.events,this.selectedClass="apexcharts-selected",this.localeValues=this.w.globals.locale.toolbar,this.minX=i.globals.minX,this.maxX=i.globals.maxX}return a(e,[{key:"createToolbar",value:function(){var e=this,t=this.w,i=function(){return document.createElement("div")},n=i();if(n.setAttribute("class","apexcharts-toolbar"),n.style.top=t.config.chart.toolbar.offsetY+"px",n.style.right=3-t.config.chart.toolbar.offsetX+"px",t.globals.dom.elWrap.appendChild(n),this.elZoom=i(),this.elZoomIn=i(),this.elZoomOut=i(),this.elPan=i(),this.elSelection=i(),this.elZoomReset=i(),this.elMenuIcon=i(),this.elMenu=i(),this.elCustomIcons=[],this.t=t.config.chart.toolbar.tools,Array.isArray(this.t.customIcons))for(var r=0;r<this.t.customIcons.length;r++)this.elCustomIcons.push(i());var a=[],s=function(i,n,r){var s=i.toLowerCase();e.t[s]&&t.config.chart.zoom.enabled&&a.push({el:n,icon:"string"==typeof e.t[s]?e.t[s]:r,title:e.localeValues[i],class:"apexcharts-".concat(s,"-icon")})};s("zoomIn",this.elZoomIn,'<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">\n    <path d="M0 0h24v24H0z" fill="none"/>\n    <path d="M13 7h-2v4H7v2h4v4h2v-4h4v-2h-4V7zm-1-5C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8z"/>\n</svg>\n'),s("zoomOut",this.elZoomOut,'<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">\n    <path d="M0 0h24v24H0z" fill="none"/>\n    <path d="M7 11v2h10v-2H7zm5-9C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8z"/>\n</svg>\n');var o=function(i){e.t[i]&&t.config.chart[i].enabled&&a.push({el:"zoom"===i?e.elZoom:e.elSelection,icon:"string"==typeof e.t[i]?e.t[i]:"zoom"===i?'<svg xmlns="http://www.w3.org/2000/svg" fill="#000000" height="24" viewBox="0 0 24 24" width="24">\n    <path d="M15.5 14h-.79l-.28-.27C15.41 12.59 16 11.11 16 9.5 16 5.91 13.09 3 9.5 3S3 5.91 3 9.5 5.91 16 9.5 16c1.61 0 3.09-.59 4.23-1.57l.27.28v.79l5 4.99L20.49 19l-4.99-5zm-6 0C7.01 14 5 11.99 5 9.5S7.01 5 9.5 5 14 7.01 14 9.5 11.99 14 9.5 14z"/>\n    <path d="M0 0h24v24H0V0z" fill="none"/>\n    <path d="M12 10h-2v2H9v-2H7V9h2V7h1v2h2v1z"/>\n</svg>':'<svg fill="#6E8192" height="24" viewBox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">\n    <path d="M0 0h24v24H0z" fill="none"/>\n    <path d="M3 5h2V3c-1.1 0-2 .9-2 2zm0 8h2v-2H3v2zm4 8h2v-2H7v2zM3 9h2V7H3v2zm10-6h-2v2h2V3zm6 0v2h2c0-1.1-.9-2-2-2zM5 21v-2H3c0 1.1.9 2 2 2zm-2-4h2v-2H3v2zM9 3H7v2h2V3zm2 18h2v-2h-2v2zm8-8h2v-2h-2v2zm0 8c1.1 0 2-.9 2-2h-2v2zm0-12h2V7h-2v2zm0 8h2v-2h-2v2zm-4 4h2v-2h-2v2zm0-16h2V3h-2v2z"/>\n</svg>',title:e.localeValues["zoom"===i?"selectionZoom":"selection"],class:t.globals.isTouchDevice?"apexcharts-element-hidden":"apexcharts-".concat(i,"-icon")})};o("zoom"),o("selection"),this.t.pan&&t.config.chart.zoom.enabled&&a.push({el:this.elPan,icon:"string"==typeof this.t.pan?this.t.pan:'<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" fill="#000000" height="24" viewBox="0 0 24 24" width="24">\n    <defs>\n        <path d="M0 0h24v24H0z" id="a"/>\n    </defs>\n    <clipPath id="b">\n        <use overflow="visible" xlink:href="#a"/>\n    </clipPath>\n    <path clip-path="url(#b)" d="M23 5.5V20c0 2.2-1.8 4-4 4h-7.3c-1.08 0-2.1-.43-2.85-1.19L1 14.83s1.26-1.23 1.3-1.25c.22-.19.49-.29.79-.29.22 0 .42.06.6.16.04.01 4.31 2.46 4.31 2.46V4c0-.83.67-1.5 1.5-1.5S11 3.17 11 4v7h1V1.5c0-.83.67-1.5 1.5-1.5S15 .67 15 1.5V11h1V2.5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5V11h1V5.5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5z"/>\n</svg>',title:this.localeValues.pan,class:t.globals.isTouchDevice?"apexcharts-element-hidden":"apexcharts-pan-icon"}),s("reset",this.elZoomReset,'<svg fill="#000000" height="24" viewBox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">\n    <path d="M10 20v-6h4v6h5v-8h3L12 3 2 12h3v8z"/>\n    <path d="M0 0h24v24H0z" fill="none"/>\n</svg>'),this.t.download&&a.push({el:this.elMenuIcon,icon:"string"==typeof this.t.download?this.t.download:'<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><path fill="none" d="M0 0h24v24H0V0z"/><path d="M3 18h18v-2H3v2zm0-5h18v-2H3v2zm0-7v2h18V6H3z"/></svg>',title:this.localeValues.menu,class:"apexcharts-menu-icon"});for(var l=0;l<this.elCustomIcons.length;l++)a.push({el:this.elCustomIcons[l],icon:this.t.customIcons[l].icon,title:this.t.customIcons[l].title,index:this.t.customIcons[l].index,class:"apexcharts-toolbar-custom-icon "+this.t.customIcons[l].class});a.forEach((function(e,t){e.index&&g.moveIndexInArray(a,t,e.index)}));for(var c=0;c<a.length;c++)b.setAttrs(a[c].el,{class:a[c].class,title:a[c].title}),a[c].el.innerHTML=a[c].icon,n.appendChild(a[c].el);this._createHamburgerMenu(n),t.globals.zoomEnabled?this.elZoom.classList.add(this.selectedClass):t.globals.panEnabled?this.elPan.classList.add(this.selectedClass):t.globals.selectionEnabled&&this.elSelection.classList.add(this.selectedClass),this.addToolbarEventListeners()}},{key:"_createHamburgerMenu",value:function(e){this.elMenuItems=[],e.appendChild(this.elMenu),b.setAttrs(this.elMenu,{class:"apexcharts-menu"});for(var t=[{name:"exportSVG",title:this.localeValues.exportToSVG},{name:"exportPNG",title:this.localeValues.exportToPNG},{name:"exportCSV",title:this.localeValues.exportToCSV}],i=0;i<t.length;i++)this.elMenuItems.push(document.createElement("div")),this.elMenuItems[i].innerHTML=t[i].title,b.setAttrs(this.elMenuItems[i],{class:"apexcharts-menu-item ".concat(t[i].name),title:t[i].title}),this.elMenu.appendChild(this.elMenuItems[i])}},{key:"addToolbarEventListeners",value:function(){var e=this;this.elZoomReset.addEventListener("click",this.handleZoomReset.bind(this)),this.elSelection.addEventListener("click",this.toggleZoomSelection.bind(this,"selection")),this.elZoom.addEventListener("click",this.toggleZoomSelection.bind(this,"zoom")),this.elZoomIn.addEventListener("click",this.handleZoomIn.bind(this)),this.elZoomOut.addEventListener("click",this.handleZoomOut.bind(this)),this.elPan.addEventListener("click",this.togglePanning.bind(this)),this.elMenuIcon.addEventListener("click",this.toggleMenu.bind(this)),this.elMenuItems.forEach((function(t){t.classList.contains("exportSVG")?t.addEventListener("click",e.handleDownload.bind(e,"svg")):t.classList.contains("exportPNG")?t.addEventListener("click",e.handleDownload.bind(e,"png")):t.classList.contains("exportCSV")&&t.addEventListener("click",e.handleDownload.bind(e,"csv"))}));for(var t=0;t<this.t.customIcons.length;t++)this.elCustomIcons[t].addEventListener("click",this.t.customIcons[t].click.bind(this,this.ctx,this.ctx.w))}},{key:"toggleZoomSelection",value:function(e){this.ctx.getSyncedCharts().forEach((function(t){t.ctx.toolbar.toggleOtherControls();var i="selection"===e?t.ctx.toolbar.elSelection:t.ctx.toolbar.elZoom,n="selection"===e?"selectionEnabled":"zoomEnabled";t.w.globals[n]=!t.w.globals[n],i.classList.contains(t.ctx.toolbar.selectedClass)?i.classList.remove(t.ctx.toolbar.selectedClass):i.classList.add(t.ctx.toolbar.selectedClass)}))}},{key:"getToolbarIconsReference",value:function(){var e=this.w;this.elZoom||(this.elZoom=e.globals.dom.baseEl.querySelector(".apexcharts-zoom-icon")),this.elPan||(this.elPan=e.globals.dom.baseEl.querySelector(".apexcharts-pan-icon")),this.elSelection||(this.elSelection=e.globals.dom.baseEl.querySelector(".apexcharts-selection-icon"))}},{key:"enableZoomPanFromToolbar",value:function(e){this.toggleOtherControls(),"pan"===e?this.w.globals.panEnabled=!0:this.w.globals.zoomEnabled=!0;var t="pan"===e?this.elPan:this.elZoom,i="pan"===e?this.elZoom:this.elPan;t&&t.classList.add(this.selectedClass),i&&i.classList.remove(this.selectedClass)}},{key:"togglePanning",value:function(){this.ctx.getSyncedCharts().forEach((function(e){e.ctx.toolbar.toggleOtherControls(),e.w.globals.panEnabled=!e.w.globals.panEnabled,e.ctx.toolbar.elPan.classList.contains(e.ctx.toolbar.selectedClass)?e.ctx.toolbar.elPan.classList.remove(e.ctx.toolbar.selectedClass):e.ctx.toolbar.elPan.classList.add(e.ctx.toolbar.selectedClass)}))}},{key:"toggleOtherControls",value:function(){var e=this,t=this.w;t.globals.panEnabled=!1,t.globals.zoomEnabled=!1,t.globals.selectionEnabled=!1,this.getToolbarIconsReference(),[this.elPan,this.elSelection,this.elZoom].forEach((function(t){t&&t.classList.remove(e.selectedClass)}))}},{key:"handleZoomIn",value:function(){var e=this.w;e.globals.isRangeBar&&(this.minX=e.globals.minY,this.maxX=e.globals.maxY);var t=(this.minX+this.maxX)/2,i=(this.minX+t)/2,n=(this.maxX+t)/2,r=this._getNewMinXMaxX(i,n);e.globals.disableZoomIn||this.zoomUpdateOptions(r.minX,r.maxX)}},{key:"handleZoomOut",value:function(){var e=this.w;if(e.globals.isRangeBar&&(this.minX=e.globals.minY,this.maxX=e.globals.maxY),!("datetime"===e.config.xaxis.type&&new Date(this.minX).getUTCFullYear()<1e3)){var t=(this.minX+this.maxX)/2,i=this.minX-(t-this.minX),n=this.maxX-(t-this.maxX),r=this._getNewMinXMaxX(i,n);e.globals.disableZoomOut||this.zoomUpdateOptions(r.minX,r.maxX)}}},{key:"_getNewMinXMaxX",value:function(e,t){var i=this.w.config.xaxis.convertedCatToNumeric;return{minX:i?Math.floor(e):e,maxX:i?Math.floor(t):t}}},{key:"zoomUpdateOptions",value:function(e,t){var i=this.w;if(void 0!==e||void 0!==t){if(!(i.config.xaxis.convertedCatToNumeric&&(e<1&&(e=1,t=i.globals.dataPoints),t-e<2))){var n={min:e,max:t},r=this.getBeforeZoomRange(n);r&&(n=r.xaxis);var a={xaxis:n},s=g.clone(i.globals.initialConfig.yaxis);i.config.chart.group||(a.yaxis=s),this.w.globals.zoomed=!0,this.ctx.updateHelpers._updateOptions(a,!1,this.w.config.chart.animations.dynamicAnimation.enabled),this.zoomCallback(n,s)}}else this.handleZoomReset()}},{key:"zoomCallback",value:function(e,t){"function"==typeof this.ev.zoomed&&this.ev.zoomed(this.ctx,{xaxis:e,yaxis:t})}},{key:"getBeforeZoomRange",value:function(e,t){var i=null;return"function"==typeof this.ev.beforeZoom&&(i=this.ev.beforeZoom(this,{xaxis:e,yaxis:t})),i}},{key:"toggleMenu",value:function(){var e=this;window.setTimeout((function(){e.elMenu.classList.contains("apexcharts-menu-open")?e.elMenu.classList.remove("apexcharts-menu-open"):e.elMenu.classList.add("apexcharts-menu-open")}),0)}},{key:"handleDownload",value:function(e){var t=this.w,i=new V(this.ctx);switch(e){case"svg":i.exportToSVG(this.ctx);break;case"png":i.exportToPng(this.ctx);break;case"csv":i.exportToCSV({series:t.config.series,columnDelimiter:t.config.chart.toolbar.export.csv.columnDelimiter})}}},{key:"handleZoomReset",value:function(e){this.ctx.getSyncedCharts().forEach((function(e){var t=e.w;if(t.globals.lastXAxis.min=t.globals.initialConfig.xaxis.min,t.globals.lastXAxis.max=t.globals.initialConfig.xaxis.max,e.updateHelpers.revertDefaultAxisMinMax(),"function"==typeof t.config.chart.events.beforeResetZoom){var i=t.config.chart.events.beforeResetZoom(e,t);i&&e.updateHelpers.revertDefaultAxisMinMax(i)}"function"==typeof t.config.chart.events.zoomed&&e.ctx.toolbar.zoomCallback({min:t.config.xaxis.min,max:t.config.xaxis.max}),t.globals.zoomed=!1;var n=e.ctx.series.emptyCollapsedSeries(g.clone(t.globals.initialSeries));e.updateHelpers._updateSeries(n,t.config.chart.animations.dynamicAnimation.enabled)}))}},{key:"destroy",value:function(){this.elZoom=null,this.elZoomIn=null,this.elZoomOut=null,this.elPan=null,this.elSelection=null,this.elZoomReset=null,this.elMenuIcon=null}}]),e}(),ue=function(e){o(i,e);var t=d(i);function i(e){var r;return n(this,i),(r=t.call(this,e)).ctx=e,r.w=e.w,r.dragged=!1,r.graphics=new b(r.ctx),r.eventList=["mousedown","mouseleave","mousemove","touchstart","touchmove","mouseup","touchend"],r.clientX=0,r.clientY=0,r.startX=0,r.endX=0,r.dragX=0,r.startY=0,r.endY=0,r.dragY=0,r.moveDirection="none",r}return a(i,[{key:"init",value:function(e){var t=this,i=e.xyRatios,n=this.w,r=this;this.xyRatios=i,this.zoomRect=this.graphics.drawRect(0,0,0,0),this.selectionRect=this.graphics.drawRect(0,0,0,0),this.gridRect=n.globals.dom.baseEl.querySelector(".apexcharts-grid"),this.zoomRect.node.classList.add("apexcharts-zoom-rect"),this.selectionRect.node.classList.add("apexcharts-selection-rect"),n.globals.dom.elGraphical.add(this.zoomRect),n.globals.dom.elGraphical.add(this.selectionRect),"x"===n.config.chart.selection.type?this.slDraggableRect=this.selectionRect.draggable({minX:0,minY:0,maxX:n.globals.gridWidth,maxY:n.globals.gridHeight}).on("dragmove",this.selectionDragging.bind(this,"dragging")):"y"===n.config.chart.selection.type?this.slDraggableRect=this.selectionRect.draggable({minX:0,maxX:n.globals.gridWidth}).on("dragmove",this.selectionDragging.bind(this,"dragging")):this.slDraggableRect=this.selectionRect.draggable().on("dragmove",this.selectionDragging.bind(this,"dragging")),this.preselectedSelection(),this.hoverArea=n.globals.dom.baseEl.querySelector("".concat(n.globals.chartClass," .apexcharts-svg")),this.hoverArea.classList.add("apexcharts-zoomable"),this.eventList.forEach((function(e){t.hoverArea.addEventListener(e,r.svgMouseEvents.bind(r,i),{capture:!1,passive:!0})}))}},{key:"destroy",value:function(){this.slDraggableRect&&(this.slDraggableRect.draggable(!1),this.slDraggableRect.off(),this.selectionRect.off()),this.selectionRect=null,this.zoomRect=null,this.gridRect=null}},{key:"svgMouseEvents",value:function(e,t){var i=this.w,n=this,r=this.ctx.toolbar,a=i.globals.zoomEnabled?i.config.chart.zoom.type:i.config.chart.selection.type,s=i.config.chart.toolbar.autoSelected;if(t.shiftKey?(this.shiftWasPressed=!0,r.enableZoomPanFromToolbar("pan"===s?"zoom":"pan")):this.shiftWasPressed&&(r.enableZoomPanFromToolbar(s),this.shiftWasPressed=!1),t.target){var o,l=t.target.classList;if(t.target.parentNode&&null!==t.target.parentNode&&(o=t.target.parentNode.classList),!(l.contains("apexcharts-selection-rect")||l.contains("apexcharts-legend-marker")||l.contains("apexcharts-legend-text")||o&&o.contains("apexcharts-toolbar"))){if(n.clientX="touchmove"===t.type||"touchstart"===t.type?t.touches[0].clientX:"touchend"===t.type?t.changedTouches[0].clientX:t.clientX,n.clientY="touchmove"===t.type||"touchstart"===t.type?t.touches[0].clientY:"touchend"===t.type?t.changedTouches[0].clientY:t.clientY,"mousedown"===t.type&&1===t.which){var c=n.gridRect.getBoundingClientRect();n.startX=n.clientX-c.left,n.startY=n.clientY-c.top,n.dragged=!1,n.w.globals.mousedown=!0}if(("mousemove"===t.type&&1===t.which||"touchmove"===t.type)&&(n.dragged=!0,i.globals.panEnabled?(i.globals.selection=null,n.w.globals.mousedown&&n.panDragging({context:n,zoomtype:a,xyRatios:e})):(n.w.globals.mousedown&&i.globals.zoomEnabled||n.w.globals.mousedown&&i.globals.selectionEnabled)&&(n.selection=n.selectionDrawing({context:n,zoomtype:a}))),"mouseup"===t.type||"touchend"===t.type||"mouseleave"===t.type){var u=n.gridRect.getBoundingClientRect();n.w.globals.mousedown&&(n.endX=n.clientX-u.left,n.endY=n.clientY-u.top,n.dragX=Math.abs(n.endX-n.startX),n.dragY=Math.abs(n.endY-n.startY),(i.globals.zoomEnabled||i.globals.selectionEnabled)&&n.selectionDrawn({context:n,zoomtype:a}),i.globals.panEnabled&&i.config.xaxis.convertedCatToNumeric&&n.delayedPanScrolled()),i.globals.zoomEnabled&&n.hideSelectionRect(this.selectionRect),n.dragged=!1,n.w.globals.mousedown=!1}this.makeSelectionRectDraggable()}}}},{key:"makeSelectionRectDraggable",value:function(){var e=this.w;if(this.selectionRect){var t=this.selectionRect.node.getBoundingClientRect();t.width>0&&t.height>0&&this.slDraggableRect.selectize({points:"l, r",pointSize:8,pointType:"rect"}).resize({constraint:{minX:0,minY:0,maxX:e.globals.gridWidth,maxY:e.globals.gridHeight}}).on("resizing",this.selectionDragging.bind(this,"resizing"))}}},{key:"preselectedSelection",value:function(){var e=this.w,t=this.xyRatios;if(!e.globals.zoomEnabled)if(void 0!==e.globals.selection&&null!==e.globals.selection)this.drawSelectionRect(e.globals.selection);else if(void 0!==e.config.chart.selection.xaxis.min&&void 0!==e.config.chart.selection.xaxis.max){var i=(e.config.chart.selection.xaxis.min-e.globals.minX)/t.xRatio,n=e.globals.gridWidth-(e.globals.maxX-e.config.chart.selection.xaxis.max)/t.xRatio-i;e.globals.isRangeBar&&(i=(e.config.chart.selection.xaxis.min-e.globals.yAxisScale[0].niceMin)/t.invertedYRatio,n=(e.config.chart.selection.xaxis.max-e.config.chart.selection.xaxis.min)/t.invertedYRatio);var r={x:i,y:0,width:n,height:e.globals.gridHeight,translateX:0,translateY:0,selectionEnabled:!0};this.drawSelectionRect(r),this.makeSelectionRectDraggable(),"function"==typeof e.config.chart.events.selection&&e.config.chart.events.selection(this.ctx,{xaxis:{min:e.config.chart.selection.xaxis.min,max:e.config.chart.selection.xaxis.max},yaxis:{}})}}},{key:"drawSelectionRect",value:function(e){var t=e.x,i=e.y,n=e.width,r=e.height,a=e.translateX,s=void 0===a?0:a,o=e.translateY,l=void 0===o?0:o,c=this.w,u=this.zoomRect,d=this.selectionRect;if(this.dragged||null!==c.globals.selection){var h={transform:"translate("+s+", "+l+")"};c.globals.zoomEnabled&&this.dragged&&(n<0&&(n=1),u.attr({x:t,y:i,width:n,height:r,fill:c.config.chart.zoom.zoomedArea.fill.color,"fill-opacity":c.config.chart.zoom.zoomedArea.fill.opacity,stroke:c.config.chart.zoom.zoomedArea.stroke.color,"stroke-width":c.config.chart.zoom.zoomedArea.stroke.width,"stroke-opacity":c.config.chart.zoom.zoomedArea.stroke.opacity}),b.setAttrs(u.node,h)),c.globals.selectionEnabled&&(d.attr({x:t,y:i,width:n>0?n:0,height:r>0?r:0,fill:c.config.chart.selection.fill.color,"fill-opacity":c.config.chart.selection.fill.opacity,stroke:c.config.chart.selection.stroke.color,"stroke-width":c.config.chart.selection.stroke.width,"stroke-dasharray":c.config.chart.selection.stroke.dashArray,"stroke-opacity":c.config.chart.selection.stroke.opacity}),b.setAttrs(d.node,h))}}},{key:"hideSelectionRect",value:function(e){e&&e.attr({x:0,y:0,width:0,height:0})}},{key:"selectionDrawing",value:function(e){var t,i=e.context,n=e.zoomtype,r=this.w,a=i,s=this.gridRect.getBoundingClientRect(),o=a.startX-1,l=a.startY,c=!1,u=!1,d=a.clientX-s.left-o,h=a.clientY-s.top-l;return Math.abs(d+o)>r.globals.gridWidth?d=r.globals.gridWidth-o:a.clientX-s.left<0&&(d=o),o>a.clientX-s.left&&(c=!0,d=Math.abs(d)),l>a.clientY-s.top&&(u=!0,h=Math.abs(h)),t="x"===n?{x:c?o-d:o,y:0,width:d,height:r.globals.gridHeight}:"y"===n?{x:0,y:u?l-h:l,width:r.globals.gridWidth,height:h}:{x:c?o-d:o,y:u?l-h:l,width:d,height:h},a.drawSelectionRect(t),a.selectionDragging("resizing"),t}},{key:"selectionDragging",value:function(e,t){var i=this,n=this.w,r=this.xyRatios,a=this.selectionRect,s=0;"resizing"===e&&(s=30);var o=function(e){return parseFloat(a.node.getAttribute(e))},l={x:o("x"),y:o("y"),width:o("width"),height:o("height")};n.globals.selection=l,"function"==typeof n.config.chart.events.selection&&n.globals.selectionEnabled&&(clearTimeout(this.w.globals.selectionResizeTimer),this.w.globals.selectionResizeTimer=window.setTimeout((function(){var e,t,s,o,l=i.gridRect.getBoundingClientRect(),c=a.node.getBoundingClientRect();n.globals.isRangeBar?(e=n.globals.yAxisScale[0].niceMin+(c.left-l.left)*r.invertedYRatio,t=n.globals.yAxisScale[0].niceMin+(c.right-l.left)*r.invertedYRatio,s=0,o=1):(e=n.globals.xAxisScale.niceMin+(c.left-l.left)*r.xRatio,t=n.globals.xAxisScale.niceMin+(c.right-l.left)*r.xRatio,s=n.globals.yAxisScale[0].niceMin+(l.bottom-c.bottom)*r.yRatio[0],o=n.globals.yAxisScale[0].niceMax-(c.top-l.top)*r.yRatio[0]);var u={xaxis:{min:e,max:t},yaxis:{min:s,max:o}};n.config.chart.events.selection(i.ctx,u),n.config.chart.brush.enabled&&void 0!==n.config.chart.events.brushScrolled&&n.config.chart.events.brushScrolled(i.ctx,u)}),s))}},{key:"selectionDrawn",value:function(e){var t=e.context,i=e.zoomtype,n=this.w,r=t,a=this.xyRatios,s=this.ctx.toolbar;if(r.startX>r.endX){var o=r.startX;r.startX=r.endX,r.endX=o}if(r.startY>r.endY){var l=r.startY;r.startY=r.endY,r.endY=l}var c=void 0,u=void 0;n.globals.isRangeBar?(c=n.globals.yAxisScale[0].niceMin+r.startX*a.invertedYRatio,u=n.globals.yAxisScale[0].niceMin+r.endX*a.invertedYRatio):(c=n.globals.xAxisScale.niceMin+r.startX*a.xRatio,u=n.globals.xAxisScale.niceMin+r.endX*a.xRatio);var d=[],h=[];if(n.config.yaxis.forEach((function(e,t){if(n.globals.seriesYAxisMap[t].length>0){var i=n.globals.seriesYAxisMap[t][0];d.push(n.globals.yAxisScale[t].niceMax-a.yRatio[i]*r.startY),h.push(n.globals.yAxisScale[t].niceMax-a.yRatio[i]*r.endY)}})),r.dragged&&(r.dragX>10||r.dragY>10)&&c!==u)if(n.globals.zoomEnabled){var f=g.clone(n.globals.initialConfig.yaxis),p=g.clone(n.globals.initialConfig.xaxis);if(n.globals.zoomed=!0,n.config.xaxis.convertedCatToNumeric&&(c=Math.floor(c),u=Math.floor(u),c<1&&(c=1,u=n.globals.dataPoints),u-c<2&&(u=c+1)),"xy"!==i&&"x"!==i||(p={min:c,max:u}),"xy"!==i&&"y"!==i||f.forEach((function(e,t){f[t].min=h[t],f[t].max=d[t]})),s){var m=s.getBeforeZoomRange(p,f);m&&(p=m.xaxis?m.xaxis:p,f=m.yaxis?m.yaxis:f)}var v={xaxis:p};n.config.chart.group||(v.yaxis=f),r.ctx.updateHelpers._updateOptions(v,!1,r.w.config.chart.animations.dynamicAnimation.enabled),"function"==typeof n.config.chart.events.zoomed&&s.zoomCallback(p,f)}else if(n.globals.selectionEnabled){var y,b=null;y={min:c,max:u},"xy"!==i&&"y"!==i||(b=g.clone(n.config.yaxis)).forEach((function(e,t){b[t].min=h[t],b[t].max=d[t]})),n.globals.selection=r.selection,"function"==typeof n.config.chart.events.selection&&n.config.chart.events.selection(r.ctx,{xaxis:y,yaxis:b})}}},{key:"panDragging",value:function(e){var t=e.context,i=this.w,n=t;if(void 0!==i.globals.lastClientPosition.x){var r=i.globals.lastClientPosition.x-n.clientX,a=i.globals.lastClientPosition.y-n.clientY;Math.abs(r)>Math.abs(a)&&r>0?this.moveDirection="left":Math.abs(r)>Math.abs(a)&&r<0?this.moveDirection="right":Math.abs(a)>Math.abs(r)&&a>0?this.moveDirection="up":Math.abs(a)>Math.abs(r)&&a<0&&(this.moveDirection="down")}i.globals.lastClientPosition={x:n.clientX,y:n.clientY};var s=i.globals.isRangeBar?i.globals.minY:i.globals.minX,o=i.globals.isRangeBar?i.globals.maxY:i.globals.maxX;i.config.xaxis.convertedCatToNumeric||n.panScrolled(s,o)}},{key:"delayedPanScrolled",value:function(){var e=this.w,t=e.globals.minX,i=e.globals.maxX,n=(e.globals.maxX-e.globals.minX)/2;"left"===this.moveDirection?(t=e.globals.minX+n,i=e.globals.maxX+n):"right"===this.moveDirection&&(t=e.globals.minX-n,i=e.globals.maxX-n),t=Math.floor(t),i=Math.floor(i),this.updateScrolledChart({xaxis:{min:t,max:i}},t,i)}},{key:"panScrolled",value:function(e,t){var i=this.w,n=this.xyRatios,r=g.clone(i.globals.initialConfig.yaxis),a=n.xRatio,s=i.globals.minX,o=i.globals.maxX;i.globals.isRangeBar&&(a=n.invertedYRatio,s=i.globals.minY,o=i.globals.maxY),"left"===this.moveDirection?(e=s+i.globals.gridWidth/15*a,t=o+i.globals.gridWidth/15*a):"right"===this.moveDirection&&(e=s-i.globals.gridWidth/15*a,t=o-i.globals.gridWidth/15*a),i.globals.isRangeBar||(e<i.globals.initialMinX||t>i.globals.initialMaxX)&&(e=s,t=o);var l={xaxis:{min:e,max:t}};i.config.chart.group||(l.yaxis=r),this.updateScrolledChart(l,e,t)}},{key:"updateScrolledChart",value:function(e,t,i){var n=this.w;this.ctx.updateHelpers._updateOptions(e,!1,!1),"function"==typeof n.config.chart.events.scrolled&&n.config.chart.events.scrolled(this.ctx,{xaxis:{min:t,max:i}})}}]),i}(ce),de=function(){function e(t){n(this,e),this.w=t.w,this.ttCtx=t,this.ctx=t.ctx}return a(e,[{key:"getNearestValues",value:function(e){var t=e.hoverArea,i=e.elGrid,n=e.clientX,r=e.clientY,a=this.w,s=i.getBoundingClientRect(),o=s.width,l=s.height,c=o/(a.globals.dataPoints-1),u=l/a.globals.dataPoints,d=this.hasBars();!a.globals.comboCharts&&!d||a.config.xaxis.convertedCatToNumeric||(c=o/a.globals.dataPoints);var h=n-s.left-a.globals.barPadForNumericAxis,f=r-s.top;h<0||f<0||h>o||f>l?(t.classList.remove("hovering-zoom"),t.classList.remove("hovering-pan")):a.globals.zoomEnabled?(t.classList.remove("hovering-pan"),t.classList.add("hovering-zoom")):a.globals.panEnabled&&(t.classList.remove("hovering-zoom"),t.classList.add("hovering-pan"));var p=Math.round(h/c),m=Math.floor(f/u);d&&!a.config.xaxis.convertedCatToNumeric&&(p=Math.ceil(h/c),p-=1);var v=null,y=null,b=a.globals.seriesXvalues.map((function(e){return e.filter((function(e){return g.isNumber(e)}))})),x=a.globals.seriesYvalues.map((function(e){return e.filter((function(e){return g.isNumber(e)}))}));if(a.globals.isXNumeric){var _=this.ttCtx.getElGrid().getBoundingClientRect(),w=h*(_.width/o),k=f*(_.height/l);v=(y=this.closestInMultiArray(w,k,b,x)).index,p=y.j,null!==v&&(b=a.globals.seriesXvalues[v],p=(y=this.closestInArray(w,b)).index)}return a.globals.capturedSeriesIndex=null===v?-1:v,(!p||p<1)&&(p=0),a.globals.isBarHorizontal?a.globals.capturedDataPointIndex=m:a.globals.capturedDataPointIndex=p,{capturedSeries:v,j:a.globals.isBarHorizontal?m:p,hoverX:h,hoverY:f}}},{key:"closestInMultiArray",value:function(e,t,i,n){var r=this.w,a=0,s=null,o=-1;r.globals.series.length>1?a=this.getFirstActiveXArray(i):s=0;var l=i[a][0],c=Math.abs(e-l);if(i.forEach((function(t){t.forEach((function(t,i){var n=Math.abs(e-t);n<=c&&(c=n,o=i)}))})),-1!==o){var u=n[a][o],d=Math.abs(t-u);s=a,n.forEach((function(e,i){var n=Math.abs(t-e[o]);n<=d&&(d=n,s=i)}))}return{index:s,j:o}}},{key:"getFirstActiveXArray",value:function(e){for(var t=this.w,i=0,n=e.map((function(e,t){return e.length>0?t:-1})),r=0;r<n.length;r++)if(-1!==n[r]&&-1===t.globals.collapsedSeriesIndices.indexOf(r)&&-1===t.globals.ancillaryCollapsedSeriesIndices.indexOf(r)){i=n[r];break}return i}},{key:"closestInArray",value:function(e,t){for(var i=t[0],n=null,r=Math.abs(e-i),a=0;a<t.length;a++){var s=Math.abs(e-t[a]);s<r&&(r=s,n=a)}return{index:n}}},{key:"isXoverlap",value:function(e){var t=[],i=this.w.globals.seriesX.filter((function(e){return void 0!==e[0]}));if(i.length>0)for(var n=0;n<i.length-1;n++)void 0!==i[n][e]&&void 0!==i[n+1][e]&&i[n][e]!==i[n+1][e]&&t.push("unEqual");return 0===t.length}},{key:"isInitialSeriesSameLen",value:function(){for(var e=!0,t=this.w.globals.initialSeries,i=0;i<t.length-1;i++)if(t[i].data.length!==t[i+1].data.length){e=!1;break}return e}},{key:"getBarsHeight",value:function(e){return f(e).reduce((function(e,t){return e+t.getBBox().height}),0)}},{key:"getElMarkers",value:function(e){return"number"==typeof e?this.w.globals.dom.baseEl.querySelectorAll(".apexcharts-series[data\\:realIndex='".concat(e,"'] .apexcharts-series-markers-wrap > *")):this.w.globals.dom.baseEl.querySelectorAll(".apexcharts-series-markers-wrap > *")}},{key:"getAllMarkers",value:function(){var e=this.w.globals.dom.baseEl.querySelectorAll(".apexcharts-series-markers-wrap");(e=f(e)).sort((function(e,t){var i=Number(e.getAttribute("data:realIndex")),n=Number(t.getAttribute("data:realIndex"));return n<i?1:n>i?-1:0}));var t=[];return e.forEach((function(e){t.push(e.querySelector(".apexcharts-marker"))})),t}},{key:"hasMarkers",value:function(e){return this.getElMarkers(e).length>0}},{key:"getElBars",value:function(){return this.w.globals.dom.baseEl.querySelectorAll(".apexcharts-bar-series,  .apexcharts-candlestick-series, .apexcharts-boxPlot-series, .apexcharts-rangebar-series")}},{key:"hasBars",value:function(){return this.getElBars().length>0}},{key:"getHoverMarkerSize",value:function(e){var t=this.w,i=t.config.markers.hover.size;return void 0===i&&(i=t.globals.markers.size[e]+t.config.markers.hover.sizeOffset),i}},{key:"toggleAllTooltipSeriesGroups",value:function(e){var t=this.w,i=this.ttCtx;0===i.allTooltipSeriesGroups.length&&(i.allTooltipSeriesGroups=t.globals.dom.baseEl.querySelectorAll(".apexcharts-tooltip-series-group"));for(var n=i.allTooltipSeriesGroups,r=0;r<n.length;r++)"enable"===e?(n[r].classList.add("apexcharts-active"),n[r].style.display=t.config.tooltip.items.display):(n[r].classList.remove("apexcharts-active"),n[r].style.display="none")}}]),e}(),he=function(){function e(t){n(this,e),this.w=t.w,this.ctx=t.ctx,this.ttCtx=t,this.tooltipUtil=new de(t)}return a(e,[{key:"drawSeriesTexts",value:function(e){var t=e.shared,i=void 0===t||t,n=e.ttItems,r=e.i,a=void 0===r?0:r,s=e.j,o=void 0===s?null:s,l=e.y1,c=e.y2,u=e.e,d=this.w;void 0!==d.config.tooltip.custom?this.handleCustomTooltip({i:a,j:o,y1:l,y2:c,w:d}):this.toggleActiveInactiveSeries(i);var h=this.getValuesToPrint({i:a,j:o});this.printLabels({i:a,j:o,values:h,ttItems:n,shared:i,e:u});var f=this.ttCtx.getElTooltip();this.ttCtx.tooltipRect.ttWidth=f.getBoundingClientRect().width,this.ttCtx.tooltipRect.ttHeight=f.getBoundingClientRect().height}},{key:"printLabels",value:function(e){var i,n=this,r=e.i,a=e.j,s=e.values,o=e.ttItems,l=e.shared,c=e.e,u=this.w,d=[],h=function(e){return u.globals.seriesGoals[e]&&u.globals.seriesGoals[e][a]&&Array.isArray(u.globals.seriesGoals[e][a])},f=s.xVal,p=s.zVal,m=s.xAxisTTVal,g="",v=u.globals.colors[r];null!==a&&u.config.plotOptions.bar.distributed&&(v=u.globals.colors[a]);for(var y=function(e,s){var y=n.getFormatters(r);g=n.getSeriesName({fn:y.yLbTitleFormatter,index:r,seriesIndex:r,j:a}),"treemap"===u.config.chart.type&&(g=y.yLbTitleFormatter(String(u.config.series[r].data[a].x),{series:u.globals.series,seriesIndex:r,dataPointIndex:a,w:u}));var b=u.config.tooltip.inverseOrder?s:e;if(u.globals.axisCharts){var x=function(e){var t,i,n,r;return u.globals.isRangeData?y.yLbFormatter(null===(t=u.globals.seriesRangeStart)||void 0===t||null===(i=t[e])||void 0===i?void 0:i[a],{series:u.globals.seriesRangeStart,seriesIndex:e,dataPointIndex:a,w:u})+" - "+y.yLbFormatter(null===(n=u.globals.seriesRangeEnd)||void 0===n||null===(r=n[e])||void 0===r?void 0:r[a],{series:u.globals.seriesRangeEnd,seriesIndex:e,dataPointIndex:a,w:u}):y.yLbFormatter(u.globals.series[e][a],{series:u.globals.series,seriesIndex:e,dataPointIndex:a,w:u})};if(l)y=n.getFormatters(b),g=n.getSeriesName({fn:y.yLbTitleFormatter,index:b,seriesIndex:r,j:a}),v=u.globals.colors[b],i=x(b),h(b)&&(d=u.globals.seriesGoals[b][a].map((function(e){return{attrs:e,val:y.yLbFormatter(e.value,{seriesIndex:b,dataPointIndex:a,w:u})}})));else{var _,w=null==c||null===(_=c.target)||void 0===_?void 0:_.getAttribute("fill");w&&(v=-1!==w.indexOf("url")?document.querySelector(w.substr(4).slice(0,-1)).childNodes[0].getAttribute("stroke"):w),i=x(r),h(r)&&Array.isArray(u.globals.seriesGoals[r][a])&&(d=u.globals.seriesGoals[r][a].map((function(e){return{attrs:e,val:y.yLbFormatter(e.value,{seriesIndex:r,dataPointIndex:a,w:u})}})))}}null===a&&(i=y.yLbFormatter(u.globals.series[r],t(t({},u),{},{seriesIndex:r,dataPointIndex:r}))),n.DOMHandling({i:r,t:b,j:a,ttItems:o,values:{val:i,goalVals:d,xVal:f,xAxisTTVal:m,zVal:p},seriesName:g,shared:l,pColor:v})},b=0,x=u.globals.series.length-1;b<u.globals.series.length;b++,x--)y(b,x)}},{key:"getFormatters",value:function(e){var t,i=this.w,n=i.globals.yLabelFormatters[e];return void 0!==i.globals.ttVal?Array.isArray(i.globals.ttVal)?(n=i.globals.ttVal[e]&&i.globals.ttVal[e].formatter,t=i.globals.ttVal[e]&&i.globals.ttVal[e].title&&i.globals.ttVal[e].title.formatter):(n=i.globals.ttVal.formatter,"function"==typeof i.globals.ttVal.title.formatter&&(t=i.globals.ttVal.title.formatter)):t=i.config.tooltip.y.title.formatter,"function"!=typeof n&&(n=i.globals.yLabelFormatters[0]?i.globals.yLabelFormatters[0]:function(e){return e}),"function"!=typeof t&&(t=function(e){return e}),{yLbFormatter:n,yLbTitleFormatter:t}}},{key:"getSeriesName",value:function(e){var t=e.fn,i=e.index,n=e.seriesIndex,r=e.j,a=this.w;return t(String(a.globals.seriesNames[i]),{series:a.globals.series,seriesIndex:n,dataPointIndex:r,w:a})}},{key:"DOMHandling",value:function(e){e.i;var t=e.t,i=e.j,n=e.ttItems,r=e.values,a=e.seriesName,s=e.shared,o=e.pColor,l=this.w,c=this.ttCtx,u=r.val,d=r.goalVals,h=r.xVal,f=r.xAxisTTVal,p=r.zVal,m=null;m=n[t].children,l.config.tooltip.fillSeriesColor&&(n[t].style.backgroundColor=o,m[0].style.display="none"),c.showTooltipTitle&&(null===c.tooltipTitle&&(c.tooltipTitle=l.globals.dom.baseEl.querySelector(".apexcharts-tooltip-title")),c.tooltipTitle.innerHTML=h),c.isXAxisTooltipEnabled&&(c.xaxisTooltipText.innerHTML=""!==f?f:h);var g=n[t].querySelector(".apexcharts-tooltip-text-y-label");g&&(g.innerHTML=a||"");var v=n[t].querySelector(".apexcharts-tooltip-text-y-value");v&&(v.innerHTML=void 0!==u?u:""),m[0]&&m[0].classList.contains("apexcharts-tooltip-marker")&&(l.config.tooltip.marker.fillColors&&Array.isArray(l.config.tooltip.marker.fillColors)&&(o=l.config.tooltip.marker.fillColors[t]),m[0].style.backgroundColor=o),l.config.tooltip.marker.show||(m[0].style.display="none");var y=n[t].querySelector(".apexcharts-tooltip-text-goals-label"),b=n[t].querySelector(".apexcharts-tooltip-text-goals-value");if(d.length&&l.globals.seriesGoals[t]){var x=function(){var e="<div >",t="<div>";d.forEach((function(i,n){e+=' <div style="display: flex"><span class="apexcharts-tooltip-marker" style="background-color: '.concat(i.attrs.strokeColor,'; height: 3px; border-radius: 0; top: 5px;"></span> ').concat(i.attrs.name,"</div>"),t+="<div>".concat(i.val,"</div>")})),y.innerHTML=e+"</div>",b.innerHTML=t+"</div>"};s?l.globals.seriesGoals[t][i]&&Array.isArray(l.globals.seriesGoals[t][i])?x():(y.innerHTML="",b.innerHTML=""):x()}else y.innerHTML="",b.innerHTML="";if(null!==p&&(n[t].querySelector(".apexcharts-tooltip-text-z-label").innerHTML=l.config.tooltip.z.title,n[t].querySelector(".apexcharts-tooltip-text-z-value").innerHTML=void 0!==p?p:""),s&&m[0]){if(l.config.tooltip.hideEmptySeries){var _=n[t].querySelector(".apexcharts-tooltip-marker"),w=n[t].querySelector(".apexcharts-tooltip-text");0==parseFloat(u)?(_.style.display="none",w.style.display="none"):(_.style.display="block",w.style.display="block")}null==u||l.globals.ancillaryCollapsedSeriesIndices.indexOf(t)>-1||l.globals.collapsedSeriesIndices.indexOf(t)>-1?m[0].parentNode.style.display="none":m[0].parentNode.style.display=l.config.tooltip.items.display}}},{key:"toggleActiveInactiveSeries",value:function(e){var t=this.w;if(e)this.tooltipUtil.toggleAllTooltipSeriesGroups("enable");else{this.tooltipUtil.toggleAllTooltipSeriesGroups("disable");var i=t.globals.dom.baseEl.querySelector(".apexcharts-tooltip-series-group");i&&(i.classList.add("apexcharts-active"),i.style.display=t.config.tooltip.items.display)}}},{key:"getValuesToPrint",value:function(e){var t=e.i,i=e.j,n=this.w,r=this.ctx.series.filteredSeriesX(),a="",s="",o=null,l=null,c={series:n.globals.series,seriesIndex:t,dataPointIndex:i,w:n},u=n.globals.ttZFormatter;null===i?l=n.globals.series[t]:n.globals.isXNumeric&&"treemap"!==n.config.chart.type?(a=r[t][i],0===r[t].length&&(a=r[this.tooltipUtil.getFirstActiveXArray(r)][i])):a=void 0!==n.globals.labels[i]?n.globals.labels[i]:"";var d=a;return a=n.globals.isXNumeric&&"datetime"===n.config.xaxis.type?new M(this.ctx).xLabelFormat(n.globals.ttKeyFormatter,d,d,{i:void 0,dateFormatter:new k(this.ctx).formatDate,w:this.w}):n.globals.isBarHorizontal?n.globals.yLabelFormatters[0](d,c):n.globals.xLabelFormatter(d,c),void 0!==n.config.tooltip.x.formatter&&(a=n.globals.ttKeyFormatter(d,c)),n.globals.seriesZ.length>0&&n.globals.seriesZ[t].length>0&&(o=u(n.globals.seriesZ[t][i],n)),s="function"==typeof n.config.xaxis.tooltip.formatter?n.globals.xaxisTooltipFormatter(d,c):a,{val:Array.isArray(l)?l.join(" "):l,xVal:Array.isArray(a)?a.join(" "):a,xAxisTTVal:Array.isArray(s)?s.join(" "):s,zVal:o}}},{key:"handleCustomTooltip",value:function(e){var t=e.i,i=e.j,n=e.y1,r=e.y2,a=e.w,s=this.ttCtx.getElTooltip(),o=a.config.tooltip.custom;Array.isArray(o)&&o[t]&&(o=o[t]),s.innerHTML=o({ctx:this.ctx,series:a.globals.series,seriesIndex:t,dataPointIndex:i,y1:n,y2:r,w:a})}}]),e}(),fe=function(){function e(t){n(this,e),this.ttCtx=t,this.ctx=t.ctx,this.w=t.w}return a(e,[{key:"moveXCrosshairs",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null,i=this.ttCtx,n=this.w,r=i.getElXCrosshairs(),a=e-i.xcrosshairsWidth/2,s=n.globals.labels.slice().length;if(null!==t&&(a=n.globals.gridWidth/s*t),null===r||n.globals.isBarHorizontal||(r.setAttribute("x",a),r.setAttribute("x1",a),r.setAttribute("x2",a),r.setAttribute("y2",n.globals.gridHeight),r.classList.add("apexcharts-active")),a<0&&(a=0),a>n.globals.gridWidth&&(a=n.globals.gridWidth),i.isXAxisTooltipEnabled){var o=a;"tickWidth"!==n.config.xaxis.crosshairs.width&&"barWidth"!==n.config.xaxis.crosshairs.width||(o=a+i.xcrosshairsWidth/2),this.moveXAxisTooltip(o)}}},{key:"moveYCrosshairs",value:function(e){var t=this.ttCtx;null!==t.ycrosshairs&&b.setAttrs(t.ycrosshairs,{y1:e,y2:e}),null!==t.ycrosshairsHidden&&b.setAttrs(t.ycrosshairsHidden,{y1:e,y2:e})}},{key:"moveXAxisTooltip",value:function(e){var t=this.w,i=this.ttCtx;if(null!==i.xaxisTooltip&&0!==i.xcrosshairsWidth){i.xaxisTooltip.classList.add("apexcharts-active");var n,r=i.xaxisOffY+t.config.xaxis.tooltip.offsetY+t.globals.translateY+1+t.config.xaxis.offsetY;if(e-=i.xaxisTooltip.getBoundingClientRect().width/2,!isNaN(e))e+=t.globals.translateX,n=new b(this.ctx).getTextRects(i.xaxisTooltipText.innerHTML),i.xaxisTooltipText.style.minWidth=n.width+"px",i.xaxisTooltip.style.left=e+"px",i.xaxisTooltip.style.top=r+"px"}}},{key:"moveYAxisTooltip",value:function(e){var t=this.w,i=this.ttCtx;null===i.yaxisTTEls&&(i.yaxisTTEls=t.globals.dom.baseEl.querySelectorAll(".apexcharts-yaxistooltip"));var n=parseInt(i.ycrosshairsHidden.getAttribute("y1"),10),r=t.globals.translateY+n,a=i.yaxisTTEls[e].getBoundingClientRect().height,s=t.globals.translateYAxisX[e]-2;t.config.yaxis[e].opposite&&(s-=26),r-=a/2,-1===t.globals.ignoreYAxisIndexes.indexOf(e)?(i.yaxisTTEls[e].classList.add("apexcharts-active"),i.yaxisTTEls[e].style.top=r+"px",i.yaxisTTEls[e].style.left=s+t.config.yaxis[e].tooltip.offsetX+"px"):i.yaxisTTEls[e].classList.remove("apexcharts-active")}},{key:"moveTooltip",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null,n=this.w,r=this.ttCtx,a=r.getElTooltip(),s=r.tooltipRect,o=null!==i?parseFloat(i):1,l=parseFloat(e)+o+5,c=parseFloat(t)+o/2;if(l>n.globals.gridWidth/2&&(l=l-s.ttWidth-o-10),l>n.globals.gridWidth-s.ttWidth-10&&(l=n.globals.gridWidth-s.ttWidth),l<-20&&(l=-20),n.config.tooltip.followCursor){var u=r.getElGrid().getBoundingClientRect();(l=r.e.clientX-u.left)>n.globals.gridWidth/2&&(l-=r.tooltipRect.ttWidth),(c=r.e.clientY+n.globals.translateY-u.top)>n.globals.gridHeight/2&&(c-=r.tooltipRect.ttHeight)}else n.globals.isBarHorizontal||s.ttHeight/2+c>n.globals.gridHeight&&(c=n.globals.gridHeight-s.ttHeight+n.globals.translateY);isNaN(l)||(l+=n.globals.translateX,a.style.left=l+"px",a.style.top=c+"px")}},{key:"moveMarkers",value:function(e,t){var i=this.w,n=this.ttCtx;if(i.globals.markers.size[e]>0)for(var r=i.globals.dom.baseEl.querySelectorAll(" .apexcharts-series[data\\:realIndex='".concat(e,"'] .apexcharts-marker")),a=0;a<r.length;a++)parseInt(r[a].getAttribute("rel"),10)===t&&(n.marker.resetPointsSize(),n.marker.enlargeCurrentPoint(t,r[a]));else n.marker.resetPointsSize(),this.moveDynamicPointOnHover(t,e)}},{key:"moveDynamicPointOnHover",value:function(e,t){var i,n,r=this.w,a=this.ttCtx,s=r.globals.pointsArray,o=a.tooltipUtil.getHoverMarkerSize(t),l=r.config.series[t].type;if(!l||"column"!==l&&"candlestick"!==l&&"boxPlot"!==l){i=s[t][e][0],n=s[t][e][1]?s[t][e][1]:0;var c=r.globals.dom.baseEl.querySelector(".apexcharts-series[data\\:realIndex='".concat(t,"'] .apexcharts-series-markers circle"));c&&n<r.globals.gridHeight&&n>0&&(c.setAttribute("r",o),c.setAttribute("cx",i),c.setAttribute("cy",n)),this.moveXCrosshairs(i),a.fixedTooltip||this.moveTooltip(i,n,o)}}},{key:"moveDynamicPointsOnHover",value:function(e){var t,i=this.ttCtx,n=i.w,r=0,a=0,s=n.globals.pointsArray;t=new z(this.ctx).getActiveConfigSeriesIndex("asc",["line","area","scatter","bubble"]);var o=i.tooltipUtil.getHoverMarkerSize(t);s[t]&&(r=s[t][e][0],a=s[t][e][1]);var l=i.tooltipUtil.getAllMarkers();if(null!==l)for(var c=0;c<n.globals.series.length;c++){var u=s[c];if(n.globals.comboCharts&&void 0===u&&l.splice(c,0,null),u&&u.length){var d=s[c][e][1],h=void 0;if(l[c].setAttribute("cx",r),"rangeArea"===n.config.chart.type&&!n.globals.comboCharts){var f=e+n.globals.series[c].length;h=s[c][f][1],d-=Math.abs(d-h)/2}null!==d&&!isNaN(d)&&d<n.globals.gridHeight+o&&d+o>0?(l[c]&&l[c].setAttribute("r",o),l[c]&&l[c].setAttribute("cy",d)):l[c]&&l[c].setAttribute("r",0)}}this.moveXCrosshairs(r),i.fixedTooltip||this.moveTooltip(r,a||n.globals.gridHeight,o)}},{key:"moveStickyTooltipOverBars",value:function(e,t){var i=this.w,n=this.ttCtx,r=i.globals.columnSeries?i.globals.columnSeries.length:i.globals.series.length,a=r>=2&&r%2==0?Math.floor(r/2):Math.floor(r/2)+1;i.globals.isBarHorizontal&&(a=new z(this.ctx).getActiveConfigSeriesIndex("desc")+1);var s=i.globals.dom.baseEl.querySelector(".apexcharts-bar-series .apexcharts-series[rel='".concat(a,"'] path[j='").concat(e,"'], .apexcharts-candlestick-series .apexcharts-series[rel='").concat(a,"'] path[j='").concat(e,"'], .apexcharts-boxPlot-series .apexcharts-series[rel='").concat(a,"'] path[j='").concat(e,"'], .apexcharts-rangebar-series .apexcharts-series[rel='").concat(a,"'] path[j='").concat(e,"']"));s||"number"!=typeof t||(s=i.globals.dom.baseEl.querySelector(".apexcharts-bar-series .apexcharts-series[data\\:realIndex='".concat(t,"'] path[j='").concat(e,"'],\n        .apexcharts-candlestick-series .apexcharts-series[data\\:realIndex='").concat(t,"'] path[j='").concat(e,"'],\n        .apexcharts-boxPlot-series .apexcharts-series[data\\:realIndex='").concat(t,"'] path[j='").concat(e,"'],\n        .apexcharts-rangebar-series .apexcharts-series[data\\:realIndex='").concat(t,"'] path[j='").concat(e,"']")));var o=s?parseFloat(s.getAttribute("cx")):0,l=s?parseFloat(s.getAttribute("cy")):0,c=s?parseFloat(s.getAttribute("barWidth")):0,u=n.getElGrid().getBoundingClientRect(),d=s&&(s.classList.contains("apexcharts-candlestick-area")||s.classList.contains("apexcharts-boxPlot-area"));i.globals.isXNumeric?(s&&!d&&(o-=r%2!=0?c/2:0),s&&d&&i.globals.comboCharts&&(o-=c/2)):i.globals.isBarHorizontal||(o=n.xAxisTicksPositions[e-1]+n.dataPointsDividedWidth/2,isNaN(o)&&(o=n.xAxisTicksPositions[e]-n.dataPointsDividedWidth/2)),i.globals.isBarHorizontal?l-=n.tooltipRect.ttHeight:i.config.tooltip.followCursor?l=n.e.clientY-u.top-n.tooltipRect.ttHeight/2:l+n.tooltipRect.ttHeight+15>i.globals.gridHeight&&(l=i.globals.gridHeight),i.globals.isBarHorizontal||this.moveXCrosshairs(o),n.fixedTooltip||this.moveTooltip(o,l||i.globals.gridHeight)}}]),e}(),pe=function(){function e(t){n(this,e),this.w=t.w,this.ttCtx=t,this.ctx=t.ctx,this.tooltipPosition=new fe(t)}return a(e,[{key:"drawDynamicPoints",value:function(){var e=this.w,t=new b(this.ctx),i=new H(this.ctx),n=e.globals.dom.baseEl.querySelectorAll(".apexcharts-series");n=f(n),e.config.chart.stacked&&n.sort((function(e,t){return parseFloat(e.getAttribute("data:realIndex"))-parseFloat(t.getAttribute("data:realIndex"))}));for(var r=0;r<n.length;r++){var a=n[r].querySelector(".apexcharts-series-markers-wrap");if(null!==a){var s=void 0,o="apexcharts-marker w".concat((Math.random()+1).toString(36).substring(4));"line"!==e.config.chart.type&&"area"!==e.config.chart.type||e.globals.comboCharts||e.config.tooltip.intersect||(o+=" no-pointer-events");var l=i.getMarkerConfig({cssClass:o,seriesIndex:Number(a.getAttribute("data:realIndex"))});(s=t.drawMarker(0,0,l)).node.setAttribute("default-marker-size",0);var c=document.createElementNS(e.globals.SVGNS,"g");c.classList.add("apexcharts-series-markers"),c.appendChild(s.node),a.appendChild(c)}}}},{key:"enlargeCurrentPoint",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null,n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:null,r=this.w;"bubble"!==r.config.chart.type&&this.newPointSize(e,t);var a=t.getAttribute("cx"),s=t.getAttribute("cy");if(null!==i&&null!==n&&(a=i,s=n),this.tooltipPosition.moveXCrosshairs(a),!this.fixedTooltip){if("radar"===r.config.chart.type){var o=this.ttCtx.getElGrid().getBoundingClientRect();a=this.ttCtx.e.clientX-o.left}this.tooltipPosition.moveTooltip(a,s,r.config.markers.hover.size)}}},{key:"enlargePoints",value:function(e){for(var t=this.w,i=this,n=this.ttCtx,r=e,a=t.globals.dom.baseEl.querySelectorAll(".apexcharts-series:not(.apexcharts-series-collapsed) .apexcharts-marker"),s=t.config.markers.hover.size,o=0;o<a.length;o++){var l=a[o].getAttribute("rel"),c=a[o].getAttribute("index");if(void 0===s&&(s=t.globals.markers.size[c]+t.config.markers.hover.sizeOffset),r===parseInt(l,10)){i.newPointSize(r,a[o]);var u=a[o].getAttribute("cx"),d=a[o].getAttribute("cy");i.tooltipPosition.moveXCrosshairs(u),n.fixedTooltip||i.tooltipPosition.moveTooltip(u,d,s)}else i.oldPointSize(a[o])}}},{key:"newPointSize",value:function(e,t){var i=this.w,n=i.config.markers.hover.size,r=0===e?t.parentNode.firstChild:t.parentNode.lastChild;if("0"!==r.getAttribute("default-marker-size")){var a=parseInt(r.getAttribute("index"),10);void 0===n&&(n=i.globals.markers.size[a]+i.config.markers.hover.sizeOffset),n<0&&(n=0),r.setAttribute("r",n)}}},{key:"oldPointSize",value:function(e){var t=parseFloat(e.getAttribute("default-marker-size"));e.setAttribute("r",t)}},{key:"resetPointsSize",value:function(){for(var e=this.w.globals.dom.baseEl.querySelectorAll(".apexcharts-series:not(.apexcharts-series-collapsed) .apexcharts-marker"),t=0;t<e.length;t++){var i=parseFloat(e[t].getAttribute("default-marker-size"));g.isNumber(i)&&i>=0?e[t].setAttribute("r",i):e[t].setAttribute("r",0)}}}]),e}(),me=function(){function e(t){n(this,e),this.w=t.w;var i=this.w;this.ttCtx=t,this.isVerticalGroupedRangeBar=!i.globals.isBarHorizontal&&"rangeBar"===i.config.chart.type&&i.config.plotOptions.bar.rangeBarGroupRows}return a(e,[{key:"getAttr",value:function(e,t){return parseFloat(e.target.getAttribute(t))}},{key:"handleHeatTreeTooltip",value:function(e){var t=e.e,i=e.opt,n=e.x,r=e.y,a=e.type,s=this.ttCtx,o=this.w;if(t.target.classList.contains("apexcharts-".concat(a,"-rect"))){var l=this.getAttr(t,"i"),c=this.getAttr(t,"j"),u=this.getAttr(t,"cx"),d=this.getAttr(t,"cy"),h=this.getAttr(t,"width"),f=this.getAttr(t,"height");if(s.tooltipLabels.drawSeriesTexts({ttItems:i.ttItems,i:l,j:c,shared:!1,e:t}),o.globals.capturedSeriesIndex=l,o.globals.capturedDataPointIndex=c,n=u+s.tooltipRect.ttWidth/2+h,r=d+s.tooltipRect.ttHeight/2-f/2,s.tooltipPosition.moveXCrosshairs(u+h/2),n>o.globals.gridWidth/2&&(n=u-s.tooltipRect.ttWidth/2+h),s.w.config.tooltip.followCursor){var p=o.globals.dom.elWrap.getBoundingClientRect();n=o.globals.clientX-p.left-(n>o.globals.gridWidth/2?s.tooltipRect.ttWidth:0),r=o.globals.clientY-p.top-(r>o.globals.gridHeight/2?s.tooltipRect.ttHeight:0)}}return{x:n,y:r}}},{key:"handleMarkerTooltip",value:function(e){var t,i,n=e.e,r=e.opt,a=e.x,s=e.y,o=this.w,l=this.ttCtx;if(n.target.classList.contains("apexcharts-marker")){var c=parseInt(r.paths.getAttribute("cx"),10),u=parseInt(r.paths.getAttribute("cy"),10),d=parseFloat(r.paths.getAttribute("val"));if(i=parseInt(r.paths.getAttribute("rel"),10),t=parseInt(r.paths.parentNode.parentNode.parentNode.getAttribute("rel"),10)-1,l.intersect){var h=g.findAncestor(r.paths,"apexcharts-series");h&&(t=parseInt(h.getAttribute("data:realIndex"),10))}if(l.tooltipLabels.drawSeriesTexts({ttItems:r.ttItems,i:t,j:i,shared:!l.showOnIntersect&&o.config.tooltip.shared,e:n}),"mouseup"===n.type&&l.markerClick(n,t,i),o.globals.capturedSeriesIndex=t,o.globals.capturedDataPointIndex=i,a=c,s=u+o.globals.translateY-1.4*l.tooltipRect.ttHeight,l.w.config.tooltip.followCursor){var f=l.getElGrid().getBoundingClientRect();s=l.e.clientY+o.globals.translateY-f.top}d<0&&(s=u),l.marker.enlargeCurrentPoint(i,r.paths,a,s)}return{x:a,y:s}}},{key:"handleBarTooltip",value:function(e){var t,i,n=e.e,r=e.opt,a=this.w,s=this.ttCtx,o=s.getElTooltip(),l=0,c=0,u=0,d=this.getBarTooltipXY({e:n,opt:r});t=d.i;var h=d.barHeight,f=d.j;a.globals.capturedSeriesIndex=t,a.globals.capturedDataPointIndex=f,a.globals.isBarHorizontal&&s.tooltipUtil.hasBars()||!a.config.tooltip.shared?(c=d.x,u=d.y,i=Array.isArray(a.config.stroke.width)?a.config.stroke.width[t]:a.config.stroke.width,l=c):a.globals.comboCharts||a.config.tooltip.shared||(l/=2),isNaN(u)&&(u=a.globals.svgHeight-s.tooltipRect.ttHeight);var p=parseInt(r.paths.parentNode.getAttribute("data:realIndex"),10),m=a.globals.isMultipleYAxis?a.config.yaxis[p]&&a.config.yaxis[p].reversed:a.config.yaxis[0].reversed;if(c+s.tooltipRect.ttWidth>a.globals.gridWidth&&!m?c-=s.tooltipRect.ttWidth:c<0&&(c=0),s.w.config.tooltip.followCursor){var g=s.getElGrid().getBoundingClientRect();u=s.e.clientY-g.top}null===s.tooltip&&(s.tooltip=a.globals.dom.baseEl.querySelector(".apexcharts-tooltip")),a.config.tooltip.shared||(a.globals.comboBarCount>0?s.tooltipPosition.moveXCrosshairs(l+i/2):s.tooltipPosition.moveXCrosshairs(l)),!s.fixedTooltip&&(!a.config.tooltip.shared||a.globals.isBarHorizontal&&s.tooltipUtil.hasBars())&&(m&&(c-=s.tooltipRect.ttWidth)<0&&(c=0),!m||a.globals.isBarHorizontal&&s.tooltipUtil.hasBars()||(u=u+h-2*(a.globals.series[t][f]<0?h:0)),u=u+a.globals.translateY-s.tooltipRect.ttHeight/2,o.style.left=c+a.globals.translateX+"px",o.style.top=u+"px")}},{key:"getBarTooltipXY",value:function(e){var t=this,i=e.e,n=e.opt,r=this.w,a=null,s=this.ttCtx,o=0,l=0,c=0,u=0,d=0,h=i.target.classList;if(h.contains("apexcharts-bar-area")||h.contains("apexcharts-candlestick-area")||h.contains("apexcharts-boxPlot-area")||h.contains("apexcharts-rangebar-area")){var f=i.target,p=f.getBoundingClientRect(),m=n.elGrid.getBoundingClientRect(),g=p.height;d=p.height;var v=p.width,y=parseInt(f.getAttribute("cx"),10),b=parseInt(f.getAttribute("cy"),10);u=parseFloat(f.getAttribute("barWidth"));var x="touchmove"===i.type?i.touches[0].clientX:i.clientX;a=parseInt(f.getAttribute("j"),10),o=parseInt(f.parentNode.getAttribute("rel"),10)-1;var _=f.getAttribute("data-range-y1"),w=f.getAttribute("data-range-y2");r.globals.comboCharts&&(o=parseInt(f.parentNode.getAttribute("data:realIndex"),10));var k=function(e){return r.globals.isXNumeric?y-v/2:t.isVerticalGroupedRangeBar?y+v/2:y-s.dataPointsDividedWidth+v/2},M=function(){return b-s.dataPointsDividedHeight+g/2-s.tooltipRect.ttHeight/2};s.tooltipLabels.drawSeriesTexts({ttItems:n.ttItems,i:o,j:a,y1:_?parseInt(_,10):null,y2:w?parseInt(w,10):null,shared:!s.showOnIntersect&&r.config.tooltip.shared,e:i}),r.config.tooltip.followCursor?r.globals.isBarHorizontal?(l=x-m.left+15,c=M()):(l=k(),c=i.clientY-m.top-s.tooltipRect.ttHeight/2-15):r.globals.isBarHorizontal?((l=y)<s.xyRatios.baseLineInvertedY&&(l=y-s.tooltipRect.ttWidth),c=M()):(l=k(),c=b)}return{x:l,y:c,barHeight:d,barWidth:u,i:o,j:a}}}]),e}(),ge=function(){function e(t){n(this,e),this.w=t.w,this.ttCtx=t}return a(e,[{key:"drawXaxisTooltip",value:function(){var e=this.w,t=this.ttCtx,i="bottom"===e.config.xaxis.position;t.xaxisOffY=i?e.globals.gridHeight+1:-e.globals.xAxisHeight-e.config.xaxis.axisTicks.height+3;var n=i?"apexcharts-xaxistooltip apexcharts-xaxistooltip-bottom":"apexcharts-xaxistooltip apexcharts-xaxistooltip-top",r=e.globals.dom.elWrap;t.isXAxisTooltipEnabled&&null===e.globals.dom.baseEl.querySelector(".apexcharts-xaxistooltip")&&(t.xaxisTooltip=document.createElement("div"),t.xaxisTooltip.setAttribute("class",n+" apexcharts-theme-"+e.config.tooltip.theme),r.appendChild(t.xaxisTooltip),t.xaxisTooltipText=document.createElement("div"),t.xaxisTooltipText.classList.add("apexcharts-xaxistooltip-text"),t.xaxisTooltipText.style.fontFamily=e.config.xaxis.tooltip.style.fontFamily||e.config.chart.fontFamily,t.xaxisTooltipText.style.fontSize=e.config.xaxis.tooltip.style.fontSize,t.xaxisTooltip.appendChild(t.xaxisTooltipText))}},{key:"drawYaxisTooltip",value:function(){for(var e=this.w,t=this.ttCtx,i=0;i<e.config.yaxis.length;i++){var n=e.config.yaxis[i].opposite||e.config.yaxis[i].crosshairs.opposite;t.yaxisOffX=n?e.globals.gridWidth+1:1;var r="apexcharts-yaxistooltip apexcharts-yaxistooltip-".concat(i,n?" apexcharts-yaxistooltip-right":" apexcharts-yaxistooltip-left"),a=e.globals.dom.elWrap;null===e.globals.dom.baseEl.querySelector(".apexcharts-yaxistooltip apexcharts-yaxistooltip-".concat(i))&&(t.yaxisTooltip=document.createElement("div"),t.yaxisTooltip.setAttribute("class",r+" apexcharts-theme-"+e.config.tooltip.theme),a.appendChild(t.yaxisTooltip),0===i&&(t.yaxisTooltipText=[]),t.yaxisTooltipText[i]=document.createElement("div"),t.yaxisTooltipText[i].classList.add("apexcharts-yaxistooltip-text"),t.yaxisTooltip.appendChild(t.yaxisTooltipText[i]))}}},{key:"setXCrosshairWidth",value:function(){var e=this.w,t=this.ttCtx,i=t.getElXCrosshairs();if(t.xcrosshairsWidth=parseInt(e.config.xaxis.crosshairs.width,10),e.globals.comboCharts){var n=e.globals.dom.baseEl.querySelector(".apexcharts-bar-area");if(null!==n&&"barWidth"===e.config.xaxis.crosshairs.width){var r=parseFloat(n.getAttribute("barWidth"));t.xcrosshairsWidth=r}else if("tickWidth"===e.config.xaxis.crosshairs.width){var a=e.globals.labels.length;t.xcrosshairsWidth=e.globals.gridWidth/a}}else if("tickWidth"===e.config.xaxis.crosshairs.width){var s=e.globals.labels.length;t.xcrosshairsWidth=e.globals.gridWidth/s}else if("barWidth"===e.config.xaxis.crosshairs.width){var o=e.globals.dom.baseEl.querySelector(".apexcharts-bar-area");if(null!==o){var l=parseFloat(o.getAttribute("barWidth"));t.xcrosshairsWidth=l}else t.xcrosshairsWidth=1}e.globals.isBarHorizontal&&(t.xcrosshairsWidth=0),null!==i&&t.xcrosshairsWidth>0&&i.setAttribute("width",t.xcrosshairsWidth)}},{key:"handleYCrosshair",value:function(){var e=this.w,t=this.ttCtx;t.ycrosshairs=e.globals.dom.baseEl.querySelector(".apexcharts-ycrosshairs"),t.ycrosshairsHidden=e.globals.dom.baseEl.querySelector(".apexcharts-ycrosshairs-hidden")}},{key:"drawYaxisTooltipText",value:function(e,t,i){var n=this.ttCtx,r=this.w,a=r.globals,s=a.seriesYAxisMap[e];if(n.yaxisTooltips[e]&&s.length>0){var o=a.yLabelFormatters[e],l=n.getElGrid().getBoundingClientRect(),c=s[0];i.yRatio.length>1&&function(e){throw new TypeError('"translationsIndex" is read-only')}();var u=(t-l.top)*i.yRatio[0],d=a.maxYArr[c]-a.minYArr[c],h=a.minYArr[c]+(d-u);r.config.yaxis[e].reversed&&(h=a.maxYArr[c]-(d-u)),n.tooltipPosition.moveYCrosshairs(t-l.top),n.yaxisTooltipText[e].innerHTML=o(h),n.tooltipPosition.moveYAxisTooltip(e)}}}]),e}(),ve=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w;var i=this.w;this.tConfig=i.config.tooltip,this.tooltipUtil=new de(this),this.tooltipLabels=new he(this),this.tooltipPosition=new fe(this),this.marker=new pe(this),this.intersect=new me(this),this.axesTooltip=new ge(this),this.showOnIntersect=this.tConfig.intersect,this.showTooltipTitle=this.tConfig.x.show,this.fixedTooltip=this.tConfig.fixed.enabled,this.xaxisTooltip=null,this.yaxisTTEls=null,this.isBarShared=!i.globals.isBarHorizontal&&this.tConfig.shared,this.lastHoverTime=Date.now()}return a(e,[{key:"getElTooltip",value:function(e){return e||(e=this),e.w.globals.dom.baseEl?e.w.globals.dom.baseEl.querySelector(".apexcharts-tooltip"):null}},{key:"getElXCrosshairs",value:function(){return this.w.globals.dom.baseEl.querySelector(".apexcharts-xcrosshairs")}},{key:"getElGrid",value:function(){return this.w.globals.dom.baseEl.querySelector(".apexcharts-grid")}},{key:"drawTooltip",value:function(e){var t=this.w;this.xyRatios=e,this.isXAxisTooltipEnabled=t.config.xaxis.tooltip.enabled&&t.globals.axisCharts,this.yaxisTooltips=t.config.yaxis.map((function(e,i){return!!(e.show&&e.tooltip.enabled&&t.globals.axisCharts)})),this.allTooltipSeriesGroups=[],t.globals.axisCharts||(this.showTooltipTitle=!1);var i=document.createElement("div");if(i.classList.add("apexcharts-tooltip"),t.config.tooltip.cssClass&&i.classList.add(t.config.tooltip.cssClass),i.classList.add("apexcharts-theme-".concat(this.tConfig.theme)),t.globals.dom.elWrap.appendChild(i),t.globals.axisCharts){this.axesTooltip.drawXaxisTooltip(),this.axesTooltip.drawYaxisTooltip(),this.axesTooltip.setXCrosshairWidth(),this.axesTooltip.handleYCrosshair();var n=new W(this.ctx);this.xAxisTicksPositions=n.getXAxisTicksPositions()}if(!t.globals.comboCharts&&!this.tConfig.intersect&&"rangeBar"!==t.config.chart.type||this.tConfig.shared||(this.showOnIntersect=!0),0!==t.config.markers.size&&0!==t.globals.markers.largestSize||this.marker.drawDynamicPoints(this),t.globals.collapsedSeries.length!==t.globals.series.length){this.dataPointsDividedHeight=t.globals.gridHeight/t.globals.dataPoints,this.dataPointsDividedWidth=t.globals.gridWidth/t.globals.dataPoints,this.showTooltipTitle&&(this.tooltipTitle=document.createElement("div"),this.tooltipTitle.classList.add("apexcharts-tooltip-title"),this.tooltipTitle.style.fontFamily=this.tConfig.style.fontFamily||t.config.chart.fontFamily,this.tooltipTitle.style.fontSize=this.tConfig.style.fontSize,i.appendChild(this.tooltipTitle));var r=t.globals.series.length;(t.globals.xyCharts||t.globals.comboCharts)&&this.tConfig.shared&&(r=this.showOnIntersect?1:t.globals.series.length),this.legendLabels=t.globals.dom.baseEl.querySelectorAll(".apexcharts-legend-text"),this.ttItems=this.createTTElements(r),this.addSVGEvents()}}},{key:"createTTElements",value:function(e){for(var t=this,i=this.w,n=[],r=this.getElTooltip(),a=function(a){var s=document.createElement("div");s.classList.add("apexcharts-tooltip-series-group"),s.style.order=i.config.tooltip.inverseOrder?e-a:a+1,t.tConfig.shared&&t.tConfig.enabledOnSeries&&Array.isArray(t.tConfig.enabledOnSeries)&&t.tConfig.enabledOnSeries.indexOf(a)<0&&s.classList.add("apexcharts-tooltip-series-group-hidden");var o=document.createElement("span");o.classList.add("apexcharts-tooltip-marker"),o.style.backgroundColor=i.globals.colors[a],s.appendChild(o);var l=document.createElement("div");l.classList.add("apexcharts-tooltip-text"),l.style.fontFamily=t.tConfig.style.fontFamily||i.config.chart.fontFamily,l.style.fontSize=t.tConfig.style.fontSize,["y","goals","z"].forEach((function(e){var t=document.createElement("div");t.classList.add("apexcharts-tooltip-".concat(e,"-group"));var i=document.createElement("span");i.classList.add("apexcharts-tooltip-text-".concat(e,"-label")),t.appendChild(i);var n=document.createElement("span");n.classList.add("apexcharts-tooltip-text-".concat(e,"-value")),t.appendChild(n),l.appendChild(t)})),s.appendChild(l),r.appendChild(s),n.push(s)},s=0;s<e;s++)a(s);return n}},{key:"addSVGEvents",value:function(){var e=this.w,t=e.config.chart.type,i=this.getElTooltip(),n=!("bar"!==t&&"candlestick"!==t&&"boxPlot"!==t&&"rangeBar"!==t),r="area"===t||"line"===t||"scatter"===t||"bubble"===t||"radar"===t,a=e.globals.dom.Paper.node,s=this.getElGrid();s&&(this.seriesBound=s.getBoundingClientRect());var o,l=[],c=[],u={hoverArea:a,elGrid:s,tooltipEl:i,tooltipY:l,tooltipX:c,ttItems:this.ttItems};if(e.globals.axisCharts&&(r?o=e.globals.dom.baseEl.querySelectorAll(".apexcharts-series[data\\:longestSeries='true'] .apexcharts-marker"):n?o=e.globals.dom.baseEl.querySelectorAll(".apexcharts-series .apexcharts-bar-area, .apexcharts-series .apexcharts-candlestick-area, .apexcharts-series .apexcharts-boxPlot-area, .apexcharts-series .apexcharts-rangebar-area"):"heatmap"!==t&&"treemap"!==t||(o=e.globals.dom.baseEl.querySelectorAll(".apexcharts-series .apexcharts-heatmap, .apexcharts-series .apexcharts-treemap")),o&&o.length))for(var d=0;d<o.length;d++)l.push(o[d].getAttribute("cy")),c.push(o[d].getAttribute("cx"));if(e.globals.xyCharts&&!this.showOnIntersect||e.globals.comboCharts&&!this.showOnIntersect||n&&this.tooltipUtil.hasBars()&&this.tConfig.shared)this.addPathsEventListeners([a],u);else if(n&&!e.globals.comboCharts||r&&this.showOnIntersect)this.addDatapointEventsListeners(u);else if(!e.globals.axisCharts||"heatmap"===t||"treemap"===t){var h=e.globals.dom.baseEl.querySelectorAll(".apexcharts-series");this.addPathsEventListeners(h,u)}if(this.showOnIntersect){var f=e.globals.dom.baseEl.querySelectorAll(".apexcharts-line-series .apexcharts-marker, .apexcharts-area-series .apexcharts-marker");f.length>0&&this.addPathsEventListeners(f,u),this.tooltipUtil.hasBars()&&!this.tConfig.shared&&this.addDatapointEventsListeners(u)}}},{key:"drawFixedTooltipRect",value:function(){var e=this.w,t=this.getElTooltip(),i=t.getBoundingClientRect(),n=i.width+10,r=i.height+10,a=this.tConfig.fixed.offsetX,s=this.tConfig.fixed.offsetY,o=this.tConfig.fixed.position.toLowerCase();return o.indexOf("right")>-1&&(a=a+e.globals.svgWidth-n+10),o.indexOf("bottom")>-1&&(s=s+e.globals.svgHeight-r-10),t.style.left=a+"px",t.style.top=s+"px",{x:a,y:s,ttWidth:n,ttHeight:r}}},{key:"addDatapointEventsListeners",value:function(e){var t=this.w.globals.dom.baseEl.querySelectorAll(".apexcharts-series-markers .apexcharts-marker, .apexcharts-bar-area, .apexcharts-candlestick-area, .apexcharts-boxPlot-area, .apexcharts-rangebar-area");this.addPathsEventListeners(t,e)}},{key:"addPathsEventListeners",value:function(e,t){for(var i=this,n=function(n){var r={paths:e[n],tooltipEl:t.tooltipEl,tooltipY:t.tooltipY,tooltipX:t.tooltipX,elGrid:t.elGrid,hoverArea:t.hoverArea,ttItems:t.ttItems};["mousemove","mouseup","touchmove","mouseout","touchend"].map((function(t){return e[n].addEventListener(t,i.onSeriesHover.bind(i,r),{capture:!1,passive:!0})}))},r=0;r<e.length;r++)n(r)}},{key:"onSeriesHover",value:function(e,t){var i=this,n=Date.now()-this.lastHoverTime;n>=100?this.seriesHover(e,t):(clearTimeout(this.seriesHoverTimeout),this.seriesHoverTimeout=setTimeout((function(){i.seriesHover(e,t)}),100-n))}},{key:"seriesHover",value:function(e,t){var i=this;this.lastHoverTime=Date.now();var n=[],r=this.w;r.config.chart.group&&(n=this.ctx.getGroupedCharts()),r.globals.axisCharts&&(r.globals.minX===-1/0&&r.globals.maxX===1/0||0===r.globals.dataPoints)||(n.length?n.forEach((function(n){var r=i.getElTooltip(n),a={paths:e.paths,tooltipEl:r,tooltipY:e.tooltipY,tooltipX:e.tooltipX,elGrid:e.elGrid,hoverArea:e.hoverArea,ttItems:n.w.globals.tooltip.ttItems};n.w.globals.minX===i.w.globals.minX&&n.w.globals.maxX===i.w.globals.maxX&&n.w.globals.tooltip.seriesHoverByContext({chartCtx:n,ttCtx:n.w.globals.tooltip,opt:a,e:t})})):this.seriesHoverByContext({chartCtx:this.ctx,ttCtx:this.w.globals.tooltip,opt:e,e:t}))}},{key:"seriesHoverByContext",value:function(e){var t=e.chartCtx,i=e.ttCtx,n=e.opt,r=e.e,a=t.w,s=this.getElTooltip();s&&(i.tooltipRect={x:0,y:0,ttWidth:s.getBoundingClientRect().width,ttHeight:s.getBoundingClientRect().height},i.e=r,!i.tooltipUtil.hasBars()||a.globals.comboCharts||i.isBarShared||this.tConfig.onDatasetHover.highlightDataSeries&&new z(t).toggleSeriesOnHover(r,r.target.parentNode),i.fixedTooltip&&i.drawFixedTooltipRect(),a.globals.axisCharts?i.axisChartsTooltips({e:r,opt:n,tooltipRect:i.tooltipRect}):i.nonAxisChartsTooltips({e:r,opt:n,tooltipRect:i.tooltipRect}))}},{key:"axisChartsTooltips",value:function(e){var t,i,n=e.e,r=e.opt,a=this.w,s=r.elGrid.getBoundingClientRect(),o="touchmove"===n.type?n.touches[0].clientX:n.clientX,l="touchmove"===n.type?n.touches[0].clientY:n.clientY;if(this.clientY=l,this.clientX=o,a.globals.capturedSeriesIndex=-1,a.globals.capturedDataPointIndex=-1,l<s.top||l>s.top+s.height)this.handleMouseOut(r);else{if(Array.isArray(this.tConfig.enabledOnSeries)&&!a.config.tooltip.shared){var c=parseInt(r.paths.getAttribute("index"),10);if(this.tConfig.enabledOnSeries.indexOf(c)<0)return void this.handleMouseOut(r)}var u=this.getElTooltip(),d=this.getElXCrosshairs(),h=a.globals.xyCharts||"bar"===a.config.chart.type&&!a.globals.isBarHorizontal&&this.tooltipUtil.hasBars()&&this.tConfig.shared||a.globals.comboCharts&&this.tooltipUtil.hasBars();if("mousemove"===n.type||"touchmove"===n.type||"mouseup"===n.type){if(a.globals.collapsedSeries.length+a.globals.ancillaryCollapsedSeries.length===a.globals.series.length)return;null!==d&&d.classList.add("apexcharts-active");var f=this.yaxisTooltips.filter((function(e){return!0===e}));if(null!==this.ycrosshairs&&f.length&&this.ycrosshairs.classList.add("apexcharts-active"),h&&!this.showOnIntersect)this.handleStickyTooltip(n,o,l,r);else if("heatmap"===a.config.chart.type||"treemap"===a.config.chart.type){var p=this.intersect.handleHeatTreeTooltip({e:n,opt:r,x:t,y:i,type:a.config.chart.type});t=p.x,i=p.y,u.style.left=t+"px",u.style.top=i+"px"}else this.tooltipUtil.hasBars()&&this.intersect.handleBarTooltip({e:n,opt:r}),this.tooltipUtil.hasMarkers()&&this.intersect.handleMarkerTooltip({e:n,opt:r,x:t,y:i});if(this.yaxisTooltips.length)for(var m=0;m<a.config.yaxis.length;m++)this.axesTooltip.drawYaxisTooltipText(m,l,this.xyRatios);r.tooltipEl.classList.add("apexcharts-active")}else"mouseout"!==n.type&&"touchend"!==n.type||this.handleMouseOut(r)}}},{key:"nonAxisChartsTooltips",value:function(e){var t=e.e,i=e.opt,n=e.tooltipRect,r=this.w,a=i.paths.getAttribute("rel"),s=this.getElTooltip(),o=r.globals.dom.elWrap.getBoundingClientRect();if("mousemove"===t.type||"touchmove"===t.type){s.classList.add("apexcharts-active"),this.tooltipLabels.drawSeriesTexts({ttItems:i.ttItems,i:parseInt(a,10)-1,shared:!1});var l=r.globals.clientX-o.left-n.ttWidth/2,c=r.globals.clientY-o.top-n.ttHeight-10;if(s.style.left=l+"px",s.style.top=c+"px",r.config.legend.tooltipHoverFormatter){var u=a-1,d=(0,r.config.legend.tooltipHoverFormatter)(this.legendLabels[u].getAttribute("data:default-text"),{seriesIndex:u,dataPointIndex:u,w:r});this.legendLabels[u].innerHTML=d}}else"mouseout"!==t.type&&"touchend"!==t.type||(s.classList.remove("apexcharts-active"),r.config.legend.tooltipHoverFormatter&&this.legendLabels.forEach((function(e){var t=e.getAttribute("data:default-text");e.innerHTML=decodeURIComponent(t)})))}},{key:"handleStickyTooltip",value:function(e,t,i,n){var r=this.w,a=this.tooltipUtil.getNearestValues({context:this,hoverArea:n.hoverArea,elGrid:n.elGrid,clientX:t,clientY:i}),s=a.j,o=a.capturedSeries;r.globals.collapsedSeriesIndices.includes(o)&&(o=null);var l=n.elGrid.getBoundingClientRect();if(a.hoverX<0||a.hoverX>l.width)this.handleMouseOut(n);else if(null!==o)this.handleStickyCapturedSeries(e,o,n,s);else if(this.tooltipUtil.isXoverlap(s)||r.globals.isBarHorizontal){var c=r.globals.series.findIndex((function(e,t){return!r.globals.collapsedSeriesIndices.includes(t)}));this.create(e,this,c,s,n.ttItems)}}},{key:"handleStickyCapturedSeries",value:function(e,t,i,n){var r=this.w;if(this.tConfig.shared||null!==r.globals.series[t][n]){if(void 0!==r.globals.series[t][n])this.tConfig.shared&&this.tooltipUtil.isXoverlap(n)&&this.tooltipUtil.isInitialSeriesSameLen()?this.create(e,this,t,n,i.ttItems):this.create(e,this,t,n,i.ttItems,!1);else if(this.tooltipUtil.isXoverlap(n)){var a=r.globals.series.findIndex((function(e,t){return!r.globals.collapsedSeriesIndices.includes(t)}));this.create(e,this,a,n,i.ttItems)}}else this.handleMouseOut(i)}},{key:"deactivateHoverFilter",value:function(){for(var e=this.w,t=new b(this.ctx),i=e.globals.dom.Paper.select(".apexcharts-bar-area"),n=0;n<i.length;n++)t.pathMouseLeave(i[n])}},{key:"handleMouseOut",value:function(e){var t=this.w,i=this.getElXCrosshairs();if(e.tooltipEl.classList.remove("apexcharts-active"),this.deactivateHoverFilter(),"bubble"!==t.config.chart.type&&this.marker.resetPointsSize(),null!==i&&i.classList.remove("apexcharts-active"),null!==this.ycrosshairs&&this.ycrosshairs.classList.remove("apexcharts-active"),this.isXAxisTooltipEnabled&&this.xaxisTooltip.classList.remove("apexcharts-active"),this.yaxisTooltips.length){null===this.yaxisTTEls&&(this.yaxisTTEls=t.globals.dom.baseEl.querySelectorAll(".apexcharts-yaxistooltip"));for(var n=0;n<this.yaxisTTEls.length;n++)this.yaxisTTEls[n].classList.remove("apexcharts-active")}t.config.legend.tooltipHoverFormatter&&this.legendLabels.forEach((function(e){var t=e.getAttribute("data:default-text");e.innerHTML=decodeURIComponent(t)}))}},{key:"markerClick",value:function(e,t,i){var n=this.w;"function"==typeof n.config.chart.events.markerClick&&n.config.chart.events.markerClick(e,this.ctx,{seriesIndex:t,dataPointIndex:i,w:n}),this.ctx.events.fireEvent("markerClick",[e,this.ctx,{seriesIndex:t,dataPointIndex:i,w:n}])}},{key:"create",value:function(e,i,n,r,a){var s,o,l,c,u,d,h,f,p,m,g,v,y,x,_,w,k=arguments.length>5&&void 0!==arguments[5]?arguments[5]:null,M=this.w,S=i;"mouseup"===e.type&&this.markerClick(e,n,r),null===k&&(k=this.tConfig.shared);var A=this.tooltipUtil.hasMarkers(n),L=this.tooltipUtil.getElBars();if(M.config.legend.tooltipHoverFormatter){var T=M.config.legend.tooltipHoverFormatter,C=Array.from(this.legendLabels);C.forEach((function(e){var t=e.getAttribute("data:default-text");e.innerHTML=decodeURIComponent(t)}));for(var D=0;D<C.length;D++){var E=C[D],O=parseInt(E.getAttribute("i"),10),P=decodeURIComponent(E.getAttribute("data:default-text")),Y=T(P,{seriesIndex:k?O:n,dataPointIndex:r,w:M});if(k)E.innerHTML=M.globals.collapsedSeriesIndices.indexOf(O)<0?Y:P;else if(E.innerHTML=O===n?Y:P,n===O)break}}var I=t(t({ttItems:a,i:n,j:r},void 0!==(null===(s=M.globals.seriesRange)||void 0===s||null===(o=s[n])||void 0===o||null===(l=o[r])||void 0===l||null===(c=l.y[0])||void 0===c?void 0:c.y1)&&{y1:null===(u=M.globals.seriesRange)||void 0===u||null===(d=u[n])||void 0===d||null===(h=d[r])||void 0===h||null===(f=h.y[0])||void 0===f?void 0:f.y1}),void 0!==(null===(p=M.globals.seriesRange)||void 0===p||null===(m=p[n])||void 0===m||null===(g=m[r])||void 0===g||null===(v=g.y[0])||void 0===v?void 0:v.y2)&&{y2:null===(y=M.globals.seriesRange)||void 0===y||null===(x=y[n])||void 0===x||null===(_=x[r])||void 0===_||null===(w=_.y[0])||void 0===w?void 0:w.y2});if(k){if(S.tooltipLabels.drawSeriesTexts(t(t({},I),{},{shared:!this.showOnIntersect&&this.tConfig.shared})),A)M.globals.markers.largestSize>0?S.marker.enlargePoints(r):S.tooltipPosition.moveDynamicPointsOnHover(r);else if(this.tooltipUtil.hasBars()&&(this.barSeriesHeight=this.tooltipUtil.getBarsHeight(L),this.barSeriesHeight>0)){var N=new b(this.ctx),j=M.globals.dom.Paper.select(".apexcharts-bar-area[j='".concat(r,"']"));this.deactivateHoverFilter(),this.tooltipPosition.moveStickyTooltipOverBars(r,n);for(var H=0;H<j.length;H++)N.pathMouseEnter(j[H])}}else S.tooltipLabels.drawSeriesTexts(t({shared:!1},I)),this.tooltipUtil.hasBars()&&S.tooltipPosition.moveStickyTooltipOverBars(r,n),A&&S.tooltipPosition.moveMarkers(n,r)}}]),e}(),ye=function(){function e(t){n(this,e),this.w=t.w,this.barCtx=t,this.totalFormatter=this.w.config.plotOptions.bar.dataLabels.total.formatter,this.totalFormatter||(this.totalFormatter=this.w.config.dataLabels.formatter)}return a(e,[{key:"handleBarDataLabels",value:function(e){var t,i,n=e.x,r=e.y,a=e.y1,s=e.y2,o=e.i,l=e.j,c=e.realIndex,u=e.columnGroupIndex,d=e.series,h=e.barHeight,f=e.barWidth,p=e.barXPosition,m=e.barYPosition,g=e.visibleSeries,v=e.renderedPath,y=this.w,x=new b(this.barCtx.ctx),_=Array.isArray(this.barCtx.strokeWidth)?this.barCtx.strokeWidth[c]:this.barCtx.strokeWidth;y.globals.isXNumeric&&!y.globals.isBarHorizontal?(t=n+parseFloat(f*(g+1)),i=r+parseFloat(h*(g+1))-_):(t=n+parseFloat(f*g),i=r+parseFloat(h*g));var w,k,M=null,S=n,A=r,L=y.config.dataLabels,T=this.barCtx.barOptions.dataLabels,C=this.barCtx.barOptions.dataLabels.total;void 0!==m&&this.barCtx.isRangeBar&&(i=m,A=m),void 0!==p&&this.barCtx.isVerticalGroupedRangeBar&&(t=p,S=p);var D=L.offsetX,E=L.offsetY,O={width:0,height:0};if(y.config.dataLabels.enabled){var P=this.barCtx.series[o][l];O=x.getTextRects(y.globals.yLabelFormatters[0](P),parseFloat(L.style.fontSize))}var Y={x:n,y:r,i:o,j:l,realIndex:c,columnGroupIndex:u,renderedPath:v,bcx:t,bcy:i,barHeight:h,barWidth:f,textRects:O,strokeWidth:_,dataLabelsX:S,dataLabelsY:A,dataLabelsConfig:L,barDataLabelsConfig:T,barTotalDataLabelsConfig:C,offX:D,offY:E};return k=this.barCtx.isHorizontal?this.calculateBarsDataLabelsPosition(Y):this.calculateColumnsDataLabelsPosition(Y),v.attr({cy:k.bcy,cx:k.bcx,j:l,val:d[o][l],barHeight:h,barWidth:f}),w=this.drawCalculatedDataLabels({x:k.dataLabelsX,y:k.dataLabelsY,val:this.barCtx.isRangeBar?[a,s]:d[o][l],i:c,j:l,barWidth:f,barHeight:h,textRects:O,dataLabelsConfig:L}),y.config.chart.stacked&&C.enabled&&(M=this.drawTotalDataLabels({x:k.totalDataLabelsX,y:k.totalDataLabelsY,barWidth:f,barHeight:h,realIndex:c,textAnchor:k.totalDataLabelsAnchor,val:this.getStackedTotalDataLabel({realIndex:c,j:l}),dataLabelsConfig:L,barTotalDataLabelsConfig:C})),{dataLabels:w,totalDataLabels:M}}},{key:"getStackedTotalDataLabel",value:function(e){var i=e.realIndex,n=e.j,r=this.w,a=this.barCtx.stackedSeriesTotals[n];return this.totalFormatter&&(a=this.totalFormatter(a,t(t({},r),{},{seriesIndex:i,dataPointIndex:n,w:r}))),a}},{key:"calculateColumnsDataLabelsPosition",value:function(e){var t,i,n=this.w,r=e.i,a=e.j,s=e.realIndex,o=e.columnGroupIndex,l=e.y,c=e.bcx,u=e.barWidth,d=e.barHeight,h=e.textRects,f=e.dataLabelsX,p=e.dataLabelsY,m=e.dataLabelsConfig,g=e.barDataLabelsConfig,v=e.barTotalDataLabelsConfig,y=e.strokeWidth,x=e.offX,_=e.offY,w=c;d=Math.abs(d);var k="vertical"===n.config.plotOptions.bar.dataLabels.orientation,M=this.barCtx.barHelpers.getZeroValueEncounters({i:r,j:a}).zeroEncounters;c=c-y/2+o*u;var S=n.globals.gridWidth/n.globals.dataPoints;this.barCtx.isVerticalGroupedRangeBar?f+=u/2:(f=n.globals.isXNumeric?c-u/2+x:c-S+u/2+x,M>0&&n.config.plotOptions.bar.hideZeroBarsWhenGrouped&&(f-=u*M)),k&&(f=f+h.height/2-y/2-2);var A=this.barCtx.series[r][a]<0,L=l;switch(this.barCtx.isReversed&&(L=l+(A?d:-d),l-=d),g.position){case"center":p=k?A?L-d/2+_:L+d/2-_:A?L-d/2+h.height/2+_:L+d/2+h.height/2-_;break;case"bottom":p=k?A?L-d+_:L+d-_:A?L-d+h.height+y+_:L+d-h.height/2+y-_;break;case"top":p=k?A?L+_:L-_:A?L-h.height/2-_:L+h.height+_}if(this.barCtx.lastActiveBarSerieIndex===s&&v.enabled){var T=new b(this.barCtx.ctx).getTextRects(this.getStackedTotalDataLabel({realIndex:s,j:a}),m.fontSize);t=A?L-T.height/2-_-v.offsetY+18:L+T.height+_+v.offsetY-18,i=w+(n.globals.isXNumeric?u*(n.globals.barGroups.length-1)-u/2:-(u*n.globals.barGroups.length-u/2-2*y))+v.offsetX}return n.config.chart.stacked||(p<0?p=0+y:p+h.height/3>n.globals.gridHeight&&(p=n.globals.gridHeight-y)),{bcx:c,bcy:l,dataLabelsX:f,dataLabelsY:p,totalDataLabelsX:i,totalDataLabelsY:t,totalDataLabelsAnchor:"middle"}}},{key:"calculateBarsDataLabelsPosition",value:function(e){var t=this.w,i=e.x,n=e.i,r=e.j,a=e.realIndex,s=e.columnGroupIndex,o=e.bcy,l=e.barHeight,c=e.barWidth,u=e.textRects,d=e.dataLabelsX,h=e.strokeWidth,f=e.dataLabelsConfig,p=e.barDataLabelsConfig,m=e.barTotalDataLabelsConfig,g=e.offX,v=e.offY,y=t.globals.gridHeight/t.globals.dataPoints;c=Math.abs(c);var x,_,w=(o+=s*l)-(this.barCtx.isRangeBar?0:y)+l/2+u.height/2+v-3,k="start",M=this.barCtx.series[n][r]<0,S=i;switch(this.barCtx.isReversed&&(S=i+(M?-c:c),i=t.globals.gridWidth-c,k=M?"start":"end"),p.position){case"center":d=M?S+c/2-g:Math.max(u.width/2,S-c/2)+g;break;case"bottom":d=M?S+c-h-Math.round(u.width/2)-g:S-c+h+Math.round(u.width/2)+g;break;case"top":d=M?S-h+Math.round(u.width/2)-g:S-h-Math.round(u.width/2)+g}if(this.barCtx.lastActiveBarSerieIndex===a&&m.enabled){var A=new b(this.barCtx.ctx).getTextRects(this.getStackedTotalDataLabel({realIndex:a,j:r}),f.fontSize);M?(x=S-h-g-m.offsetX,k="end"):x=S+g+m.offsetX+(this.barCtx.isReversed?-(c+h):h),_=w-u.height/2+A.height/2+m.offsetY+h}return t.config.chart.stacked||(d<0?d=d+u.width+h:d+u.width/2>t.globals.gridWidth&&(d=t.globals.gridWidth-u.width-h)),{bcx:i,bcy:o,dataLabelsX:d,dataLabelsY:w,totalDataLabelsX:x,totalDataLabelsY:_,totalDataLabelsAnchor:k}}},{key:"drawCalculatedDataLabels",value:function(e){var i=e.x,n=e.y,r=e.val,a=e.i,s=e.j,o=e.textRects,l=e.barHeight,c=e.barWidth,u=e.dataLabelsConfig,d=this.w,h="rotate(0)";"vertical"===d.config.plotOptions.bar.dataLabels.orientation&&(h="rotate(-90, ".concat(i,", ").concat(n,")"));var f=new R(this.barCtx.ctx),p=new b(this.barCtx.ctx),m=u.formatter,g=null,v=d.globals.collapsedSeriesIndices.indexOf(a)>-1;if(u.enabled&&!v){g=p.group({class:"apexcharts-data-labels",transform:h});var y="";void 0!==r&&(y=m(r,t(t({},d),{},{seriesIndex:a,dataPointIndex:s,w:d}))),!r&&d.config.plotOptions.bar.hideZeroBarsWhenGrouped&&(y="");var x=d.globals.series[a][s]<0,_=d.config.plotOptions.bar.dataLabels.position;"vertical"===d.config.plotOptions.bar.dataLabels.orientation&&("top"===_&&(u.textAnchor=x?"end":"start"),"center"===_&&(u.textAnchor="middle"),"bottom"===_&&(u.textAnchor=x?"end":"start")),this.barCtx.isRangeBar&&this.barCtx.barOptions.dataLabels.hideOverflowingLabels&&c<p.getTextRects(y,parseFloat(u.style.fontSize)).width&&(y=""),d.config.chart.stacked&&this.barCtx.barOptions.dataLabels.hideOverflowingLabels&&(this.barCtx.isHorizontal?o.width/1.6>Math.abs(c)&&(y=""):o.height/1.6>Math.abs(l)&&(y=""));var w=t({},u);this.barCtx.isHorizontal&&r<0&&("start"===u.textAnchor?w.textAnchor="end":"end"===u.textAnchor&&(w.textAnchor="start")),f.plotDataLabelsText({x:i,y:n,text:y,i:a,j:s,parent:g,dataLabelsConfig:w,alwaysDrawDataLabel:!0,offsetCorrection:!0})}return g}},{key:"drawTotalDataLabels",value:function(e){var t,i=e.x,n=e.y,r=e.val,a=e.barWidth,s=e.barHeight,o=e.realIndex,l=e.textAnchor,c=e.barTotalDataLabelsConfig,u=this.w,d=new b(this.barCtx.ctx);return c.enabled&&void 0!==i&&void 0!==n&&this.barCtx.lastActiveBarSerieIndex===o&&(t=d.drawText({x:i-(!u.globals.isBarHorizontal&&u.globals.barGroups.length?a*(u.globals.barGroups.length-1)/2:0),y:n-(u.globals.isBarHorizontal&&u.globals.barGroups.length?s*(u.globals.barGroups.length-1)/2:0),foreColor:c.style.color,text:r,textAnchor:l,fontFamily:c.style.fontFamily,fontSize:c.style.fontSize,fontWeight:c.style.fontWeight})),t}}]),e}(),be=function(){function e(t){n(this,e),this.w=t.w,this.barCtx=t}return a(e,[{key:"initVariables",value:function(e){var t=this.w;this.barCtx.series=e,this.barCtx.totalItems=0,this.barCtx.seriesLen=0,this.barCtx.visibleI=-1,this.barCtx.visibleItems=1;for(var i=0;i<e.length;i++)if(e[i].length>0&&(this.barCtx.seriesLen=this.barCtx.seriesLen+1,this.barCtx.totalItems+=e[i].length),t.globals.isXNumeric)for(var n=0;n<e[i].length;n++)t.globals.seriesX[i][n]>t.globals.minX&&t.globals.seriesX[i][n]<t.globals.maxX&&this.barCtx.visibleItems++;else this.barCtx.visibleItems=t.globals.dataPoints;0===this.barCtx.seriesLen&&(this.barCtx.seriesLen=1),this.barCtx.zeroSerieses=[],t.globals.comboCharts||this.checkZeroSeries({series:e})}},{key:"initialPositions",value:function(){var e,t,i,n,r,a,s,o,l=this.w,c=l.globals.dataPoints;this.barCtx.isRangeBar&&(c=l.globals.labels.length);var u=this.barCtx.seriesLen;if(l.config.plotOptions.bar.rangeBarGroupRows&&(u=1),this.barCtx.isHorizontal)r=(i=l.globals.gridHeight/c)/u,l.globals.isXNumeric&&(r=(i=l.globals.gridHeight/this.barCtx.totalItems)/this.barCtx.seriesLen),r=r*parseInt(this.barCtx.barOptions.barHeight,10)/100,-1===String(this.barCtx.barOptions.barHeight).indexOf("%")&&(r=parseInt(this.barCtx.barOptions.barHeight,10)),o=this.barCtx.baseLineInvertedY+l.globals.padHorizontal+(this.barCtx.isReversed?l.globals.gridWidth:0)-(this.barCtx.isReversed?2*this.barCtx.baseLineInvertedY:0),this.barCtx.isFunnel&&(o=l.globals.gridWidth/2),t=(i-r*this.barCtx.seriesLen)/2;else{if(n=l.globals.gridWidth/this.barCtx.visibleItems,l.config.xaxis.convertedCatToNumeric&&(n=l.globals.gridWidth/l.globals.dataPoints),a=n/u*parseInt(this.barCtx.barOptions.columnWidth,10)/100,l.globals.isXNumeric){var d=this.barCtx.xRatio;l.globals.minXDiff&&.5!==l.globals.minXDiff&&l.globals.minXDiff/d>0&&(n=l.globals.minXDiff/d),(a=n/u*parseInt(this.barCtx.barOptions.columnWidth,10)/100)<1&&(a=1)}-1===String(this.barCtx.barOptions.columnWidth).indexOf("%")&&(a=parseInt(this.barCtx.barOptions.columnWidth,10)),s=l.globals.gridHeight-this.barCtx.baseLineY[this.barCtx.translationsIndex]-(this.barCtx.isReversed?l.globals.gridHeight:0)+(this.barCtx.isReversed?2*this.barCtx.baseLineY[this.barCtx.translationsIndex]:0),e=l.globals.padHorizontal+(n-a*this.barCtx.seriesLen)/2}return l.globals.barHeight=r,l.globals.barWidth=a,{x:e,y:t,yDivision:i,xDivision:n,barHeight:r,barWidth:a,zeroH:s,zeroW:o}}},{key:"initializeStackedPrevVars",value:function(e){e.w.globals.seriesGroups.forEach((function(t){e[t]||(e[t]={}),e[t].prevY=[],e[t].prevX=[],e[t].prevYF=[],e[t].prevXF=[],e[t].prevYVal=[],e[t].prevXVal=[]}))}},{key:"initializeStackedXYVars",value:function(e){e.w.globals.seriesGroups.forEach((function(t){e[t]||(e[t]={}),e[t].xArrj=[],e[t].xArrjF=[],e[t].xArrjVal=[],e[t].yArrj=[],e[t].yArrjF=[],e[t].yArrjVal=[]}))}},{key:"getPathFillColor",value:function(e,t,i,n){var r,a,s,o,l=this.w,c=new j(this.barCtx.ctx),u=null,d=this.barCtx.barOptions.distributed?i:t;return this.barCtx.barOptions.colors.ranges.length>0&&this.barCtx.barOptions.colors.ranges.map((function(n){e[t][i]>=n.from&&e[t][i]<=n.to&&(u=n.color)})),l.config.series[t].data[i]&&l.config.series[t].data[i].fillColor&&(u=l.config.series[t].data[i].fillColor),c.fillPath({seriesNumber:this.barCtx.barOptions.distributed?d:n,dataPointIndex:i,color:u,value:e[t][i],fillConfig:null===(r=l.config.series[t].data[i])||void 0===r?void 0:r.fill,fillType:null!==(a=l.config.series[t].data[i])&&void 0!==a&&null!==(s=a.fill)&&void 0!==s&&s.type?null===(o=l.config.series[t].data[i])||void 0===o?void 0:o.fill.type:Array.isArray(l.config.fill.type)?l.config.fill.type[t]:l.config.fill.type})}},{key:"getStrokeWidth",value:function(e,t,i){var n=0,r=this.w;return void 0===this.barCtx.series[e][t]||null===this.barCtx.series[e][t]?this.barCtx.isNullValue=!0:this.barCtx.isNullValue=!1,r.config.stroke.show&&(this.barCtx.isNullValue||(n=Array.isArray(this.barCtx.strokeWidth)?this.barCtx.strokeWidth[i]:this.barCtx.strokeWidth)),n}},{key:"shouldApplyRadius",value:function(e){var t=this.w,i=!1;return t.config.plotOptions.bar.borderRadius>0&&(t.config.chart.stacked&&"last"===t.config.plotOptions.bar.borderRadiusWhenStacked?this.barCtx.lastActiveBarSerieIndex===e&&(i=!0):i=!0),i}},{key:"barBackground",value:function(e){var t=e.j,i=e.i,n=e.x1,r=e.x2,a=e.y1,s=e.y2,o=e.elSeries,l=this.w,c=new b(this.barCtx.ctx),u=new z(this.barCtx.ctx).getActiveConfigSeriesIndex();if(this.barCtx.barOptions.colors.backgroundBarColors.length>0&&u===i){t>=this.barCtx.barOptions.colors.backgroundBarColors.length&&(t%=this.barCtx.barOptions.colors.backgroundBarColors.length);var d=this.barCtx.barOptions.colors.backgroundBarColors[t],h=c.drawRect(void 0!==n?n:0,void 0!==a?a:0,void 0!==r?r:l.globals.gridWidth,void 0!==s?s:l.globals.gridHeight,this.barCtx.barOptions.colors.backgroundBarRadius,d,this.barCtx.barOptions.colors.backgroundBarOpacity);o.add(h),h.node.classList.add("apexcharts-backgroundBar")}}},{key:"getColumnPaths",value:function(e){var t,i=e.barWidth,n=e.barXPosition,r=e.y1,a=e.y2,s=e.strokeWidth,o=e.seriesGroup,l=e.realIndex,c=e.i,u=e.j,d=e.w,h=new b(this.barCtx.ctx);(s=Array.isArray(s)?s[l]:s)||(s=0);var f=i,p=n;null!==(t=d.config.series[l].data[u])&&void 0!==t&&t.columnWidthOffset&&(p=n-d.config.series[l].data[u].columnWidthOffset/2,f=i+d.config.series[l].data[u].columnWidthOffset);var m=s/2,g=p+m,v=p+f-m;r+=.001-m,a+=.001+m;var y=h.move(g,r),x=h.move(g,r),_=h.line(v,r);if(d.globals.previousPaths.length>0&&(x=this.barCtx.getPreviousPath(l,u,!1)),y=y+h.line(g,a)+h.line(v,a)+h.line(v,r)+("around"===d.config.plotOptions.bar.borderRadiusApplication?" Z":" z"),x=x+h.line(g,r)+_+_+_+_+_+h.line(g,r)+("around"===d.config.plotOptions.bar.borderRadiusApplication?" Z":" z"),this.shouldApplyRadius(l)&&(y=h.roundPathCorners(y,d.config.plotOptions.bar.borderRadius)),d.config.chart.stacked){var w=this.barCtx;(w=this.barCtx[o]).yArrj.push(a-m),w.yArrjF.push(Math.abs(r-a+s)),w.yArrjVal.push(this.barCtx.series[c][u])}return{pathTo:y,pathFrom:x}}},{key:"getBarpaths",value:function(e){var t,i=e.barYPosition,n=e.barHeight,r=e.x1,a=e.x2,s=e.strokeWidth,o=e.seriesGroup,l=e.realIndex,c=e.i,u=e.j,d=e.w,h=new b(this.barCtx.ctx);(s=Array.isArray(s)?s[l]:s)||(s=0);var f=i,p=n;null!==(t=d.config.series[l].data[u])&&void 0!==t&&t.barHeightOffset&&(f=i-d.config.series[l].data[u].barHeightOffset/2,p=n+d.config.series[l].data[u].barHeightOffset);var m=s/2,g=f+m,v=f+p-m;r+=.001-m,a+=.001+m;var y=h.move(r,g),x=h.move(r,g);d.globals.previousPaths.length>0&&(x=this.barCtx.getPreviousPath(l,u,!1));var _=h.line(r,v);if(y=y+h.line(a,g)+h.line(a,v)+_+("around"===d.config.plotOptions.bar.borderRadiusApplication?" Z":" z"),x=x+h.line(r,g)+_+_+_+_+_+h.line(r,g)+("around"===d.config.plotOptions.bar.borderRadiusApplication?" Z":" z"),this.shouldApplyRadius(l)&&(y=h.roundPathCorners(y,d.config.plotOptions.bar.borderRadius)),d.config.chart.stacked){var w=this.barCtx;(w=this.barCtx[o]).xArrj.push(a+m),w.xArrjF.push(Math.abs(r-a)),w.xArrjVal.push(this.barCtx.series[c][u])}return{pathTo:y,pathFrom:x}}},{key:"checkZeroSeries",value:function(e){for(var t=e.series,i=this.w,n=0;n<t.length;n++){for(var r=0,a=0;a<t[i.globals.maxValsInArrayIndex].length;a++)r+=t[n][a];0===r&&this.barCtx.zeroSerieses.push(n)}}},{key:"getXForValue",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]&&!arguments[2]?null:t;return null!=e&&(i=t+e/this.barCtx.invertedYRatio-2*(this.barCtx.isReversed?e/this.barCtx.invertedYRatio:0)),i}},{key:"getYForValue",value:function(e,t,i){var n=arguments.length>3&&void 0!==arguments[3]&&!arguments[3]?null:t;return null!=e&&(n=t-e/this.barCtx.yRatio[i]+2*(this.barCtx.isReversed?e/this.barCtx.yRatio[i]:0)),n}},{key:"getGoalValues",value:function(e,i,n,r,a,o){var l=this,c=this.w,u=[],d=function(t,r){var a;u.push((s(a={},e,"x"===e?l.getXForValue(t,i,!1):l.getYForValue(t,n,o,!1)),s(a,"attrs",r),a))};if(c.globals.seriesGoals[r]&&c.globals.seriesGoals[r][a]&&Array.isArray(c.globals.seriesGoals[r][a])&&c.globals.seriesGoals[r][a].forEach((function(e){d(e.value,e)})),this.barCtx.barOptions.isDumbbell&&c.globals.seriesRange.length){var h=this.barCtx.barOptions.dumbbellColors?this.barCtx.barOptions.dumbbellColors:c.globals.colors,f={strokeHeight:"x"===e?0:c.globals.markers.size[r],strokeWidth:"x"===e?c.globals.markers.size[r]:0,strokeDashArray:0,strokeLineCap:"round",strokeColor:Array.isArray(h[r])?h[r][0]:h[r]};d(c.globals.seriesRangeStart[r][a],f),d(c.globals.seriesRangeEnd[r][a],t(t({},f),{},{strokeColor:Array.isArray(h[r])?h[r][1]:h[r]}))}return u}},{key:"drawGoalLine",value:function(e){var t=e.barXPosition,i=e.barYPosition,n=e.goalX,r=e.goalY,a=e.barWidth,s=e.barHeight,o=new b(this.barCtx.ctx),l=o.group({className:"apexcharts-bar-goals-groups"});l.node.classList.add("apexcharts-element-hidden"),this.barCtx.w.globals.delayedElements.push({el:l.node}),l.attr("clip-path","url(#gridRectMarkerMask".concat(this.barCtx.w.globals.cuid,")"));var c=null;return this.barCtx.isHorizontal?Array.isArray(n)&&n.forEach((function(e){if(e.x>=-1&&e.x<=o.w.globals.gridWidth+1){var t=void 0!==e.attrs.strokeHeight?e.attrs.strokeHeight:s/2,n=i+t+s/2;c=o.drawLine(e.x,n-2*t,e.x,n,e.attrs.strokeColor?e.attrs.strokeColor:void 0,e.attrs.strokeDashArray,e.attrs.strokeWidth?e.attrs.strokeWidth:2,e.attrs.strokeLineCap),l.add(c)}})):Array.isArray(r)&&r.forEach((function(e){if(e.y>=-1&&e.y<=o.w.globals.gridHeight+1){var i=void 0!==e.attrs.strokeWidth?e.attrs.strokeWidth:a/2,n=t+i+a/2;c=o.drawLine(n-2*i,e.y,n,e.y,e.attrs.strokeColor?e.attrs.strokeColor:void 0,e.attrs.strokeDashArray,e.attrs.strokeHeight?e.attrs.strokeHeight:2,e.attrs.strokeLineCap),l.add(c)}})),l}},{key:"drawBarShadow",value:function(e){var t=e.prevPaths,i=e.currPaths,n=e.color,r=this.w,a=t.x,s=t.x1,o=t.barYPosition,l=i.x,c=i.x1,u=i.barYPosition,d=o+i.barHeight,h=new b(this.barCtx.ctx),f=new g,p=h.move(s,d)+h.line(a,d)+h.line(l,u)+h.line(c,u)+h.line(s,d)+("around"===r.config.plotOptions.bar.borderRadiusApplication?" Z":" z");return h.drawPath({d:p,fill:f.shadeColor(.5,g.rgb2hex(n)),stroke:"none",strokeWidth:0,fillOpacity:1,classes:"apexcharts-bar-shadows"})}},{key:"getZeroValueEncounters",value:function(e){var t,i=e.i,n=e.j,r=this.w,a=0,s=0;return(r.config.plotOptions.bar.horizontal?r.globals.series.map((function(e,t){return t})):(null===(t=r.globals.columnSeries)||void 0===t?void 0:t.i.map((function(e){return e})))||[]).forEach((function(e){var t=r.globals.seriesPercent[e][n];t&&a++,e<i&&0===t&&s++})),{nonZeroColumns:a,zeroEncounters:s}}},{key:"getGroupIndex",value:function(e){var t=this.w,i=t.globals.seriesGroups.findIndex((function(i){return i.indexOf(t.globals.seriesNames[e])>-1})),n=this.barCtx.columnGroupIndices,r=n.indexOf(i);return r<0&&(n.push(i),r=n.length-1),{groupIndex:i,columnGroupIndex:r}}}]),e}(),xe=function(){function e(t,i){n(this,e),this.ctx=t,this.w=t.w;var r=this.w;this.barOptions=r.config.plotOptions.bar,this.isHorizontal=this.barOptions.horizontal,this.strokeWidth=r.config.stroke.width,this.isNullValue=!1,this.isRangeBar=r.globals.seriesRange.length&&this.isHorizontal,this.isVerticalGroupedRangeBar=!r.globals.isBarHorizontal&&r.globals.seriesRange.length&&r.config.plotOptions.bar.rangeBarGroupRows,this.isFunnel=this.barOptions.isFunnel,this.xyRatios=i,null!==this.xyRatios&&(this.xRatio=i.xRatio,this.yRatio=i.yRatio,this.invertedXRatio=i.invertedXRatio,this.invertedYRatio=i.invertedYRatio,this.baseLineY=i.baseLineY,this.baseLineInvertedY=i.baseLineInvertedY),this.yaxisIndex=0,this.translationsIndex=0,this.seriesLen=0,this.pathArr=[];var a=new z(this.ctx);this.lastActiveBarSerieIndex=a.getActiveConfigSeriesIndex("desc",["bar","column"]),this.columnGroupIndices=[];var s=a.getBarSeriesIndices(),o=new x(this.ctx);this.stackedSeriesTotals=o.getStackedSeriesTotals(this.w.config.series.map((function(e,t){return-1===s.indexOf(t)?t:-1})).filter((function(e){return-1!==e}))),this.barHelpers=new be(this)}return a(e,[{key:"draw",value:function(e,i){var n=this.w,r=new b(this.ctx),a=new x(this.ctx,n);e=a.getLogSeries(e),this.series=e,this.yRatio=a.getLogYRatios(this.yRatio),this.barHelpers.initVariables(e);var s=r.group({class:"apexcharts-bar-series apexcharts-plot-series"});n.config.dataLabels.enabled&&this.totalItems>this.barOptions.dataLabels.maxItems&&console.warn("WARNING: DataLabels are enabled but there are too many to display. This may cause performance issue when rendering - ApexCharts");for(var o=0,l=0;o<e.length;o++,l++){var c,u,d,h,f=void 0,p=void 0,m=[],v=[],y=n.globals.comboCharts?i[o]:o,_=this.barHelpers.getGroupIndex(y).columnGroupIndex,w=r.group({class:"apexcharts-series",rel:o+1,seriesName:g.escapeString(n.globals.seriesNames[y]),"data:realIndex":y});this.ctx.series.addCollapsedClassToSeries(w,y),e[o].length>0&&(this.visibleI=this.visibleI+1);var k=0,M=0;this.yRatio.length>1&&(this.yaxisIndex=n.globals.seriesYAxisReverseMap[y],this.translationsIndex=y);var S=this.translationsIndex;this.isReversed=n.config.yaxis[this.yaxisIndex]&&n.config.yaxis[this.yaxisIndex].reversed;var A=this.barHelpers.initialPositions();p=A.y,k=A.barHeight,u=A.yDivision,h=A.zeroW,f=A.x,M=A.barWidth,c=A.xDivision,d=A.zeroH,this.horizontal||v.push(f+M/2);var L=r.group({class:"apexcharts-datalabels","data:realIndex":y});n.globals.delayedElements.push({el:L.node}),L.node.classList.add("apexcharts-element-hidden");var T=r.group({class:"apexcharts-bar-goals-markers"}),C=r.group({class:"apexcharts-bar-shadows"});n.globals.delayedElements.push({el:C.node}),C.node.classList.add("apexcharts-element-hidden");for(var D=0;D<e[o].length;D++){var E=this.barHelpers.getStrokeWidth(o,D,y),O=null,P={indexes:{i:o,j:D,realIndex:y,translationsIndex:S,bc:l},x:f,y:p,strokeWidth:E,elSeries:w};this.isHorizontal?(O=this.drawBarPaths(t(t({},P),{},{barHeight:k,zeroW:h,yDivision:u})),M=this.series[o][D]/this.invertedYRatio):(O=this.drawColumnPaths(t(t({},P),{},{xDivision:c,barWidth:M,zeroH:d})),k=this.series[o][D]/this.yRatio[S]);var Y=this.barHelpers.getPathFillColor(e,o,D,y);if(this.isFunnel&&this.barOptions.isFunnel3d&&this.pathArr.length&&D>0){var I=this.barHelpers.drawBarShadow({color:"string"==typeof Y&&-1===(null==Y?void 0:Y.indexOf("url"))?Y:g.hexToRgba(n.globals.colors[o]),prevPaths:this.pathArr[this.pathArr.length-1],currPaths:O});I&&C.add(I)}this.pathArr.push(O);var N=this.barHelpers.drawGoalLine({barXPosition:O.barXPosition,barYPosition:O.barYPosition,goalX:O.goalX,goalY:O.goalY,barHeight:k,barWidth:M});N&&T.add(N),p=O.y,f=O.x,D>0&&v.push(f+M/2),m.push(p),this.renderSeries({realIndex:y,pathFill:Y,j:D,i:o,columnGroupIndex:_,pathFrom:O.pathFrom,pathTo:O.pathTo,strokeWidth:E,elSeries:w,x:f,y:p,series:e,barHeight:O.barHeight?O.barHeight:k,barWidth:O.barWidth?O.barWidth:M,elDataLabelsWrap:L,elGoalsMarkers:T,elBarShadows:C,visibleSeries:this.visibleI,type:"bar"})}n.globals.seriesXvalues[y]=v,n.globals.seriesYvalues[y]=m,s.add(w)}return s}},{key:"renderSeries",value:function(e){var t=e.realIndex,i=e.pathFill,n=e.lineFill,r=e.j,a=e.i,s=e.columnGroupIndex,o=e.pathFrom,l=e.pathTo,c=e.strokeWidth,u=e.elSeries,d=e.x,h=e.y,f=e.y1,p=e.y2,m=e.series,g=e.barHeight,v=e.barWidth,x=e.barXPosition,_=e.barYPosition,w=e.elDataLabelsWrap,k=e.elGoalsMarkers,M=e.elBarShadows,S=e.visibleSeries,A=e.type,L=this.w,T=new b(this.ctx);if(!n){var C="function"==typeof L.globals.stroke.colors[t]?function(e){var t,i=L.config.stroke.colors;return Array.isArray(i)&&i.length>0&&((t=i[e])||(t=""),"function"==typeof t)?t({value:L.globals.series[e][r],dataPointIndex:r,w:L}):t}(t):L.globals.stroke.colors[t];n=this.barOptions.distributed?L.globals.stroke.colors[r]:C}L.config.series[a].data[r]&&L.config.series[a].data[r].strokeColor&&(n=L.config.series[a].data[r].strokeColor),this.isNullValue&&(i="none");var D=r/L.config.chart.animations.animateGradually.delay*(L.config.chart.animations.speed/L.globals.dataPoints)/2.4,E=T.renderPaths({i:a,j:r,realIndex:t,pathFrom:o,pathTo:l,stroke:n,strokeWidth:c,strokeLineCap:L.config.stroke.lineCap,fill:i,animationDelay:D,initialSpeed:L.config.chart.animations.speed,dataChangeSpeed:L.config.chart.animations.dynamicAnimation.speed,className:"apexcharts-".concat(A,"-area")});E.attr("clip-path","url(#gridRectMask".concat(L.globals.cuid,")"));var O=L.config.forecastDataPoints;O.count>0&&r>=L.globals.dataPoints-O.count&&(E.node.setAttribute("stroke-dasharray",O.dashArray),E.node.setAttribute("stroke-width",O.strokeWidth),E.node.setAttribute("fill-opacity",O.fillOpacity)),void 0!==f&&void 0!==p&&(E.attr("data-range-y1",f),E.attr("data-range-y2",p)),new y(this.ctx).setSelectionFilter(E,t,r),u.add(E);var P=new ye(this).handleBarDataLabels({x:d,y:h,y1:f,y2:p,i:a,j:r,series:m,realIndex:t,columnGroupIndex:s,barHeight:g,barWidth:v,barXPosition:x,barYPosition:_,renderedPath:E,visibleSeries:S});return null!==P.dataLabels&&w.add(P.dataLabels),P.totalDataLabels&&w.add(P.totalDataLabels),u.add(w),k&&u.add(k),M&&u.add(M),u}},{key:"drawBarPaths",value:function(e){var t,i=e.indexes,n=e.barHeight,r=e.strokeWidth,a=e.zeroW,s=e.x,o=e.y,l=e.yDivision,c=e.elSeries,u=this.w,d=i.i,h=i.j;if(u.globals.isXNumeric)t=(o=(u.globals.seriesX[d][h]-u.globals.minX)/this.invertedXRatio-n)+n*this.visibleI;else if(u.config.plotOptions.bar.hideZeroBarsWhenGrouped){var f=0,p=0;u.globals.seriesPercent.forEach((function(e,t){e[h]&&f++,t<d&&0===e[h]&&p++})),f>0&&(n=this.seriesLen*n/f),t=o+n*this.visibleI,t-=n*p}else t=o+n*this.visibleI;this.isFunnel&&(a-=(this.barHelpers.getXForValue(this.series[d][h],a)-a)/2),s=this.barHelpers.getXForValue(this.series[d][h],a);var m=this.barHelpers.getBarpaths({barYPosition:t,barHeight:n,x1:a,x2:s,strokeWidth:r,series:this.series,realIndex:i.realIndex,i:d,j:h,w:u});return u.globals.isXNumeric||(o+=l),this.barHelpers.barBackground({j:h,i:d,y1:t-n*this.visibleI,y2:n*this.seriesLen,elSeries:c}),{pathTo:m.pathTo,pathFrom:m.pathFrom,x1:a,x:s,y:o,goalX:this.barHelpers.getGoalValues("x",a,null,d,h),barYPosition:t,barHeight:n}}},{key:"drawColumnPaths",value:function(e){var t,i=e.indexes,n=e.x,r=e.y,a=e.xDivision,s=e.barWidth,o=e.zeroH,l=e.strokeWidth,c=e.elSeries,u=this.w,d=i.realIndex,h=i.translationsIndex,f=i.i,p=i.j,m=i.bc;if(u.globals.isXNumeric){var g=this.getBarXForNumericXAxis({x:n,j:p,realIndex:d,barWidth:s});n=g.x,t=g.barXPosition}else if(u.config.plotOptions.bar.hideZeroBarsWhenGrouped){var v=this.barHelpers.getZeroValueEncounters({i:f,j:p}),y=v.nonZeroColumns,b=v.zeroEncounters;y>0&&(s=this.seriesLen*s/y),t=n+s*this.visibleI,t-=s*b}else t=n+s*this.visibleI;r=this.barHelpers.getYForValue(this.series[f][p],o,h);var x=this.barHelpers.getColumnPaths({barXPosition:t,barWidth:s,y1:o,y2:r,strokeWidth:l,series:this.series,realIndex:d,i:f,j:p,w:u});return u.globals.isXNumeric||(n+=a),this.barHelpers.barBackground({bc:m,j:p,i:f,x1:t-l/2-s*this.visibleI,x2:s*this.seriesLen+l/2,elSeries:c}),{pathTo:x.pathTo,pathFrom:x.pathFrom,x:n,y:r,goalY:this.barHelpers.getGoalValues("y",null,o,f,p,h),barXPosition:t,barWidth:s}}},{key:"getBarXForNumericXAxis",value:function(e){var t=e.x,i=e.barWidth,n=e.realIndex,r=e.j,a=this.w,s=n;return a.globals.seriesX[n].length||(s=a.globals.maxValsInArrayIndex),a.globals.seriesX[s][r]&&(t=(a.globals.seriesX[s][r]-a.globals.minX)/this.xRatio-i*this.seriesLen/2),{barXPosition:t+i*this.visibleI,x:t}}},{key:"getPreviousPath",value:function(e,t){for(var i,n=this.w,r=0;r<n.globals.previousPaths.length;r++){var a=n.globals.previousPaths[r];a.paths&&a.paths.length>0&&parseInt(a.realIndex,10)===parseInt(e,10)&&void 0!==n.globals.previousPaths[r].paths[t]&&(i=n.globals.previousPaths[r].paths[t].d)}return i}}]),e}(),_e=function(e){o(r,e);var i=d(r);function r(){return n(this,r),i.apply(this,arguments)}return a(r,[{key:"draw",value:function(e,i){var n=this,r=this.w;this.graphics=new b(this.ctx),this.bar=new xe(this.ctx,this.xyRatios);var a=new x(this.ctx,r);e=a.getLogSeries(e),this.yRatio=a.getLogYRatios(this.yRatio),this.barHelpers.initVariables(e),"100%"===r.config.chart.stackType&&(e=r.globals.comboCharts?i.map((function(e){return r.globals.seriesPercent[e]})):r.globals.seriesPercent.slice()),this.series=e,this.barHelpers.initializeStackedPrevVars(this);for(var s=this.graphics.group({class:"apexcharts-bar-series apexcharts-plot-series"}),o=0,l=0,c=function(a,c){var u=void 0,d=void 0,h=void 0,f=void 0,p=r.globals.comboCharts?i[a]:a,m=n.barHelpers.getGroupIndex(p),v=m.groupIndex,y=m.columnGroupIndex;n.groupCtx=n[r.globals.seriesGroups[v]];var b=[],x=[],_=0;n.yRatio.length>1&&(n.yaxisIndex=r.globals.seriesYAxisReverseMap[p][0],_=p),n.isReversed=r.config.yaxis[n.yaxisIndex]&&r.config.yaxis[n.yaxisIndex].reversed;var w=n.graphics.group({class:"apexcharts-series",seriesName:g.escapeString(r.globals.seriesNames[p]),rel:a+1,"data:realIndex":p});n.ctx.series.addCollapsedClassToSeries(w,p);var k=n.graphics.group({class:"apexcharts-datalabels","data:realIndex":p}),M=n.graphics.group({class:"apexcharts-bar-goals-markers"}),S=0,A=0,L=n.initialPositions(o,l,u,d,h,f,_);l=L.y,S=L.barHeight,d=L.yDivision,f=L.zeroW,o=L.x,A=L.barWidth,u=L.xDivision,h=L.zeroH,r.globals.barHeight=S,r.globals.barWidth=A,n.barHelpers.initializeStackedXYVars(n),1===n.groupCtx.prevY.length&&n.groupCtx.prevY[0].every((function(e){return isNaN(e)}))&&(n.groupCtx.prevY[0]=n.groupCtx.prevY[0].map((function(){return h})),n.groupCtx.prevYF[0]=n.groupCtx.prevYF[0].map((function(){return 0})));for(var T=0;T<r.globals.dataPoints;T++){var C=n.barHelpers.getStrokeWidth(a,T,p),D={indexes:{i:a,j:T,realIndex:p,translationsIndex:_,bc:c},strokeWidth:C,x:o,y:l,elSeries:w,columnGroupIndex:y,seriesGroup:r.globals.seriesGroups[v]},E=null;n.isHorizontal?(E=n.drawStackedBarPaths(t(t({},D),{},{zeroW:f,barHeight:S,yDivision:d})),A=n.series[a][T]/n.invertedYRatio):(E=n.drawStackedColumnPaths(t(t({},D),{},{xDivision:u,barWidth:A,zeroH:h})),S=n.series[a][T]/n.yRatio[_]);var O=n.barHelpers.drawGoalLine({barXPosition:E.barXPosition,barYPosition:E.barYPosition,goalX:E.goalX,goalY:E.goalY,barHeight:S,barWidth:A});O&&M.add(O),l=E.y,o=E.x,b.push(o),x.push(l);var P=n.barHelpers.getPathFillColor(e,a,T,p);w=n.renderSeries({realIndex:p,pathFill:P,j:T,i:a,columnGroupIndex:y,pathFrom:E.pathFrom,pathTo:E.pathTo,strokeWidth:C,elSeries:w,x:o,y:l,series:e,barHeight:S,barWidth:A,elDataLabelsWrap:k,elGoalsMarkers:M,type:"bar",visibleSeries:0})}r.globals.seriesXvalues[p]=b,r.globals.seriesYvalues[p]=x,n.groupCtx.prevY.push(n.groupCtx.yArrj),n.groupCtx.prevYF.push(n.groupCtx.yArrjF),n.groupCtx.prevYVal.push(n.groupCtx.yArrjVal),n.groupCtx.prevX.push(n.groupCtx.xArrj),n.groupCtx.prevXF.push(n.groupCtx.xArrjF),n.groupCtx.prevXVal.push(n.groupCtx.xArrjVal),s.add(w)},u=0,d=0;u<e.length;u++,d++)c(u,d);return s}},{key:"initialPositions",value:function(e,t,i,n,r,a,s){var o,l,c=this.w;if(this.isHorizontal){n=c.globals.gridHeight/c.globals.dataPoints;var u=c.config.plotOptions.bar.barHeight;o=-1===String(u).indexOf("%")?parseInt(u,10):n*parseInt(u,10)/100,a=c.globals.padHorizontal+(this.isReversed?c.globals.gridWidth-this.baseLineInvertedY:this.baseLineInvertedY),t=(n-o)/2}else{l=i=c.globals.gridWidth/c.globals.dataPoints;var d=c.config.plotOptions.bar.columnWidth;c.globals.isXNumeric&&c.globals.dataPoints>1?l=(i=c.globals.minXDiff/this.xRatio)*parseInt(this.barOptions.columnWidth,10)/100:-1===String(d).indexOf("%")?l=parseInt(d,10):l*=parseInt(d,10)/100,r=c.globals.gridHeight-this.baseLineY[s]-(this.isReversed?c.globals.gridHeight:0),e=c.globals.padHorizontal+(i-l)/2}var h=c.globals.barGroups.length||1;return{x:e,y:t,yDivision:n,xDivision:i,barHeight:o/h,barWidth:l/h,zeroH:r,zeroW:a}}},{key:"drawStackedBarPaths",value:function(e){for(var t,i=e.indexes,n=e.barHeight,r=e.strokeWidth,a=e.zeroW,s=e.x,o=e.y,l=e.columnGroupIndex,c=e.seriesGroup,u=e.yDivision,d=e.elSeries,h=this.w,f=o+l*n,p=i.i,m=i.j,g=i.realIndex,v=i.translationsIndex,y=0,b=0;b<this.groupCtx.prevXF.length;b++)y+=this.groupCtx.prevXF[b][m];var x;if((x=c.indexOf(h.config.series[g].name))>0){var _=a;this.groupCtx.prevXVal[x-1][m]<0?_=this.series[p][m]>=0?this.groupCtx.prevX[x-1][m]+y-2*(this.isReversed?y:0):this.groupCtx.prevX[x-1][m]:this.groupCtx.prevXVal[x-1][m]>=0&&(_=this.series[p][m]>=0?this.groupCtx.prevX[x-1][m]:this.groupCtx.prevX[x-1][m]-y+2*(this.isReversed?y:0)),t=_}else t=a;s=null===this.series[p][m]?t:t+this.series[p][m]/this.invertedYRatio-2*(this.isReversed?this.series[p][m]/this.invertedYRatio:0);var w=this.barHelpers.getBarpaths({barYPosition:f,barHeight:n,x1:t,x2:s,strokeWidth:r,series:this.series,realIndex:i.realIndex,seriesGroup:c,i:p,j:m,w:h});return this.barHelpers.barBackground({j:m,i:p,y1:f,y2:n,elSeries:d}),o+=u,{pathTo:w.pathTo,pathFrom:w.pathFrom,goalX:this.barHelpers.getGoalValues("x",a,null,p,m,v),barXPosition:t,barYPosition:f,x:s,y:o}}},{key:"drawStackedColumnPaths",value:function(e){var t=e.indexes,i=e.x,n=e.y,r=e.xDivision,a=e.barWidth,s=e.zeroH,o=e.columnGroupIndex,l=e.seriesGroup,c=e.elSeries,u=this.w,d=t.i,h=t.j,f=t.bc,p=t.realIndex,m=t.translationsIndex;if(u.globals.isXNumeric){var g=u.globals.seriesX[p][h];g||(g=0),i=(g-u.globals.minX)/this.xRatio-a/2*u.globals.barGroups.length}for(var v,y=i+o*a,b=0,x=0;x<this.groupCtx.prevYF.length;x++)b+=isNaN(this.groupCtx.prevYF[x][h])?0:this.groupCtx.prevYF[x][h];var _=d;if(l&&(_=l.indexOf(u.globals.seriesNames[p])),_>0&&!u.globals.isXNumeric||_>0&&u.globals.isXNumeric&&u.globals.seriesX[p-1][h]===u.globals.seriesX[p][h]){var w,k,M,S=Math.min(this.yRatio.length+1,p+1);if(void 0!==this.groupCtx.prevY[_-1]&&this.groupCtx.prevY[_-1].length)for(var A=1;A<S;A++){var L;if(!isNaN(null===(L=this.groupCtx.prevY[_-A])||void 0===L?void 0:L[h])){M=this.groupCtx.prevY[_-A][h];break}}for(var T=1;T<S;T++){var C,D;if((null===(C=this.groupCtx.prevYVal[_-T])||void 0===C?void 0:C[h])<0){k=this.series[d][h]>=0?M-b+2*(this.isReversed?b:0):M;break}if((null===(D=this.groupCtx.prevYVal[_-T])||void 0===D?void 0:D[h])>=0){k=this.series[d][h]>=0?M:M+b-2*(this.isReversed?b:0);break}}void 0===k&&(k=u.globals.gridHeight),v=null!==(w=this.groupCtx.prevYF[0])&&void 0!==w&&w.every((function(e){return 0===e}))&&this.groupCtx.prevYF.slice(1,_).every((function(e){return e.every((function(e){return isNaN(e)}))}))?s:k}else v=s;n=this.series[d][h]?v-this.series[d][h]/this.yRatio[m]+2*(this.isReversed?this.series[d][h]/this.yRatio[m]:0):v;var E=this.barHelpers.getColumnPaths({barXPosition:y,barWidth:a,y1:v,y2:n,yRatio:this.yRatio[m],strokeWidth:this.strokeWidth,series:this.series,seriesGroup:l,realIndex:t.realIndex,i:d,j:h,w:u});return this.barHelpers.barBackground({bc:f,j:h,i:d,x1:y,x2:a,elSeries:c}),i+=r,{pathTo:E.pathTo,pathFrom:E.pathFrom,goalY:this.barHelpers.getGoalValues("y",null,s,d,h),barXPosition:y,x:u.globals.isXNumeric?i-r:i,y:n}}}]),r}(xe),we=function(e){o(r,e);var i=d(r);function r(){return n(this,r),i.apply(this,arguments)}return a(r,[{key:"draw",value:function(e,i,n){var r=this,a=this.w,s=new b(this.ctx),o=a.globals.comboCharts?i:a.config.chart.type,l=new j(this.ctx);this.candlestickOptions=this.w.config.plotOptions.candlestick,this.boxOptions=this.w.config.plotOptions.boxPlot,this.isHorizontal=a.config.plotOptions.bar.horizontal;var c=new x(this.ctx,a);e=c.getLogSeries(e),this.series=e,this.yRatio=c.getLogYRatios(this.yRatio),this.barHelpers.initVariables(e);for(var u=s.group({class:"apexcharts-".concat(o,"-series apexcharts-plot-series")}),d=function(i){r.isBoxPlot="boxPlot"===a.config.chart.type||"boxPlot"===a.config.series[i].type;var o,c,d,h,f=void 0,p=void 0,m=[],v=[],y=a.globals.comboCharts?n[i]:i,b=r.barHelpers.getGroupIndex(y).columnGroupIndex,x=s.group({class:"apexcharts-series",seriesName:g.escapeString(a.globals.seriesNames[y]),rel:i+1,"data:realIndex":y});r.ctx.series.addCollapsedClassToSeries(x,y),e[i].length>0&&(r.visibleI=r.visibleI+1);var _,w,k=0;r.yRatio.length>1&&(r.yaxisIndex=a.globals.seriesYAxisReverseMap[y][0],k=y);var M=r.barHelpers.initialPositions();p=M.y,_=M.barHeight,c=M.yDivision,h=M.zeroW,f=M.x,w=M.barWidth,o=M.xDivision,d=M.zeroH,v.push(f+w/2);for(var S=s.group({class:"apexcharts-datalabels","data:realIndex":y}),A=function(n){var s=r.barHelpers.getStrokeWidth(i,n,y),u=null,g={indexes:{i:i,j:n,realIndex:y,translationsIndex:k},x:f,y:p,strokeWidth:s,elSeries:x};u=r.isHorizontal?r.drawHorizontalBoxPaths(t(t({},g),{},{yDivision:c,barHeight:_,zeroW:h})):r.drawVerticalBoxPaths(t(t({},g),{},{xDivision:o,barWidth:w,zeroH:d})),p=u.y,f=u.x,n>0&&v.push(f+w/2),m.push(p),u.pathTo.forEach((function(t,o){var c=!r.isBoxPlot&&r.candlestickOptions.wick.useFillColor?u.color[o]:a.globals.stroke.colors[i],d=l.fillPath({seriesNumber:y,dataPointIndex:n,color:u.color[o],value:e[i][n]});r.renderSeries({realIndex:y,pathFill:d,lineFill:c,j:n,i:i,pathFrom:u.pathFrom,pathTo:t,strokeWidth:s,elSeries:x,x:f,y:p,series:e,columnGroupIndex:b,barHeight:_,barWidth:w,elDataLabelsWrap:S,visibleSeries:r.visibleI,type:a.config.chart.type})}))},L=0;L<a.globals.dataPoints;L++)A(L);a.globals.seriesXvalues[y]=v,a.globals.seriesYvalues[y]=m,u.add(x)},h=0;h<e.length;h++)d(h);return u}},{key:"drawVerticalBoxPaths",value:function(e){var t=e.indexes,i=e.x;e.y;var n=e.xDivision,r=e.barWidth,a=e.zeroH,s=e.strokeWidth,o=this.w,l=new b(this.ctx),c=t.i,u=t.j,d=!0,h=o.config.plotOptions.candlestick.colors.upward,f=o.config.plotOptions.candlestick.colors.downward,p="";this.isBoxPlot&&(p=[this.boxOptions.colors.lower,this.boxOptions.colors.upper]);var m=this.yRatio[t.translationsIndex],g=t.realIndex,v=this.getOHLCValue(g,u),y=a,x=a;v.o>v.c&&(d=!1);var _=Math.min(v.o,v.c),w=Math.max(v.o,v.c),k=v.m;o.globals.isXNumeric&&(i=(o.globals.seriesX[g][u]-o.globals.minX)/this.xRatio-r/2);var M=i+r*this.visibleI;void 0===this.series[c][u]||null===this.series[c][u]?(_=a,w=a):(_=a-_/m,w=a-w/m,y=a-v.h/m,x=a-v.l/m,k=a-v.m/m);var S=l.move(M,a),A=l.move(M+r/2,_);return o.globals.previousPaths.length>0&&(A=this.getPreviousPath(g,u,!0)),S=this.isBoxPlot?[l.move(M,_)+l.line(M+r/2,_)+l.line(M+r/2,y)+l.line(M+r/4,y)+l.line(M+r-r/4,y)+l.line(M+r/2,y)+l.line(M+r/2,_)+l.line(M+r,_)+l.line(M+r,k)+l.line(M,k)+l.line(M,_+s/2),l.move(M,k)+l.line(M+r,k)+l.line(M+r,w)+l.line(M+r/2,w)+l.line(M+r/2,x)+l.line(M+r-r/4,x)+l.line(M+r/4,x)+l.line(M+r/2,x)+l.line(M+r/2,w)+l.line(M,w)+l.line(M,k)+"z"]:[l.move(M,w)+l.line(M+r/2,w)+l.line(M+r/2,y)+l.line(M+r/2,w)+l.line(M+r,w)+l.line(M+r,_)+l.line(M+r/2,_)+l.line(M+r/2,x)+l.line(M+r/2,_)+l.line(M,_)+l.line(M,w-s/2)],A+=l.move(M,_),o.globals.isXNumeric||(i+=n),{pathTo:S,pathFrom:A,x:i,y:w,barXPosition:M,color:this.isBoxPlot?p:d?[h]:[f]}}},{key:"drawHorizontalBoxPaths",value:function(e){var t=e.indexes;e.x;var i=e.y,n=e.yDivision,r=e.barHeight,a=e.zeroW,s=e.strokeWidth,o=this.w,l=new b(this.ctx),c=t.i,u=t.j,d=this.boxOptions.colors.lower;this.isBoxPlot&&(d=[this.boxOptions.colors.lower,this.boxOptions.colors.upper]);var h=this.invertedYRatio,f=t.realIndex,p=this.getOHLCValue(f,u),m=a,g=a,v=Math.min(p.o,p.c),y=Math.max(p.o,p.c),x=p.m;o.globals.isXNumeric&&(i=(o.globals.seriesX[f][u]-o.globals.minX)/this.invertedXRatio-r/2);var _=i+r*this.visibleI;void 0===this.series[c][u]||null===this.series[c][u]?(v=a,y=a):(v=a+v/h,y=a+y/h,m=a+p.h/h,g=a+p.l/h,x=a+p.m/h);var w=l.move(a,_),k=l.move(v,_+r/2);return o.globals.previousPaths.length>0&&(k=this.getPreviousPath(f,u,!0)),w=[l.move(v,_)+l.line(v,_+r/2)+l.line(m,_+r/2)+l.line(m,_+r/2-r/4)+l.line(m,_+r/2+r/4)+l.line(m,_+r/2)+l.line(v,_+r/2)+l.line(v,_+r)+l.line(x,_+r)+l.line(x,_)+l.line(v+s/2,_),l.move(x,_)+l.line(x,_+r)+l.line(y,_+r)+l.line(y,_+r/2)+l.line(g,_+r/2)+l.line(g,_+r-r/4)+l.line(g,_+r/4)+l.line(g,_+r/2)+l.line(y,_+r/2)+l.line(y,_)+l.line(x,_)+"z"],k+=l.move(v,_),o.globals.isXNumeric||(i+=n),{pathTo:w,pathFrom:k,x:y,y:i,barYPosition:_,color:d}}},{key:"getOHLCValue",value:function(e,t){var i=this.w;return{o:this.isBoxPlot?i.globals.seriesCandleH[e][t]:i.globals.seriesCandleO[e][t],h:this.isBoxPlot?i.globals.seriesCandleO[e][t]:i.globals.seriesCandleH[e][t],m:i.globals.seriesCandleM[e][t],l:this.isBoxPlot?i.globals.seriesCandleC[e][t]:i.globals.seriesCandleL[e][t],c:this.isBoxPlot?i.globals.seriesCandleL[e][t]:i.globals.seriesCandleC[e][t]}}}]),r}(xe),ke=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"checkColorRange",value:function(){var e=this.w,t=!1,i=e.config.plotOptions[e.config.chart.type];return i.colorScale.ranges.length>0&&i.colorScale.ranges.map((function(e,i){e.from<=0&&(t=!0)})),t}},{key:"getShadeColor",value:function(e,t,i,n){var r=this.w,a=1,s=r.config.plotOptions[e].shadeIntensity,o=this.determineColor(e,t,i);r.globals.hasNegs||n?a=r.config.plotOptions[e].reverseNegativeShade?o.percent<0?o.percent/100*(1.25*s):(1-o.percent/100)*(1.25*s):o.percent<=0?1-(1+o.percent/100)*s:(1-o.percent/100)*s:(a=1-o.percent/100,"treemap"===e&&(a=(1-o.percent/100)*(1.25*s)));var l=o.color,c=new g;return r.config.plotOptions[e].enableShades&&(l="dark"===this.w.config.theme.mode?g.hexToRgba(c.shadeColor(-1*a,o.color),r.config.fill.opacity):g.hexToRgba(c.shadeColor(a,o.color),r.config.fill.opacity)),{color:l,colorProps:o}}},{key:"determineColor",value:function(e,t,i){var n=this.w,r=n.globals.series[t][i],a=n.config.plotOptions[e],s=a.colorScale.inverse?i:t;a.distributed&&"treemap"===n.config.chart.type&&(s=i);var o=n.globals.colors[s],l=null,c=Math.min.apply(Math,f(n.globals.series[t])),u=Math.max.apply(Math,f(n.globals.series[t]));a.distributed||"heatmap"!==e||(c=n.globals.minY,u=n.globals.maxY),void 0!==a.colorScale.min&&(c=a.colorScale.min<n.globals.minY?a.colorScale.min:n.globals.minY,u=a.colorScale.max>n.globals.maxY?a.colorScale.max:n.globals.maxY);var d=Math.abs(u)+Math.abs(c),h=100*r/(0===d?d-1e-6:d);return a.colorScale.ranges.length>0&&a.colorScale.ranges.map((function(e,t){if(r>=e.from&&r<=e.to){o=e.color,l=e.foreColor?e.foreColor:null,c=e.from,u=e.to;var i=Math.abs(u)+Math.abs(c);h=100*r/(0===i?i-1e-6:i)}})),{color:o,foreColor:l,percent:h}}},{key:"calculateDataLabels",value:function(e){var t=e.text,i=e.x,n=e.y,r=e.i,a=e.j,s=e.colorProps,o=e.fontSize,l=this.w.config.dataLabels,c=new b(this.ctx),u=new R(this.ctx),d=null;if(l.enabled){d=c.group({class:"apexcharts-data-labels"});var h=l.offsetX,f=l.offsetY,p=i+h,m=n+parseFloat(l.style.fontSize)/3+f;u.plotDataLabelsText({x:p,y:m,text:t,i:r,j:a,color:s.foreColor,parent:d,fontSize:o,dataLabelsConfig:l})}return d}},{key:"addListeners",value:function(e){var t=new b(this.ctx);e.node.addEventListener("mouseenter",t.pathMouseEnter.bind(this,e)),e.node.addEventListener("mouseleave",t.pathMouseLeave.bind(this,e)),e.node.addEventListener("mousedown",t.pathMouseDown.bind(this,e))}}]),e}(),Me=function(){function e(t,i){n(this,e),this.ctx=t,this.w=t.w,this.xRatio=i.xRatio,this.yRatio=i.yRatio,this.dynamicAnim=this.w.config.chart.animations.dynamicAnimation,this.helpers=new ke(t),this.rectRadius=this.w.config.plotOptions.heatmap.radius,this.strokeWidth=this.w.config.stroke.show?this.w.config.stroke.width:0}return a(e,[{key:"draw",value:function(e){var t=this.w,i=new b(this.ctx),n=i.group({class:"apexcharts-heatmap"});n.attr("clip-path","url(#gridRectMask".concat(t.globals.cuid,")"));var r=t.globals.gridWidth/t.globals.dataPoints,a=t.globals.gridHeight/t.globals.series.length,s=0,o=!1;this.negRange=this.helpers.checkColorRange();var l=e.slice();t.config.yaxis[0].reversed&&(o=!0,l.reverse());for(var c=o?0:l.length-1;o?c<l.length:c>=0;o?c++:c--){var u=i.group({class:"apexcharts-series apexcharts-heatmap-series",seriesName:g.escapeString(t.globals.seriesNames[c]),rel:c+1,"data:realIndex":c});if(this.ctx.series.addCollapsedClassToSeries(u,c),t.config.chart.dropShadow.enabled){var d=t.config.chart.dropShadow;new y(this.ctx).dropShadow(u,d,c)}for(var h=0,f=t.config.plotOptions.heatmap.shadeIntensity,p=0;p<l[c].length;p++){var m=this.helpers.getShadeColor(t.config.chart.type,c,p,this.negRange),v=m.color,x=m.colorProps;"image"===t.config.fill.type&&(v=new j(this.ctx).fillPath({seriesNumber:c,dataPointIndex:p,opacity:t.globals.hasNegs?x.percent<0?1-(1+x.percent/100):f+x.percent/100:x.percent/100,patternID:g.randomId(),width:t.config.fill.image.width?t.config.fill.image.width:r,height:t.config.fill.image.height?t.config.fill.image.height:a}));var _=this.rectRadius,w=i.drawRect(h,s,r,a,_);if(w.attr({cx:h,cy:s}),w.node.classList.add("apexcharts-heatmap-rect"),u.add(w),w.attr({fill:v,i:c,index:c,j:p,val:e[c][p],"stroke-width":this.strokeWidth,stroke:t.config.plotOptions.heatmap.useFillColorAsStroke?v:t.globals.stroke.colors[0],color:v}),this.helpers.addListeners(w),t.config.chart.animations.enabled&&!t.globals.dataChanged){var k=1;t.globals.resized||(k=t.config.chart.animations.speed),this.animateHeatMap(w,h,s,r,a,k)}if(t.globals.dataChanged){var M=1;if(this.dynamicAnim.enabled&&t.globals.shouldAnimate){M=this.dynamicAnim.speed;var S=t.globals.previousPaths[c]&&t.globals.previousPaths[c][p]&&t.globals.previousPaths[c][p].color;S||(S="rgba(255, 255, 255, 0)"),this.animateHeatColor(w,g.isColorHex(S)?S:g.rgb2hex(S),g.isColorHex(v)?v:g.rgb2hex(v),M)}}var A=(0,t.config.dataLabels.formatter)(t.globals.series[c][p],{value:t.globals.series[c][p],seriesIndex:c,dataPointIndex:p,w:t}),L=this.helpers.calculateDataLabels({text:A,x:h+r/2,y:s+a/2,i:c,j:p,colorProps:x,series:l});null!==L&&u.add(L),h+=r}s+=a,n.add(u)}var T=t.globals.yAxisScale[0].result.slice();return t.config.yaxis[0].reversed?T.unshift(""):T.push(""),t.globals.yAxisScale[0].result=T,n}},{key:"animateHeatMap",value:function(e,t,i,n,r,a){var s=new v(this.ctx);s.animateRect(e,{x:t+n/2,y:i+r/2,width:0,height:0},{x:t,y:i,width:n,height:r},a,(function(){s.animationCompleted(e)}))}},{key:"animateHeatColor",value:function(e,t,i,n){e.attr({fill:t}).animate(n).attr({fill:i})}}]),e}(),Se=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"drawYAxisTexts",value:function(e,t,i,n){var r=this.w,a=r.config.yaxis[0],s=r.globals.yLabelFormatters[0];return new b(this.ctx).drawText({x:e+a.labels.offsetX,y:t+a.labels.offsetY,text:s(n,i),textAnchor:"middle",fontSize:a.labels.style.fontSize,fontFamily:a.labels.style.fontFamily,foreColor:Array.isArray(a.labels.style.colors)?a.labels.style.colors[i]:a.labels.style.colors})}}]),e}(),Ae=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w;var i=this.w;this.chartType=this.w.config.chart.type,this.initialAnim=this.w.config.chart.animations.enabled,this.dynamicAnim=this.initialAnim&&this.w.config.chart.animations.dynamicAnimation.enabled,this.animBeginArr=[0],this.animDur=0,this.donutDataLabels=this.w.config.plotOptions.pie.donut.labels,this.lineColorArr=void 0!==i.globals.stroke.colors?i.globals.stroke.colors:i.globals.colors,this.defaultSize=Math.min(i.globals.gridWidth,i.globals.gridHeight),this.centerY=this.defaultSize/2,this.centerX=i.globals.gridWidth/2,"radialBar"===i.config.chart.type?this.fullAngle=360:this.fullAngle=Math.abs(i.config.plotOptions.pie.endAngle-i.config.plotOptions.pie.startAngle),this.initialAngle=i.config.plotOptions.pie.startAngle%this.fullAngle,i.globals.radialSize=this.defaultSize/2.05-i.config.stroke.width-(i.config.chart.sparkline.enabled?0:i.config.chart.dropShadow.blur),this.donutSize=i.globals.radialSize*parseInt(i.config.plotOptions.pie.donut.size,10)/100,this.maxY=0,this.sliceLabels=[],this.sliceSizes=[],this.prevSectorAngleArr=[]}return a(e,[{key:"draw",value:function(e){var t=this,i=this.w,n=new b(this.ctx);if(this.ret=n.group({class:"apexcharts-pie"}),i.globals.noData)return this.ret;for(var r=0,a=0;a<e.length;a++)r+=g.negToZero(e[a]);var s=[],o=n.group();0===r&&(r=1e-5),e.forEach((function(e){t.maxY=Math.max(t.maxY,e)})),i.config.yaxis[0].max&&(this.maxY=i.config.yaxis[0].max),"back"===i.config.grid.position&&"polarArea"===this.chartType&&this.drawPolarElements(this.ret);for(var l=0;l<e.length;l++){var c=this.fullAngle*g.negToZero(e[l])/r;s.push(c),"polarArea"===this.chartType?(s[l]=this.fullAngle/e.length,this.sliceSizes.push(i.globals.radialSize*e[l]/this.maxY)):this.sliceSizes.push(i.globals.radialSize)}if(i.globals.dataChanged){for(var u,d=0,h=0;h<i.globals.previousPaths.length;h++)d+=g.negToZero(i.globals.previousPaths[h]);for(var f=0;f<i.globals.previousPaths.length;f++)u=this.fullAngle*g.negToZero(i.globals.previousPaths[f])/d,this.prevSectorAngleArr.push(u)}this.donutSize<0&&(this.donutSize=0);var p=i.config.plotOptions.pie.customScale,m=i.globals.gridWidth/2,v=i.globals.gridHeight/2,y=m-i.globals.gridWidth/2*p,x=v-i.globals.gridHeight/2*p;if("donut"===this.chartType){var _=n.drawCircle(this.donutSize);_.attr({cx:this.centerX,cy:this.centerY,fill:i.config.plotOptions.pie.donut.background?i.config.plotOptions.pie.donut.background:"transparent"}),o.add(_)}var w=this.drawArcs(s,e);if(this.sliceLabels.forEach((function(e){w.add(e)})),o.attr({transform:"translate(".concat(y,", ").concat(x,") scale(").concat(p,")")}),o.add(w),this.ret.add(o),this.donutDataLabels.show){var k=this.renderInnerDataLabels(this.donutDataLabels,{hollowSize:this.donutSize,centerX:this.centerX,centerY:this.centerY,opacity:this.donutDataLabels.show,translateX:y,translateY:x});this.ret.add(k)}return"front"===i.config.grid.position&&"polarArea"===this.chartType&&this.drawPolarElements(this.ret),this.ret}},{key:"drawArcs",value:function(e,t){var i=this.w,n=new y(this.ctx),r=new b(this.ctx),a=new j(this.ctx),s=r.group({class:"apexcharts-slices"}),o=this.initialAngle,l=this.initialAngle,c=this.initialAngle,u=this.initialAngle;this.strokeWidth=i.config.stroke.show?i.config.stroke.width:0;for(var d=0;d<e.length;d++){var h=r.group({class:"apexcharts-series apexcharts-pie-series",seriesName:g.escapeString(i.globals.seriesNames[d]),rel:d+1,"data:realIndex":d});s.add(h),l=u,c=(o=c)+e[d],u=l+this.prevSectorAngleArr[d];var f=c<o?this.fullAngle+c-o:c-o,p=a.fillPath({seriesNumber:d,size:this.sliceSizes[d],value:t[d]}),m=this.getChangedPath(l,u),v=r.drawPath({d:m,stroke:Array.isArray(this.lineColorArr)?this.lineColorArr[d]:this.lineColorArr,strokeWidth:0,fill:p,fillOpacity:i.config.fill.opacity,classes:"apexcharts-pie-area apexcharts-".concat(this.chartType.toLowerCase(),"-slice-").concat(d)});if(v.attr({index:0,j:d}),n.setSelectionFilter(v,0,d),i.config.chart.dropShadow.enabled){var x=i.config.chart.dropShadow;n.dropShadow(v,x,d)}this.addListeners(v,this.donutDataLabels),b.setAttrs(v.node,{"data:angle":f,"data:startAngle":o,"data:strokeWidth":this.strokeWidth,"data:value":t[d]});var _={x:0,y:0};"pie"===this.chartType||"polarArea"===this.chartType?_=g.polarToCartesian(this.centerX,this.centerY,i.globals.radialSize/1.25+i.config.plotOptions.pie.dataLabels.offset,(o+f/2)%this.fullAngle):"donut"===this.chartType&&(_=g.polarToCartesian(this.centerX,this.centerY,(i.globals.radialSize+this.donutSize)/2+i.config.plotOptions.pie.dataLabels.offset,(o+f/2)%this.fullAngle)),h.add(v);var w=0;if(!this.initialAnim||i.globals.resized||i.globals.dataChanged?this.animBeginArr.push(0):(0==(w=f/this.fullAngle*i.config.chart.animations.speed)&&(w=1),this.animDur=w+this.animDur,this.animBeginArr.push(this.animDur)),this.dynamicAnim&&i.globals.dataChanged?this.animatePaths(v,{size:this.sliceSizes[d],endAngle:c,startAngle:o,prevStartAngle:l,prevEndAngle:u,animateStartingPos:!0,i:d,animBeginArr:this.animBeginArr,shouldSetPrevPaths:!0,dur:i.config.chart.animations.dynamicAnimation.speed}):this.animatePaths(v,{size:this.sliceSizes[d],endAngle:c,startAngle:o,i:d,totalItems:e.length-1,animBeginArr:this.animBeginArr,dur:w}),i.config.plotOptions.pie.expandOnClick&&"polarArea"!==this.chartType&&v.node.addEventListener("mouseup",this.pieClicked.bind(this,d)),void 0!==i.globals.selectedDataPoints[0]&&i.globals.selectedDataPoints[0].indexOf(d)>-1&&this.pieClicked(d),i.config.dataLabels.enabled){var k=_.x,M=_.y,S=100*f/this.fullAngle+"%";if(0!==f&&i.config.plotOptions.pie.dataLabels.minAngleToShowLabel<e[d]){var A=i.config.dataLabels.formatter;void 0!==A&&(S=A(i.globals.seriesPercent[d][0],{seriesIndex:d,w:i}));var L=i.globals.dataLabels.style.colors[d],T=r.group({class:"apexcharts-datalabels"}),C=r.drawText({x:k,y:M,text:S,textAnchor:"middle",fontSize:i.config.dataLabels.style.fontSize,fontFamily:i.config.dataLabels.style.fontFamily,fontWeight:i.config.dataLabels.style.fontWeight,foreColor:L});if(T.add(C),i.config.dataLabels.dropShadow.enabled){var D=i.config.dataLabels.dropShadow;n.dropShadow(C,D)}C.node.classList.add("apexcharts-pie-label"),i.config.chart.animations.animate&&!1===i.globals.resized&&(C.node.classList.add("apexcharts-pie-label-delay"),C.node.style.animationDelay=i.config.chart.animations.speed/940+"s"),this.sliceLabels.push(T)}}}return s}},{key:"addListeners",value:function(e,t){var i=new b(this.ctx);e.node.addEventListener("mouseenter",i.pathMouseEnter.bind(this,e)),e.node.addEventListener("mouseleave",i.pathMouseLeave.bind(this,e)),e.node.addEventListener("mouseleave",this.revertDataLabelsInner.bind(this,e.node,t)),e.node.addEventListener("mousedown",i.pathMouseDown.bind(this,e)),this.donutDataLabels.total.showAlways||(e.node.addEventListener("mouseenter",this.printDataLabelsInner.bind(this,e.node,t)),e.node.addEventListener("mousedown",this.printDataLabelsInner.bind(this,e.node,t)))}},{key:"animatePaths",value:function(e,t){var i=this.w,n=t.endAngle<t.startAngle?this.fullAngle+t.endAngle-t.startAngle:t.endAngle-t.startAngle,r=n,a=t.startAngle,s=t.startAngle;void 0!==t.prevStartAngle&&void 0!==t.prevEndAngle&&(a=t.prevEndAngle,r=t.prevEndAngle<t.prevStartAngle?this.fullAngle+t.prevEndAngle-t.prevStartAngle:t.prevEndAngle-t.prevStartAngle),t.i===i.config.series.length-1&&(n+s>this.fullAngle?t.endAngle=t.endAngle-(n+s):n+s<this.fullAngle&&(t.endAngle=t.endAngle+(this.fullAngle-(n+s)))),n===this.fullAngle&&(n=this.fullAngle-.01),this.animateArc(e,a,s,n,r,t)}},{key:"animateArc",value:function(e,t,i,n,r,a){var s,o=this,l=this.w,c=new v(this.ctx),u=a.size;(isNaN(t)||isNaN(r))&&(t=i,r=n,a.dur=0);var d=n,h=i,f=t<i?this.fullAngle+t-i:t-i;l.globals.dataChanged&&a.shouldSetPrevPaths&&a.prevEndAngle&&(s=o.getPiePath({me:o,startAngle:a.prevStartAngle,angle:a.prevEndAngle<a.prevStartAngle?this.fullAngle+a.prevEndAngle-a.prevStartAngle:a.prevEndAngle-a.prevStartAngle,size:u}),e.attr({d:s})),0!==a.dur?e.animate(a.dur,l.globals.easing,a.animBeginArr[a.i]).afterAll((function(){"pie"!==o.chartType&&"donut"!==o.chartType&&"polarArea"!==o.chartType||this.animate(l.config.chart.animations.dynamicAnimation.speed).attr({"stroke-width":o.strokeWidth}),a.i===l.config.series.length-1&&c.animationCompleted(e)})).during((function(l){d=f+(n-f)*l,a.animateStartingPos&&(d=r+(n-r)*l,h=t-r+(i-(t-r))*l),s=o.getPiePath({me:o,startAngle:h,angle:d,size:u}),e.node.setAttribute("data:pathOrig",s),e.attr({d:s})})):(s=o.getPiePath({me:o,startAngle:h,angle:n,size:u}),a.isTrack||(l.globals.animationEnded=!0),e.node.setAttribute("data:pathOrig",s),e.attr({d:s,"stroke-width":o.strokeWidth}))}},{key:"pieClicked",value:function(e){var t,i=this.w,n=this,r=n.sliceSizes[e]+(i.config.plotOptions.pie.expandOnClick?4:0),a=i.globals.dom.Paper.select(".apexcharts-".concat(n.chartType.toLowerCase(),"-slice-").concat(e)).members[0];if("true"!==a.attr("data:pieClicked")){var s=i.globals.dom.baseEl.getElementsByClassName("apexcharts-pie-area");Array.prototype.forEach.call(s,(function(e){e.setAttribute("data:pieClicked","false");var t=e.getAttribute("data:pathOrig");t&&e.setAttribute("d",t)})),i.globals.capturedDataPointIndex=e,a.attr("data:pieClicked","true");var o=parseInt(a.attr("data:startAngle"),10),l=parseInt(a.attr("data:angle"),10);t=n.getPiePath({me:n,startAngle:o,angle:l,size:r}),360!==l&&a.plot(t)}else{a.attr({"data:pieClicked":"false"}),this.revertDataLabelsInner(a.node,this.donutDataLabels);var c=a.attr("data:pathOrig");a.attr({d:c})}}},{key:"getChangedPath",value:function(e,t){var i="";return this.dynamicAnim&&this.w.globals.dataChanged&&(i=this.getPiePath({me:this,startAngle:e,angle:t-e,size:this.size})),i}},{key:"getPiePath",value:function(e){var t,i=e.me,n=e.startAngle,r=e.angle,a=e.size,s=new b(this.ctx),o=n,l=Math.PI*(o-90)/180,c=r+n;Math.ceil(c)>=this.fullAngle+this.w.config.plotOptions.pie.startAngle%this.fullAngle&&(c=this.fullAngle+this.w.config.plotOptions.pie.startAngle%this.fullAngle-.01),Math.ceil(c)>this.fullAngle&&(c-=this.fullAngle);var u=Math.PI*(c-90)/180,d=i.centerX+a*Math.cos(l),h=i.centerY+a*Math.sin(l),f=i.centerX+a*Math.cos(u),p=i.centerY+a*Math.sin(u),m=g.polarToCartesian(i.centerX,i.centerY,i.donutSize,c),v=g.polarToCartesian(i.centerX,i.centerY,i.donutSize,o),y=r>180?1:0,x=["M",d,h,"A",a,a,0,y,1,f,p];return t="donut"===i.chartType?[].concat(x,["L",m.x,m.y,"A",i.donutSize,i.donutSize,0,y,0,v.x,v.y,"L",d,h,"z"]).join(" "):"pie"===i.chartType||"polarArea"===i.chartType?[].concat(x,["L",i.centerX,i.centerY,"L",d,h]).join(" "):[].concat(x).join(" "),s.roundPathCorners(t,2*this.strokeWidth)}},{key:"drawPolarElements",value:function(e){var t=this.w,i=new q(this.ctx),n=new b(this.ctx),r=new Se(this.ctx),a=n.group(),s=n.group(),o=i.niceScale(0,Math.ceil(this.maxY),0),l=o.result.reverse(),c=o.result.length;this.maxY=o.niceMax;for(var u=t.globals.radialSize,d=u/(c-1),h=0;h<c-1;h++){var f=n.drawCircle(u);if(f.attr({cx:this.centerX,cy:this.centerY,fill:"none","stroke-width":t.config.plotOptions.polarArea.rings.strokeWidth,stroke:t.config.plotOptions.polarArea.rings.strokeColor}),t.config.yaxis[0].show){var p=r.drawYAxisTexts(this.centerX,this.centerY-u+parseInt(t.config.yaxis[0].labels.style.fontSize,10)/2,h,l[h]);s.add(p)}a.add(f),u-=d}this.drawSpokes(e),e.add(a),e.add(s)}},{key:"renderInnerDataLabels",value:function(e,t){var i=this.w,n=new b(this.ctx),r=n.group({class:"apexcharts-datalabels-group",transform:"translate(".concat(t.translateX?t.translateX:0,", ").concat(t.translateY?t.translateY:0,") scale(").concat(i.config.plotOptions.pie.customScale,")")}),a=e.total.show;r.node.style.opacity=t.opacity;var s,o,l=t.centerX,c=t.centerY;s=void 0===e.name.color?i.globals.colors[0]:e.name.color;var u=e.name.fontSize,d=e.name.fontFamily,h=e.name.fontWeight;o=void 0===e.value.color?i.config.chart.foreColor:e.value.color;var f=e.value.formatter,p="",m="";if(a?(s=e.total.color,u=e.total.fontSize,d=e.total.fontFamily,h=e.total.fontWeight,m=e.total.label,p=e.total.formatter(i)):1===i.globals.series.length&&(p=f(i.globals.series[0],i),m=i.globals.seriesNames[0]),m&&(m=e.name.formatter(m,e.total.show,i)),e.name.show){var g=n.drawText({x:l,y:c+parseFloat(e.name.offsetY),text:m,textAnchor:"middle",foreColor:s,fontSize:u,fontWeight:h,fontFamily:d});g.node.classList.add("apexcharts-datalabel-label"),r.add(g)}if(e.value.show){var v=e.name.show?parseFloat(e.value.offsetY)+16:e.value.offsetY,y=n.drawText({x:l,y:c+v,text:p,textAnchor:"middle",foreColor:o,fontWeight:e.value.fontWeight,fontSize:e.value.fontSize,fontFamily:e.value.fontFamily});y.node.classList.add("apexcharts-datalabel-value"),r.add(y)}return r}},{key:"printInnerLabels",value:function(e,t,i,n){var r,a=this.w;n?r=void 0===e.name.color?a.globals.colors[parseInt(n.parentNode.getAttribute("rel"),10)-1]:e.name.color:a.globals.series.length>1&&e.total.show&&(r=e.total.color);var s=a.globals.dom.baseEl.querySelector(".apexcharts-datalabel-label"),o=a.globals.dom.baseEl.querySelector(".apexcharts-datalabel-value");i=(0,e.value.formatter)(i,a),n||"function"!=typeof e.total.formatter||(i=e.total.formatter(a));var l=t===e.total.label;t=e.name.formatter(t,l,a),null!==s&&(s.textContent=t),null!==o&&(o.textContent=i),null!==s&&(s.style.fill=r)}},{key:"printDataLabelsInner",value:function(e,t){var i=this.w,n=e.getAttribute("data:value"),r=i.globals.seriesNames[parseInt(e.parentNode.getAttribute("rel"),10)-1];i.globals.series.length>1&&this.printInnerLabels(t,r,n,e);var a=i.globals.dom.baseEl.querySelector(".apexcharts-datalabels-group");null!==a&&(a.style.opacity=1)}},{key:"drawSpokes",value:function(e){var t=this,i=this.w,n=new b(this.ctx),r=i.config.plotOptions.polarArea.spokes;if(0!==r.strokeWidth){for(var a=[],s=360/i.globals.series.length,o=0;o<i.globals.series.length;o++)a.push(g.polarToCartesian(this.centerX,this.centerY,i.globals.radialSize,i.config.plotOptions.pie.startAngle+s*o));a.forEach((function(i,a){var s=n.drawLine(i.x,i.y,t.centerX,t.centerY,Array.isArray(r.connectorColors)?r.connectorColors[a]:r.connectorColors);e.add(s)}))}}},{key:"revertDataLabelsInner",value:function(e,t,i){var n=this,r=this.w,a=r.globals.dom.baseEl.querySelector(".apexcharts-datalabels-group"),s=!1,o=r.globals.dom.baseEl.getElementsByClassName("apexcharts-pie-area"),l=function(e){var i=e.makeSliceOut,r=e.printLabel;Array.prototype.forEach.call(o,(function(e){"true"===e.getAttribute("data:pieClicked")&&(i&&(s=!0),r&&n.printDataLabelsInner(e,t))}))};if(l({makeSliceOut:!0,printLabel:!1}),t.total.show&&r.globals.series.length>1)s&&!t.total.showAlways?l({makeSliceOut:!1,printLabel:!0}):this.printInnerLabels(t,t.total.label,t.total.formatter(r));else if(l({makeSliceOut:!1,printLabel:!0}),!s)if(r.globals.selectedDataPoints.length&&r.globals.series.length>1)if(r.globals.selectedDataPoints[0].length>0){var c=r.globals.selectedDataPoints[0],u=r.globals.dom.baseEl.querySelector(".apexcharts-".concat(this.chartType.toLowerCase(),"-slice-").concat(c));this.printDataLabelsInner(u,t)}else a&&r.globals.selectedDataPoints.length&&0===r.globals.selectedDataPoints[0].length&&(a.style.opacity=0);else a&&r.globals.series.length>1&&(a.style.opacity=0)}}]),e}(),Le=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.chartType=this.w.config.chart.type,this.initialAnim=this.w.config.chart.animations.enabled,this.dynamicAnim=this.initialAnim&&this.w.config.chart.animations.dynamicAnimation.enabled,this.animDur=0;var i=this.w;this.graphics=new b(this.ctx),this.lineColorArr=void 0!==i.globals.stroke.colors?i.globals.stroke.colors:i.globals.colors,this.defaultSize=i.globals.svgHeight<i.globals.svgWidth?i.globals.gridHeight+1.5*i.globals.goldenPadding:i.globals.gridWidth,this.isLog=i.config.yaxis[0].logarithmic,this.logBase=i.config.yaxis[0].logBase,this.coreUtils=new x(this.ctx),this.maxValue=this.isLog?this.coreUtils.getLogVal(this.logBase,i.globals.maxY,0):i.globals.maxY,this.minValue=this.isLog?this.coreUtils.getLogVal(this.logBase,this.w.globals.minY,0):i.globals.minY,this.polygons=i.config.plotOptions.radar.polygons,this.strokeWidth=i.config.stroke.show?i.config.stroke.width:0,this.size=this.defaultSize/2.1-this.strokeWidth-i.config.chart.dropShadow.blur,i.config.xaxis.labels.show&&(this.size=this.size-i.globals.xAxisLabelsWidth/1.75),void 0!==i.config.plotOptions.radar.size&&(this.size=i.config.plotOptions.radar.size),this.dataRadiusOfPercent=[],this.dataRadius=[],this.angleArr=[],this.yaxisLabelsTextsPos=[]}return a(e,[{key:"draw",value:function(e){var i=this,n=this.w,r=new j(this.ctx),a=[],s=new R(this.ctx);e.length&&(this.dataPointsLen=e[n.globals.maxValsInArrayIndex].length),this.disAngle=2*Math.PI/this.dataPointsLen;var o=n.globals.gridWidth/2,l=n.globals.gridHeight/2,c=o+n.config.plotOptions.radar.offsetX,u=l+n.config.plotOptions.radar.offsetY,d=this.graphics.group({class:"apexcharts-radar-series apexcharts-plot-series",transform:"translate(".concat(c||0,", ").concat(u||0,")")}),h=[],f=null,p=null;if(this.yaxisLabels=this.graphics.group({class:"apexcharts-yaxis"}),e.forEach((function(e,o){var l=e.length===n.globals.dataPoints,c=i.graphics.group().attr({class:"apexcharts-series","data:longestSeries":l,seriesName:g.escapeString(n.globals.seriesNames[o]),rel:o+1,"data:realIndex":o});i.dataRadiusOfPercent[o]=[],i.dataRadius[o]=[],i.angleArr[o]=[],e.forEach((function(e,t){var n=Math.abs(i.maxValue-i.minValue);e-=i.minValue,i.isLog&&(e=i.coreUtils.getLogVal(i.logBase,e,0)),i.dataRadiusOfPercent[o][t]=e/n,i.dataRadius[o][t]=i.dataRadiusOfPercent[o][t]*i.size,i.angleArr[o][t]=t*i.disAngle})),h=i.getDataPointsPos(i.dataRadius[o],i.angleArr[o]);var u=i.createPaths(h,{x:0,y:0});f=i.graphics.group({class:"apexcharts-series-markers-wrap apexcharts-element-hidden"}),p=i.graphics.group({class:"apexcharts-datalabels","data:realIndex":o}),n.globals.delayedElements.push({el:f.node,index:o});var d={i:o,realIndex:o,animationDelay:o,initialSpeed:n.config.chart.animations.speed,dataChangeSpeed:n.config.chart.animations.dynamicAnimation.speed,className:"apexcharts-radar",shouldClipToGrid:!1,bindEventsOnPaths:!1,stroke:n.globals.stroke.colors[o],strokeLineCap:n.config.stroke.lineCap},m=null;n.globals.previousPaths.length>0&&(m=i.getPreviousPath(o));for(var v=0;v<u.linePathsTo.length;v++){var b=i.graphics.renderPaths(t(t({},d),{},{pathFrom:null===m?u.linePathsFrom[v]:m,pathTo:u.linePathsTo[v],strokeWidth:Array.isArray(i.strokeWidth)?i.strokeWidth[o]:i.strokeWidth,fill:"none",drawShadow:!1}));c.add(b);var x=r.fillPath({seriesNumber:o}),_=i.graphics.renderPaths(t(t({},d),{},{pathFrom:null===m?u.areaPathsFrom[v]:m,pathTo:u.areaPathsTo[v],strokeWidth:0,fill:x,drawShadow:!1}));if(n.config.chart.dropShadow.enabled){var w=new y(i.ctx),k=n.config.chart.dropShadow;w.dropShadow(_,Object.assign({},k,{noUserSpaceOnUse:!0}),o)}c.add(_)}e.forEach((function(e,r){var a=new H(i.ctx).getMarkerConfig({cssClass:"apexcharts-marker",seriesIndex:o,dataPointIndex:r}),l=i.graphics.drawMarker(h[r].x,h[r].y,a);l.attr("rel",r),l.attr("j",r),l.attr("index",o),l.node.setAttribute("default-marker-size",a.pSize);var u=i.graphics.group({class:"apexcharts-series-markers"});u&&u.add(l),f.add(u),c.add(f);var d=n.config.dataLabels;if(d.enabled){var m=d.formatter(n.globals.series[o][r],{seriesIndex:o,dataPointIndex:r,w:n});s.plotDataLabelsText({x:h[r].x,y:h[r].y,text:m,textAnchor:"middle",i:o,j:o,parent:p,offsetCorrection:!1,dataLabelsConfig:t({},d)})}c.add(p)})),a.push(c)})),this.drawPolygons({parent:d}),n.config.xaxis.labels.show){var m=this.drawXAxisTexts();d.add(m)}return a.forEach((function(e){d.add(e)})),d.add(this.yaxisLabels),d}},{key:"drawPolygons",value:function(e){for(var t=this,i=this.w,n=e.parent,r=new Se(this.ctx),a=i.globals.yAxisScale[0].result.reverse(),s=a.length,o=[],l=this.size/(s-1),c=0;c<s;c++)o[c]=l*c;o.reverse();var u=[],d=[];o.forEach((function(e,i){var n=g.getPolygonPos(e,t.dataPointsLen),r="";n.forEach((function(e,n){if(0===i){var a=t.graphics.drawLine(e.x,e.y,0,0,Array.isArray(t.polygons.connectorColors)?t.polygons.connectorColors[n]:t.polygons.connectorColors);d.push(a)}0===n&&t.yaxisLabelsTextsPos.push({x:e.x,y:e.y}),r+=e.x+","+e.y+" "})),u.push(r)})),u.forEach((function(e,r){var a=t.polygons.strokeColors,s=t.polygons.strokeWidth,o=t.graphics.drawPolygon(e,Array.isArray(a)?a[r]:a,Array.isArray(s)?s[r]:s,i.globals.radarPolygons.fill.colors[r]);n.add(o)})),d.forEach((function(e){n.add(e)})),i.config.yaxis[0].show&&this.yaxisLabelsTextsPos.forEach((function(e,i){var n=r.drawYAxisTexts(e.x,e.y,i,a[i]);t.yaxisLabels.add(n)}))}},{key:"drawXAxisTexts",value:function(){var e=this,i=this.w,n=i.config.xaxis.labels,r=this.graphics.group({class:"apexcharts-xaxis"}),a=g.getPolygonPos(this.size,this.dataPointsLen);return i.globals.labels.forEach((function(s,o){var l=i.config.xaxis.labels.formatter,c=new R(e.ctx);if(a[o]){var u=e.getTextPos(a[o],e.size),d=l(s,{seriesIndex:-1,dataPointIndex:o,w:i});c.plotDataLabelsText({x:u.newX,y:u.newY,text:d,textAnchor:u.textAnchor,i:o,j:o,parent:r,color:Array.isArray(n.style.colors)&&n.style.colors[o]?n.style.colors[o]:"#a8a8a8",dataLabelsConfig:t({textAnchor:u.textAnchor,dropShadow:{enabled:!1}},n),offsetCorrection:!1})}})),r}},{key:"createPaths",value:function(e,t){var i=this,n=[],r=[],a=[],s=[];if(e.length){r=[this.graphics.move(t.x,t.y)],s=[this.graphics.move(t.x,t.y)];var o=this.graphics.move(e[0].x,e[0].y),l=this.graphics.move(e[0].x,e[0].y);e.forEach((function(t,n){o+=i.graphics.line(t.x,t.y),l+=i.graphics.line(t.x,t.y),n===e.length-1&&(o+="Z",l+="Z")})),n.push(o),a.push(l)}return{linePathsFrom:r,linePathsTo:n,areaPathsFrom:s,areaPathsTo:a}}},{key:"getTextPos",value:function(e,t){var i="middle",n=e.x,r=e.y;return Math.abs(e.x)>=10?e.x>0?(i="start",n+=10):e.x<0&&(i="end",n-=10):i="middle",Math.abs(e.y)>=t-10&&(e.y<0?r-=10:e.y>0&&(r+=10)),{textAnchor:i,newX:n,newY:r}}},{key:"getPreviousPath",value:function(e){for(var t=this.w,i=null,n=0;n<t.globals.previousPaths.length;n++){var r=t.globals.previousPaths[n];r.paths.length>0&&parseInt(r.realIndex,10)===parseInt(e,10)&&void 0!==t.globals.previousPaths[n].paths[0]&&(i=t.globals.previousPaths[n].paths[0].d)}return i}},{key:"getDataPointsPos",value:function(e,t){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:this.dataPointsLen;e=e||[],t=t||[];for(var n=[],r=0;r<i;r++){var a={};a.x=e[r]*Math.sin(t[r]),a.y=-e[r]*Math.cos(t[r]),n.push(a)}return n}}]),e}(),Te=function(e){o(i,e);var t=d(i);function i(e){var r;n(this,i),(r=t.call(this,e)).ctx=e,r.w=e.w,r.animBeginArr=[0],r.animDur=0;var a=r.w;return r.startAngle=a.config.plotOptions.radialBar.startAngle,r.endAngle=a.config.plotOptions.radialBar.endAngle,r.totalAngle=Math.abs(a.config.plotOptions.radialBar.endAngle-a.config.plotOptions.radialBar.startAngle),r.trackStartAngle=a.config.plotOptions.radialBar.track.startAngle,r.trackEndAngle=a.config.plotOptions.radialBar.track.endAngle,r.barLabels=r.w.config.plotOptions.radialBar.barLabels,r.donutDataLabels=r.w.config.plotOptions.radialBar.dataLabels,r.radialDataLabels=r.donutDataLabels,r.trackStartAngle||(r.trackStartAngle=r.startAngle),r.trackEndAngle||(r.trackEndAngle=r.endAngle),360===r.endAngle&&(r.endAngle=359.99),r.margin=parseInt(a.config.plotOptions.radialBar.track.margin,10),r.onBarLabelClick=r.onBarLabelClick.bind(u(r)),r}return a(i,[{key:"draw",value:function(e){var t=this.w,i=new b(this.ctx),n=i.group({class:"apexcharts-radialbar"});if(t.globals.noData)return n;var r=i.group(),a=this.defaultSize/2,s=t.globals.gridWidth/2,o=this.defaultSize/2.05;t.config.chart.sparkline.enabled||(o=o-t.config.stroke.width-t.config.chart.dropShadow.blur);var l=t.globals.fill.colors;if(t.config.plotOptions.radialBar.track.show){var c=this.drawTracks({size:o,centerX:s,centerY:a,colorArr:l,series:e});r.add(c)}var u=this.drawArcs({size:o,centerX:s,centerY:a,colorArr:l,series:e}),d=360;t.config.plotOptions.radialBar.startAngle<0&&(d=this.totalAngle);var h=(360-d)/360;if(t.globals.radialSize=o-o*h,this.radialDataLabels.value.show){var f=Math.max(this.radialDataLabels.value.offsetY,this.radialDataLabels.name.offsetY);t.globals.radialSize+=f*h}return r.add(u.g),"front"===t.config.plotOptions.radialBar.hollow.position&&(u.g.add(u.elHollow),u.dataLabels&&u.g.add(u.dataLabels)),n.add(r),n}},{key:"drawTracks",value:function(e){var t=this.w,i=new b(this.ctx),n=i.group({class:"apexcharts-tracks"}),r=new y(this.ctx),a=new j(this.ctx),s=this.getStrokeWidth(e);e.size=e.size-s/2;for(var o=0;o<e.series.length;o++){var l=i.group({class:"apexcharts-radialbar-track apexcharts-track"});n.add(l),l.attr({rel:o+1}),e.size=e.size-s-this.margin;var c=t.config.plotOptions.radialBar.track,u=a.fillPath({seriesNumber:0,size:e.size,fillColors:Array.isArray(c.background)?c.background[o]:c.background,solid:!0}),d=this.trackStartAngle,h=this.trackEndAngle;Math.abs(h)+Math.abs(d)>=360&&(h=360-Math.abs(this.startAngle)-.1);var f=i.drawPath({d:"",stroke:u,strokeWidth:s*parseInt(c.strokeWidth,10)/100,fill:"none",strokeOpacity:c.opacity,classes:"apexcharts-radialbar-area"});if(c.dropShadow.enabled){var p=c.dropShadow;r.dropShadow(f,p)}l.add(f),f.attr("id","apexcharts-radialbarTrack-"+o),this.animatePaths(f,{centerX:e.centerX,centerY:e.centerY,endAngle:h,startAngle:d,size:e.size,i:o,totalItems:2,animBeginArr:0,dur:0,isTrack:!0,easing:t.globals.easing})}return n}},{key:"drawArcs",value:function(e){var t=this.w,i=new b(this.ctx),n=new j(this.ctx),r=new y(this.ctx),a=i.group(),s=this.getStrokeWidth(e);e.size=e.size-s/2;var o=t.config.plotOptions.radialBar.hollow.background,l=e.size-s*e.series.length-this.margin*e.series.length-s*parseInt(t.config.plotOptions.radialBar.track.strokeWidth,10)/100/2,c=l-t.config.plotOptions.radialBar.hollow.margin;void 0!==t.config.plotOptions.radialBar.hollow.image&&(o=this.drawHollowImage(e,a,l,o));var u=this.drawHollow({size:c,centerX:e.centerX,centerY:e.centerY,fill:o||"transparent"});if(t.config.plotOptions.radialBar.hollow.dropShadow.enabled){var d=t.config.plotOptions.radialBar.hollow.dropShadow;r.dropShadow(u,d)}var h=1;!this.radialDataLabels.total.show&&t.globals.series.length>1&&(h=0);var f=null;this.radialDataLabels.show&&(f=this.renderInnerDataLabels(this.radialDataLabels,{hollowSize:l,centerX:e.centerX,centerY:e.centerY,opacity:h})),"back"===t.config.plotOptions.radialBar.hollow.position&&(a.add(u),f&&a.add(f));var p=!1;t.config.plotOptions.radialBar.inverseOrder&&(p=!0);for(var m=p?e.series.length-1:0;p?m>=0:m<e.series.length;p?m--:m++){var v=i.group({class:"apexcharts-series apexcharts-radial-series",seriesName:g.escapeString(t.globals.seriesNames[m])});a.add(v),v.attr({rel:m+1,"data:realIndex":m}),this.ctx.series.addCollapsedClassToSeries(v,m),e.size=e.size-s-this.margin;var x=n.fillPath({seriesNumber:m,size:e.size,value:e.series[m]}),_=this.startAngle,w=void 0,k=g.negToZero(e.series[m]>100?100:e.series[m])/100,M=Math.round(this.totalAngle*k)+this.startAngle,S=void 0;t.globals.dataChanged&&(w=this.startAngle,S=Math.round(this.totalAngle*g.negToZero(t.globals.previousPaths[m])/100)+w),Math.abs(M)+Math.abs(_)>=360&&(M-=.01),Math.abs(S)+Math.abs(w)>=360&&(S-=.01);var A=M-_,L=Array.isArray(t.config.stroke.dashArray)?t.config.stroke.dashArray[m]:t.config.stroke.dashArray,T=i.drawPath({d:"",stroke:x,strokeWidth:s,fill:"none",fillOpacity:t.config.fill.opacity,classes:"apexcharts-radialbar-area apexcharts-radialbar-slice-"+m,strokeDashArray:L});if(b.setAttrs(T.node,{"data:angle":A,"data:value":e.series[m]}),t.config.chart.dropShadow.enabled){var C=t.config.chart.dropShadow;r.dropShadow(T,C,m)}if(r.setSelectionFilter(T,0,m),this.addListeners(T,this.radialDataLabels),v.add(T),T.attr({index:0,j:m}),this.barLabels.enabled){var D=g.polarToCartesian(e.centerX,e.centerY,e.size,_),E=this.barLabels.formatter(t.globals.seriesNames[m],{seriesIndex:m,w:t}),O=["apexcharts-radialbar-label"];this.barLabels.onClick||O.push("apexcharts-no-click");var P=this.barLabels.useSeriesColors?t.globals.colors[m]:t.config.chart.foreColor;P||(P=t.config.chart.foreColor);var Y=D.x-this.barLabels.margin,I=D.y,N=i.drawText({x:Y,y:I,text:E,textAnchor:"end",dominantBaseline:"middle",fontFamily:this.barLabels.fontFamily,fontWeight:this.barLabels.fontWeight,fontSize:this.barLabels.fontSize,foreColor:P,cssClass:O.join(" ")});N.on("click",this.onBarLabelClick),N.attr({rel:m+1}),0!==_&&N.attr({"transform-origin":"".concat(Y," ").concat(I),transform:"rotate(".concat(_," 0 0)")}),v.add(N)}var H=0;!this.initialAnim||t.globals.resized||t.globals.dataChanged||(H=t.config.chart.animations.speed),t.globals.dataChanged&&(H=t.config.chart.animations.dynamicAnimation.speed),this.animDur=H/(1.2*e.series.length)+this.animDur,this.animBeginArr.push(this.animDur),this.animatePaths(T,{centerX:e.centerX,centerY:e.centerY,endAngle:M,startAngle:_,prevEndAngle:S,prevStartAngle:w,size:e.size,i:m,totalItems:2,animBeginArr:this.animBeginArr,dur:H,shouldSetPrevPaths:!0,easing:t.globals.easing})}return{g:a,elHollow:u,dataLabels:f}}},{key:"drawHollow",value:function(e){var t=new b(this.ctx).drawCircle(2*e.size);return t.attr({class:"apexcharts-radialbar-hollow",cx:e.centerX,cy:e.centerY,r:e.size,fill:e.fill}),t}},{key:"drawHollowImage",value:function(e,t,i,n){var r=this.w,a=new j(this.ctx),s=g.randomId(),o=r.config.plotOptions.radialBar.hollow.image;if(r.config.plotOptions.radialBar.hollow.imageClipped)a.clippedImgArea({width:i,height:i,image:o,patternID:"pattern".concat(r.globals.cuid).concat(s)}),n="url(#pattern".concat(r.globals.cuid).concat(s,")");else{var l=r.config.plotOptions.radialBar.hollow.imageWidth,c=r.config.plotOptions.radialBar.hollow.imageHeight;if(void 0===l&&void 0===c){var u=r.globals.dom.Paper.image(o).loaded((function(t){this.move(e.centerX-t.width/2+r.config.plotOptions.radialBar.hollow.imageOffsetX,e.centerY-t.height/2+r.config.plotOptions.radialBar.hollow.imageOffsetY)}));t.add(u)}else{var d=r.globals.dom.Paper.image(o).loaded((function(t){this.move(e.centerX-l/2+r.config.plotOptions.radialBar.hollow.imageOffsetX,e.centerY-c/2+r.config.plotOptions.radialBar.hollow.imageOffsetY),this.size(l,c)}));t.add(d)}}return n}},{key:"getStrokeWidth",value:function(e){var t=this.w;return e.size*(100-parseInt(t.config.plotOptions.radialBar.hollow.size,10))/100/(e.series.length+1)-this.margin}},{key:"onBarLabelClick",value:function(e){var t=parseInt(e.target.getAttribute("rel"),10)-1,i=this.barLabels.onClick,n=this.w;i&&i(n.globals.seriesNames[t],{w:n,seriesIndex:t})}}]),i}(Ae),Ce=function(e){o(r,e);var i=d(r);function r(){return n(this,r),i.apply(this,arguments)}return a(r,[{key:"draw",value:function(e,i){var n=this.w,r=new b(this.ctx);this.rangeBarOptions=this.w.config.plotOptions.rangeBar,this.series=e,this.seriesRangeStart=n.globals.seriesRangeStart,this.seriesRangeEnd=n.globals.seriesRangeEnd,this.barHelpers.initVariables(e);for(var a=r.group({class:"apexcharts-rangebar-series apexcharts-plot-series"}),o=0;o<e.length;o++){var l,c,u,d,h=void 0,f=void 0,p=n.globals.comboCharts?i[o]:o,m=this.barHelpers.getGroupIndex(p).columnGroupIndex,v=r.group({class:"apexcharts-series",seriesName:g.escapeString(n.globals.seriesNames[p]),rel:o+1,"data:realIndex":p});this.ctx.series.addCollapsedClassToSeries(v,p),e[o].length>0&&(this.visibleI=this.visibleI+1);var y=0,x=0,_=0;this.yRatio.length>1&&(this.yaxisIndex=n.globals.seriesYAxisReverseMap[p][0],_=p);var w=this.barHelpers.initialPositions();f=w.y,d=w.zeroW,h=w.x,x=w.barWidth,y=w.barHeight,l=w.xDivision,c=w.yDivision,u=w.zeroH;for(var k=r.group({class:"apexcharts-datalabels","data:realIndex":p}),M=r.group({class:"apexcharts-rangebar-goals-markers"}),S=0;S<n.globals.dataPoints;S++){var A,L=this.barHelpers.getStrokeWidth(o,S,p),T=this.seriesRangeStart[o][S],C=this.seriesRangeEnd[o][S],D=null,E=null,O=null,P={x:h,y:f,strokeWidth:L,elSeries:v},Y=this.seriesLen;if(n.config.plotOptions.bar.rangeBarGroupRows&&(Y=1),void 0===n.config.series[o].data[S])break;if(this.isHorizontal){O=f+y*this.visibleI;var I=(c-y*Y)/2;if(n.config.series[o].data[S].x){var N=this.detectOverlappingBars({i:o,j:S,barYPosition:O,srty:I,barHeight:y,yDivision:c,initPositions:w});y=N.barHeight,O=N.barYPosition}x=(D=this.drawRangeBarPaths(t({indexes:{i:o,j:S,realIndex:p},barHeight:y,barYPosition:O,zeroW:d,yDivision:c,y1:T,y2:C},P))).barWidth}else{n.globals.isXNumeric&&(h=(n.globals.seriesX[o][S]-n.globals.minX)/this.xRatio-x/2),E=h+x*this.visibleI;var j=(l-x*Y)/2;if(n.config.series[o].data[S].x){var H=this.detectOverlappingBars({i:o,j:S,barXPosition:E,srtx:j,barWidth:x,xDivision:l,initPositions:w});x=H.barWidth,E=H.barXPosition}y=(D=this.drawRangeColumnPaths(t({indexes:{i:o,j:S,realIndex:p,translationsIndex:_},barWidth:x,barXPosition:E,zeroH:u,xDivision:l},P))).barHeight}var F=this.barHelpers.drawGoalLine({barXPosition:D.barXPosition,barYPosition:O,goalX:D.goalX,goalY:D.goalY,barHeight:y,barWidth:x});F&&M.add(F),f=D.y,h=D.x;var R=this.barHelpers.getPathFillColor(e,o,S,p),z=n.globals.stroke.colors[p];this.renderSeries((s(A={realIndex:p,pathFill:R,lineFill:z,j:S,i:o,x:h,y:f,y1:T,y2:C,pathFrom:D.pathFrom,pathTo:D.pathTo,strokeWidth:L,elSeries:v,series:e,barHeight:y,barWidth:x,barXPosition:E,barYPosition:O},"barWidth",x),s(A,"columnGroupIndex",m),s(A,"elDataLabelsWrap",k),s(A,"elGoalsMarkers",M),s(A,"visibleSeries",this.visibleI),s(A,"type","rangebar"),A))}a.add(v)}return a}},{key:"detectOverlappingBars",value:function(e){var t=e.i,i=e.j,n=e.barYPosition,r=e.barXPosition,a=e.srty,s=e.srtx,o=e.barHeight,l=e.barWidth,c=e.yDivision,u=e.xDivision,d=e.initPositions,h=this.w,f=[],p=h.config.series[t].data[i].rangeName,m=h.config.series[t].data[i].x,g=Array.isArray(m)?m.join(" "):m,v=h.globals.labels.map((function(e){return Array.isArray(e)?e.join(" "):e})).indexOf(g),y=h.globals.seriesRange[t].findIndex((function(e){return e.x===g&&e.overlaps.length>0}));return this.isHorizontal?(n=h.config.plotOptions.bar.rangeBarGroupRows?a+c*v:a+o*this.visibleI+c*v,y>-1&&!h.config.plotOptions.bar.rangeBarOverlap&&(f=h.globals.seriesRange[t][y].overlaps).indexOf(p)>-1&&(n=(o=d.barHeight/f.length)*this.visibleI+c*(100-parseInt(this.barOptions.barHeight,10))/100/2+o*(this.visibleI+f.indexOf(p))+c*v)):(v>-1&&!h.globals.timescaleLabels.length&&(r=h.config.plotOptions.bar.rangeBarGroupRows?s+u*v:s+l*this.visibleI+u*v),y>-1&&!h.config.plotOptions.bar.rangeBarOverlap&&(f=h.globals.seriesRange[t][y].overlaps).indexOf(p)>-1&&(r=(l=d.barWidth/f.length)*this.visibleI+u*(100-parseInt(this.barOptions.barWidth,10))/100/2+l*(this.visibleI+f.indexOf(p))+u*v)),{barYPosition:n,barXPosition:r,barHeight:o,barWidth:l}}},{key:"drawRangeColumnPaths",value:function(e){var t=e.indexes,i=e.x,n=e.xDivision,r=e.barWidth,a=e.barXPosition,s=e.zeroH,o=this.w,l=t.i,c=t.j,u=t.realIndex,d=t.translationsIndex,h=this.yRatio[d],f=this.getRangeValue(u,c),p=Math.min(f.start,f.end),m=Math.max(f.start,f.end);void 0===this.series[l][c]||null===this.series[l][c]?p=s:(p=s-p/h,m=s-m/h);var g=Math.abs(m-p),v=this.barHelpers.getColumnPaths({barXPosition:a,barWidth:r,y1:p,y2:m,strokeWidth:this.strokeWidth,series:this.seriesRangeEnd,realIndex:u,i:u,j:c,w:o});if(o.globals.isXNumeric){var y=this.getBarXForNumericXAxis({x:i,j:c,realIndex:u,barWidth:r});i=y.x,a=y.barXPosition}else i+=n;return{pathTo:v.pathTo,pathFrom:v.pathFrom,barHeight:g,x:i,y:f.start<0&&f.end<0?p:m,goalY:this.barHelpers.getGoalValues("y",null,s,l,c,d),barXPosition:a}}},{key:"drawRangeBarPaths",value:function(e){var t=e.indexes,i=e.y,n=e.y1,r=e.y2,a=e.yDivision,s=e.barHeight,o=e.barYPosition,l=e.zeroW,c=this.w,u=t.realIndex,d=t.j,h=l+n/this.invertedYRatio,f=l+r/this.invertedYRatio,p=this.getRangeValue(u,d),m=Math.abs(f-h),g=this.barHelpers.getBarpaths({barYPosition:o,barHeight:s,x1:h,x2:f,strokeWidth:this.strokeWidth,series:this.seriesRangeEnd,i:u,realIndex:u,j:d,w:c});return c.globals.isXNumeric||(i+=a),{pathTo:g.pathTo,pathFrom:g.pathFrom,barWidth:m,x:p.start<0&&p.end<0?h:f,goalX:this.barHelpers.getGoalValues("x",l,null,u,d),y:i}}},{key:"getRangeValue",value:function(e,t){var i=this.w;return{start:i.globals.seriesRangeStart[e][t],end:i.globals.seriesRangeEnd[e][t]}}}]),r}(xe),De=function(){function e(t){n(this,e),this.w=t.w,this.lineCtx=t}return a(e,[{key:"sameValueSeriesFix",value:function(e,t){var i=this.w;if(("gradient"===i.config.fill.type||"gradient"===i.config.fill.type[e])&&new x(this.lineCtx.ctx,i).seriesHaveSameValues(e)){var n=t[e].slice();n[n.length-1]=n[n.length-1]+1e-6,t[e]=n}return t}},{key:"calculatePoints",value:function(e){var t=e.series,i=e.realIndex,n=e.x,r=e.y,a=e.i,s=e.j,o=e.prevY,l=this.w,c=[],u=[];if(0===s){var d=this.lineCtx.categoryAxisCorrection+l.config.markers.offsetX;l.globals.isXNumeric&&(d=(l.globals.seriesX[i][0]-l.globals.minX)/this.lineCtx.xRatio+l.config.markers.offsetX),c.push(d),u.push(g.isNumber(t[a][0])?o+l.config.markers.offsetY:null),c.push(n+l.config.markers.offsetX),u.push(g.isNumber(t[a][s+1])?r+l.config.markers.offsetY:null)}else c.push(n+l.config.markers.offsetX),u.push(g.isNumber(t[a][s+1])?r+l.config.markers.offsetY:null);return{x:c,y:u}}},{key:"checkPreviousPaths",value:function(e){for(var t=e.pathFromLine,i=e.pathFromArea,n=e.realIndex,r=this.w,a=0;a<r.globals.previousPaths.length;a++){var s=r.globals.previousPaths[a];("line"===s.type||"area"===s.type)&&s.paths.length>0&&parseInt(s.realIndex,10)===parseInt(n,10)&&("line"===s.type?(this.lineCtx.appendPathFrom=!1,t=r.globals.previousPaths[a].paths[0].d):"area"===s.type&&(this.lineCtx.appendPathFrom=!1,i=r.globals.previousPaths[a].paths[0].d,r.config.stroke.show&&r.globals.previousPaths[a].paths[1]&&(t=r.globals.previousPaths[a].paths[1].d)))}return{pathFromLine:t,pathFromArea:i}}},{key:"determineFirstPrevY",value:function(e){var t,i,n,r=e.i,a=e.realIndex,s=e.series,o=e.prevY,l=e.lineYPosition,c=e.translationsIndex,u=this.w,d=u.config.chart.stacked&&!u.globals.comboCharts||u.config.chart.stacked&&u.globals.comboCharts&&(!this.w.config.chart.stackOnlyBar||"bar"===(null===(t=this.w.config.series[a])||void 0===t?void 0:t.type)||"column"===(null===(i=this.w.config.series[a])||void 0===i?void 0:i.type));if(void 0!==(null===(n=s[r])||void 0===n?void 0:n[0]))o=(l=d&&r>0?this.lineCtx.prevSeriesY[r-1][0]:this.lineCtx.zeroY)-s[r][0]/this.lineCtx.yRatio[c]+2*(this.lineCtx.isReversed?s[r][0]/this.lineCtx.yRatio[c]:0);else if(d&&r>0&&void 0===s[r][0])for(var h=r-1;h>=0;h--)if(null!==s[h][0]&&void 0!==s[h][0]){o=l=this.lineCtx.prevSeriesY[h][0];break}return{prevY:o,lineYPosition:l}}}]),e}(),Ee=function(e){var t=function(e){for(var t,i,n,r,a=function(e){for(var t=[],i=e[0],n=e[1],r=t[0]=Pe(i,n),a=1,s=e.length-1;a<s;a++)i=n,n=e[a+1],t[a]=.5*(r+(r=Pe(i,n)));return t[a]=r,t}(e),s=e.length-1,o=[],l=0;l<s;l++)n=Pe(e[l],e[l+1]),Math.abs(n)<1e-6?a[l]=a[l+1]=0:(r=(t=a[l]/n)*t+(i=a[l+1]/n)*i)>9&&(r=3*n/Math.sqrt(r),a[l]=r*t,a[l+1]=r*i);for(var c=0;c<=s;c++)r=(e[Math.min(s,c+1)][0]-e[Math.max(0,c-1)][0])/(6*(1+a[c]*a[c])),o.push([r||0,a[c]*r||0]);return o}(e),i=e[1],n=e[0],r=[],a=t[1],s=t[0];r.push(n,[n[0]+s[0],n[1]+s[1],i[0]-a[0],i[1]-a[1],i[0],i[1]]);for(var o=2,l=t.length;o<l;o++){var c=e[o],u=t[o];r.push([c[0]-u[0],c[1]-u[1],c[0],c[1]])}return r},Oe=function(e,t,i){var n=e.slice(t,i);if(t){if(i-t>1&&n[1].length<6){var r=n[0].length;n[1]=[2*n[0][r-2]-n[0][r-4],2*n[0][r-1]-n[0][r-3]].concat(n[1])}n[0]=n[0].slice(-2)}return n};function Pe(e,t){return(t[1]-e[1])/(t[0]-e[0])}var Ye=function(){function e(t,i,r){n(this,e),this.ctx=t,this.w=t.w,this.xyRatios=i,this.pointsChart=!("bubble"!==this.w.config.chart.type&&"scatter"!==this.w.config.chart.type)||r,this.scatter=new F(this.ctx),this.noNegatives=this.w.globals.minX===Number.MAX_VALUE,this.lineHelpers=new De(this),this.markers=new H(this.ctx),this.prevSeriesY=[],this.categoryAxisCorrection=0,this.yaxisIndex=0}return a(e,[{key:"draw",value:function(e,i,n,r){var a,s=this.w,o=new b(this.ctx),l=s.globals.comboCharts?i:s.config.chart.type,c=o.group({class:"apexcharts-".concat(l,"-series apexcharts-plot-series")}),u=new x(this.ctx,s);this.yRatio=this.xyRatios.yRatio,this.zRatio=this.xyRatios.zRatio,this.xRatio=this.xyRatios.xRatio,this.baseLineY=this.xyRatios.baseLineY,e=u.getLogSeries(e),this.yRatio=u.getLogYRatios(this.yRatio),this.prevSeriesY=[];for(var d=[],h=0;h<e.length;h++){e=this.lineHelpers.sameValueSeriesFix(h,e);var f=s.globals.comboCharts?n[h]:h,p=this.yRatio.length>1?f:0;this._initSerieVariables(e,h,f);var m=[],g=[],v=[],y=s.globals.padHorizontal+this.categoryAxisCorrection;this.ctx.series.addCollapsedClassToSeries(this.elSeries,f),s.globals.isXNumeric&&s.globals.seriesX.length>0&&(y=(s.globals.seriesX[f][0]-s.globals.minX)/this.xRatio),v.push(y);var _,w=y,k=void 0,M=w,S=this.zeroY,A=this.zeroY;S=this.lineHelpers.determineFirstPrevY({i:h,realIndex:f,series:e,prevY:S,lineYPosition:0,translationsIndex:p}).prevY,"monotoneCubic"===s.config.stroke.curve&&null===e[h][0]?m.push(null):m.push(S),_=S,"rangeArea"===l&&(k=A=this.lineHelpers.determineFirstPrevY({i:h,realIndex:f,series:r,prevY:A,lineYPosition:0,translationsIndex:p}).prevY,g.push(null!==m[0]?A:null));var L=this._calculatePathsFrom({type:l,series:e,i:h,realIndex:f,translationsIndex:p,prevX:M,prevY:S,prevY2:A}),T=[m[0]],C=[g[0]],D={type:l,series:e,realIndex:f,translationsIndex:p,i:h,x:y,y:1,pX:w,pY:_,pathsFrom:L,linePaths:[],areaPaths:[],seriesIndex:n,lineYPosition:0,xArrj:v,yArrj:m,y2Arrj:g,seriesRangeEnd:r},E=this._iterateOverDataPoints(t(t({},D),{},{iterations:"rangeArea"===l?e[h].length-1:void 0,isRangeStart:!0}));if("rangeArea"===l){for(var O=this._calculatePathsFrom({series:r,i:h,realIndex:f,prevX:M,prevY:A}),P=this._iterateOverDataPoints(t(t({},D),{},{series:r,xArrj:[y],yArrj:T,y2Arrj:C,pY:k,areaPaths:E.areaPaths,pathsFrom:O,iterations:r[h].length-1,isRangeStart:!1})),Y=E.linePaths.length/2,I=0;I<Y;I++)E.linePaths[I]=P.linePaths[I+Y]+E.linePaths[I];E.linePaths.splice(Y),E.pathFromLine=P.pathFromLine+E.pathFromLine}else E.pathFromArea+=o.line(0,this.zeroY);this._handlePaths({type:l,realIndex:f,i:h,paths:E}),this.elSeries.add(this.elPointsMain),this.elSeries.add(this.elDataLabelsWrap),d.push(this.elSeries)}if(void 0!==(null===(a=s.config.series[0])||void 0===a?void 0:a.zIndex)&&d.sort((function(e,t){return Number(e.node.getAttribute("zIndex"))-Number(t.node.getAttribute("zIndex"))})),s.config.chart.stacked)for(var N=d.length-1;N>=0;N--)c.add(d[N]);else for(var j=0;j<d.length;j++)c.add(d[j]);return c}},{key:"_initSerieVariables",value:function(e,t,i){var n=this.w,r=new b(this.ctx);this.xDivision=n.globals.gridWidth/(n.globals.dataPoints-("on"===n.config.xaxis.tickPlacement?1:0)),this.strokeWidth=Array.isArray(n.config.stroke.width)?n.config.stroke.width[i]:n.config.stroke.width;var a=0;this.yRatio.length>1&&(this.yaxisIndex=n.globals.seriesYAxisReverseMap[i],a=i),this.isReversed=n.config.yaxis[this.yaxisIndex]&&n.config.yaxis[this.yaxisIndex].reversed,this.zeroY=n.globals.gridHeight-this.baseLineY[a]-(this.isReversed?n.globals.gridHeight:0)+(this.isReversed?2*this.baseLineY[a]:0),this.areaBottomY=this.zeroY,(this.zeroY>n.globals.gridHeight||"end"===n.config.plotOptions.area.fillTo)&&(this.areaBottomY=n.globals.gridHeight),this.categoryAxisCorrection=this.xDivision/2,this.elSeries=r.group({class:"apexcharts-series",zIndex:void 0!==n.config.series[i].zIndex?n.config.series[i].zIndex:i,seriesName:g.escapeString(n.globals.seriesNames[i])}),this.elPointsMain=r.group({class:"apexcharts-series-markers-wrap","data:realIndex":i}),this.elDataLabelsWrap=r.group({class:"apexcharts-datalabels","data:realIndex":i});var s=e[t].length===n.globals.dataPoints;this.elSeries.attr({"data:longestSeries":s,rel:t+1,"data:realIndex":i}),this.appendPathFrom=!0}},{key:"_calculatePathsFrom",value:function(e){var t,i,n,r,a=e.type,s=e.series,o=e.i,l=e.realIndex,c=e.translationsIndex,u=e.prevX,d=e.prevY,h=e.prevY2,f=this.w,p=new b(this.ctx);if(null===s[o][0]){for(var m=0;m<s[o].length;m++)if(null!==s[o][m]){u=this.xDivision*m,d=this.zeroY-s[o][m]/this.yRatio[c],t=p.move(u,d),i=p.move(u,this.areaBottomY);break}}else t=p.move(u,d),"rangeArea"===a&&(t=p.move(u,h)+p.line(u,d)),i=p.move(u,this.areaBottomY)+p.line(u,d);if(n=p.move(0,this.zeroY)+p.line(0,this.zeroY),r=p.move(0,this.zeroY)+p.line(0,this.zeroY),f.globals.previousPaths.length>0){var g=this.lineHelpers.checkPreviousPaths({pathFromLine:n,pathFromArea:r,realIndex:l});n=g.pathFromLine,r=g.pathFromArea}return{prevX:u,prevY:d,linePath:t,areaPath:i,pathFromLine:n,pathFromArea:r}}},{key:"_handlePaths",value:function(e){var i=e.type,n=e.realIndex,r=e.i,a=e.paths,s=this.w,o=new b(this.ctx),l=new j(this.ctx);this.prevSeriesY.push(a.yArrj),s.globals.seriesXvalues[n]=a.xArrj,s.globals.seriesYvalues[n]=a.yArrj;var c=s.config.forecastDataPoints;if(c.count>0&&"rangeArea"!==i){var u=s.globals.seriesXvalues[n][s.globals.seriesXvalues[n].length-c.count-1],d=o.drawRect(u,0,s.globals.gridWidth,s.globals.gridHeight,0);s.globals.dom.elForecastMask.appendChild(d.node);var h=o.drawRect(0,0,u,s.globals.gridHeight,0);s.globals.dom.elNonForecastMask.appendChild(h.node)}this.pointsChart||s.globals.delayedElements.push({el:this.elPointsMain.node,index:n});var f={i:r,realIndex:n,animationDelay:r,initialSpeed:s.config.chart.animations.speed,dataChangeSpeed:s.config.chart.animations.dynamicAnimation.speed,className:"apexcharts-".concat(i)};if("area"===i)for(var p=l.fillPath({seriesNumber:n}),m=0;m<a.areaPaths.length;m++){var g=o.renderPaths(t(t({},f),{},{pathFrom:a.pathFromArea,pathTo:a.areaPaths[m],stroke:"none",strokeWidth:0,strokeLineCap:null,fill:p}));this.elSeries.add(g)}if(s.config.stroke.show&&!this.pointsChart){var v=null;if("line"===i)v=l.fillPath({seriesNumber:n,i:r});else if("solid"===s.config.stroke.fill.type)v=s.globals.stroke.colors[n];else{var y=s.config.fill;s.config.fill=s.config.stroke.fill,v=l.fillPath({seriesNumber:n,i:r}),s.config.fill=y}for(var x=0;x<a.linePaths.length;x++){var _=v;"rangeArea"===i&&(_=l.fillPath({seriesNumber:n}));var w=t(t({},f),{},{pathFrom:a.pathFromLine,pathTo:a.linePaths[x],stroke:v,strokeWidth:this.strokeWidth,strokeLineCap:s.config.stroke.lineCap,fill:"rangeArea"===i?_:"none"}),k=o.renderPaths(w);if(this.elSeries.add(k),k.attr("fill-rule","evenodd"),c.count>0&&"rangeArea"!==i){var M=o.renderPaths(w);M.node.setAttribute("stroke-dasharray",c.dashArray),c.strokeWidth&&M.node.setAttribute("stroke-width",c.strokeWidth),this.elSeries.add(M),M.attr("clip-path","url(#forecastMask".concat(s.globals.cuid,")")),k.attr("clip-path","url(#nonForecastMask".concat(s.globals.cuid,")"))}}}}},{key:"_iterateOverDataPoints",value:function(e){var t,i,n=this,r=e.type,a=e.series,s=e.iterations,o=e.realIndex,l=e.translationsIndex,c=e.i,u=e.x,d=e.y,h=e.pX,f=e.pY,p=e.pathsFrom,m=e.linePaths,v=e.areaPaths,y=e.seriesIndex,x=e.lineYPosition,_=e.xArrj,w=e.yArrj,k=e.y2Arrj,M=e.isRangeStart,S=e.seriesRangeEnd,A=this.w,L=new b(this.ctx),T=this.yRatio,C=p.prevY,D=p.linePath,E=p.areaPath,O=p.pathFromLine,P=p.pathFromArea,Y=g.isNumber(A.globals.minYArr[o])?A.globals.minYArr[o]:A.globals.minY;s||(s=A.globals.dataPoints>1?A.globals.dataPoints-1:A.globals.dataPoints);var I=function(e,t){return t-e/T[l]+2*(n.isReversed?e/T[l]:0)},N=d,j=A.config.chart.stacked&&!A.globals.comboCharts||A.config.chart.stacked&&A.globals.comboCharts&&(!this.w.config.chart.stackOnlyBar||"bar"===(null===(t=this.w.config.series[o])||void 0===t?void 0:t.type)||"column"===(null===(i=this.w.config.series[o])||void 0===i?void 0:i.type)),H=A.config.stroke.curve;Array.isArray(H)&&(H=Array.isArray(y)?H[y[c]]:H[c]);for(var F,R=0,z=0;z<s;z++){var B=void 0===a[c][z+1]||null===a[c][z+1];if(A.globals.isXNumeric){var V=A.globals.seriesX[o][z+1];void 0===A.globals.seriesX[o][z+1]&&(V=A.globals.seriesX[o][s-1]),u=(V-A.globals.minX)/this.xRatio}else u+=this.xDivision;x=j&&c>0&&A.globals.collapsedSeries.length<A.config.series.length-1?this.prevSeriesY[function(e){for(var t=e;t>0;t--){if(!(A.globals.collapsedSeriesIndices.indexOf((null==y?void 0:y[t])||t)>-1))return t;t--}return 0}(c-1)][z+1]:this.zeroY,B?d=I(Y,x):(d=I(a[c][z+1],x),"rangeArea"===r&&(N=I(S[c][z+1],x))),_.push(u),!B||"smooth"!==A.config.stroke.curve&&"monotoneCubic"!==A.config.stroke.curve?(w.push(d),k.push(N)):(w.push(null),k.push(null));var W=this.lineHelpers.calculatePoints({series:a,x:u,y:d,realIndex:o,i:c,j:z,prevY:C}),U=this._createPaths({type:r,series:a,i:c,realIndex:o,j:z,x:u,y:d,y2:N,xArrj:_,yArrj:w,y2Arrj:k,pX:h,pY:f,pathState:R,segmentStartX:F,linePath:D,areaPath:E,linePaths:m,areaPaths:v,curve:H,isRangeStart:M});v=U.areaPaths,m=U.linePaths,h=U.pX,f=U.pY,R=U.pathState,F=U.segmentStartX,E=U.areaPath,D=U.linePath,!this.appendPathFrom||"monotoneCubic"===H&&"rangeArea"===r||(O+=L.line(u,this.zeroY),P+=L.line(u,this.zeroY)),this.handleNullDataPoints(a,W,c,z,o),this._handleMarkersAndLabels({type:r,pointsPos:W,i:c,j:z,realIndex:o,isRangeStart:M})}return{yArrj:w,xArrj:_,pathFromArea:P,areaPaths:v,pathFromLine:O,linePaths:m,linePath:D,areaPath:E}}},{key:"_handleMarkersAndLabels",value:function(e){var t=e.type,i=e.pointsPos,n=e.isRangeStart,r=e.i,a=e.j,s=e.realIndex,o=this.w,l=new R(this.ctx);if(this.pointsChart)this.scatter.draw(this.elSeries,a,{realIndex:s,pointsPos:i,zRatio:this.zRatio,elParent:this.elPointsMain});else{o.globals.series[r].length>1&&this.elPointsMain.node.classList.add("apexcharts-element-hidden");var c=this.markers.plotChartMarkers(i,s,a+1);null!==c&&this.elPointsMain.add(c)}var u=l.drawDataLabel({type:t,isRangeStart:n,pos:i,i:s,j:a+1});null!==u&&this.elDataLabelsWrap.add(u)}},{key:"_createPaths",value:function(e){var t=e.type,i=e.series,n=e.i;e.realIndex;var r=e.j,a=e.x,s=e.y,o=e.xArrj,l=e.yArrj,c=e.y2,u=e.y2Arrj,d=e.pX,h=e.pY,f=e.pathState,p=e.segmentStartX,m=e.linePath,g=e.areaPath,v=e.linePaths,y=e.areaPaths,x=e.curve,_=e.isRangeStart;this.w;var w,k=new b(this.ctx),M=this.areaBottomY,S="rangeArea"===t,A="rangeArea"===t&&_;switch(x){case"monotoneCubic":var L=_?l:u;switch(f){case 0:if(null===L[r+1])break;f=1;case 1:if(!(S?o.length===i[n].length:r===i[n].length-2))break;case 2:var T=_?o:o.slice().reverse(),C=_?L:L.slice().reverse(),D=(w=C,T.map((function(e,t){return[e,w[t]]})).filter((function(e){return null!==e[1]}))),E=D.length>1?Ee(D):D,O=[];S&&(A?y=D:O=y.reverse());var P=0,Y=0;if(function(e,t){for(var i=function(e){var t=[],i=0;return e.forEach((function(e){null!==e?i++:i>0&&(t.push(i),i=0)})),i>0&&t.push(i),t}(e),n=[],r=0,a=0;r<i.length;a+=i[r++])n[r]=Oe(t,a,a+i[r]);return n}(C,E).forEach((function(e){P++;var t=function(e){for(var t="",i=0;i<e.length;i++){var n=e[i],r=n.length;r>4?(t+="C".concat(n[0],", ").concat(n[1]),t+=", ".concat(n[2],", ").concat(n[3]),t+=", ".concat(n[4],", ").concat(n[5])):r>2&&(t+="S".concat(n[0],", ").concat(n[1]),t+=", ".concat(n[2],", ").concat(n[3]))}return t}(e),i=Y,n=(Y+=e.length)-1;A?m=k.move(D[i][0],D[i][1])+t:S?m=k.move(O[i][0],O[i][1])+k.line(D[i][0],D[i][1])+t+k.line(O[n][0],O[n][1]):(m=k.move(D[i][0],D[i][1])+t,g=m+k.line(D[n][0],M)+k.line(D[i][0],M)+"z",y.push(g)),v.push(m)})),S&&P>1&&!A){var I=v.slice(P).reverse();v.splice(P),I.forEach((function(e){return v.push(e)}))}f=0}break;case"smooth":var N=.35*(a-d);if(null===i[n][r])f=0;else switch(f){case 0:if(p=d,m=A?k.move(d,u[r])+k.line(d,h):k.move(d,h),g=k.move(d,h),f=1,r<i[n].length-2){var j=k.curve(d+N,h,a-N,s,a,s);m+=j,g+=j;break}case 1:if(null===i[n][r+1])m+=A?k.line(d,c):k.move(d,h),g+=k.line(d,M)+k.line(p,M)+"z",v.push(m),y.push(g);else{var H=k.curve(d+N,h,a-N,s,a,s);m+=H,g+=H,r>=i[n].length-2&&(A&&(m+=k.curve(a,s,a,s,a,c)+k.move(a,c)),g+=k.curve(a,s,a,s,a,M)+k.line(p,M)+"z",v.push(m),y.push(g))}}d=a,h=s;break;default:var F=function(e,t,i){var n=[];switch(e){case"stepline":n=k.line(t,null,"H")+k.line(null,i,"V");break;case"linestep":n=k.line(null,i,"V")+k.line(t,null,"H");break;case"straight":n=k.line(t,i)}return n};if(null===i[n][r])f=0;else switch(f){case 0:if(p=d,m=A?k.move(d,u[r])+k.line(d,h):k.move(d,h),g=k.move(d,h),f=1,r<i[n].length-2){var R=F(x,a,s);m+=R,g+=R;break}case 1:if(null===i[n][r+1])m+=A?k.line(d,c):k.move(d,h),g+=k.line(d,M)+k.line(p,M)+"z",v.push(m),y.push(g);else{var z=F(x,a,s);m+=z,g+=z,r>=i[n].length-2&&(A&&(m+=k.line(a,c)),g+=k.line(a,M)+k.line(p,M)+"z",v.push(m),y.push(g))}}d=a,h=s}return{linePaths:v,areaPaths:y,pX:d,pY:h,pathState:f,segmentStartX:p,linePath:m,areaPath:g}}},{key:"handleNullDataPoints",value:function(e,t,i,n,r){var a=this.w;if(null===e[i][n]&&a.config.markers.showNullDataPoints||1===e[i].length){var s=this.strokeWidth-a.config.markers.strokeWidth/2;s>0||(s=0);var o=this.markers.plotChartMarkers(t,r,n+1,s,!0);null!==o&&this.elPointsMain.add(o)}}}]),e}();window.TreemapSquared={},window.TreemapSquared.generate=function(){function e(t,i,n,r){this.xoffset=t,this.yoffset=i,this.height=r,this.width=n,this.shortestEdge=function(){return Math.min(this.height,this.width)},this.getCoordinates=function(e){var t,i=[],n=this.xoffset,r=this.yoffset,s=a(e)/this.height,o=a(e)/this.width;if(this.width>=this.height)for(t=0;t<e.length;t++)i.push([n,r,n+s,r+e[t]/s]),r+=e[t]/s;else for(t=0;t<e.length;t++)i.push([n,r,n+e[t]/o,r+o]),n+=e[t]/o;return i},this.cutArea=function(t){var i;if(this.width>=this.height){var n=t/this.height,r=this.width-n;i=new e(this.xoffset+n,this.yoffset,r,this.height)}else{var a=t/this.width,s=this.height-a;i=new e(this.xoffset,this.yoffset+a,this.width,s)}return i}}function t(t,n,r,s,o){s=void 0===s?0:s,o=void 0===o?0:o;var l=i(function(e,t){var i,n=[],r=t/a(e);for(i=0;i<e.length;i++)n[i]=e[i]*r;return n}(t,n*r),[],new e(s,o,n,r),[]);return function(e){var t,i,n=[];for(t=0;t<e.length;t++)for(i=0;i<e[t].length;i++)n.push(e[t][i]);return n}(l)}function i(e,t,r,s){var o,l,c;if(0!==e.length)return o=r.shortestEdge(),function(e,t,i){var r;return 0===e.length||((r=e.slice()).push(t),n(e,i)>=n(r,i))}(t,l=e[0],o)?(t.push(l),i(e.slice(1),t,r,s)):(c=r.cutArea(a(t),s),s.push(r.getCoordinates(t)),i(e,[],c,s)),s;s.push(r.getCoordinates(t))}function n(e,t){var i=Math.min.apply(Math,e),n=Math.max.apply(Math,e),r=a(e);return Math.max(Math.pow(t,2)*n/Math.pow(r,2),Math.pow(r,2)/(Math.pow(t,2)*i))}function r(e){return e&&e.constructor===Array}function a(e){var t,i=0;for(t=0;t<e.length;t++)i+=e[t];return i}function s(e){var t,i=0;if(r(e[0]))for(t=0;t<e.length;t++)i+=s(e[t]);else i=a(e);return i}return function e(i,n,a,o,l){o=void 0===o?0:o,l=void 0===l?0:l;var c,u,d=[],h=[];if(r(i[0])){for(u=0;u<i.length;u++)d[u]=s(i[u]);for(c=t(d,n,a,o,l),u=0;u<i.length;u++)h.push(e(i[u],c[u][2]-c[u][0],c[u][3]-c[u][1],c[u][0],c[u][1]))}else h=t(i,n,a,o,l);return h}}();var Ie,Ne,je=function(){function e(t,i){n(this,e),this.ctx=t,this.w=t.w,this.strokeWidth=this.w.config.stroke.width,this.helpers=new ke(t),this.dynamicAnim=this.w.config.chart.animations.dynamicAnimation,this.labels=[]}return a(e,[{key:"draw",value:function(e){var t=this,i=this.w,n=new b(this.ctx),r=new j(this.ctx),a=n.group({class:"apexcharts-treemap"});if(i.globals.noData)return a;var s=[];return e.forEach((function(e){var t=e.map((function(e){return Math.abs(e)}));s.push(t)})),this.negRange=this.helpers.checkColorRange(),i.config.series.forEach((function(e,i){e.data.forEach((function(e){Array.isArray(t.labels[i])||(t.labels[i]=[]),t.labels[i].push(e.x)}))})),window.TreemapSquared.generate(s,i.globals.gridWidth,i.globals.gridHeight).forEach((function(s,o){var l=n.group({class:"apexcharts-series apexcharts-treemap-series",seriesName:g.escapeString(i.globals.seriesNames[o]),rel:o+1,"data:realIndex":o});if(i.config.chart.dropShadow.enabled){var c=i.config.chart.dropShadow;new y(t.ctx).dropShadow(a,c,o)}var u=n.group({class:"apexcharts-data-labels"});s.forEach((function(a,s){var c=a[0],u=a[1],d=a[2],h=a[3],f=n.drawRect(c,u,d-c,h-u,i.config.plotOptions.treemap.borderRadius,"#fff",1,t.strokeWidth,i.config.plotOptions.treemap.useFillColorAsStroke?m:i.globals.stroke.colors[o]);f.attr({cx:c,cy:u,index:o,i:o,j:s,width:d-c,height:h-u});var p=t.helpers.getShadeColor(i.config.chart.type,o,s,t.negRange),m=p.color;void 0!==i.config.series[o].data[s]&&i.config.series[o].data[s].fillColor&&(m=i.config.series[o].data[s].fillColor);var g=r.fillPath({color:m,seriesNumber:o,dataPointIndex:s});f.node.classList.add("apexcharts-treemap-rect"),f.attr({fill:g}),t.helpers.addListeners(f);var v={x:c+(d-c)/2,y:u+(h-u)/2,width:0,height:0},y={x:c,y:u,width:d-c,height:h-u};if(i.config.chart.animations.enabled&&!i.globals.dataChanged){var b=1;i.globals.resized||(b=i.config.chart.animations.speed),t.animateTreemap(f,v,y,b)}if(i.globals.dataChanged){var x=1;t.dynamicAnim.enabled&&i.globals.shouldAnimate&&(x=t.dynamicAnim.speed,i.globals.previousPaths[o]&&i.globals.previousPaths[o][s]&&i.globals.previousPaths[o][s].rect&&(v=i.globals.previousPaths[o][s].rect),t.animateTreemap(f,v,y,x))}var _=t.getFontSize(a),w=i.config.dataLabels.formatter(t.labels[o][s],{value:i.globals.series[o][s],seriesIndex:o,dataPointIndex:s,w:i});"truncate"===i.config.plotOptions.treemap.dataLabels.format&&(_=parseInt(i.config.dataLabels.style.fontSize,10),w=t.truncateLabels(w,_,c,u,d,h));var k=t.helpers.calculateDataLabels({text:w,x:(c+d)/2,y:(u+h)/2+t.strokeWidth/2+_/3,i:o,j:s,colorProps:p,fontSize:_,series:e});i.config.dataLabels.enabled&&k&&t.rotateToFitLabel(k,_,w,c,u,d,h),l.add(f),null!==k&&l.add(k)})),l.add(u),a.add(l)})),a}},{key:"getFontSize",value:function(e){var t,i,n=this.w,r=function e(t){var i,n=0;if(Array.isArray(t[0]))for(i=0;i<t.length;i++)n+=e(t[i]);else for(i=0;i<t.length;i++)n+=t[i].length;return n}(this.labels)/function e(t){var i,n=0;if(Array.isArray(t[0]))for(i=0;i<t.length;i++)n+=e(t[i]);else for(i=0;i<t.length;i++)n+=1;return n}(this.labels);return t=(e[2]-e[0])*(e[3]-e[1]),i=Math.pow(t,.5),Math.min(i/r,parseInt(n.config.dataLabels.style.fontSize,10))}},{key:"rotateToFitLabel",value:function(e,t,i,n,r,a,s){var o=new b(this.ctx),l=o.getTextRects(i,t);if(l.width+this.w.config.stroke.width+5>a-n&&l.width<=s-r){var c=o.rotateAroundCenter(e.node);e.node.setAttribute("transform","rotate(-90 ".concat(c.x," ").concat(c.y,") translate(").concat(l.height/3,")"))}}},{key:"truncateLabels",value:function(e,t,i,n,r,a){var s=new b(this.ctx),o=s.getTextRects(e,t).width+this.w.config.stroke.width+5>r-i&&a-n>r-i?a-n:r-i,l=s.getTextBasedOnMaxWidth({text:e,maxWidth:o,fontSize:t});return e.length!==l.length&&o/t<5?"":l}},{key:"animateTreemap",value:function(e,t,i,n){var r=new v(this.ctx);r.animateRect(e,{x:t.x,y:t.y,width:t.width,height:t.height},{x:i.x,y:i.y,width:i.width,height:i.height},n,(function(){r.animationCompleted(e)}))}}]),e}(),He=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w,this.timeScaleArray=[],this.utc=this.w.config.xaxis.labels.datetimeUTC}return a(e,[{key:"calculateTimeScaleTicks",value:function(e,i){var n=this,r=this.w;if(r.globals.allSeriesCollapsed)return r.globals.labels=[],r.globals.timescaleLabels=[],[];var a=new k(this.ctx),s=(i-e)/864e5;this.determineInterval(s),r.globals.disableZoomIn=!1,r.globals.disableZoomOut=!1,s<.00011574074074074075?r.globals.disableZoomIn=!0:s>5e4&&(r.globals.disableZoomOut=!0);var o=a.getTimeUnitsfromTimestamp(e,i,this.utc),l=r.globals.gridWidth/s,c=l/24,u=c/60,d=u/60,h=Math.floor(24*s),f=Math.floor(1440*s),p=Math.floor(86400*s),m=Math.floor(s),g=Math.floor(s/30),v=Math.floor(s/365),y={minMillisecond:o.minMillisecond,minSecond:o.minSecond,minMinute:o.minMinute,minHour:o.minHour,minDate:o.minDate,minMonth:o.minMonth,minYear:o.minYear},b={firstVal:y,currentMillisecond:y.minMillisecond,currentSecond:y.minSecond,currentMinute:y.minMinute,currentHour:y.minHour,currentMonthDate:y.minDate,currentDate:y.minDate,currentMonth:y.minMonth,currentYear:y.minYear,daysWidthOnXAxis:l,hoursWidthOnXAxis:c,minutesWidthOnXAxis:u,secondsWidthOnXAxis:d,numberOfSeconds:p,numberOfMinutes:f,numberOfHours:h,numberOfDays:m,numberOfMonths:g,numberOfYears:v};switch(this.tickInterval){case"years":this.generateYearScale(b);break;case"months":case"half_year":this.generateMonthScale(b);break;case"months_days":case"months_fortnight":case"days":case"week_days":this.generateDayScale(b);break;case"hours":this.generateHourScale(b);break;case"minutes_fives":case"minutes":this.generateMinuteScale(b);break;case"seconds_tens":case"seconds_fives":case"seconds":this.generateSecondScale(b)}var x=this.timeScaleArray.map((function(e){var i={position:e.position,unit:e.unit,year:e.year,day:e.day?e.day:1,hour:e.hour?e.hour:0,month:e.month+1};return"month"===e.unit?t(t({},i),{},{day:1,value:e.value+1}):"day"===e.unit||"hour"===e.unit?t(t({},i),{},{value:e.value}):"minute"===e.unit?t(t({},i),{},{value:e.value,minute:e.value}):"second"===e.unit?t(t({},i),{},{value:e.value,minute:e.minute,second:e.second}):e}));return x.filter((function(e){var t=1,i=Math.ceil(r.globals.gridWidth/120),a=e.value;void 0!==r.config.xaxis.tickAmount&&(i=r.config.xaxis.tickAmount),x.length>i&&(t=Math.floor(x.length/i));var s=!1,o=!1;switch(n.tickInterval){case"years":"year"===e.unit&&(s=!0);break;case"half_year":t=7,"year"===e.unit&&(s=!0);break;case"months":t=1,"year"===e.unit&&(s=!0);break;case"months_fortnight":t=15,"year"!==e.unit&&"month"!==e.unit||(s=!0),30===a&&(o=!0);break;case"months_days":t=10,"month"===e.unit&&(s=!0),30===a&&(o=!0);break;case"week_days":t=8,"month"===e.unit&&(s=!0);break;case"days":t=1,"month"===e.unit&&(s=!0);break;case"hours":"day"===e.unit&&(s=!0);break;case"minutes_fives":case"seconds_fives":a%5!=0&&(o=!0);break;case"seconds_tens":a%10!=0&&(o=!0)}if("hours"===n.tickInterval||"minutes_fives"===n.tickInterval||"seconds_tens"===n.tickInterval||"seconds_fives"===n.tickInterval){if(!o)return!0}else if((a%t==0||s)&&!o)return!0}))}},{key:"recalcDimensionsBasedOnFormat",value:function(e,t){var i=this.w,n=this.formatDates(e),r=this.removeOverlappingTS(n);i.globals.timescaleLabels=r.slice(),new se(this.ctx).plotCoords()}},{key:"determineInterval",value:function(e){var t=24*e,i=60*t;switch(!0){case e/365>5:this.tickInterval="years";break;case e>800:this.tickInterval="half_year";break;case e>180:this.tickInterval="months";break;case e>90:this.tickInterval="months_fortnight";break;case e>60:this.tickInterval="months_days";break;case e>30:this.tickInterval="week_days";break;case e>2:this.tickInterval="days";break;case t>2.4:this.tickInterval="hours";break;case i>15:this.tickInterval="minutes_fives";break;case i>5:this.tickInterval="minutes";break;case i>1:this.tickInterval="seconds_tens";break;case 60*i>20:this.tickInterval="seconds_fives";break;default:this.tickInterval="seconds"}}},{key:"generateYearScale",value:function(e){var t=e.firstVal,i=e.currentMonth,n=e.currentYear,r=e.daysWidthOnXAxis,a=e.numberOfYears,s=t.minYear,o=0,l=new k(this.ctx),c="year";if(t.minDate>1||t.minMonth>0){var u=l.determineRemainingDaysOfYear(t.minYear,t.minMonth,t.minDate);o=(l.determineDaysOfYear(t.minYear)-u+1)*r,s=t.minYear+1,this.timeScaleArray.push({position:o,value:s,unit:c,year:s,month:g.monthMod(i+1)})}else 1===t.minDate&&0===t.minMonth&&this.timeScaleArray.push({position:o,value:s,unit:c,year:n,month:g.monthMod(i+1)});for(var d=s,h=o,f=0;f<a;f++)d++,h=l.determineDaysOfYear(d-1)*r+h,this.timeScaleArray.push({position:h,value:d,unit:c,year:d,month:1})}},{key:"generateMonthScale",value:function(e){var t=e.firstVal,i=e.currentMonthDate,n=e.currentMonth,r=e.currentYear,a=e.daysWidthOnXAxis,s=e.numberOfMonths,o=n,l=0,c=new k(this.ctx),u="month",d=0;if(t.minDate>1){l=(c.determineDaysOfMonths(n+1,t.minYear)-i+1)*a,o=g.monthMod(n+1);var h=r+d,f=g.monthMod(o),p=o;0===o&&(u="year",p=h,f=1,h+=d+=1),this.timeScaleArray.push({position:l,value:p,unit:u,year:h,month:f})}else this.timeScaleArray.push({position:l,value:o,unit:u,year:r,month:g.monthMod(n)});for(var m=o+1,v=l,y=0,b=1;y<s;y++,b++){0===(m=g.monthMod(m))?(u="year",d+=1):u="month";var x=this._getYear(r,m,d);v=c.determineDaysOfMonths(m,x)*a+v;var _=0===m?x:m;this.timeScaleArray.push({position:v,value:_,unit:u,year:x,month:0===m?1:m}),m++}}},{key:"generateDayScale",value:function(e){var t=e.firstVal,i=e.currentMonth,n=e.currentYear,r=e.hoursWidthOnXAxis,a=e.numberOfDays,s=new k(this.ctx),o="day",l=t.minDate+1,c=l,u=function(e,t,i){return e>s.determineDaysOfMonths(t+1,i)?(c=1,o="month",h=t+=1,t):t},d=(24-t.minHour)*r,h=l,f=u(c,i,n);0===t.minHour&&1===t.minDate?(d=0,h=g.monthMod(t.minMonth),o="month",c=t.minDate):1!==t.minDate&&0===t.minHour&&0===t.minMinute&&(d=0,l=t.minDate,h=l,f=u(c=l,i,n)),this.timeScaleArray.push({position:d,value:h,unit:o,year:this._getYear(n,f,0),month:g.monthMod(f),day:c});for(var p=d,m=0;m<a;m++){o="day",f=u(c+=1,f,this._getYear(n,f,0));var v=this._getYear(n,f,0);p=24*r+p;var y=1===c?g.monthMod(f):c;this.timeScaleArray.push({position:p,value:y,unit:o,year:v,month:g.monthMod(f),day:y})}}},{key:"generateHourScale",value:function(e){var t=e.firstVal,i=e.currentDate,n=e.currentMonth,r=e.currentYear,a=e.minutesWidthOnXAxis,s=e.numberOfHours,o=new k(this.ctx),l="hour",c=function(e,t){return e>o.determineDaysOfMonths(t+1,r)&&(m=1,t+=1),{month:t,date:m}},u=function(e,t){return e>o.determineDaysOfMonths(t+1,r)?t+=1:t},d=60-(t.minMinute+t.minSecond/60),h=d*a,f=t.minHour+1,p=f;60===d&&(h=0,p=f=t.minHour);var m=i;p>=24&&(p=0,m+=1,l="day");var v=c(m,n).month;v=u(m,v),this.timeScaleArray.push({position:h,value:f,unit:l,day:m,hour:p,year:r,month:g.monthMod(v)}),p++;for(var y=h,b=0;b<s;b++){l="hour",p>=24&&(p=0,l="day",v=c(m+=1,v).month,v=u(m,v));var x=this._getYear(r,v,0);y=60*a+y;var _=0===p?m:p;this.timeScaleArray.push({position:y,value:_,unit:l,hour:p,day:m,year:x,month:g.monthMod(v)}),p++}}},{key:"generateMinuteScale",value:function(e){for(var t=e.currentMillisecond,i=e.currentSecond,n=e.currentMinute,r=e.currentHour,a=e.currentDate,s=e.currentMonth,o=e.currentYear,l=e.minutesWidthOnXAxis,c=e.secondsWidthOnXAxis,u=e.numberOfMinutes,d=n+1,h=a,f=s,p=o,m=r,v=(60-i-t/1e3)*c,y=0;y<u;y++)d>=60&&(d=0,24===(m+=1)&&(m=0)),this.timeScaleArray.push({position:v,value:d,unit:"minute",hour:m,minute:d,day:h,year:this._getYear(p,f,0),month:g.monthMod(f)}),v+=l,d++}},{key:"generateSecondScale",value:function(e){for(var t=e.currentMillisecond,i=e.currentSecond,n=e.currentMinute,r=e.currentHour,a=e.currentDate,s=e.currentMonth,o=e.currentYear,l=e.secondsWidthOnXAxis,c=e.numberOfSeconds,u=i+1,d=n,h=a,f=s,p=o,m=r,v=(1e3-t)/1e3*l,y=0;y<c;y++)u>=60&&(u=0,++d>=60&&(d=0,24==++m&&(m=0))),this.timeScaleArray.push({position:v,value:u,unit:"second",hour:m,minute:d,second:u,day:h,year:this._getYear(p,f,0),month:g.monthMod(f)}),v+=l,u++}},{key:"createRawDateString",value:function(e,t){var i=e.year;return 0===e.month&&(e.month=1),i+="-"+("0"+e.month.toString()).slice(-2),"day"===e.unit?i+="day"===e.unit?"-"+("0"+t).slice(-2):"-01":i+="-"+("0"+(e.day?e.day:"1")).slice(-2),"hour"===e.unit?i+="hour"===e.unit?"T"+("0"+t).slice(-2):"T00":i+="T"+("0"+(e.hour?e.hour:"0")).slice(-2),"minute"===e.unit?i+=":"+("0"+t).slice(-2):i+=":"+(e.minute?("0"+e.minute).slice(-2):"00"),"second"===e.unit?i+=":"+("0"+t).slice(-2):i+=":00",this.utc&&(i+=".000Z"),i}},{key:"formatDates",value:function(e){var t=this,i=this.w;return e.map((function(e){var n=e.value.toString(),r=new k(t.ctx),a=t.createRawDateString(e,n),s=r.getDate(r.parseDate(a));if(t.utc||(s=r.getDate(r.parseDateWithTimezone(a))),void 0===i.config.xaxis.labels.format){var o="dd MMM",l=i.config.xaxis.labels.datetimeFormatter;"year"===e.unit&&(o=l.year),"month"===e.unit&&(o=l.month),"day"===e.unit&&(o=l.day),"hour"===e.unit&&(o=l.hour),"minute"===e.unit&&(o=l.minute),"second"===e.unit&&(o=l.second),n=r.formatDate(s,o)}else n=r.formatDate(s,i.config.xaxis.labels.format);return{dateString:a,position:e.position,value:n,unit:e.unit,year:e.year,month:e.month}}))}},{key:"removeOverlappingTS",value:function(e){var t,i=this,n=new b(this.ctx),r=!1;e.length>0&&e[0].value&&e.every((function(t){return t.value.length===e[0].value.length}))&&(r=!0,t=n.getTextRects(e[0].value).width);var a=0,s=e.map((function(s,o){if(o>0&&i.w.config.xaxis.labels.hideOverlappingLabels){var l=r?t:n.getTextRects(e[a].value).width,c=e[a].position;return s.position>c+l+10?(a=o,s):null}return s}));return s.filter((function(e){return null!==e}))}},{key:"_getYear",value:function(e,t,i){return e+Math.floor(t/12)+i}}]),e}(),Fe=function(){function e(t,i){n(this,e),this.ctx=i,this.w=i.w,this.el=t}return a(e,[{key:"setupElements",value:function(){var e=this.w.globals,t=this.w.config,i=t.chart.type;e.axisCharts=["line","area","bar","rangeBar","rangeArea","candlestick","boxPlot","scatter","bubble","radar","heatmap","treemap"].indexOf(i)>-1,e.xyCharts=["line","area","bar","rangeBar","rangeArea","candlestick","boxPlot","scatter","bubble"].indexOf(i)>-1,e.isBarHorizontal=("bar"===t.chart.type||"rangeBar"===t.chart.type||"boxPlot"===t.chart.type)&&t.plotOptions.bar.horizontal,e.chartClass=".apexcharts"+e.chartID,e.dom.baseEl=this.el,e.dom.elWrap=document.createElement("div"),b.setAttrs(e.dom.elWrap,{id:e.chartClass.substring(1),class:"apexcharts-canvas "+e.chartClass.substring(1)}),this.el.appendChild(e.dom.elWrap),e.dom.Paper=new window.SVG.Doc(e.dom.elWrap),e.dom.Paper.attr({class:"apexcharts-svg","xmlns:data":"ApexChartsNS",transform:"translate(".concat(t.chart.offsetX,", ").concat(t.chart.offsetY,")")}),e.dom.Paper.node.style.background="dark"!==t.theme.mode||t.chart.background?t.chart.background:"rgba(0, 0, 0, 0.8)",this.setSVGDimensions(),e.dom.elLegendForeign=document.createElementNS(e.SVGNS,"foreignObject"),b.setAttrs(e.dom.elLegendForeign,{x:0,y:0,width:e.svgWidth,height:e.svgHeight}),e.dom.elLegendWrap=document.createElement("div"),e.dom.elLegendWrap.classList.add("apexcharts-legend"),e.dom.elLegendWrap.setAttribute("xmlns","http://www.w3.org/1999/xhtml"),e.dom.elLegendForeign.appendChild(e.dom.elLegendWrap),e.dom.Paper.node.appendChild(e.dom.elLegendForeign),e.dom.elGraphical=e.dom.Paper.group().attr({class:"apexcharts-inner apexcharts-graphical"}),e.dom.elDefs=e.dom.Paper.defs(),e.dom.Paper.add(e.dom.elGraphical),e.dom.elGraphical.add(e.dom.elDefs)}},{key:"plotChartType",value:function(e,t){var i=this.w,n=i.config,r=i.globals,a={series:[],i:[]},s={series:[],i:[]},o={series:[],i:[]},l={series:[],i:[]},c={series:[],i:[]},u={series:[],i:[]},d={series:[],i:[]},h={series:[],i:[]},p={series:[],seriesRangeEnd:[],i:[]},m=void 0!==n.chart.type?n.chart.type:"line",g=null,v=0;r.series.forEach((function(t,n){var f=e[n].type||m;switch(f){case"column":case"bar":c.series.push(t),c.i.push(n),i.globals.columnSeries=c;break;case"area":s.series.push(t),s.i.push(n);break;case"line":a.series.push(t),a.i.push(n);break;case"scatter":o.series.push(t),o.i.push(n);break;case"bubble":l.series.push(t),l.i.push(n);break;case"candlestick":u.series.push(t),u.i.push(n);break;case"boxPlot":d.series.push(t),d.i.push(n);break;case"rangeBar":h.series.push(t),h.i.push(n);break;case"rangeArea":p.series.push(r.seriesRangeStart[n]),p.seriesRangeEnd.push(r.seriesRangeEnd[n]),p.i.push(n);break;case"heatmap":case"treemap":case"pie":case"donut":case"polarArea":case"radialBar":case"radar":g=f;break;default:console.warn("You have specified an unrecognized series type (",f,").")}m!==f&&"scatter"!==f&&v++})),v>0&&(null!==g&&console.warn("Chart or series type ",g," can not appear with other chart or series types."),c.series.length>0&&n.plotOptions.bar.horizontal&&(v-=c.length,c={series:[],i:[]},i.globals.columnSeries={series:[],i:[]},console.warn("Horizontal bars are not supported in a mixed/combo chart. Please turn off `plotOptions.bar.horizontal`"))),r.comboCharts||(r.comboCharts=v>0);var y=new Ye(this.ctx,t),b=new we(this.ctx,t);this.ctx.pie=new Ae(this.ctx);var _=new Te(this.ctx);this.ctx.rangeBar=new Ce(this.ctx,t);var w=new Le(this.ctx),k=[];if(r.comboCharts){var M,S,A=new x(this.ctx);if(s.series.length>0&&(M=k).push.apply(M,f(A.drawSeriesByGroup(s,r.areaGroups,"area",y))),c.series.length>0)if(i.config.chart.stacked){var L=new _e(this.ctx,t);k.push(L.draw(c.series,c.i))}else this.ctx.bar=new xe(this.ctx,t),k.push(this.ctx.bar.draw(c.series,c.i));if(p.series.length>0&&k.push(y.draw(p.series,"rangeArea",p.i,p.seriesRangeEnd)),a.series.length>0&&(S=k).push.apply(S,f(A.drawSeriesByGroup(a,r.lineGroups,"line",y))),u.series.length>0&&k.push(b.draw(u.series,"candlestick",u.i)),d.series.length>0&&k.push(b.draw(d.series,"boxPlot",d.i)),h.series.length>0&&k.push(this.ctx.rangeBar.draw(h.series,h.i)),o.series.length>0){var T=new Ye(this.ctx,t,!0);k.push(T.draw(o.series,"scatter",o.i))}if(l.series.length>0){var C=new Ye(this.ctx,t,!0);k.push(C.draw(l.series,"bubble",l.i))}}else switch(n.chart.type){case"line":k=y.draw(r.series,"line");break;case"area":k=y.draw(r.series,"area");break;case"bar":n.chart.stacked?k=new _e(this.ctx,t).draw(r.series):(this.ctx.bar=new xe(this.ctx,t),k=this.ctx.bar.draw(r.series));break;case"candlestick":k=new we(this.ctx,t).draw(r.series,"candlestick");break;case"boxPlot":k=new we(this.ctx,t).draw(r.series,n.chart.type);break;case"rangeBar":k=this.ctx.rangeBar.draw(r.series);break;case"rangeArea":k=y.draw(r.seriesRangeStart,"rangeArea",void 0,r.seriesRangeEnd);break;case"heatmap":k=new Me(this.ctx,t).draw(r.series);break;case"treemap":k=new je(this.ctx,t).draw(r.series);break;case"pie":case"donut":case"polarArea":k=this.ctx.pie.draw(r.series);break;case"radialBar":k=_.draw(r.series);break;case"radar":k=w.draw(r.series);break;default:k=y.draw(r.series)}return k}},{key:"setSVGDimensions",value:function(){var e=this.w.globals,t=this.w.config;e.svgWidth=t.chart.width,e.svgHeight=t.chart.height;var i=g.getDimensions(this.el),n=t.chart.width.toString().split(/[0-9]+/g).pop();"%"===n?g.isNumber(i[0])&&(0===i[0].width&&(i=g.getDimensions(this.el.parentNode)),e.svgWidth=i[0]*parseInt(t.chart.width,10)/100):"px"!==n&&""!==n||(e.svgWidth=parseInt(t.chart.width,10));var r=t.chart.height.toString().split(/[0-9]+/g).pop();if("auto"!==e.svgHeight&&""!==e.svgHeight)if("%"===r){var a=g.getDimensions(this.el.parentNode);e.svgHeight=a[1]*parseInt(t.chart.height,10)/100}else e.svgHeight=parseInt(t.chart.height,10);else e.axisCharts?e.svgHeight=e.svgWidth/1.61:e.svgHeight=e.svgWidth/1.2;if(e.svgWidth<0&&(e.svgWidth=0),e.svgHeight<0&&(e.svgHeight=0),b.setAttrs(e.dom.Paper.node,{width:e.svgWidth,height:e.svgHeight}),"%"!==r){var s=t.chart.sparkline.enabled?0:e.axisCharts?t.chart.parentHeightOffset:0;e.dom.Paper.node.parentNode.parentNode.style.minHeight=e.svgHeight+s+"px"}e.dom.elWrap.style.width=e.svgWidth+"px",e.dom.elWrap.style.height=e.svgHeight+"px"}},{key:"shiftGraphPosition",value:function(){var e=this.w.globals,t=e.translateY,i={transform:"translate("+e.translateX+", "+t+")"};b.setAttrs(e.dom.elGraphical.node,i)}},{key:"resizeNonAxisCharts",value:function(){var e=this.w,t=e.globals,i=0,n=e.config.chart.sparkline.enabled?1:15;n+=e.config.grid.padding.bottom,"top"!==e.config.legend.position&&"bottom"!==e.config.legend.position||!e.config.legend.show||e.config.legend.floating||(i=new le(this.ctx).legendHelpers.getLegendBBox().clwh+10);var r=e.globals.dom.baseEl.querySelector(".apexcharts-radialbar, .apexcharts-pie"),a=2.05*e.globals.radialSize;if(r&&!e.config.chart.sparkline.enabled&&0!==e.config.plotOptions.radialBar.startAngle){var s=g.getBoundingClientRect(r);a=s.bottom;var o=s.bottom-s.top;a=Math.max(2.05*e.globals.radialSize,o)}var l=a+t.translateY+i+n;t.dom.elLegendForeign&&t.dom.elLegendForeign.setAttribute("height",l),e.config.chart.height&&String(e.config.chart.height).indexOf("%")>0||(t.dom.elWrap.style.height=l+"px",b.setAttrs(t.dom.Paper.node,{height:l}),t.dom.Paper.node.parentNode.parentNode.style.minHeight=l+"px")}},{key:"coreCalculations",value:function(){new $(this.ctx).init()}},{key:"resetGlobals",value:function(){var e=this,t=function(){return e.w.config.series.map((function(e){return[]}))},i=new I,n=this.w.globals;i.initGlobalVars(n),n.seriesXvalues=t(),n.seriesYvalues=t()}},{key:"isMultipleY",value:function(){if(this.w.config.yaxis.constructor===Array&&this.w.config.yaxis.length>1)return this.w.globals.isMultipleYAxis=!0,!0}},{key:"xySettings",value:function(){var e=null,t=this.w;if(t.globals.axisCharts){if("back"===t.config.xaxis.crosshairs.position&&new J(this.ctx).drawXCrosshairs(),"back"===t.config.yaxis[0].crosshairs.position&&new J(this.ctx).drawYCrosshairs(),"datetime"===t.config.xaxis.type&&void 0===t.config.xaxis.labels.formatter){this.ctx.timeScale=new He(this.ctx);var i=[];isFinite(t.globals.minX)&&isFinite(t.globals.maxX)&&!t.globals.isBarHorizontal?i=this.ctx.timeScale.calculateTimeScaleTicks(t.globals.minX,t.globals.maxX):t.globals.isBarHorizontal&&(i=this.ctx.timeScale.calculateTimeScaleTicks(t.globals.minY,t.globals.maxY)),this.ctx.timeScale.recalcDimensionsBasedOnFormat(i)}e=new x(this.ctx).getCalculatedRatios()}return e}},{key:"updateSourceChart",value:function(e){this.ctx.w.globals.selection=void 0,this.ctx.updateHelpers._updateOptions({chart:{selection:{xaxis:{min:e.w.globals.minX,max:e.w.globals.maxX}}}},!1,!1)}},{key:"setupBrushHandler",value:function(){var e=this,t=this.w;if(t.config.chart.brush.enabled&&"function"!=typeof t.config.chart.events.selection){var i=Array.isArray(t.config.chart.brush.targets)?t.config.chart.brush.targets:[t.config.chart.brush.target];i.forEach((function(t){var i=ApexCharts.getChartByID(t);i.w.globals.brushSource=e.ctx,"function"!=typeof i.w.config.chart.events.zoomed&&(i.w.config.chart.events.zoomed=function(){e.updateSourceChart(i)}),"function"!=typeof i.w.config.chart.events.scrolled&&(i.w.config.chart.events.scrolled=function(){e.updateSourceChart(i)})})),t.config.chart.events.selection=function(e,t){i.forEach((function(e){ApexCharts.getChartByID(e).ctx.updateHelpers._updateOptions({xaxis:{min:t.xaxis.min,max:t.xaxis.max}},!1,!1,!1,!1)}))}}}}]),e}(),Re=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"_updateOptions",value:function(e){var t=this,n=arguments.length>1&&void 0!==arguments[1]&&arguments[1],r=!(arguments.length>2&&void 0!==arguments[2])||arguments[2],a=!(arguments.length>3&&void 0!==arguments[3])||arguments[3],s=arguments.length>4&&void 0!==arguments[4]&&arguments[4];return new Promise((function(o){var l=[t.ctx];a&&(l=t.ctx.getSyncedCharts()),t.ctx.w.globals.isExecCalled&&(l=[t.ctx],t.ctx.w.globals.isExecCalled=!1),l.forEach((function(a,c){var u=a.w;if(u.globals.shouldAnimate=r,n||(u.globals.resized=!0,u.globals.dataChanged=!0,r&&a.series.getPreviousPaths()),e&&"object"===i(e)&&(a.config=new Y(e),e=x.extendArrayProps(a.config,e,u),a.w.globals.chartID!==t.ctx.w.globals.chartID&&delete e.series,u.config=g.extend(u.config,e),s&&(u.globals.lastXAxis=e.xaxis?g.clone(e.xaxis):[],u.globals.lastYAxis=e.yaxis?g.clone(e.yaxis):[],u.globals.initialConfig=g.extend({},u.config),u.globals.initialSeries=g.clone(u.config.series),e.series))){for(var d=0;d<u.globals.collapsedSeriesIndices.length;d++){var h=u.config.series[u.globals.collapsedSeriesIndices[d]];u.globals.collapsedSeries[d].data=u.globals.axisCharts?h.data.slice():h}for(var f=0;f<u.globals.ancillaryCollapsedSeriesIndices.length;f++){var p=u.config.series[u.globals.ancillaryCollapsedSeriesIndices[f]];u.globals.ancillaryCollapsedSeries[f].data=u.globals.axisCharts?p.data.slice():p}a.series.emptyCollapsedSeries(u.config.series)}return a.update(e).then((function(){c===l.length-1&&o(a)}))}))}))}},{key:"_updateSeries",value:function(e,t){var i=this,n=arguments.length>2&&void 0!==arguments[2]&&arguments[2];return new Promise((function(r){var a,s=i.w;return s.globals.shouldAnimate=t,s.globals.dataChanged=!0,t&&i.ctx.series.getPreviousPaths(),s.globals.axisCharts?(0===(a=e.map((function(e,t){return i._extendSeries(e,t)}))).length&&(a=[{data:[]}]),s.config.series=a):s.config.series=e.slice(),n&&(s.globals.initialConfig.series=g.clone(s.config.series),s.globals.initialSeries=g.clone(s.config.series)),i.ctx.update().then((function(){r(i.ctx)}))}))}},{key:"_extendSeries",value:function(e,i){var n=this.w,r=n.config.series[i];return t(t({},n.config.series[i]),{},{name:e.name?e.name:null==r?void 0:r.name,color:e.color?e.color:null==r?void 0:r.color,type:e.type?e.type:null==r?void 0:r.type,group:e.group?e.group:null==r?void 0:r.group,data:e.data?e.data:null==r?void 0:r.data,zIndex:void 0!==e.zIndex?e.zIndex:i})}},{key:"toggleDataPointSelection",value:function(e,t){var i=this.w,n=null,r=".apexcharts-series[data\\:realIndex='".concat(e,"']");return i.globals.axisCharts?n=i.globals.dom.Paper.select("".concat(r," path[j='").concat(t,"'], ").concat(r," circle[j='").concat(t,"'], ").concat(r," rect[j='").concat(t,"']")).members[0]:void 0===t&&(n=i.globals.dom.Paper.select("".concat(r," path[j='").concat(e,"']")).members[0],"pie"!==i.config.chart.type&&"polarArea"!==i.config.chart.type&&"donut"!==i.config.chart.type||this.ctx.pie.pieClicked(e)),n?(new b(this.ctx).pathMouseDown(n,null),n.node?n.node:null):(console.warn("toggleDataPointSelection: Element not found"),null)}},{key:"forceXAxisUpdate",value:function(e){var t=this.w;if(["min","max"].forEach((function(i){void 0!==e.xaxis[i]&&(t.config.xaxis[i]=e.xaxis[i],t.globals.lastXAxis[i]=e.xaxis[i])})),e.xaxis.categories&&e.xaxis.categories.length&&(t.config.xaxis.categories=e.xaxis.categories),t.config.xaxis.convertedCatToNumeric){var i=new P(e);e=i.convertCatToNumericXaxis(e,this.ctx)}return e}},{key:"forceYAxisUpdate",value:function(e){return e.chart&&e.chart.stacked&&"100%"===e.chart.stackType&&(Array.isArray(e.yaxis)?e.yaxis.forEach((function(t,i){e.yaxis[i].min=0,e.yaxis[i].max=100})):(e.yaxis.min=0,e.yaxis.max=100)),e}},{key:"revertDefaultAxisMinMax",value:function(e){var t=this,i=this.w,n=i.globals.lastXAxis,r=i.globals.lastYAxis;e&&e.xaxis&&(n=e.xaxis),e&&e.yaxis&&(r=e.yaxis),i.config.xaxis.min=n.min,i.config.xaxis.max=n.max;i.config.yaxis.map((function(e,n){i.globals.zoomed||void 0!==r[n]?function(e){void 0!==r[e]&&(i.config.yaxis[e].min=r[e].min,i.config.yaxis[e].max=r[e].max)}(n):void 0!==t.ctx.opts.yaxis[n]&&(e.min=t.ctx.opts.yaxis[n].min,e.max=t.ctx.opts.yaxis[n].max)}))}}]),e}();Ie="undefined"!=typeof window?window:void 0,Ne=function(e,t){var n=(void 0!==this?this:e).SVG=function(e){if(n.supported)return e=new n.Doc(e),n.parser.draw||n.prepare(),e};if(n.ns="http://www.w3.org/2000/svg",n.xmlns="http://www.w3.org/2000/xmlns/",n.xlink="http://www.w3.org/1999/xlink",n.svgjs="http://svgjs.dev",n.supported=!0,!n.supported)return!1;n.did=1e3,n.eid=function(e){return"Svgjs"+d(e)+n.did++},n.create=function(e){var i=t.createElementNS(this.ns,e);return i.setAttribute("id",this.eid(e)),i},n.extend=function(){var e,t;t=(e=[].slice.call(arguments)).pop();for(var i=e.length-1;i>=0;i--)if(e[i])for(var r in t)e[i].prototype[r]=t[r];n.Set&&n.Set.inherit&&n.Set.inherit()},n.invent=function(e){var t="function"==typeof e.create?e.create:function(){this.constructor.call(this,n.create(e.create))};return e.inherit&&(t.prototype=new e.inherit),e.extend&&n.extend(t,e.extend),e.construct&&n.extend(e.parent||n.Container,e.construct),t},n.adopt=function(t){return t?t.instance?t.instance:((i="svg"==t.nodeName?t.parentNode instanceof e.SVGElement?new n.Nested:new n.Doc:"linearGradient"==t.nodeName?new n.Gradient("linear"):"radialGradient"==t.nodeName?new n.Gradient("radial"):n[d(t.nodeName)]?new(n[d(t.nodeName)]):new n.Element(t)).type=t.nodeName,i.node=t,t.instance=i,i instanceof n.Doc&&i.namespace().defs(),i.setData(JSON.parse(t.getAttribute("svgjs:data"))||{}),i):null;var i},n.prepare=function(){var e=t.getElementsByTagName("body")[0],i=(e?new n.Doc(e):n.adopt(t.documentElement).nested()).size(2,0);n.parser={body:e||t.documentElement,draw:i.style("opacity:0;position:absolute;left:-100%;top:-100%;overflow:hidden").node,poly:i.polyline().node,path:i.path().node,native:n.create("svg")}},n.parser={native:n.create("svg")},t.addEventListener("DOMContentLoaded",(function(){n.parser.draw||n.prepare()}),!1),n.regex={numberAndUnit:/^([+-]?(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?)([a-z%]*)$/i,hex:/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i,rgb:/rgb\((\d+),(\d+),(\d+)\)/,reference:/#([a-z0-9\-_]+)/i,transforms:/\)\s*,?\s*/,whitespace:/\s/g,isHex:/^#[a-f0-9]{3,6}$/i,isRgb:/^rgb\(/,isCss:/[^:]+:[^;]+;?/,isBlank:/^(\s+)?$/,isNumber:/^[+-]?(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?$/i,isPercent:/^-?[\d\.]+%$/,isImage:/\.(jpg|jpeg|png|gif|svg)(\?[^=]+.*)?/i,delimiter:/[\s,]+/,hyphen:/([^e])\-/gi,pathLetters:/[MLHVCSQTAZ]/gi,isPathLetter:/[MLHVCSQTAZ]/i,numbersWithDots:/((\d?\.\d+(?:e[+-]?\d+)?)((?:\.\d+(?:e[+-]?\d+)?)+))+/gi,dots:/\./g},n.utils={map:function(e,t){for(var i=e.length,n=[],r=0;r<i;r++)n.push(t(e[r]));return n},filter:function(e,t){for(var i=e.length,n=[],r=0;r<i;r++)t(e[r])&&n.push(e[r]);return n},filterSVGElements:function(t){return this.filter(t,(function(t){return t instanceof e.SVGElement}))}},n.defaults={attrs:{"fill-opacity":1,"stroke-opacity":1,"stroke-width":0,"stroke-linejoin":"miter","stroke-linecap":"butt",fill:"#000000",stroke:"#000000",opacity:1,x:0,y:0,cx:0,cy:0,width:0,height:0,r:0,rx:0,ry:0,offset:0,"stop-opacity":1,"stop-color":"#000000","font-size":16,"font-family":"Helvetica, Arial, sans-serif","text-anchor":"start"}},n.Color=function(e){var t,r;this.r=0,this.g=0,this.b=0,e&&("string"==typeof e?n.regex.isRgb.test(e)?(t=n.regex.rgb.exec(e.replace(n.regex.whitespace,"")),this.r=parseInt(t[1]),this.g=parseInt(t[2]),this.b=parseInt(t[3])):n.regex.isHex.test(e)&&(t=n.regex.hex.exec(4==(r=e).length?["#",r.substring(1,2),r.substring(1,2),r.substring(2,3),r.substring(2,3),r.substring(3,4),r.substring(3,4)].join(""):r),this.r=parseInt(t[1],16),this.g=parseInt(t[2],16),this.b=parseInt(t[3],16)):"object"===i(e)&&(this.r=e.r,this.g=e.g,this.b=e.b))},n.extend(n.Color,{toString:function(){return this.toHex()},toHex:function(){return"#"+h(this.r)+h(this.g)+h(this.b)},toRgb:function(){return"rgb("+[this.r,this.g,this.b].join()+")"},brightness:function(){return this.r/255*.3+this.g/255*.59+this.b/255*.11},morph:function(e){return this.destination=new n.Color(e),this},at:function(e){return this.destination?(e=e<0?0:e>1?1:e,new n.Color({r:~~(this.r+(this.destination.r-this.r)*e),g:~~(this.g+(this.destination.g-this.g)*e),b:~~(this.b+(this.destination.b-this.b)*e)})):this}}),n.Color.test=function(e){return e+="",n.regex.isHex.test(e)||n.regex.isRgb.test(e)},n.Color.isRgb=function(e){return e&&"number"==typeof e.r&&"number"==typeof e.g&&"number"==typeof e.b},n.Color.isColor=function(e){return n.Color.isRgb(e)||n.Color.test(e)},n.Array=function(e,t){0==(e=(e||[]).valueOf()).length&&t&&(e=t.valueOf()),this.value=this.parse(e)},n.extend(n.Array,{toString:function(){return this.value.join(" ")},valueOf:function(){return this.value},parse:function(e){return e=e.valueOf(),Array.isArray(e)?e:this.split(e)}}),n.PointArray=function(e,t){n.Array.call(this,e,t||[[0,0]])},n.PointArray.prototype=new n.Array,n.PointArray.prototype.constructor=n.PointArray;for(var r={M:function(e,t,i){return t.x=i.x=e[0],t.y=i.y=e[1],["M",t.x,t.y]},L:function(e,t){return t.x=e[0],t.y=e[1],["L",e[0],e[1]]},H:function(e,t){return t.x=e[0],["H",e[0]]},V:function(e,t){return t.y=e[0],["V",e[0]]},C:function(e,t){return t.x=e[4],t.y=e[5],["C",e[0],e[1],e[2],e[3],e[4],e[5]]},Q:function(e,t){return t.x=e[2],t.y=e[3],["Q",e[0],e[1],e[2],e[3]]},S:function(e,t){return t.x=e[2],t.y=e[3],["S",e[0],e[1],e[2],e[3]]},Z:function(e,t,i){return t.x=i.x,t.y=i.y,["Z"]}},a="mlhvqtcsaz".split(""),s=0,o=a.length;s<o;++s)r[a[s]]=function(e){return function(t,i,n){if("H"==e)t[0]=t[0]+i.x;else if("V"==e)t[0]=t[0]+i.y;else if("A"==e)t[5]=t[5]+i.x,t[6]=t[6]+i.y;else for(var a=0,s=t.length;a<s;++a)t[a]=t[a]+(a%2?i.y:i.x);if(r&&"function"==typeof r[e])return r[e](t,i,n)}}(a[s].toUpperCase());n.PathArray=function(e,t){n.Array.call(this,e,t||[["M",0,0]])},n.PathArray.prototype=new n.Array,n.PathArray.prototype.constructor=n.PathArray,n.extend(n.PathArray,{toString:function(){return function(e){for(var t=0,i=e.length,n="";t<i;t++)n+=e[t][0],null!=e[t][1]&&(n+=e[t][1],null!=e[t][2]&&(n+=" ",n+=e[t][2],null!=e[t][3]&&(n+=" ",n+=e[t][3],n+=" ",n+=e[t][4],null!=e[t][5]&&(n+=" ",n+=e[t][5],n+=" ",n+=e[t][6],null!=e[t][7]&&(n+=" ",n+=e[t][7])))));return n+" "}(this.value)},move:function(e,t){var i=this.bbox();return i.x,i.y,this},at:function(e){if(!this.destination)return this;for(var t=this.value,i=this.destination.value,r=[],a=new n.PathArray,s=0,o=t.length;s<o;s++){r[s]=[t[s][0]];for(var l=1,c=t[s].length;l<c;l++)r[s][l]=t[s][l]+(i[s][l]-t[s][l])*e;"A"===r[s][0]&&(r[s][4]=+(0!=r[s][4]),r[s][5]=+(0!=r[s][5]))}return a.value=r,a},parse:function(e){if(e instanceof n.PathArray)return e.valueOf();var t,i={M:2,L:2,H:1,V:1,C:6,S:4,Q:4,T:2,A:7,Z:0};e="string"==typeof e?e.replace(n.regex.numbersWithDots,c).replace(n.regex.pathLetters," $& ").replace(n.regex.hyphen,"$1 -").trim().split(n.regex.delimiter):e.reduce((function(e,t){return[].concat.call(e,t)}),[]);var a=[],s=new n.Point,o=new n.Point,l=0,u=e.length;do{n.regex.isPathLetter.test(e[l])?(t=e[l],++l):"M"==t?t="L":"m"==t&&(t="l"),a.push(r[t].call(null,e.slice(l,l+=i[t.toUpperCase()]).map(parseFloat),s,o))}while(u>l);return a},bbox:function(){return n.parser.draw||n.prepare(),n.parser.path.setAttribute("d",this.toString()),n.parser.path.getBBox()}}),n.Number=n.invent({create:function(e,t){this.value=0,this.unit=t||"","number"==typeof e?this.value=isNaN(e)?0:isFinite(e)?e:e<0?-34e37:34e37:"string"==typeof e?(t=e.match(n.regex.numberAndUnit))&&(this.value=parseFloat(t[1]),"%"==t[5]?this.value/=100:"s"==t[5]&&(this.value*=1e3),this.unit=t[5]):e instanceof n.Number&&(this.value=e.valueOf(),this.unit=e.unit)},extend:{toString:function(){return("%"==this.unit?~~(1e8*this.value)/1e6:"s"==this.unit?this.value/1e3:this.value)+this.unit},toJSON:function(){return this.toString()},valueOf:function(){return this.value},plus:function(e){return e=new n.Number(e),new n.Number(this+e,this.unit||e.unit)},minus:function(e){return e=new n.Number(e),new n.Number(this-e,this.unit||e.unit)},times:function(e){return e=new n.Number(e),new n.Number(this*e,this.unit||e.unit)},divide:function(e){return e=new n.Number(e),new n.Number(this/e,this.unit||e.unit)},to:function(e){var t=new n.Number(this);return"string"==typeof e&&(t.unit=e),t},morph:function(e){return this.destination=new n.Number(e),e.relative&&(this.destination.value+=this.value),this},at:function(e){return this.destination?new n.Number(this.destination).minus(this).times(e).plus(this):this}}}),n.Element=n.invent({create:function(e){this._stroke=n.defaults.attrs.stroke,this._event=null,this.dom={},(this.node=e)&&(this.type=e.nodeName,this.node.instance=this,this._stroke=e.getAttribute("stroke")||this._stroke)},extend:{x:function(e){return this.attr("x",e)},y:function(e){return this.attr("y",e)},cx:function(e){return null==e?this.x()+this.width()/2:this.x(e-this.width()/2)},cy:function(e){return null==e?this.y()+this.height()/2:this.y(e-this.height()/2)},move:function(e,t){return this.x(e).y(t)},center:function(e,t){return this.cx(e).cy(t)},width:function(e){return this.attr("width",e)},height:function(e){return this.attr("height",e)},size:function(e,t){var i=f(this,e,t);return this.width(new n.Number(i.width)).height(new n.Number(i.height))},clone:function(e){this.writeDataToDom();var t=g(this.node.cloneNode(!0));return e?e.add(t):this.after(t),t},remove:function(){return this.parent()&&this.parent().removeElement(this),this},replace:function(e){return this.after(e).remove(),e},addTo:function(e){return e.put(this)},putIn:function(e){return e.add(this)},id:function(e){return this.attr("id",e)},show:function(){return this.style("display","")},hide:function(){return this.style("display","none")},visible:function(){return"none"!=this.style("display")},toString:function(){return this.attr("id")},classes:function(){var e=this.attr("class");return null==e?[]:e.trim().split(n.regex.delimiter)},hasClass:function(e){return-1!=this.classes().indexOf(e)},addClass:function(e){if(!this.hasClass(e)){var t=this.classes();t.push(e),this.attr("class",t.join(" "))}return this},removeClass:function(e){return this.hasClass(e)&&this.attr("class",this.classes().filter((function(t){return t!=e})).join(" ")),this},toggleClass:function(e){return this.hasClass(e)?this.removeClass(e):this.addClass(e)},reference:function(e){return n.get(this.attr(e))},parent:function(t){var i=this;if(!i.node.parentNode)return null;if(i=n.adopt(i.node.parentNode),!t)return i;for(;i&&i.node instanceof e.SVGElement;){if("string"==typeof t?i.matches(t):i instanceof t)return i;if(!i.node.parentNode||"#document"==i.node.parentNode.nodeName)return null;i=n.adopt(i.node.parentNode)}},doc:function(){return this instanceof n.Doc?this:this.parent(n.Doc)},parents:function(e){var t=[],i=this;do{if(!(i=i.parent(e))||!i.node)break;t.push(i)}while(i.parent);return t},matches:function(e){return function(e,t){return(e.matches||e.matchesSelector||e.msMatchesSelector||e.mozMatchesSelector||e.webkitMatchesSelector||e.oMatchesSelector).call(e,t)}(this.node,e)},native:function(){return this.node},svg:function(e){var i=t.createElementNS("http://www.w3.org/2000/svg","svg");if(!(e&&this instanceof n.Parent))return i.appendChild(e=t.createElementNS("http://www.w3.org/2000/svg","svg")),this.writeDataToDom(),e.appendChild(this.node.cloneNode(!0)),i.innerHTML.replace(/^<svg>/,"").replace(/<\/svg>$/,"");i.innerHTML="<svg>"+e.replace(/\n/,"").replace(/<([\w:-]+)([^<]+?)\/>/g,"<$1$2></$1>")+"</svg>";for(var r=0,a=i.firstChild.childNodes.length;r<a;r++)this.node.appendChild(i.firstChild.firstChild);return this},writeDataToDom:function(){return(this.each||this.lines)&&(this.each?this:this.lines()).each((function(){this.writeDataToDom()})),this.node.removeAttribute("svgjs:data"),Object.keys(this.dom).length&&this.node.setAttribute("svgjs:data",JSON.stringify(this.dom)),this},setData:function(e){return this.dom=e,this},is:function(e){return function(e,t){return e instanceof t}(this,e)}}}),n.easing={"-":function(e){return e},"<>":function(e){return-Math.cos(e*Math.PI)/2+.5},">":function(e){return Math.sin(e*Math.PI/2)},"<":function(e){return 1-Math.cos(e*Math.PI/2)}},n.morph=function(e){return function(t,i){return new n.MorphObj(t,i).at(e)}},n.Situation=n.invent({create:function(e){this.init=!1,this.reversed=!1,this.reversing=!1,this.duration=new n.Number(e.duration).valueOf(),this.delay=new n.Number(e.delay).valueOf(),this.start=+new Date+this.delay,this.finish=this.start+this.duration,this.ease=e.ease,this.loop=0,this.loops=!1,this.animations={},this.attrs={},this.styles={},this.transforms=[],this.once={}}}),n.FX=n.invent({create:function(e){this._target=e,this.situations=[],this.active=!1,this.situation=null,this.paused=!1,this.lastPos=0,this.pos=0,this.absPos=0,this._speed=1},extend:{animate:function(e,t,r){"object"===i(e)&&(t=e.ease,r=e.delay,e=e.duration);var a=new n.Situation({duration:e||1e3,delay:r||0,ease:n.easing[t||"-"]||t});return this.queue(a),this},target:function(e){return e&&e instanceof n.Element?(this._target=e,this):this._target},timeToAbsPos:function(e){return(e-this.situation.start)/(this.situation.duration/this._speed)},absPosToTime:function(e){return this.situation.duration/this._speed*e+this.situation.start},startAnimFrame:function(){this.stopAnimFrame(),this.animationFrame=e.requestAnimationFrame(function(){this.step()}.bind(this))},stopAnimFrame:function(){e.cancelAnimationFrame(this.animationFrame)},start:function(){return!this.active&&this.situation&&(this.active=!0,this.startCurrent()),this},startCurrent:function(){return this.situation.start=+new Date+this.situation.delay/this._speed,this.situation.finish=this.situation.start+this.situation.duration/this._speed,this.initAnimations().step()},queue:function(e){return("function"==typeof e||e instanceof n.Situation)&&this.situations.push(e),this.situation||(this.situation=this.situations.shift()),this},dequeue:function(){return this.stop(),this.situation=this.situations.shift(),this.situation&&(this.situation instanceof n.Situation?this.start():this.situation.call(this)),this},initAnimations:function(){var e,t=this.situation;if(t.init)return this;for(var i in t.animations){e=this.target()[i](),Array.isArray(e)||(e=[e]),Array.isArray(t.animations[i])||(t.animations[i]=[t.animations[i]]);for(var r=e.length;r--;)t.animations[i][r]instanceof n.Number&&(e[r]=new n.Number(e[r])),t.animations[i][r]=e[r].morph(t.animations[i][r])}for(var i in t.attrs)t.attrs[i]=new n.MorphObj(this.target().attr(i),t.attrs[i]);for(var i in t.styles)t.styles[i]=new n.MorphObj(this.target().style(i),t.styles[i]);return t.initialTransformation=this.target().matrixify(),t.init=!0,this},clearQueue:function(){return this.situations=[],this},clearCurrent:function(){return this.situation=null,this},stop:function(e,t){var i=this.active;return this.active=!1,t&&this.clearQueue(),e&&this.situation&&(!i&&this.startCurrent(),this.atEnd()),this.stopAnimFrame(),this.clearCurrent()},after:function(e){var t=this.last();return this.target().on("finished.fx",(function i(n){n.detail.situation==t&&(e.call(this,t),this.off("finished.fx",i))})),this._callStart()},during:function(e){var t=this.last(),i=function(i){i.detail.situation==t&&e.call(this,i.detail.pos,n.morph(i.detail.pos),i.detail.eased,t)};return this.target().off("during.fx",i).on("during.fx",i),this.after((function(){this.off("during.fx",i)})),this._callStart()},afterAll:function(e){var t=function t(i){e.call(this),this.off("allfinished.fx",t)};return this.target().off("allfinished.fx",t).on("allfinished.fx",t),this._callStart()},last:function(){return this.situations.length?this.situations[this.situations.length-1]:this.situation},add:function(e,t,i){return this.last()[i||"animations"][e]=t,this._callStart()},step:function(e){var t,i,n;e||(this.absPos=this.timeToAbsPos(+new Date)),!1!==this.situation.loops?(t=Math.max(this.absPos,0),i=Math.floor(t),!0===this.situation.loops||i<this.situation.loops?(this.pos=t-i,n=this.situation.loop,this.situation.loop=i):(this.absPos=this.situation.loops,this.pos=1,n=this.situation.loop-1,this.situation.loop=this.situation.loops),this.situation.reversing&&(this.situation.reversed=this.situation.reversed!=Boolean((this.situation.loop-n)%2))):(this.absPos=Math.min(this.absPos,1),this.pos=this.absPos),this.pos<0&&(this.pos=0),this.situation.reversed&&(this.pos=1-this.pos);var r=this.situation.ease(this.pos);for(var a in this.situation.once)a>this.lastPos&&a<=r&&(this.situation.once[a].call(this.target(),this.pos,r),delete this.situation.once[a]);return this.active&&this.target().fire("during",{pos:this.pos,eased:r,fx:this,situation:this.situation}),this.situation?(this.eachAt(),1==this.pos&&!this.situation.reversed||this.situation.reversed&&0==this.pos?(this.stopAnimFrame(),this.target().fire("finished",{fx:this,situation:this.situation}),this.situations.length||(this.target().fire("allfinished"),this.situations.length||(this.target().off(".fx"),this.active=!1)),this.active?this.dequeue():this.clearCurrent()):!this.paused&&this.active&&this.startAnimFrame(),this.lastPos=r,this):this},eachAt:function(){var e,t=this,i=this.target(),r=this.situation;for(var a in r.animations)e=[].concat(r.animations[a]).map((function(e){return"string"!=typeof e&&e.at?e.at(r.ease(t.pos),t.pos):e})),i[a].apply(i,e);for(var a in r.attrs)e=[a].concat(r.attrs[a]).map((function(e){return"string"!=typeof e&&e.at?e.at(r.ease(t.pos),t.pos):e})),i.attr.apply(i,e);for(var a in r.styles)e=[a].concat(r.styles[a]).map((function(e){return"string"!=typeof e&&e.at?e.at(r.ease(t.pos),t.pos):e})),i.style.apply(i,e);if(r.transforms.length){e=r.initialTransformation,a=0;for(var s=r.transforms.length;a<s;a++){var o=r.transforms[a];o instanceof n.Matrix?e=o.relative?e.multiply((new n.Matrix).morph(o).at(r.ease(this.pos))):e.morph(o).at(r.ease(this.pos)):(o.relative||o.undo(e.extract()),e=e.multiply(o.at(r.ease(this.pos))))}i.matrix(e)}return this},once:function(e,t,i){var n=this.last();return i||(e=n.ease(e)),n.once[e]=t,this},_callStart:function(){return setTimeout(function(){this.start()}.bind(this),0),this}},parent:n.Element,construct:{animate:function(e,t,i){return(this.fx||(this.fx=new n.FX(this))).animate(e,t,i)},delay:function(e){return(this.fx||(this.fx=new n.FX(this))).delay(e)},stop:function(e,t){return this.fx&&this.fx.stop(e,t),this},finish:function(){return this.fx&&this.fx.finish(),this}}}),n.MorphObj=n.invent({create:function(e,t){return n.Color.isColor(t)?new n.Color(e).morph(t):n.regex.delimiter.test(e)?n.regex.pathLetters.test(e)?new n.PathArray(e).morph(t):new n.Array(e).morph(t):n.regex.numberAndUnit.test(t)?new n.Number(e).morph(t):(this.value=e,void(this.destination=t))},extend:{at:function(e,t){return t<1?this.value:this.destination},valueOf:function(){return this.value}}}),n.extend(n.FX,{attr:function(e,t,n){if("object"===i(e))for(var r in e)this.attr(r,e[r]);else this.add(e,t,"attrs");return this},plot:function(e,t,i,n){return 4==arguments.length?this.plot([e,t,i,n]):this.add("plot",new(this.target().morphArray)(e))}}),n.Box=n.invent({create:function(e,t,r,a){if(!("object"!==i(e)||e instanceof n.Element))return n.Box.call(this,null!=e.left?e.left:e.x,null!=e.top?e.top:e.y,e.width,e.height);var s;4==arguments.length&&(this.x=e,this.y=t,this.width=r,this.height=a),null==(s=this).x&&(s.x=0,s.y=0,s.width=0,s.height=0),s.w=s.width,s.h=s.height,s.x2=s.x+s.width,s.y2=s.y+s.height,s.cx=s.x+s.width/2,s.cy=s.y+s.height/2}}),n.BBox=n.invent({create:function(e){if(n.Box.apply(this,[].slice.call(arguments)),e instanceof n.Element){var i;try{if(!t.documentElement.contains){for(var r=e.node;r.parentNode;)r=r.parentNode;if(r!=t)throw new Error("Element not in the dom")}i=e.node.getBBox()}catch(t){if(e instanceof n.Shape){n.parser.draw||n.prepare();var a=e.clone(n.parser.draw.instance).show();a&&a.node&&"function"==typeof a.node.getBBox&&(i=a.node.getBBox()),a&&"function"==typeof a.remove&&a.remove()}else i={x:e.node.clientLeft,y:e.node.clientTop,width:e.node.clientWidth,height:e.node.clientHeight}}n.Box.call(this,i)}},inherit:n.Box,parent:n.Element,construct:{bbox:function(){return new n.BBox(this)}}}),n.BBox.prototype.constructor=n.BBox,n.Matrix=n.invent({create:function(e){var t=m([1,0,0,1,0,0]);e=null===e?t:e instanceof n.Element?e.matrixify():"string"==typeof e?m(e.split(n.regex.delimiter).map(parseFloat)):6==arguments.length?m([].slice.call(arguments)):Array.isArray(e)?m(e):e&&"object"===i(e)?e:t;for(var r=y.length-1;r>=0;--r)this[y[r]]=null!=e[y[r]]?e[y[r]]:t[y[r]]},extend:{extract:function(){var e=p(this,0,1);p(this,1,0);var t=180/Math.PI*Math.atan2(e.y,e.x)-90;return{x:this.e,y:this.f,transformedX:(this.e*Math.cos(t*Math.PI/180)+this.f*Math.sin(t*Math.PI/180))/Math.sqrt(this.a*this.a+this.b*this.b),transformedY:(this.f*Math.cos(t*Math.PI/180)+this.e*Math.sin(-t*Math.PI/180))/Math.sqrt(this.c*this.c+this.d*this.d),rotation:t,a:this.a,b:this.b,c:this.c,d:this.d,e:this.e,f:this.f,matrix:new n.Matrix(this)}},clone:function(){return new n.Matrix(this)},morph:function(e){return this.destination=new n.Matrix(e),this},multiply:function(e){return new n.Matrix(this.native().multiply(function(e){return e instanceof n.Matrix||(e=new n.Matrix(e)),e}(e).native()))},inverse:function(){return new n.Matrix(this.native().inverse())},translate:function(e,t){return new n.Matrix(this.native().translate(e||0,t||0))},native:function(){for(var e=n.parser.native.createSVGMatrix(),t=y.length-1;t>=0;t--)e[y[t]]=this[y[t]];return e},toString:function(){return"matrix("+v(this.a)+","+v(this.b)+","+v(this.c)+","+v(this.d)+","+v(this.e)+","+v(this.f)+")"}},parent:n.Element,construct:{ctm:function(){return new n.Matrix(this.node.getCTM())},screenCTM:function(){if(this instanceof n.Nested){var e=this.rect(1,1),t=e.node.getScreenCTM();return e.remove(),new n.Matrix(t)}return new n.Matrix(this.node.getScreenCTM())}}}),n.Point=n.invent({create:function(e,t){var n;n=Array.isArray(e)?{x:e[0],y:e[1]}:"object"===i(e)?{x:e.x,y:e.y}:null!=e?{x:e,y:null!=t?t:e}:{x:0,y:0},this.x=n.x,this.y=n.y},extend:{clone:function(){return new n.Point(this)},morph:function(e,t){return this.destination=new n.Point(e,t),this}}}),n.extend(n.Element,{point:function(e,t){return new n.Point(e,t).transform(this.screenCTM().inverse())}}),n.extend(n.Element,{attr:function(e,t,r){if(null==e){for(e={},r=(t=this.node.attributes).length-1;r>=0;r--)e[t[r].nodeName]=n.regex.isNumber.test(t[r].nodeValue)?parseFloat(t[r].nodeValue):t[r].nodeValue;return e}if("object"===i(e))for(var a in e)this.attr(a,e[a]);else if(null===t)this.node.removeAttribute(e);else{if(null==t)return null==(t=this.node.getAttribute(e))?n.defaults.attrs[e]:n.regex.isNumber.test(t)?parseFloat(t):t;"stroke-width"==e?this.attr("stroke",parseFloat(t)>0?this._stroke:null):"stroke"==e&&(this._stroke=t),"fill"!=e&&"stroke"!=e||(n.regex.isImage.test(t)&&(t=this.doc().defs().image(t,0,0)),t instanceof n.Image&&(t=this.doc().defs().pattern(0,0,(function(){this.add(t)})))),"number"==typeof t?t=new n.Number(t):n.Color.isColor(t)?t=new n.Color(t):Array.isArray(t)&&(t=new n.Array(t)),"leading"==e?this.leading&&this.leading(t):"string"==typeof r?this.node.setAttributeNS(r,e,t.toString()):this.node.setAttribute(e,t.toString()),!this.rebuild||"font-size"!=e&&"x"!=e||this.rebuild(e,t)}return this}}),n.extend(n.Element,{transform:function(e,t){var r;return"object"!==i(e)?(r=new n.Matrix(this).extract(),"string"==typeof e?r[e]:r):(r=new n.Matrix(this),t=!!t||!!e.relative,null!=e.a&&(r=t?r.multiply(new n.Matrix(e)):new n.Matrix(e)),this.attr("transform",r))}}),n.extend(n.Element,{untransform:function(){return this.attr("transform",null)},matrixify:function(){return(this.attr("transform")||"").split(n.regex.transforms).slice(0,-1).map((function(e){var t=e.trim().split("(");return[t[0],t[1].split(n.regex.delimiter).map((function(e){return parseFloat(e)}))]})).reduce((function(e,t){return"matrix"==t[0]?e.multiply(m(t[1])):e[t[0]].apply(e,t[1])}),new n.Matrix)},toParent:function(e){if(this==e)return this;var t=this.screenCTM(),i=e.screenCTM().inverse();return this.addTo(e).untransform().transform(i.multiply(t)),this},toDoc:function(){return this.toParent(this.doc())}}),n.Transformation=n.invent({create:function(e,t){if(arguments.length>1&&"boolean"!=typeof t)return this.constructor.call(this,[].slice.call(arguments));if(Array.isArray(e))for(var n=0,r=this.arguments.length;n<r;++n)this[this.arguments[n]]=e[n];else if(e&&"object"===i(e))for(n=0,r=this.arguments.length;n<r;++n)this[this.arguments[n]]=e[this.arguments[n]];this.inversed=!1,!0===t&&(this.inversed=!0)}}),n.Translate=n.invent({parent:n.Matrix,inherit:n.Transformation,create:function(e,t){this.constructor.apply(this,[].slice.call(arguments))},extend:{arguments:["transformedX","transformedY"],method:"translate"}}),n.extend(n.Element,{style:function(e,t){if(0==arguments.length)return this.node.style.cssText||"";if(arguments.length<2)if("object"===i(e))for(var r in e)this.style(r,e[r]);else{if(!n.regex.isCss.test(e))return this.node.style[u(e)];for(e=e.split(/\s*;\s*/).filter((function(e){return!!e})).map((function(e){return e.split(/\s*:\s*/)}));t=e.pop();)this.style(t[0],t[1])}else this.node.style[u(e)]=null===t||n.regex.isBlank.test(t)?"":t;return this}}),n.Parent=n.invent({create:function(e){this.constructor.call(this,e)},inherit:n.Element,extend:{children:function(){return n.utils.map(n.utils.filterSVGElements(this.node.childNodes),(function(e){return n.adopt(e)}))},add:function(e,t){return null==t?this.node.appendChild(e.node):e.node!=this.node.childNodes[t]&&this.node.insertBefore(e.node,this.node.childNodes[t]),this},put:function(e,t){return this.add(e,t),e},has:function(e){return this.index(e)>=0},index:function(e){return[].slice.call(this.node.childNodes).indexOf(e.node)},get:function(e){return n.adopt(this.node.childNodes[e])},first:function(){return this.get(0)},last:function(){return this.get(this.node.childNodes.length-1)},each:function(e,t){for(var i=this.children(),r=0,a=i.length;r<a;r++)i[r]instanceof n.Element&&e.apply(i[r],[r,i]),t&&i[r]instanceof n.Container&&i[r].each(e,t);return this},removeElement:function(e){return this.node.removeChild(e.node),this},clear:function(){for(;this.node.hasChildNodes();)this.node.removeChild(this.node.lastChild);return delete this._defs,this},defs:function(){return this.doc().defs()}}}),n.extend(n.Parent,{ungroup:function(e,t){return 0===t||this instanceof n.Defs||this.node==n.parser.draw||(e=e||(this instanceof n.Doc?this:this.parent(n.Parent)),t=t||1/0,this.each((function(){return this instanceof n.Defs?this:this instanceof n.Parent?this.ungroup(e,t-1):this.toParent(e)})),this.node.firstChild||this.remove()),this},flatten:function(e,t){return this.ungroup(e,t)}}),n.Container=n.invent({create:function(e){this.constructor.call(this,e)},inherit:n.Parent}),n.ViewBox=n.invent({parent:n.Container,construct:{}}),["click","dblclick","mousedown","mouseup","mouseover","mouseout","mousemove","touchstart","touchmove","touchleave","touchend","touchcancel"].forEach((function(e){n.Element.prototype[e]=function(t){return n.on(this.node,e,t),this}})),n.listeners=[],n.handlerMap=[],n.listenerId=0,n.on=function(e,t,i,r,a){var s=i.bind(r||e.instance||e),o=(n.handlerMap.indexOf(e)+1||n.handlerMap.push(e))-1,l=t.split(".")[0],c=t.split(".")[1]||"*";n.listeners[o]=n.listeners[o]||{},n.listeners[o][l]=n.listeners[o][l]||{},n.listeners[o][l][c]=n.listeners[o][l][c]||{},i._svgjsListenerId||(i._svgjsListenerId=++n.listenerId),n.listeners[o][l][c][i._svgjsListenerId]=s,e.addEventListener(l,s,a||{passive:!1})},n.off=function(e,t,i){var r=n.handlerMap.indexOf(e),a=t&&t.split(".")[0],s=t&&t.split(".")[1],o="";if(-1!=r)if(i){if("function"==typeof i&&(i=i._svgjsListenerId),!i)return;n.listeners[r][a]&&n.listeners[r][a][s||"*"]&&(e.removeEventListener(a,n.listeners[r][a][s||"*"][i],!1),delete n.listeners[r][a][s||"*"][i])}else if(s&&a){if(n.listeners[r][a]&&n.listeners[r][a][s]){for(var l in n.listeners[r][a][s])n.off(e,[a,s].join("."),l);delete n.listeners[r][a][s]}}else if(s)for(var c in n.listeners[r])for(var o in n.listeners[r][c])s===o&&n.off(e,[c,s].join("."));else if(a){if(n.listeners[r][a]){for(var o in n.listeners[r][a])n.off(e,[a,o].join("."));delete n.listeners[r][a]}}else{for(var c in n.listeners[r])n.off(e,c);delete n.listeners[r],delete n.handlerMap[r]}},n.extend(n.Element,{on:function(e,t,i,r){return n.on(this.node,e,t,i,r),this},off:function(e,t){return n.off(this.node,e,t),this},fire:function(t,i){return t instanceof e.Event?this.node.dispatchEvent(t):this.node.dispatchEvent(t=new n.CustomEvent(t,{detail:i,cancelable:!0})),this._event=t,this},event:function(){return this._event}}),n.Defs=n.invent({create:"defs",inherit:n.Container}),n.G=n.invent({create:"g",inherit:n.Container,extend:{x:function(e){return null==e?this.transform("x"):this.transform({x:e-this.x()},!0)}},construct:{group:function(){return this.put(new n.G)}}}),n.Doc=n.invent({create:function(e){e&&("svg"==(e="string"==typeof e?t.getElementById(e):e).nodeName?this.constructor.call(this,e):(this.constructor.call(this,n.create("svg")),e.appendChild(this.node),this.size("100%","100%")),this.namespace().defs())},inherit:n.Container,extend:{namespace:function(){return this.attr({xmlns:n.ns,version:"1.1"}).attr("xmlns:xlink",n.xlink,n.xmlns).attr("xmlns:svgjs",n.svgjs,n.xmlns)},defs:function(){var e;return this._defs||((e=this.node.getElementsByTagName("defs")[0])?this._defs=n.adopt(e):this._defs=new n.Defs,this.node.appendChild(this._defs.node)),this._defs},parent:function(){return this.node.parentNode&&"#document"!=this.node.parentNode.nodeName?this.node.parentNode:null},remove:function(){return this.parent()&&this.parent().removeChild(this.node),this},clear:function(){for(;this.node.hasChildNodes();)this.node.removeChild(this.node.lastChild);return delete this._defs,n.parser.draw&&!n.parser.draw.parentNode&&this.node.appendChild(n.parser.draw),this},clone:function(e){this.writeDataToDom();var t=this.node,i=g(t.cloneNode(!0));return e?(e.node||e).appendChild(i.node):t.parentNode.insertBefore(i.node,t.nextSibling),i}}}),n.extend(n.Element,{}),n.Gradient=n.invent({create:function(e){this.constructor.call(this,n.create(e+"Gradient")),this.type=e},inherit:n.Container,extend:{at:function(e,t,i){return this.put(new n.Stop).update(e,t,i)},update:function(e){return this.clear(),"function"==typeof e&&e.call(this,this),this},fill:function(){return"url(#"+this.id()+")"},toString:function(){return this.fill()},attr:function(e,t,i){return"transform"==e&&(e="gradientTransform"),n.Container.prototype.attr.call(this,e,t,i)}},construct:{gradient:function(e,t){return this.defs().gradient(e,t)}}}),n.extend(n.Gradient,n.FX,{from:function(e,t){return"radial"==(this._target||this).type?this.attr({fx:new n.Number(e),fy:new n.Number(t)}):this.attr({x1:new n.Number(e),y1:new n.Number(t)})},to:function(e,t){return"radial"==(this._target||this).type?this.attr({cx:new n.Number(e),cy:new n.Number(t)}):this.attr({x2:new n.Number(e),y2:new n.Number(t)})}}),n.extend(n.Defs,{gradient:function(e,t){return this.put(new n.Gradient(e)).update(t)}}),n.Stop=n.invent({create:"stop",inherit:n.Element,extend:{update:function(e){return("number"==typeof e||e instanceof n.Number)&&(e={offset:arguments[0],color:arguments[1],opacity:arguments[2]}),null!=e.opacity&&this.attr("stop-opacity",e.opacity),null!=e.color&&this.attr("stop-color",e.color),null!=e.offset&&this.attr("offset",new n.Number(e.offset)),this}}}),n.Pattern=n.invent({create:"pattern",inherit:n.Container,extend:{fill:function(){return"url(#"+this.id()+")"},update:function(e){return this.clear(),"function"==typeof e&&e.call(this,this),this},toString:function(){return this.fill()},attr:function(e,t,i){return"transform"==e&&(e="patternTransform"),n.Container.prototype.attr.call(this,e,t,i)}},construct:{pattern:function(e,t,i){return this.defs().pattern(e,t,i)}}}),n.extend(n.Defs,{pattern:function(e,t,i){return this.put(new n.Pattern).update(i).attr({x:0,y:0,width:e,height:t,patternUnits:"userSpaceOnUse"})}}),n.Shape=n.invent({create:function(e){this.constructor.call(this,e)},inherit:n.Element}),n.Symbol=n.invent({create:"symbol",inherit:n.Container,construct:{symbol:function(){return this.put(new n.Symbol)}}}),n.Use=n.invent({create:"use",inherit:n.Shape,extend:{element:function(e,t){return this.attr("href",(t||"")+"#"+e,n.xlink)}},construct:{use:function(e,t){return this.put(new n.Use).element(e,t)}}}),n.Rect=n.invent({create:"rect",inherit:n.Shape,construct:{rect:function(e,t){return this.put(new n.Rect).size(e,t)}}}),n.Circle=n.invent({create:"circle",inherit:n.Shape,construct:{circle:function(e){return this.put(new n.Circle).rx(new n.Number(e).divide(2)).move(0,0)}}}),n.extend(n.Circle,n.FX,{rx:function(e){return this.attr("r",e)},ry:function(e){return this.rx(e)}}),n.Ellipse=n.invent({create:"ellipse",inherit:n.Shape,construct:{ellipse:function(e,t){return this.put(new n.Ellipse).size(e,t).move(0,0)}}}),n.extend(n.Ellipse,n.Rect,n.FX,{rx:function(e){return this.attr("rx",e)},ry:function(e){return this.attr("ry",e)}}),n.extend(n.Circle,n.Ellipse,{x:function(e){return null==e?this.cx()-this.rx():this.cx(e+this.rx())},y:function(e){return null==e?this.cy()-this.ry():this.cy(e+this.ry())},cx:function(e){return null==e?this.attr("cx"):this.attr("cx",e)},cy:function(e){return null==e?this.attr("cy"):this.attr("cy",e)},width:function(e){return null==e?2*this.rx():this.rx(new n.Number(e).divide(2))},height:function(e){return null==e?2*this.ry():this.ry(new n.Number(e).divide(2))},size:function(e,t){var i=f(this,e,t);return this.rx(new n.Number(i.width).divide(2)).ry(new n.Number(i.height).divide(2))}}),n.Line=n.invent({create:"line",inherit:n.Shape,extend:{array:function(){return new n.PointArray([[this.attr("x1"),this.attr("y1")],[this.attr("x2"),this.attr("y2")]])},plot:function(e,t,i,r){return null==e?this.array():(e=void 0!==t?{x1:e,y1:t,x2:i,y2:r}:new n.PointArray(e).toLine(),this.attr(e))},move:function(e,t){return this.attr(this.array().move(e,t).toLine())},size:function(e,t){var i=f(this,e,t);return this.attr(this.array().size(i.width,i.height).toLine())}},construct:{line:function(e,t,i,r){return n.Line.prototype.plot.apply(this.put(new n.Line),null!=e?[e,t,i,r]:[0,0,0,0])}}}),n.Polyline=n.invent({create:"polyline",inherit:n.Shape,construct:{polyline:function(e){return this.put(new n.Polyline).plot(e||new n.PointArray)}}}),n.Polygon=n.invent({create:"polygon",inherit:n.Shape,construct:{polygon:function(e){return this.put(new n.Polygon).plot(e||new n.PointArray)}}}),n.extend(n.Polyline,n.Polygon,{array:function(){return this._array||(this._array=new n.PointArray(this.attr("points")))},plot:function(e){return null==e?this.array():this.clear().attr("points","string"==typeof e?e:this._array=new n.PointArray(e))},clear:function(){return delete this._array,this},move:function(e,t){return this.attr("points",this.array().move(e,t))},size:function(e,t){var i=f(this,e,t);return this.attr("points",this.array().size(i.width,i.height))}}),n.extend(n.Line,n.Polyline,n.Polygon,{morphArray:n.PointArray,x:function(e){return null==e?this.bbox().x:this.move(e,this.bbox().y)},y:function(e){return null==e?this.bbox().y:this.move(this.bbox().x,e)},width:function(e){var t=this.bbox();return null==e?t.width:this.size(e,t.height)},height:function(e){var t=this.bbox();return null==e?t.height:this.size(t.width,e)}}),n.Path=n.invent({create:"path",inherit:n.Shape,extend:{morphArray:n.PathArray,array:function(){return this._array||(this._array=new n.PathArray(this.attr("d")))},plot:function(e){return null==e?this.array():this.clear().attr("d","string"==typeof e?e:this._array=new n.PathArray(e))},clear:function(){return delete this._array,this}},construct:{path:function(e){return this.put(new n.Path).plot(e||new n.PathArray)}}}),n.Image=n.invent({create:"image",inherit:n.Shape,extend:{load:function(t){if(!t)return this;var i=this,r=new e.Image;return n.on(r,"load",(function(){n.off(r);var e=i.parent(n.Pattern);null!==e&&(0==i.width()&&0==i.height()&&i.size(r.width,r.height),e&&0==e.width()&&0==e.height()&&e.size(i.width(),i.height()),"function"==typeof i._loaded&&i._loaded.call(i,{width:r.width,height:r.height,ratio:r.width/r.height,url:t}))})),n.on(r,"error",(function(e){n.off(r),"function"==typeof i._error&&i._error.call(i,e)})),this.attr("href",r.src=this.src=t,n.xlink)},loaded:function(e){return this._loaded=e,this},error:function(e){return this._error=e,this}},construct:{image:function(e,t,i){return this.put(new n.Image).load(e).size(t||0,i||t||0)}}}),n.Text=n.invent({create:function(){this.constructor.call(this,n.create("text")),this.dom.leading=new n.Number(1.3),this._rebuild=!0,this._build=!1,this.attr("font-family",n.defaults.attrs["font-family"])},inherit:n.Shape,extend:{x:function(e){return null==e?this.attr("x"):this.attr("x",e)},text:function(e){if(void 0===e){e="";for(var t=this.node.childNodes,i=0,r=t.length;i<r;++i)0!=i&&3!=t[i].nodeType&&1==n.adopt(t[i]).dom.newLined&&(e+="\n"),e+=t[i].textContent;return e}if(this.clear().build(!0),"function"==typeof e)e.call(this,this);else{i=0;for(var a=(e=e.split("\n")).length;i<a;i++)this.tspan(e[i]).newLine()}return this.build(!1).rebuild()},size:function(e){return this.attr("font-size",e).rebuild()},leading:function(e){return null==e?this.dom.leading:(this.dom.leading=new n.Number(e),this.rebuild())},lines:function(){var e=(this.textPath&&this.textPath()||this).node,t=n.utils.map(n.utils.filterSVGElements(e.childNodes),(function(e){return n.adopt(e)}));return new n.Set(t)},rebuild:function(e){if("boolean"==typeof e&&(this._rebuild=e),this._rebuild){var t=this,i=0,r=this.dom.leading*new n.Number(this.attr("font-size"));this.lines().each((function(){this.dom.newLined&&(t.textPath()||this.attr("x",t.attr("x")),"\n"==this.text()?i+=r:(this.attr("dy",r+i),i=0))})),this.fire("rebuild")}return this},build:function(e){return this._build=!!e,this},setData:function(e){return this.dom=e,this.dom.leading=new n.Number(e.leading||1.3),this}},construct:{text:function(e){return this.put(new n.Text).text(e)},plain:function(e){return this.put(new n.Text).plain(e)}}}),n.Tspan=n.invent({create:"tspan",inherit:n.Shape,extend:{text:function(e){return null==e?this.node.textContent+(this.dom.newLined?"\n":""):("function"==typeof e?e.call(this,this):this.plain(e),this)},dx:function(e){return this.attr("dx",e)},dy:function(e){return this.attr("dy",e)},newLine:function(){var e=this.parent(n.Text);return this.dom.newLined=!0,this.dy(e.dom.leading*e.attr("font-size")).attr("x",e.x())}}}),n.extend(n.Text,n.Tspan,{plain:function(e){return!1===this._build&&this.clear(),this.node.appendChild(t.createTextNode(e)),this},tspan:function(e){var t=(this.textPath&&this.textPath()||this).node,i=new n.Tspan;return!1===this._build&&this.clear(),t.appendChild(i.node),i.text(e)},clear:function(){for(var e=(this.textPath&&this.textPath()||this).node;e.hasChildNodes();)e.removeChild(e.lastChild);return this},length:function(){return this.node.getComputedTextLength()}}),n.TextPath=n.invent({create:"textPath",inherit:n.Parent,parent:n.Text,construct:{morphArray:n.PathArray,array:function(){var e=this.track();return e?e.array():null},plot:function(e){var t=this.track(),i=null;return t&&(i=t.plot(e)),null==e?i:this},track:function(){var e=this.textPath();if(e)return e.reference("href")},textPath:function(){if(this.node.firstChild&&"textPath"==this.node.firstChild.nodeName)return n.adopt(this.node.firstChild)}}}),n.Nested=n.invent({create:function(){this.constructor.call(this,n.create("svg")),this.style("overflow","visible")},inherit:n.Container,construct:{nested:function(){return this.put(new n.Nested)}}});var l={stroke:["color","width","opacity","linecap","linejoin","miterlimit","dasharray","dashoffset"],fill:["color","opacity","rule"],prefix:function(e,t){return"color"==t?e:e+"-"+t}};function c(e,t,i,r){return i+r.replace(n.regex.dots," .")}function u(e){return e.toLowerCase().replace(/-(.)/g,(function(e,t){return t.toUpperCase()}))}function d(e){return e.charAt(0).toUpperCase()+e.slice(1)}function h(e){var t=e.toString(16);return 1==t.length?"0"+t:t}function f(e,t,i){if(null==t||null==i){var n=e.bbox();null==t?t=n.width/n.height*i:null==i&&(i=n.height/n.width*t)}return{width:t,height:i}}function p(e,t,i){return{x:t*e.a+i*e.c+0,y:t*e.b+i*e.d+0}}function m(e){return{a:e[0],b:e[1],c:e[2],d:e[3],e:e[4],f:e[5]}}function g(t){for(var i=t.childNodes.length-1;i>=0;i--)t.childNodes[i]instanceof e.SVGElement&&g(t.childNodes[i]);return n.adopt(t).id(n.eid(t.nodeName))}function v(e){return Math.abs(e)>1e-37?e:0}["fill","stroke"].forEach((function(e){var t={};t[e]=function(t){if(void 0===t)return this;if("string"==typeof t||n.Color.isRgb(t)||t&&"function"==typeof t.fill)this.attr(e,t);else for(var i=l[e].length-1;i>=0;i--)null!=t[l[e][i]]&&this.attr(l.prefix(e,l[e][i]),t[l[e][i]]);return this},n.extend(n.Element,n.FX,t)})),n.extend(n.Element,n.FX,{translate:function(e,t){return this.transform({x:e,y:t})},matrix:function(e){return this.attr("transform",new n.Matrix(6==arguments.length?[].slice.call(arguments):e))},opacity:function(e){return this.attr("opacity",e)},dx:function(e){return this.x(new n.Number(e).plus(this instanceof n.FX?0:this.x()),!0)},dy:function(e){return this.y(new n.Number(e).plus(this instanceof n.FX?0:this.y()),!0)}}),n.extend(n.Path,{length:function(){return this.node.getTotalLength()},pointAt:function(e){return this.node.getPointAtLength(e)}}),n.Set=n.invent({create:function(e){Array.isArray(e)?this.members=e:this.clear()},extend:{add:function(){for(var e=[].slice.call(arguments),t=0,i=e.length;t<i;t++)this.members.push(e[t]);return this},remove:function(e){var t=this.index(e);return t>-1&&this.members.splice(t,1),this},each:function(e){for(var t=0,i=this.members.length;t<i;t++)e.apply(this.members[t],[t,this.members]);return this},clear:function(){return this.members=[],this},length:function(){return this.members.length},has:function(e){return this.index(e)>=0},index:function(e){return this.members.indexOf(e)},get:function(e){return this.members[e]},first:function(){return this.get(0)},last:function(){return this.get(this.members.length-1)},valueOf:function(){return this.members}},construct:{set:function(e){return new n.Set(e)}}}),n.FX.Set=n.invent({create:function(e){this.set=e}}),n.Set.inherit=function(){var e=[];for(var t in n.Shape.prototype)"function"==typeof n.Shape.prototype[t]&&"function"!=typeof n.Set.prototype[t]&&e.push(t);for(var t in e.forEach((function(e){n.Set.prototype[e]=function(){for(var t=0,i=this.members.length;t<i;t++)this.members[t]&&"function"==typeof this.members[t][e]&&this.members[t][e].apply(this.members[t],arguments);return"animate"==e?this.fx||(this.fx=new n.FX.Set(this)):this}})),e=[],n.FX.prototype)"function"==typeof n.FX.prototype[t]&&"function"!=typeof n.FX.Set.prototype[t]&&e.push(t);e.forEach((function(e){n.FX.Set.prototype[e]=function(){for(var t=0,i=this.set.members.length;t<i;t++)this.set.members[t].fx[e].apply(this.set.members[t].fx,arguments);return this}}))},n.extend(n.Element,{}),n.extend(n.Element,{remember:function(e,t){if("object"===i(arguments[0]))for(var n in e)this.remember(n,e[n]);else{if(1==arguments.length)return this.memory()[e];this.memory()[e]=t}return this},forget:function(){if(0==arguments.length)this._memory={};else for(var e=arguments.length-1;e>=0;e--)delete this.memory()[arguments[e]];return this},memory:function(){return this._memory||(this._memory={})}}),n.get=function(e){var i=t.getElementById(function(e){var t=(e||"").toString().match(n.regex.reference);if(t)return t[1]}(e)||e);return n.adopt(i)},n.select=function(e,i){return new n.Set(n.utils.map((i||t).querySelectorAll(e),(function(e){return n.adopt(e)})))},n.extend(n.Parent,{select:function(e){return n.select(e,this.node)}});var y="abcdef".split("");if("function"!=typeof e.CustomEvent){var b=function(e,i){i=i||{bubbles:!1,cancelable:!1,detail:void 0};var n=t.createEvent("CustomEvent");return n.initCustomEvent(e,i.bubbles,i.cancelable,i.detail),n};b.prototype=e.Event.prototype,n.CustomEvent=b}else n.CustomEvent=e.CustomEvent;return n},"function"==typeof define&&define.amd?define((function(){return Ne(Ie,Ie.document)})):"object"===("undefined"==typeof exports?"undefined":i(exports))&&"undefined"!=typeof module?module.exports=Ie.document?Ne(Ie,Ie.document):function(e){return Ne(e,e.document)}:Ie.SVG=Ne(Ie,Ie.document),
/*! svg.filter.js - v2.0.2 - 2016-02-24
  * https://github.com/wout/svg.filter.js
  * Copyright (c) 2016 Wout Fierens; Licensed MIT */
function(){SVG.Filter=SVG.invent({create:"filter",inherit:SVG.Parent,extend:{source:"SourceGraphic",sourceAlpha:"SourceAlpha",background:"BackgroundImage",backgroundAlpha:"BackgroundAlpha",fill:"FillPaint",stroke:"StrokePaint",autoSetIn:!0,put:function(e,t){return this.add(e,t),!e.attr("in")&&this.autoSetIn&&e.attr("in",this.source),e.attr("result")||e.attr("result",e),e},blend:function(e,t,i){return this.put(new SVG.BlendEffect(e,t,i))},colorMatrix:function(e,t){return this.put(new SVG.ColorMatrixEffect(e,t))},convolveMatrix:function(e){return this.put(new SVG.ConvolveMatrixEffect(e))},componentTransfer:function(e){return this.put(new SVG.ComponentTransferEffect(e))},composite:function(e,t,i){return this.put(new SVG.CompositeEffect(e,t,i))},flood:function(e,t){return this.put(new SVG.FloodEffect(e,t))},offset:function(e,t){return this.put(new SVG.OffsetEffect(e,t))},image:function(e){return this.put(new SVG.ImageEffect(e))},merge:function(){var e=[void 0];for(var t in arguments)e.push(arguments[t]);return this.put(new(SVG.MergeEffect.bind.apply(SVG.MergeEffect,e)))},gaussianBlur:function(e,t){return this.put(new SVG.GaussianBlurEffect(e,t))},morphology:function(e,t){return this.put(new SVG.MorphologyEffect(e,t))},diffuseLighting:function(e,t,i){return this.put(new SVG.DiffuseLightingEffect(e,t,i))},displacementMap:function(e,t,i,n,r){return this.put(new SVG.DisplacementMapEffect(e,t,i,n,r))},specularLighting:function(e,t,i,n){return this.put(new SVG.SpecularLightingEffect(e,t,i,n))},tile:function(){return this.put(new SVG.TileEffect)},turbulence:function(e,t,i,n,r){return this.put(new SVG.TurbulenceEffect(e,t,i,n,r))},toString:function(){return"url(#"+this.attr("id")+")"}}}),SVG.extend(SVG.Defs,{filter:function(e){var t=this.put(new SVG.Filter);return"function"==typeof e&&e.call(t,t),t}}),SVG.extend(SVG.Container,{filter:function(e){return this.defs().filter(e)}}),SVG.extend(SVG.Element,SVG.G,SVG.Nested,{filter:function(e){return this.filterer=e instanceof SVG.Element?e:this.doc().filter(e),this.doc()&&this.filterer.doc()!==this.doc()&&this.doc().defs().add(this.filterer),this.attr("filter",this.filterer),this.filterer},unfilter:function(e){return this.filterer&&!0===e&&this.filterer.remove(),delete this.filterer,this.attr("filter",null)}}),SVG.Effect=SVG.invent({create:function(){this.constructor.call(this)},inherit:SVG.Element,extend:{in:function(e){return null==e?this.parent()&&this.parent().select('[result="'+this.attr("in")+'"]').get(0)||this.attr("in"):this.attr("in",e)},result:function(e){return null==e?this.attr("result"):this.attr("result",e)},toString:function(){return this.result()}}}),SVG.ParentEffect=SVG.invent({create:function(){this.constructor.call(this)},inherit:SVG.Parent,extend:{in:function(e){return null==e?this.parent()&&this.parent().select('[result="'+this.attr("in")+'"]').get(0)||this.attr("in"):this.attr("in",e)},result:function(e){return null==e?this.attr("result"):this.attr("result",e)},toString:function(){return this.result()}}});var e={blend:function(e,t){return this.parent()&&this.parent().blend(this,e,t)},colorMatrix:function(e,t){return this.parent()&&this.parent().colorMatrix(e,t).in(this)},convolveMatrix:function(e){return this.parent()&&this.parent().convolveMatrix(e).in(this)},componentTransfer:function(e){return this.parent()&&this.parent().componentTransfer(e).in(this)},composite:function(e,t){return this.parent()&&this.parent().composite(this,e,t)},flood:function(e,t){return this.parent()&&this.parent().flood(e,t)},offset:function(e,t){return this.parent()&&this.parent().offset(e,t).in(this)},image:function(e){return this.parent()&&this.parent().image(e)},merge:function(){return this.parent()&&this.parent().merge.apply(this.parent(),[this].concat(arguments))},gaussianBlur:function(e,t){return this.parent()&&this.parent().gaussianBlur(e,t).in(this)},morphology:function(e,t){return this.parent()&&this.parent().morphology(e,t).in(this)},diffuseLighting:function(e,t,i){return this.parent()&&this.parent().diffuseLighting(e,t,i).in(this)},displacementMap:function(e,t,i,n){return this.parent()&&this.parent().displacementMap(this,e,t,i,n)},specularLighting:function(e,t,i,n){return this.parent()&&this.parent().specularLighting(e,t,i,n).in(this)},tile:function(){return this.parent()&&this.parent().tile().in(this)},turbulence:function(e,t,i,n,r){return this.parent()&&this.parent().turbulence(e,t,i,n,r).in(this)}};SVG.extend(SVG.Effect,e),SVG.extend(SVG.ParentEffect,e),SVG.ChildEffect=SVG.invent({create:function(){this.constructor.call(this)},inherit:SVG.Element,extend:{in:function(e){this.attr("in",e)}}});var t={blend:function(e,t,i){this.attr({in:e,in2:t,mode:i||"normal"})},colorMatrix:function(e,t){"matrix"==e&&(t=r(t)),this.attr({type:e,values:void 0===t?null:t})},convolveMatrix:function(e){e=r(e),this.attr({order:Math.sqrt(e.split(" ").length),kernelMatrix:e})},composite:function(e,t,i){this.attr({in:e,in2:t,operator:i})},flood:function(e,t){this.attr("flood-color",e),null!=t&&this.attr("flood-opacity",t)},offset:function(e,t){this.attr({dx:e,dy:t})},image:function(e){this.attr("href",e,SVG.xlink)},displacementMap:function(e,t,i,n,r){this.attr({in:e,in2:t,scale:i,xChannelSelector:n,yChannelSelector:r})},gaussianBlur:function(e,t){null!=e||null!=t?this.attr("stdDeviation",function(e){if(!Array.isArray(e))return e;for(var t=0,i=e.length,n=[];t<i;t++)n.push(e[t]);return n.join(" ")}(Array.prototype.slice.call(arguments))):this.attr("stdDeviation","0 0")},morphology:function(e,t){this.attr({operator:e,radius:t})},tile:function(){},turbulence:function(e,t,i,n,r){this.attr({numOctaves:t,seed:i,stitchTiles:n,baseFrequency:e,type:r})}},i={merge:function(){var e;if(arguments[0]instanceof SVG.Set){var t=this;arguments[0].each((function(e){this instanceof SVG.MergeNode?t.put(this):(this instanceof SVG.Effect||this instanceof SVG.ParentEffect)&&t.put(new SVG.MergeNode(this))}))}else{e=Array.isArray(arguments[0])?arguments[0]:arguments;for(var i=0;i<e.length;i++)e[i]instanceof SVG.MergeNode?this.put(e[i]):this.put(new SVG.MergeNode(e[i]))}},componentTransfer:function(e){if(this.rgb=new SVG.Set,["r","g","b","a"].forEach(function(e){this[e]=new(SVG["Func"+e.toUpperCase()])("identity"),this.rgb.add(this[e]),this.node.appendChild(this[e].node)}.bind(this)),e)for(var t in e.rgb&&(["r","g","b"].forEach(function(t){this[t].attr(e.rgb)}.bind(this)),delete e.rgb),e)this[t].attr(e[t])},diffuseLighting:function(e,t,i){this.attr({surfaceScale:e,diffuseConstant:t,kernelUnitLength:i})},specularLighting:function(e,t,i,n){this.attr({surfaceScale:e,diffuseConstant:t,specularExponent:i,kernelUnitLength:n})}},n={distantLight:function(e,t){this.attr({azimuth:e,elevation:t})},pointLight:function(e,t,i){this.attr({x:e,y:t,z:i})},spotLight:function(e,t,i,n,r,a){this.attr({x:e,y:t,z:i,pointsAtX:n,pointsAtY:r,pointsAtZ:a})},mergeNode:function(e){this.attr("in",e)}};function r(e){return Array.isArray(e)&&(e=new SVG.Array(e)),e.toString().replace(/^\s+/,"").replace(/\s+$/,"").replace(/\s+/g," ")}function a(){var e=function(){};for(var t in"function"==typeof arguments[arguments.length-1]&&(e=arguments[arguments.length-1],Array.prototype.splice.call(arguments,arguments.length-1,1)),arguments)for(var i in arguments[t])e(arguments[t][i],i,arguments[t])}["r","g","b","a"].forEach((function(e){n["Func"+e.toUpperCase()]=function(e){switch(this.attr("type",e),e){case"table":this.attr("tableValues",arguments[1]);break;case"linear":this.attr("slope",arguments[1]),this.attr("intercept",arguments[2]);break;case"gamma":this.attr("amplitude",arguments[1]),this.attr("exponent",arguments[2]),this.attr("offset",arguments[2])}}})),a(t,(function(e,t){var i=t.charAt(0).toUpperCase()+t.slice(1);SVG[i+"Effect"]=SVG.invent({create:function(){this.constructor.call(this,SVG.create("fe"+i)),e.apply(this,arguments),this.result(this.attr("id")+"Out")},inherit:SVG.Effect,extend:{}})})),a(i,(function(e,t){var i=t.charAt(0).toUpperCase()+t.slice(1);SVG[i+"Effect"]=SVG.invent({create:function(){this.constructor.call(this,SVG.create("fe"+i)),e.apply(this,arguments),this.result(this.attr("id")+"Out")},inherit:SVG.ParentEffect,extend:{}})})),a(n,(function(e,t){var i=t.charAt(0).toUpperCase()+t.slice(1);SVG[i]=SVG.invent({create:function(){this.constructor.call(this,SVG.create("fe"+i)),e.apply(this,arguments)},inherit:SVG.ChildEffect,extend:{}})})),SVG.extend(SVG.MergeEffect,{in:function(e){return e instanceof SVG.MergeNode?this.add(e,0):this.add(new SVG.MergeNode(e),0),this}}),SVG.extend(SVG.CompositeEffect,SVG.BlendEffect,SVG.DisplacementMapEffect,{in2:function(e){return null==e?this.parent()&&this.parent().select('[result="'+this.attr("in2")+'"]').get(0)||this.attr("in2"):this.attr("in2",e)}}),SVG.filter={sepiatone:[.343,.669,.119,0,0,.249,.626,.13,0,0,.172,.334,.111,0,0,0,0,0,1,0]}}.call(void 0),function(){function e(e,r,a,s,o,l,c){for(var u=e.slice(r,a||c),d=s.slice(o,l||c),h=0,f={pos:[0,0],start:[0,0]},p={pos:[0,0],start:[0,0]};u[h]=t.call(f,u[h]),d[h]=t.call(p,d[h]),u[h][0]!=d[h][0]||"M"==u[h][0]||"A"==u[h][0]&&(u[h][4]!=d[h][4]||u[h][5]!=d[h][5])?(Array.prototype.splice.apply(u,[h,1].concat(n.call(f,u[h]))),Array.prototype.splice.apply(d,[h,1].concat(n.call(p,d[h])))):(u[h]=i.call(f,u[h]),d[h]=i.call(p,d[h])),++h!=u.length||h!=d.length;)h==u.length&&u.push(["C",f.pos[0],f.pos[1],f.pos[0],f.pos[1],f.pos[0],f.pos[1]]),h==d.length&&d.push(["C",p.pos[0],p.pos[1],p.pos[0],p.pos[1],p.pos[0],p.pos[1]]);return{start:u,dest:d}}function t(e){switch(e[0]){case"z":case"Z":e[0]="L",e[1]=this.start[0],e[2]=this.start[1];break;case"H":e[0]="L",e[2]=this.pos[1];break;case"V":e[0]="L",e[2]=e[1],e[1]=this.pos[0];break;case"T":e[0]="Q",e[3]=e[1],e[4]=e[2],e[1]=this.reflection[1],e[2]=this.reflection[0];break;case"S":e[0]="C",e[6]=e[4],e[5]=e[3],e[4]=e[2],e[3]=e[1],e[2]=this.reflection[1],e[1]=this.reflection[0]}return e}function i(e){var t=e.length;return this.pos=[e[t-2],e[t-1]],-1!="SCQT".indexOf(e[0])&&(this.reflection=[2*this.pos[0]-e[t-4],2*this.pos[1]-e[t-3]]),e}function n(e){var t=[e];switch(e[0]){case"M":return this.pos=this.start=[e[1],e[2]],t;case"L":e[5]=e[3]=e[1],e[6]=e[4]=e[2],e[1]=this.pos[0],e[2]=this.pos[1];break;case"Q":e[6]=e[4],e[5]=e[3],e[4]=1*e[4]/3+2*e[2]/3,e[3]=1*e[3]/3+2*e[1]/3,e[2]=1*this.pos[1]/3+2*e[2]/3,e[1]=1*this.pos[0]/3+2*e[1]/3;break;case"A":t=function(e,t){var i,n,r,a,s,o,l,c,u,d,h,f,p,m,g,v,y,b,x,_,w,k,M,S,A,L,T=Math.abs(t[1]),C=Math.abs(t[2]),D=t[3]%360,E=t[4],O=t[5],P=t[6],Y=t[7],I=new SVG.Point(e),N=new SVG.Point(P,Y),j=[];if(0===T||0===C||I.x===N.x&&I.y===N.y)return[["C",I.x,I.y,N.x,N.y,N.x,N.y]];for((n=(i=new SVG.Point((I.x-N.x)/2,(I.y-N.y)/2).transform((new SVG.Matrix).rotate(D))).x*i.x/(T*T)+i.y*i.y/(C*C))>1&&(T*=n=Math.sqrt(n),C*=n),r=(new SVG.Matrix).rotate(D).scale(1/T,1/C).rotate(-D),I=I.transform(r),o=(a=[(N=N.transform(r)).x-I.x,N.y-I.y])[0]*a[0]+a[1]*a[1],s=Math.sqrt(o),a[0]/=s,a[1]/=s,l=o<4?Math.sqrt(1-o/4):0,E===O&&(l*=-1),c=new SVG.Point((N.x+I.x)/2+l*-a[1],(N.y+I.y)/2+l*a[0]),u=new SVG.Point(I.x-c.x,I.y-c.y),d=new SVG.Point(N.x-c.x,N.y-c.y),h=Math.acos(u.x/Math.sqrt(u.x*u.x+u.y*u.y)),u.y<0&&(h*=-1),f=Math.acos(d.x/Math.sqrt(d.x*d.x+d.y*d.y)),d.y<0&&(f*=-1),O&&h>f&&(f+=2*Math.PI),!O&&h<f&&(f-=2*Math.PI),v=[],y=h,p=(f-h)/(m=Math.ceil(2*Math.abs(h-f)/Math.PI)),g=4*Math.tan(p/4)/3,w=0;w<=m;w++)x=Math.cos(y),b=Math.sin(y),_=new SVG.Point(c.x+x,c.y+b),v[w]=[new SVG.Point(_.x+g*b,_.y-g*x),_,new SVG.Point(_.x-g*b,_.y+g*x)],y+=p;for(v[0][0]=v[0][1].clone(),v[v.length-1][2]=v[v.length-1][1].clone(),r=(new SVG.Matrix).rotate(D).scale(T,C).rotate(-D),w=0,k=v.length;w<k;w++)v[w][0]=v[w][0].transform(r),v[w][1]=v[w][1].transform(r),v[w][2]=v[w][2].transform(r);for(w=1,k=v.length;w<k;w++)M=(_=v[w-1][2]).x,S=_.y,A=(_=v[w][0]).x,L=_.y,P=(_=v[w][1]).x,Y=_.y,j.push(["C",M,S,A,L,P,Y]);return j}(this.pos,e),e=t[0]}return e[0]="C",this.pos=[e[5],e[6]],this.reflection=[2*e[5]-e[3],2*e[6]-e[4]],t}function r(e,t){if(!1===t)return!1;for(var i=t,n=e.length;i<n;++i)if("M"==e[i][0])return i;return!1}SVG.extend(SVG.PathArray,{morph:function(t){for(var i=this.value,n=this.parse(t),a=0,s=0,o=!1,l=!1;!1!==a||!1!==s;){var c;o=r(i,!1!==a&&a+1),l=r(n,!1!==s&&s+1),!1===a&&(a=0==(c=new SVG.PathArray(u.start).bbox()).height||0==c.width?i.push(i[0])-1:i.push(["M",c.x+c.width/2,c.y+c.height/2])-1),!1===s&&(s=0==(c=new SVG.PathArray(u.dest).bbox()).height||0==c.width?n.push(n[0])-1:n.push(["M",c.x+c.width/2,c.y+c.height/2])-1);var u=e(i,a,o,n,s,l);i=i.slice(0,a).concat(u.start,!1===o?[]:i.slice(o)),n=n.slice(0,s).concat(u.dest,!1===l?[]:n.slice(l)),a=!1!==o&&a+u.start.length,s=!1!==l&&s+u.dest.length}return this.value=i,this.destination=new SVG.PathArray,this.destination.value=n,this}})}(),
/*! svg.draggable.js - v2.2.2 - 2019-01-08
  * https://github.com/svgdotjs/svg.draggable.js
  * Copyright (c) 2019 Wout Fierens; Licensed MIT */
function(){function e(e){e.remember("_draggable",this),this.el=e}e.prototype.init=function(e,t){var i=this;this.constraint=e,this.value=t,this.el.on("mousedown.drag",(function(e){i.start(e)})),this.el.on("touchstart.drag",(function(e){i.start(e)}))},e.prototype.transformPoint=function(e,t){var i=(e=e||window.event).changedTouches&&e.changedTouches[0]||e;return this.p.x=i.clientX-(t||0),this.p.y=i.clientY,this.p.matrixTransform(this.m)},e.prototype.getBBox=function(){var e=this.el.bbox();return this.el instanceof SVG.Nested&&(e=this.el.rbox()),(this.el instanceof SVG.G||this.el instanceof SVG.Use||this.el instanceof SVG.Nested)&&(e.x=this.el.x(),e.y=this.el.y()),e},e.prototype.start=function(e){if("click"!=e.type&&"mousedown"!=e.type&&"mousemove"!=e.type||1==(e.which||e.buttons)){var t=this;if(this.el.fire("beforedrag",{event:e,handler:this}),!this.el.event().defaultPrevented){e.preventDefault(),e.stopPropagation(),this.parent=this.parent||this.el.parent(SVG.Nested)||this.el.parent(SVG.Doc),this.p=this.parent.node.createSVGPoint(),this.m=this.el.node.getScreenCTM().inverse();var i,n=this.getBBox();if(this.el instanceof SVG.Text)switch(i=this.el.node.getComputedTextLength(),this.el.attr("text-anchor")){case"middle":i/=2;break;case"start":i=0}this.startPoints={point:this.transformPoint(e,i),box:n,transform:this.el.transform()},SVG.on(window,"mousemove.drag",(function(e){t.drag(e)})),SVG.on(window,"touchmove.drag",(function(e){t.drag(e)})),SVG.on(window,"mouseup.drag",(function(e){t.end(e)})),SVG.on(window,"touchend.drag",(function(e){t.end(e)})),this.el.fire("dragstart",{event:e,p:this.startPoints.point,m:this.m,handler:this})}}},e.prototype.drag=function(e){var t=this.getBBox(),i=this.transformPoint(e),n=this.startPoints.box.x+i.x-this.startPoints.point.x,r=this.startPoints.box.y+i.y-this.startPoints.point.y,a=this.constraint,s=i.x-this.startPoints.point.x,o=i.y-this.startPoints.point.y;if(this.el.fire("dragmove",{event:e,p:i,m:this.m,handler:this}),this.el.event().defaultPrevented)return i;if("function"==typeof a){var l=a.call(this.el,n,r,this.m);"boolean"==typeof l&&(l={x:l,y:l}),!0===l.x?this.el.x(n):!1!==l.x&&this.el.x(l.x),!0===l.y?this.el.y(r):!1!==l.y&&this.el.y(l.y)}else"object"==typeof a&&(null!=a.minX&&n<a.minX?s=(n=a.minX)-this.startPoints.box.x:null!=a.maxX&&n>a.maxX-t.width&&(s=(n=a.maxX-t.width)-this.startPoints.box.x),null!=a.minY&&r<a.minY?o=(r=a.minY)-this.startPoints.box.y:null!=a.maxY&&r>a.maxY-t.height&&(o=(r=a.maxY-t.height)-this.startPoints.box.y),null!=a.snapToGrid&&(n-=n%a.snapToGrid,r-=r%a.snapToGrid,s-=s%a.snapToGrid,o-=o%a.snapToGrid),this.el instanceof SVG.G?this.el.matrix(this.startPoints.transform).transform({x:s,y:o},!0):this.el.move(n,r));return i},e.prototype.end=function(e){var t=this.drag(e);this.el.fire("dragend",{event:e,p:t,m:this.m,handler:this}),SVG.off(window,"mousemove.drag"),SVG.off(window,"touchmove.drag"),SVG.off(window,"mouseup.drag"),SVG.off(window,"touchend.drag")},SVG.extend(SVG.Element,{draggable:function(t,i){"function"!=typeof t&&"object"!=typeof t||(i=t,t=!0);var n=this.remember("_draggable")||new e(this);return(t=void 0===t||t)?n.init(i||{},t):(this.off("mousedown.drag"),this.off("touchstart.drag")),this}})}.call(void 0),function(){function e(e){this.el=e,e.remember("_selectHandler",this),this.pointSelection={isSelected:!1},this.rectSelection={isSelected:!1},this.pointsList={lt:[0,0],rt:["width",0],rb:["width","height"],lb:[0,"height"],t:["width",0],r:["width","height"],b:["width","height"],l:[0,"height"]},this.pointCoord=function(e,t,i){var n="string"!=typeof e?e:t[e];return i?n/2:n},this.pointCoords=function(e,t){var i=this.pointsList[e];return{x:this.pointCoord(i[0],t,"t"===e||"b"===e),y:this.pointCoord(i[1],t,"r"===e||"l"===e)}}}e.prototype.init=function(e,t){var i=this.el.bbox();this.options={};var n=this.el.selectize.defaults.points;for(var r in this.el.selectize.defaults)this.options[r]=this.el.selectize.defaults[r],void 0!==t[r]&&(this.options[r]=t[r]);var a=["points","pointsExclude"];for(var r in a){var s=this.options[a[r]];"string"==typeof s?s=s.length>0?s.split(/\s*,\s*/i):[]:"boolean"==typeof s&&"points"===a[r]&&(s=s?n:[]),this.options[a[r]]=s}this.options.points=[n,this.options.points].reduce((function(e,t){return e.filter((function(e){return t.indexOf(e)>-1}))})),this.options.points=[this.options.points,this.options.pointsExclude].reduce((function(e,t){return e.filter((function(e){return t.indexOf(e)<0}))})),this.parent=this.el.parent(),this.nested=this.nested||this.parent.group(),this.nested.matrix(new SVG.Matrix(this.el).translate(i.x,i.y)),this.options.deepSelect&&-1!==["line","polyline","polygon"].indexOf(this.el.type)?this.selectPoints(e):this.selectRect(e),this.observe(),this.cleanup()},e.prototype.selectPoints=function(e){return this.pointSelection.isSelected=e,this.pointSelection.set||(this.pointSelection.set=this.parent.set(),this.drawPoints()),this},e.prototype.getPointArray=function(){var e=this.el.bbox();return this.el.array().valueOf().map((function(t){return[t[0]-e.x,t[1]-e.y]}))},e.prototype.drawPoints=function(){for(var e=this,t=this.getPointArray(),i=0,n=t.length;i<n;++i){var r=function(t){return function(i){(i=i||window.event).preventDefault?i.preventDefault():i.returnValue=!1,i.stopPropagation();var n=i.pageX||i.touches[0].pageX,r=i.pageY||i.touches[0].pageY;e.el.fire("point",{x:n,y:r,i:t,event:i})}}(i),a=this.drawPoint(t[i][0],t[i][1]).addClass(this.options.classPoints).addClass(this.options.classPoints+"_point").on("touchstart",r).on("mousedown",r);this.pointSelection.set.add(a)}},e.prototype.drawPoint=function(e,t){var i=this.options.pointType;switch(i){case"circle":return this.drawCircle(e,t);case"rect":return this.drawRect(e,t);default:if("function"==typeof i)return i.call(this,e,t);throw new Error("Unknown "+i+" point type!")}},e.prototype.drawCircle=function(e,t){return this.nested.circle(this.options.pointSize).center(e,t)},e.prototype.drawRect=function(e,t){return this.nested.rect(this.options.pointSize,this.options.pointSize).center(e,t)},e.prototype.updatePointSelection=function(){var e=this.getPointArray();this.pointSelection.set.each((function(t){this.cx()===e[t][0]&&this.cy()===e[t][1]||this.center(e[t][0],e[t][1])}))},e.prototype.updateRectSelection=function(){var e=this,t=this.el.bbox();if(this.rectSelection.set.get(0).attr({width:t.width,height:t.height}),this.options.points.length&&this.options.points.map((function(i,n){var r=e.pointCoords(i,t);e.rectSelection.set.get(n+1).center(r.x,r.y)})),this.options.rotationPoint){var i=this.rectSelection.set.length();this.rectSelection.set.get(i-1).center(t.width/2,20)}},e.prototype.selectRect=function(e){var t=this,i=this.el.bbox();function n(e){return function(i){(i=i||window.event).preventDefault?i.preventDefault():i.returnValue=!1,i.stopPropagation();var n=i.pageX||i.touches[0].pageX,r=i.pageY||i.touches[0].pageY;t.el.fire(e,{x:n,y:r,event:i})}}if(this.rectSelection.isSelected=e,this.rectSelection.set=this.rectSelection.set||this.parent.set(),this.rectSelection.set.get(0)||this.rectSelection.set.add(this.nested.rect(i.width,i.height).addClass(this.options.classRect)),this.options.points.length&&this.rectSelection.set.length()<2&&(this.options.points.map((function(e,r){var a=t.pointCoords(e,i),s=t.drawPoint(a.x,a.y).attr("class",t.options.classPoints+"_"+e).on("mousedown",n(e)).on("touchstart",n(e));t.rectSelection.set.add(s)})),this.rectSelection.set.each((function(){this.addClass(t.options.classPoints)}))),this.options.rotationPoint&&(this.options.points&&!this.rectSelection.set.get(9)||!this.options.points&&!this.rectSelection.set.get(1))){var r=function(e){(e=e||window.event).preventDefault?e.preventDefault():e.returnValue=!1,e.stopPropagation();var i=e.pageX||e.touches[0].pageX,n=e.pageY||e.touches[0].pageY;t.el.fire("rot",{x:i,y:n,event:e})},a=this.drawPoint(i.width/2,20).attr("class",this.options.classPoints+"_rot").on("touchstart",r).on("mousedown",r);this.rectSelection.set.add(a)}},e.prototype.handler=function(){var e=this.el.bbox();this.nested.matrix(new SVG.Matrix(this.el).translate(e.x,e.y)),this.rectSelection.isSelected&&this.updateRectSelection(),this.pointSelection.isSelected&&this.updatePointSelection()},e.prototype.observe=function(){var e=this;if(MutationObserver)if(this.rectSelection.isSelected||this.pointSelection.isSelected)this.observerInst=this.observerInst||new MutationObserver((function(){e.handler()})),this.observerInst.observe(this.el.node,{attributes:!0});else try{this.observerInst.disconnect(),delete this.observerInst}catch(e){}else this.el.off("DOMAttrModified.select"),(this.rectSelection.isSelected||this.pointSelection.isSelected)&&this.el.on("DOMAttrModified.select",(function(){e.handler()}))},e.prototype.cleanup=function(){!this.rectSelection.isSelected&&this.rectSelection.set&&(this.rectSelection.set.each((function(){this.remove()})),this.rectSelection.set.clear(),delete this.rectSelection.set),!this.pointSelection.isSelected&&this.pointSelection.set&&(this.pointSelection.set.each((function(){this.remove()})),this.pointSelection.set.clear(),delete this.pointSelection.set),this.pointSelection.isSelected||this.rectSelection.isSelected||(this.nested.remove(),delete this.nested)},SVG.extend(SVG.Element,{selectize:function(t,i){return"object"==typeof t&&(i=t,t=!0),(this.remember("_selectHandler")||new e(this)).init(void 0===t||t,i||{}),this}}),SVG.Element.prototype.selectize.defaults={points:["lt","rt","rb","lb","t","r","b","l"],pointsExclude:[],classRect:"svg_select_boundingRect",classPoints:"svg_select_points",pointSize:7,rotationPoint:!0,deepSelect:!1,pointType:"circle"}}(),function(){(function(){function e(e){e.remember("_resizeHandler",this),this.el=e,this.parameters={},this.lastUpdateCall=null,this.p=e.doc().node.createSVGPoint()}e.prototype.transformPoint=function(e,t,i){return this.p.x=e-(this.offset.x-window.pageXOffset),this.p.y=t-(this.offset.y-window.pageYOffset),this.p.matrixTransform(i||this.m)},e.prototype._extractPosition=function(e){return{x:null!=e.clientX?e.clientX:e.touches[0].clientX,y:null!=e.clientY?e.clientY:e.touches[0].clientY}},e.prototype.init=function(e){var t=this;if(this.stop(),"stop"!==e){for(var i in this.options={},this.el.resize.defaults)this.options[i]=this.el.resize.defaults[i],void 0!==e[i]&&(this.options[i]=e[i]);this.el.on("lt.resize",(function(e){t.resize(e||window.event)})),this.el.on("rt.resize",(function(e){t.resize(e||window.event)})),this.el.on("rb.resize",(function(e){t.resize(e||window.event)})),this.el.on("lb.resize",(function(e){t.resize(e||window.event)})),this.el.on("t.resize",(function(e){t.resize(e||window.event)})),this.el.on("r.resize",(function(e){t.resize(e||window.event)})),this.el.on("b.resize",(function(e){t.resize(e||window.event)})),this.el.on("l.resize",(function(e){t.resize(e||window.event)})),this.el.on("rot.resize",(function(e){t.resize(e||window.event)})),this.el.on("point.resize",(function(e){t.resize(e||window.event)})),this.update()}},e.prototype.stop=function(){return this.el.off("lt.resize"),this.el.off("rt.resize"),this.el.off("rb.resize"),this.el.off("lb.resize"),this.el.off("t.resize"),this.el.off("r.resize"),this.el.off("b.resize"),this.el.off("l.resize"),this.el.off("rot.resize"),this.el.off("point.resize"),this},e.prototype.resize=function(e){var t=this;this.m=this.el.node.getScreenCTM().inverse(),this.offset={x:window.pageXOffset,y:window.pageYOffset};var i=this._extractPosition(e.detail.event);if(this.parameters={type:this.el.type,p:this.transformPoint(i.x,i.y),x:e.detail.x,y:e.detail.y,box:this.el.bbox(),rotation:this.el.transform().rotation},"text"===this.el.type&&(this.parameters.fontSize=this.el.attr()["font-size"]),void 0!==e.detail.i){var n=this.el.array().valueOf();this.parameters.i=e.detail.i,this.parameters.pointCoords=[n[e.detail.i][0],n[e.detail.i][1]]}switch(e.type){case"lt":this.calc=function(e,t){var i=this.snapToGrid(e,t);if(this.parameters.box.width-i[0]>0&&this.parameters.box.height-i[1]>0){if("text"===this.parameters.type)return this.el.move(this.parameters.box.x+i[0],this.parameters.box.y),void this.el.attr("font-size",this.parameters.fontSize-i[0]);i=this.checkAspectRatio(i),this.el.move(this.parameters.box.x+i[0],this.parameters.box.y+i[1]).size(this.parameters.box.width-i[0],this.parameters.box.height-i[1])}};break;case"rt":this.calc=function(e,t){var i=this.snapToGrid(e,t,2);if(this.parameters.box.width+i[0]>0&&this.parameters.box.height-i[1]>0){if("text"===this.parameters.type)return this.el.move(this.parameters.box.x-i[0],this.parameters.box.y),void this.el.attr("font-size",this.parameters.fontSize+i[0]);i=this.checkAspectRatio(i,!0),this.el.move(this.parameters.box.x,this.parameters.box.y+i[1]).size(this.parameters.box.width+i[0],this.parameters.box.height-i[1])}};break;case"rb":this.calc=function(e,t){var i=this.snapToGrid(e,t,0);if(this.parameters.box.width+i[0]>0&&this.parameters.box.height+i[1]>0){if("text"===this.parameters.type)return this.el.move(this.parameters.box.x-i[0],this.parameters.box.y),void this.el.attr("font-size",this.parameters.fontSize+i[0]);i=this.checkAspectRatio(i),this.el.move(this.parameters.box.x,this.parameters.box.y).size(this.parameters.box.width+i[0],this.parameters.box.height+i[1])}};break;case"lb":this.calc=function(e,t){var i=this.snapToGrid(e,t,1);if(this.parameters.box.width-i[0]>0&&this.parameters.box.height+i[1]>0){if("text"===this.parameters.type)return this.el.move(this.parameters.box.x+i[0],this.parameters.box.y),void this.el.attr("font-size",this.parameters.fontSize-i[0]);i=this.checkAspectRatio(i,!0),this.el.move(this.parameters.box.x+i[0],this.parameters.box.y).size(this.parameters.box.width-i[0],this.parameters.box.height+i[1])}};break;case"t":this.calc=function(e,t){var i=this.snapToGrid(e,t,2);if(this.parameters.box.height-i[1]>0){if("text"===this.parameters.type)return;this.el.move(this.parameters.box.x,this.parameters.box.y+i[1]).height(this.parameters.box.height-i[1])}};break;case"r":this.calc=function(e,t){var i=this.snapToGrid(e,t,0);if(this.parameters.box.width+i[0]>0){if("text"===this.parameters.type)return;this.el.move(this.parameters.box.x,this.parameters.box.y).width(this.parameters.box.width+i[0])}};break;case"b":this.calc=function(e,t){var i=this.snapToGrid(e,t,0);if(this.parameters.box.height+i[1]>0){if("text"===this.parameters.type)return;this.el.move(this.parameters.box.x,this.parameters.box.y).height(this.parameters.box.height+i[1])}};break;case"l":this.calc=function(e,t){var i=this.snapToGrid(e,t,1);if(this.parameters.box.width-i[0]>0){if("text"===this.parameters.type)return;this.el.move(this.parameters.box.x+i[0],this.parameters.box.y).width(this.parameters.box.width-i[0])}};break;case"rot":this.calc=function(e,t){var i=e+this.parameters.p.x,n=t+this.parameters.p.y,r=Math.atan2(this.parameters.p.y-this.parameters.box.y-this.parameters.box.height/2,this.parameters.p.x-this.parameters.box.x-this.parameters.box.width/2),a=Math.atan2(n-this.parameters.box.y-this.parameters.box.height/2,i-this.parameters.box.x-this.parameters.box.width/2),s=this.parameters.rotation+180*(a-r)/Math.PI+this.options.snapToAngle/2;this.el.center(this.parameters.box.cx,this.parameters.box.cy).rotate(s-s%this.options.snapToAngle,this.parameters.box.cx,this.parameters.box.cy)};break;case"point":this.calc=function(e,t){var i=this.snapToGrid(e,t,this.parameters.pointCoords[0],this.parameters.pointCoords[1]),n=this.el.array().valueOf();n[this.parameters.i][0]=this.parameters.pointCoords[0]+i[0],n[this.parameters.i][1]=this.parameters.pointCoords[1]+i[1],this.el.plot(n)}}this.el.fire("resizestart",{dx:this.parameters.x,dy:this.parameters.y,event:e}),SVG.on(window,"touchmove.resize",(function(e){t.update(e||window.event)})),SVG.on(window,"touchend.resize",(function(){t.done()})),SVG.on(window,"mousemove.resize",(function(e){t.update(e||window.event)})),SVG.on(window,"mouseup.resize",(function(){t.done()}))},e.prototype.update=function(e){if(e){var t=this._extractPosition(e),i=this.transformPoint(t.x,t.y),n=i.x-this.parameters.p.x,r=i.y-this.parameters.p.y;this.lastUpdateCall=[n,r],this.calc(n,r),this.el.fire("resizing",{dx:n,dy:r,event:e})}else this.lastUpdateCall&&this.calc(this.lastUpdateCall[0],this.lastUpdateCall[1])},e.prototype.done=function(){this.lastUpdateCall=null,SVG.off(window,"mousemove.resize"),SVG.off(window,"mouseup.resize"),SVG.off(window,"touchmove.resize"),SVG.off(window,"touchend.resize"),this.el.fire("resizedone")},e.prototype.snapToGrid=function(e,t,i,n){var r;return void 0!==n?r=[(i+e)%this.options.snapToGrid,(n+t)%this.options.snapToGrid]:(i=null==i?3:i,r=[(this.parameters.box.x+e+(1&i?0:this.parameters.box.width))%this.options.snapToGrid,(this.parameters.box.y+t+(2&i?0:this.parameters.box.height))%this.options.snapToGrid]),e<0&&(r[0]-=this.options.snapToGrid),t<0&&(r[1]-=this.options.snapToGrid),e-=Math.abs(r[0])<this.options.snapToGrid/2?r[0]:r[0]-(e<0?-this.options.snapToGrid:this.options.snapToGrid),t-=Math.abs(r[1])<this.options.snapToGrid/2?r[1]:r[1]-(t<0?-this.options.snapToGrid:this.options.snapToGrid),this.constraintToBox(e,t,i,n)},e.prototype.constraintToBox=function(e,t,i,n){var r,a,s=this.options.constraint||{};return void 0!==n?(r=i,a=n):(r=this.parameters.box.x+(1&i?0:this.parameters.box.width),a=this.parameters.box.y+(2&i?0:this.parameters.box.height)),void 0!==s.minX&&r+e<s.minX&&(e=s.minX-r),void 0!==s.maxX&&r+e>s.maxX&&(e=s.maxX-r),void 0!==s.minY&&a+t<s.minY&&(t=s.minY-a),void 0!==s.maxY&&a+t>s.maxY&&(t=s.maxY-a),[e,t]},e.prototype.checkAspectRatio=function(e,t){if(!this.options.saveAspectRatio)return e;var i=e.slice(),n=this.parameters.box.width/this.parameters.box.height,r=this.parameters.box.width+e[0],a=this.parameters.box.height-e[1],s=r/a;return s<n?(i[1]=r/n-this.parameters.box.height,t&&(i[1]=-i[1])):s>n&&(i[0]=this.parameters.box.width-a*n,t&&(i[0]=-i[0])),i},SVG.extend(SVG.Element,{resize:function(t){return(this.remember("_resizeHandler")||new e(this)).init(t||{}),this}}),SVG.Element.prototype.resize.defaults={snapToAngle:.1,snapToGrid:1,constraint:{},saveAspectRatio:!1}}).call(this)}(),void 0===window.Apex&&(window.Apex={});var ze=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"initModules",value:function(){this.ctx.publicMethods=["updateOptions","updateSeries","appendData","appendSeries","isSeriesHidden","toggleSeries","showSeries","hideSeries","setLocale","resetSeries","zoomX","toggleDataPointSelection","dataURI","exportToCSV","addXaxisAnnotation","addYaxisAnnotation","addPointAnnotation","clearAnnotations","removeAnnotation","paper","destroy"],this.ctx.eventList=["click","mousedown","mousemove","mouseleave","touchstart","touchmove","touchleave","mouseup","touchend"],this.ctx.animations=new v(this.ctx),this.ctx.axes=new K(this.ctx),this.ctx.core=new Fe(this.ctx.el,this.ctx),this.ctx.config=new Y({}),this.ctx.data=new B(this.ctx),this.ctx.grid=new U(this.ctx),this.ctx.graphics=new b(this.ctx),this.ctx.coreUtils=new x(this.ctx),this.ctx.crosshairs=new J(this.ctx),this.ctx.events=new G(this.ctx),this.ctx.exports=new V(this.ctx),this.ctx.localization=new Z(this.ctx),this.ctx.options=new C,this.ctx.responsive=new Q(this.ctx),this.ctx.series=new z(this.ctx),this.ctx.theme=new ee(this.ctx),this.ctx.formatters=new M(this.ctx),this.ctx.titleSubtitle=new te(this.ctx),this.ctx.legend=new le(this.ctx),this.ctx.toolbar=new ce(this.ctx),this.ctx.tooltip=new ve(this.ctx),this.ctx.dimensions=new se(this.ctx),this.ctx.updateHelpers=new Re(this.ctx),this.ctx.zoomPanSelection=new ue(this.ctx),this.ctx.w.globals.tooltip=new ve(this.ctx)}}]),e}(),Be=function(){function e(t){n(this,e),this.ctx=t,this.w=t.w}return a(e,[{key:"clear",value:function(e){var t=e.isUpdating;this.ctx.zoomPanSelection&&this.ctx.zoomPanSelection.destroy(),this.ctx.toolbar&&this.ctx.toolbar.destroy(),this.ctx.animations=null,this.ctx.axes=null,this.ctx.annotations=null,this.ctx.core=null,this.ctx.data=null,this.ctx.grid=null,this.ctx.series=null,this.ctx.responsive=null,this.ctx.theme=null,this.ctx.formatters=null,this.ctx.titleSubtitle=null,this.ctx.legend=null,this.ctx.dimensions=null,this.ctx.options=null,this.ctx.crosshairs=null,this.ctx.zoomPanSelection=null,this.ctx.updateHelpers=null,this.ctx.toolbar=null,this.ctx.localization=null,this.ctx.w.globals.tooltip=null,this.clearDomElements({isUpdating:t})}},{key:"killSVG",value:function(e){e.each((function(e,t){this.removeClass("*"),this.off(),this.stop()}),!0),e.ungroup(),e.clear()}},{key:"clearDomElements",value:function(e){var t=this,i=e.isUpdating,n=this.w.globals.dom.Paper.node;n.parentNode&&n.parentNode.parentNode&&!i&&(n.parentNode.parentNode.style.minHeight="unset");var r=this.w.globals.dom.baseEl;r&&this.ctx.eventList.forEach((function(e){r.removeEventListener(e,t.ctx.events.documentEvent)}));var a=this.w.globals.dom;if(null!==this.ctx.el)for(;this.ctx.el.firstChild;)this.ctx.el.removeChild(this.ctx.el.firstChild);this.killSVG(a.Paper),a.Paper.remove(),a.elWrap=null,a.elGraphical=null,a.elLegendWrap=null,a.elLegendForeign=null,a.baseEl=null,a.elGridRect=null,a.elGridRectMask=null,a.elGridRectMarkerMask=null,a.elForecastMask=null,a.elNonForecastMask=null,a.elDefs=null}}]),e}(),Ve=new WeakMap,We=function(){function e(t,i){n(this,e),this.opts=i,this.ctx=this,this.w=new N(i).init(),this.el=t,this.w.globals.cuid=g.randomId(),this.w.globals.chartID=this.w.config.chart.id?g.escapeString(this.w.config.chart.id):this.w.globals.cuid,new ze(this).initModules(),this.create=g.bind(this.create,this),this.windowResizeHandler=this._windowResizeHandler.bind(this),this.parentResizeHandler=this._parentResizeCallback.bind(this)}return a(e,[{key:"render",value:function(){var e=this;return new Promise((function(t,i){if(null!==e.el){void 0===Apex._chartInstances&&(Apex._chartInstances=[]),e.w.config.chart.id&&Apex._chartInstances.push({id:e.w.globals.chartID,group:e.w.config.chart.group,chart:e}),e.setLocale(e.w.config.chart.defaultLocale);var n=e.w.config.chart.events.beforeMount;"function"==typeof n&&n(e,e.w),e.events.fireEvent("beforeMount",[e,e.w]),window.addEventListener("resize",e.windowResizeHandler),function(e,t){var i=!1;if(e.nodeType!==Node.DOCUMENT_FRAGMENT_NODE){var n=e.getBoundingClientRect();"none"!==e.style.display&&0!==n.width||(i=!0)}var r=new ResizeObserver((function(n){i&&t.call(e,n),i=!0}));e.nodeType===Node.DOCUMENT_FRAGMENT_NODE?Array.from(e.children).forEach((function(e){return r.observe(e)})):r.observe(e),Ve.set(t,r)}(e.el.parentNode,e.parentResizeHandler);var r=e.el.getRootNode&&e.el.getRootNode(),a=g.is("ShadowRoot",r),s=e.el.ownerDocument,o=a?r.getElementById("apexcharts-css"):s.getElementById("apexcharts-css");if(!o){var l;(o=document.createElement("style")).id="apexcharts-css",o.textContent='@keyframes opaque {\n  0% {\n      opacity: 0\n  }\n\n  to {\n      opacity: 1\n  }\n}\n\n@keyframes resizeanim {\n  0%,to {\n      opacity: 0\n  }\n}\n\n.apexcharts-canvas {\n  position: relative;\n  user-select: none\n}\n\n.apexcharts-canvas ::-webkit-scrollbar {\n  -webkit-appearance: none;\n  width: 6px\n}\n\n.apexcharts-canvas ::-webkit-scrollbar-thumb {\n  border-radius: 4px;\n  background-color: rgba(0,0,0,.5);\n  box-shadow: 0 0 1px rgba(255,255,255,.5);\n  -webkit-box-shadow: 0 0 1px rgba(255,255,255,.5)\n}\n\n.apexcharts-inner {\n  position: relative\n}\n\n.apexcharts-text tspan {\n  font-family: inherit\n}\n\n.legend-mouseover-inactive {\n  transition: .15s ease all;\n  opacity: .2\n}\n\n.apexcharts-legend-text {\n  padding-left: 15px;\n  margin-left: -15px;\n}\n\n.apexcharts-series-collapsed {\n  opacity: 0\n}\n\n.apexcharts-tooltip {\n  border-radius: 5px;\n  box-shadow: 2px 2px 6px -4px #999;\n  cursor: default;\n  font-size: 14px;\n  left: 62px;\n  opacity: 0;\n  pointer-events: none;\n  position: absolute;\n  top: 20px;\n  display: flex;\n  flex-direction: column;\n  overflow: hidden;\n  white-space: nowrap;\n  z-index: 12;\n  transition: .15s ease all\n}\n\n.apexcharts-tooltip.apexcharts-active {\n  opacity: 1;\n  transition: .15s ease all\n}\n\n.apexcharts-tooltip.apexcharts-theme-light {\n  border: 1px solid #e3e3e3;\n  background: rgba(255,255,255,.96)\n}\n\n.apexcharts-tooltip.apexcharts-theme-dark {\n  color: #fff;\n  background: rgba(30,30,30,.8)\n}\n\n.apexcharts-tooltip * {\n  font-family: inherit\n}\n\n.apexcharts-tooltip-title {\n  padding: 6px;\n  font-size: 15px;\n  margin-bottom: 4px\n}\n\n.apexcharts-tooltip.apexcharts-theme-light .apexcharts-tooltip-title {\n  background: #eceff1;\n  border-bottom: 1px solid #ddd\n}\n\n.apexcharts-tooltip.apexcharts-theme-dark .apexcharts-tooltip-title {\n  background: rgba(0,0,0,.7);\n  border-bottom: 1px solid #333\n}\n\n.apexcharts-tooltip-text-goals-value,.apexcharts-tooltip-text-y-value,.apexcharts-tooltip-text-z-value {\n  display: inline-block;\n  margin-left: 5px;\n  font-weight: 600\n}\n\n.apexcharts-tooltip-text-goals-label:empty,.apexcharts-tooltip-text-goals-value:empty,.apexcharts-tooltip-text-y-label:empty,.apexcharts-tooltip-text-y-value:empty,.apexcharts-tooltip-text-z-value:empty,.apexcharts-tooltip-title:empty {\n  display: none\n}\n\n.apexcharts-tooltip-text-goals-label,.apexcharts-tooltip-text-goals-value {\n  padding: 6px 0 5px\n}\n\n.apexcharts-tooltip-goals-group,.apexcharts-tooltip-text-goals-label,.apexcharts-tooltip-text-goals-value {\n  display: flex\n}\n\n.apexcharts-tooltip-text-goals-label:not(:empty),.apexcharts-tooltip-text-goals-value:not(:empty) {\n  margin-top: -6px\n}\n\n.apexcharts-tooltip-marker {\n  width: 12px;\n  height: 12px;\n  position: relative;\n  top: 0;\n  margin-right: 10px;\n  border-radius: 50%\n}\n\n.apexcharts-tooltip-series-group {\n  padding: 0 10px;\n  display: none;\n  text-align: left;\n  justify-content: left;\n  align-items: center\n}\n\n.apexcharts-tooltip-series-group.apexcharts-active .apexcharts-tooltip-marker {\n  opacity: 1\n}\n\n.apexcharts-tooltip-series-group.apexcharts-active,.apexcharts-tooltip-series-group:last-child {\n  padding-bottom: 4px\n}\n\n.apexcharts-tooltip-series-group-hidden {\n  opacity: 0;\n  height: 0;\n  line-height: 0;\n  padding: 0!important\n}\n\n.apexcharts-tooltip-y-group {\n  padding: 6px 0 5px\n}\n\n.apexcharts-custom-tooltip,.apexcharts-tooltip-box {\n  padding: 4px 8px\n}\n\n.apexcharts-tooltip-boxPlot {\n  display: flex;\n  flex-direction: column-reverse\n}\n\n.apexcharts-tooltip-box>div {\n  margin: 4px 0\n}\n\n.apexcharts-tooltip-box span.value {\n  font-weight: 700\n}\n\n.apexcharts-tooltip-rangebar {\n  padding: 5px 8px\n}\n\n.apexcharts-tooltip-rangebar .category {\n  font-weight: 600;\n  color: #777\n}\n\n.apexcharts-tooltip-rangebar .series-name {\n  font-weight: 700;\n  display: block;\n  margin-bottom: 5px\n}\n\n.apexcharts-xaxistooltip,.apexcharts-yaxistooltip {\n  opacity: 0;\n  pointer-events: none;\n  color: #373d3f;\n  font-size: 13px;\n  text-align: center;\n  border-radius: 2px;\n  position: absolute;\n  z-index: 10;\n  background: #eceff1;\n  border: 1px solid #90a4ae\n}\n\n.apexcharts-xaxistooltip {\n  padding: 9px 10px;\n  transition: .15s ease all\n}\n\n.apexcharts-xaxistooltip.apexcharts-theme-dark {\n  background: rgba(0,0,0,.7);\n  border: 1px solid rgba(0,0,0,.5);\n  color: #fff\n}\n\n.apexcharts-xaxistooltip:after,.apexcharts-xaxistooltip:before {\n  left: 50%;\n  border: solid transparent;\n  content: " ";\n  height: 0;\n  width: 0;\n  position: absolute;\n  pointer-events: none\n}\n\n.apexcharts-xaxistooltip:after {\n  border-color: transparent;\n  border-width: 6px;\n  margin-left: -6px\n}\n\n.apexcharts-xaxistooltip:before {\n  border-color: transparent;\n  border-width: 7px;\n  margin-left: -7px\n}\n\n.apexcharts-xaxistooltip-bottom:after,.apexcharts-xaxistooltip-bottom:before {\n  bottom: 100%\n}\n\n.apexcharts-xaxistooltip-top:after,.apexcharts-xaxistooltip-top:before {\n  top: 100%\n}\n\n.apexcharts-xaxistooltip-bottom:after {\n  border-bottom-color: #eceff1\n}\n\n.apexcharts-xaxistooltip-bottom:before {\n  border-bottom-color: #90a4ae\n}\n\n.apexcharts-xaxistooltip-bottom.apexcharts-theme-dark:after,.apexcharts-xaxistooltip-bottom.apexcharts-theme-dark:before {\n  border-bottom-color: rgba(0,0,0,.5)\n}\n\n.apexcharts-xaxistooltip-top:after {\n  border-top-color: #eceff1\n}\n\n.apexcharts-xaxistooltip-top:before {\n  border-top-color: #90a4ae\n}\n\n.apexcharts-xaxistooltip-top.apexcharts-theme-dark:after,.apexcharts-xaxistooltip-top.apexcharts-theme-dark:before {\n  border-top-color: rgba(0,0,0,.5)\n}\n\n.apexcharts-xaxistooltip.apexcharts-active {\n  opacity: 1;\n  transition: .15s ease all\n}\n\n.apexcharts-yaxistooltip {\n  padding: 4px 10px\n}\n\n.apexcharts-yaxistooltip.apexcharts-theme-dark {\n  background: rgba(0,0,0,.7);\n  border: 1px solid rgba(0,0,0,.5);\n  color: #fff\n}\n\n.apexcharts-yaxistooltip:after,.apexcharts-yaxistooltip:before {\n  top: 50%;\n  border: solid transparent;\n  content: " ";\n  height: 0;\n  width: 0;\n  position: absolute;\n  pointer-events: none\n}\n\n.apexcharts-yaxistooltip:after {\n  border-color: transparent;\n  border-width: 6px;\n  margin-top: -6px\n}\n\n.apexcharts-yaxistooltip:before {\n  border-color: transparent;\n  border-width: 7px;\n  margin-top: -7px\n}\n\n.apexcharts-yaxistooltip-left:after,.apexcharts-yaxistooltip-left:before {\n  left: 100%\n}\n\n.apexcharts-yaxistooltip-right:after,.apexcharts-yaxistooltip-right:before {\n  right: 100%\n}\n\n.apexcharts-yaxistooltip-left:after {\n  border-left-color: #eceff1\n}\n\n.apexcharts-yaxistooltip-left:before {\n  border-left-color: #90a4ae\n}\n\n.apexcharts-yaxistooltip-left.apexcharts-theme-dark:after,.apexcharts-yaxistooltip-left.apexcharts-theme-dark:before {\n  border-left-color: rgba(0,0,0,.5)\n}\n\n.apexcharts-yaxistooltip-right:after {\n  border-right-color: #eceff1\n}\n\n.apexcharts-yaxistooltip-right:before {\n  border-right-color: #90a4ae\n}\n\n.apexcharts-yaxistooltip-right.apexcharts-theme-dark:after,.apexcharts-yaxistooltip-right.apexcharts-theme-dark:before {\n  border-right-color: rgba(0,0,0,.5)\n}\n\n.apexcharts-yaxistooltip.apexcharts-active {\n  opacity: 1\n}\n\n.apexcharts-yaxistooltip-hidden {\n  display: none\n}\n\n.apexcharts-xcrosshairs,.apexcharts-ycrosshairs {\n  pointer-events: none;\n  opacity: 0;\n  transition: .15s ease all\n}\n\n.apexcharts-xcrosshairs.apexcharts-active,.apexcharts-ycrosshairs.apexcharts-active {\n  opacity: 1;\n  transition: .15s ease all\n}\n\n.apexcharts-ycrosshairs-hidden {\n  opacity: 0\n}\n\n.apexcharts-selection-rect {\n  cursor: move\n}\n\n.svg_select_boundingRect,.svg_select_points_rot {\n  pointer-events: none;\n  opacity: 0;\n  visibility: hidden\n}\n\n.apexcharts-selection-rect+g .svg_select_boundingRect,.apexcharts-selection-rect+g .svg_select_points_rot {\n  opacity: 0;\n  visibility: hidden\n}\n\n.apexcharts-selection-rect+g .svg_select_points_l,.apexcharts-selection-rect+g .svg_select_points_r {\n  cursor: ew-resize;\n  opacity: 1;\n  visibility: visible\n}\n\n.svg_select_points {\n  fill: #efefef;\n  stroke: #333;\n  rx: 2\n}\n\n.apexcharts-svg.apexcharts-zoomable.hovering-zoom {\n  cursor: crosshair\n}\n\n.apexcharts-svg.apexcharts-zoomable.hovering-pan {\n  cursor: move\n}\n\n.apexcharts-menu-icon,.apexcharts-pan-icon,.apexcharts-reset-icon,.apexcharts-selection-icon,.apexcharts-toolbar-custom-icon,.apexcharts-zoom-icon,.apexcharts-zoomin-icon,.apexcharts-zoomout-icon {\n  cursor: pointer;\n  width: 20px;\n  height: 20px;\n  line-height: 24px;\n  color: #6e8192;\n  text-align: center\n}\n\n.apexcharts-menu-icon svg,.apexcharts-reset-icon svg,.apexcharts-zoom-icon svg,.apexcharts-zoomin-icon svg,.apexcharts-zoomout-icon svg {\n  fill: #6e8192\n}\n\n.apexcharts-selection-icon svg {\n  fill: #444;\n  transform: scale(.76)\n}\n\n.apexcharts-theme-dark .apexcharts-menu-icon svg,.apexcharts-theme-dark .apexcharts-pan-icon svg,.apexcharts-theme-dark .apexcharts-reset-icon svg,.apexcharts-theme-dark .apexcharts-selection-icon svg,.apexcharts-theme-dark .apexcharts-toolbar-custom-icon svg,.apexcharts-theme-dark .apexcharts-zoom-icon svg,.apexcharts-theme-dark .apexcharts-zoomin-icon svg,.apexcharts-theme-dark .apexcharts-zoomout-icon svg {\n  fill: #f3f4f5\n}\n\n.apexcharts-canvas .apexcharts-reset-zoom-icon.apexcharts-selected svg,.apexcharts-canvas .apexcharts-selection-icon.apexcharts-selected svg,.apexcharts-canvas .apexcharts-zoom-icon.apexcharts-selected svg {\n  fill: #008ffb\n}\n\n.apexcharts-theme-light .apexcharts-menu-icon:hover svg,.apexcharts-theme-light .apexcharts-reset-icon:hover svg,.apexcharts-theme-light .apexcharts-selection-icon:not(.apexcharts-selected):hover svg,.apexcharts-theme-light .apexcharts-zoom-icon:not(.apexcharts-selected):hover svg,.apexcharts-theme-light .apexcharts-zoomin-icon:hover svg,.apexcharts-theme-light .apexcharts-zoomout-icon:hover svg {\n  fill: #333\n}\n\n.apexcharts-menu-icon,.apexcharts-selection-icon {\n  position: relative\n}\n\n.apexcharts-reset-icon {\n  margin-left: 5px\n}\n\n.apexcharts-menu-icon,.apexcharts-reset-icon,.apexcharts-zoom-icon {\n  transform: scale(.85)\n}\n\n.apexcharts-zoomin-icon,.apexcharts-zoomout-icon {\n  transform: scale(.7)\n}\n\n.apexcharts-zoomout-icon {\n  margin-right: 3px\n}\n\n.apexcharts-pan-icon {\n  transform: scale(.62);\n  position: relative;\n  left: 1px;\n  top: 0\n}\n\n.apexcharts-pan-icon svg {\n  fill: #fff;\n  stroke: #6e8192;\n  stroke-width: 2\n}\n\n.apexcharts-pan-icon.apexcharts-selected svg {\n  stroke: #008ffb\n}\n\n.apexcharts-pan-icon:not(.apexcharts-selected):hover svg {\n  stroke: #333\n}\n\n.apexcharts-toolbar {\n  position: absolute;\n  z-index: 11;\n  max-width: 176px;\n  text-align: right;\n  border-radius: 3px;\n  padding: 0 6px 2px;\n  display: flex;\n  justify-content: space-between;\n  align-items: center\n}\n\n.apexcharts-menu {\n  background: #fff;\n  position: absolute;\n  top: 100%;\n  border: 1px solid #ddd;\n  border-radius: 3px;\n  padding: 3px;\n  right: 10px;\n  opacity: 0;\n  min-width: 110px;\n  transition: .15s ease all;\n  pointer-events: none\n}\n\n.apexcharts-menu.apexcharts-menu-open {\n  opacity: 1;\n  pointer-events: all;\n  transition: .15s ease all\n}\n\n.apexcharts-menu-item {\n  padding: 6px 7px;\n  font-size: 12px;\n  cursor: pointer\n}\n\n.apexcharts-theme-light .apexcharts-menu-item:hover {\n  background: #eee\n}\n\n.apexcharts-theme-dark .apexcharts-menu {\n  background: rgba(0,0,0,.7);\n  color: #fff\n}\n\n@media screen and (min-width:768px) {\n  .apexcharts-canvas:hover .apexcharts-toolbar {\n      opacity: 1\n  }\n}\n\n.apexcharts-canvas .apexcharts-element-hidden,.apexcharts-datalabel.apexcharts-element-hidden,.apexcharts-hide .apexcharts-series-points {\n  display: none;\n}\n\n.apexcharts-hidden-element-shown {\n  opacity: 1;\n  transition: 0.25s ease all;\n}\n.apexcharts-datalabel,.apexcharts-datalabel-label,.apexcharts-datalabel-value,.apexcharts-datalabels,.apexcharts-pie-label {\n  cursor: default;\n  pointer-events: none\n}\n\n.apexcharts-pie-label-delay {\n  opacity: 0;\n  animation-name: opaque;\n  animation-duration: .3s;\n  animation-fill-mode: forwards;\n  animation-timing-function: ease\n}\n\n.apexcharts-radialbar-label {\n  cursor: pointer;\n}\n\n.apexcharts-annotation-rect,.apexcharts-area-series .apexcharts-area,.apexcharts-area-series .apexcharts-series-markers .apexcharts-marker.no-pointer-events,.apexcharts-gridline,.apexcharts-line,.apexcharts-line-series .apexcharts-series-markers .apexcharts-marker.no-pointer-events,.apexcharts-point-annotation-label,.apexcharts-radar-series path,.apexcharts-radar-series polygon,.apexcharts-toolbar svg,.apexcharts-tooltip .apexcharts-marker,.apexcharts-xaxis-annotation-label,.apexcharts-yaxis-annotation-label,.apexcharts-zoom-rect {\n  pointer-events: none\n}\n\n.apexcharts-marker {\n  transition: .15s ease all\n}\n\n.resize-triggers {\n  animation: 1ms resizeanim;\n  visibility: hidden;\n  opacity: 0;\n  height: 100%;\n  width: 100%;\n  overflow: hidden\n}\n\n.contract-trigger:before,.resize-triggers,.resize-triggers>div {\n  content: " ";\n  display: block;\n  position: absolute;\n  top: 0;\n  left: 0\n}\n\n.resize-triggers>div {\n  height: 100%;\n  width: 100%;\n  background: #eee;\n  overflow: auto\n}\n\n.contract-trigger:before {\n  overflow: hidden;\n  width: 200%;\n  height: 200%\n}\n\n.apexcharts-bar-goals-markers{\n  pointer-events: none\n}\n\n.apexcharts-bar-shadows{\n  pointer-events: none\n}\n\n.apexcharts-rangebar-goals-markers{\n  pointer-events: none\n}';var c=(null===(l=e.opts.chart)||void 0===l?void 0:l.nonce)||e.w.config.chart.nonce;c&&o.setAttribute("nonce",c),a?r.prepend(o):s.head.appendChild(o)}var u=e.create(e.w.config.series,{});if(!u)return t(e);e.mount(u).then((function(){"function"==typeof e.w.config.chart.events.mounted&&e.w.config.chart.events.mounted(e,e.w),e.events.fireEvent("mounted",[e,e.w]),t(u)})).catch((function(e){i(e)}))}else i(new Error("Element not found"))}))}},{key:"create",value:function(e,t){var i=this.w;new ze(this).initModules();var n=this.w.globals;if(n.noData=!1,n.animationEnded=!1,this.responsive.checkResponsiveConfig(t),i.config.xaxis.convertedCatToNumeric&&new P(i.config).convertCatToNumericXaxis(i.config,this.ctx),null===this.el)return n.animationEnded=!0,null;if(this.core.setupElements(),"treemap"===i.config.chart.type&&(i.config.grid.show=!1,i.config.yaxis[0].show=!1),0===n.svgWidth)return n.animationEnded=!0,null;var r=x.checkComboSeries(e,i.config.chart.type);n.comboCharts=r.comboCharts,n.comboBarCount=r.comboBarCount;var a=e.every((function(e){return e.data&&0===e.data.length}));(0===e.length||a&&n.collapsedSeries.length<1)&&this.series.handleNoData(),this.events.setupEventHandlers(),this.data.parseData(e),this.theme.init(),new H(this).setGlobalMarkerSize(),this.formatters.setLabelFormatters(),this.titleSubtitle.draw(),n.noData&&n.collapsedSeries.length!==n.series.length&&!i.config.legend.showForSingleSeries||this.legend.init(),this.series.hasAllSeriesEqualX(),n.axisCharts&&(this.core.coreCalculations(),"category"!==i.config.xaxis.type&&this.formatters.setLabelFormatters(),this.ctx.toolbar.minX=i.globals.minX,this.ctx.toolbar.maxX=i.globals.maxX),this.formatters.heatmapLabelFormatters(),new x(this).getLargestMarkerSize(),this.dimensions.plotCoords();var s=this.core.xySettings();this.grid.createGridMask();var o=this.core.plotChartType(e,s),l=new R(this);return l.bringForward(),i.config.dataLabels.background.enabled&&l.dataLabelsBackground(),this.core.shiftGraphPosition(),{elGraph:o,xyRatios:s,dimensions:{plot:{left:i.globals.translateX,top:i.globals.translateY,width:i.globals.gridWidth,height:i.globals.gridHeight}}}}},{key:"mount",value:function(){var e=this,t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null,i=this,n=i.w;return new Promise((function(r,a){if(null===i.el)return a(new Error("Not enough data to display or target element not found"));(null===t||n.globals.allSeriesCollapsed)&&i.series.handleNoData(),i.grid=new U(i);var s,o,l=i.grid.drawGrid();if(i.annotations=new D(i),i.annotations.drawImageAnnos(),i.annotations.drawTextAnnos(),"back"===n.config.grid.position&&(l&&n.globals.dom.elGraphical.add(l.el),null!=l&&null!==(s=l.elGridBorders)&&void 0!==s&&s.node&&n.globals.dom.elGraphical.add(l.elGridBorders)),Array.isArray(t.elGraph))for(var c=0;c<t.elGraph.length;c++)n.globals.dom.elGraphical.add(t.elGraph[c]);else n.globals.dom.elGraphical.add(t.elGraph);"front"===n.config.grid.position&&(l&&n.globals.dom.elGraphical.add(l.el),null!=l&&null!==(o=l.elGridBorders)&&void 0!==o&&o.node&&n.globals.dom.elGraphical.add(l.elGridBorders)),"front"===n.config.xaxis.crosshairs.position&&i.crosshairs.drawXCrosshairs(),"front"===n.config.yaxis[0].crosshairs.position&&i.crosshairs.drawYCrosshairs(),"treemap"!==n.config.chart.type&&i.axes.drawAxis(n.config.chart.type,l);var u=new W(e.ctx,l),d=new X(e.ctx,l);if(null!==l&&(u.xAxisLabelCorrections(l.xAxisTickWidth),d.setYAxisTextAlignments(),n.config.yaxis.map((function(e,t){-1===n.globals.ignoreYAxisIndexes.indexOf(t)&&d.yAxisTitleRotate(t,e.opposite)}))),i.annotations.drawAxesAnnotations(),!n.globals.noData){if(n.config.tooltip.enabled&&!n.globals.noData&&i.w.globals.tooltip.drawTooltip(t.xyRatios),n.globals.axisCharts&&(n.globals.isXNumeric||n.config.xaxis.convertedCatToNumeric||n.globals.isRangeBar))(n.config.chart.zoom.enabled||n.config.chart.selection&&n.config.chart.selection.enabled||n.config.chart.pan&&n.config.chart.pan.enabled)&&i.zoomPanSelection.init({xyRatios:t.xyRatios});else{var h=n.config.chart.toolbar.tools;["zoom","zoomin","zoomout","selection","pan","reset"].forEach((function(e){h[e]=!1}))}n.config.chart.toolbar.show&&!n.globals.allSeriesCollapsed&&i.toolbar.createToolbar()}n.globals.memory.methodsToExec.length>0&&n.globals.memory.methodsToExec.forEach((function(e){e.method(e.params,!1,e.context)})),n.globals.axisCharts||n.globals.noData||i.core.resizeNonAxisCharts(),r(i)}))}},{key:"destroy",value:function(){var e,t;window.removeEventListener("resize",this.windowResizeHandler),this.el.parentNode,e=this.parentResizeHandler,(t=Ve.get(e))&&(t.disconnect(),Ve.delete(e));var i=this.w.config.chart.id;i&&Apex._chartInstances.forEach((function(e,t){e.id===g.escapeString(i)&&Apex._chartInstances.splice(t,1)})),new Be(this.ctx).clear({isUpdating:!1})}},{key:"updateOptions",value:function(e){var t=this,i=arguments.length>1&&void 0!==arguments[1]&&arguments[1],n=!(arguments.length>2&&void 0!==arguments[2])||arguments[2],r=!(arguments.length>3&&void 0!==arguments[3])||arguments[3],a=!(arguments.length>4&&void 0!==arguments[4])||arguments[4],s=this.w;return s.globals.selection=void 0,e.series&&(this.series.resetSeries(!1,!0,!1),e.series.length&&e.series[0].data&&(e.series=e.series.map((function(e,i){return t.updateHelpers._extendSeries(e,i)}))),this.updateHelpers.revertDefaultAxisMinMax()),e.xaxis&&(e=this.updateHelpers.forceXAxisUpdate(e)),e.yaxis&&(e=this.updateHelpers.forceYAxisUpdate(e)),s.globals.collapsedSeriesIndices.length>0&&this.series.clearPreviousPaths(),e.theme&&(e=this.theme.updateThemeOptions(e)),this.updateHelpers._updateOptions(e,i,n,r,a)}},{key:"updateSeries",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=!(arguments.length>2&&void 0!==arguments[2])||arguments[2];return this.series.resetSeries(!1),this.updateHelpers.revertDefaultAxisMinMax(),this.updateHelpers._updateSeries(e,t,i)}},{key:"appendSeries",value:function(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=!(arguments.length>2&&void 0!==arguments[2])||arguments[2],n=this.w.config.series.slice();return n.push(e),this.series.resetSeries(!1),this.updateHelpers.revertDefaultAxisMinMax(),this.updateHelpers._updateSeries(n,t,i)}},{key:"appendData",value:function(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=this;i.w.globals.dataChanged=!0,i.series.getPreviousPaths();for(var n=i.w.config.series.slice(),r=0;r<n.length;r++)if(null!==e[r]&&void 0!==e[r])for(var a=0;a<e[r].data.length;a++)n[r].data.push(e[r].data[a]);return i.w.config.series=n,t&&(i.w.globals.initialSeries=g.clone(i.w.config.series)),this.update()}},{key:"update",value:function(e){var t=this;return new Promise((function(i,n){new Be(t.ctx).clear({isUpdating:!0});var r=t.create(t.w.config.series,e);if(!r)return i(t);t.mount(r).then((function(){"function"==typeof t.w.config.chart.events.updated&&t.w.config.chart.events.updated(t,t.w),t.events.fireEvent("updated",[t,t.w]),t.w.globals.isDirty=!0,i(t)})).catch((function(e){n(e)}))}))}},{key:"getSyncedCharts",value:function(){var e=this.getGroupedCharts(),t=[this];return e.length&&(t=[],e.forEach((function(e){t.push(e)}))),t}},{key:"getGroupedCharts",value:function(){var e=this;return Apex._chartInstances.filter((function(e){if(e.group)return!0})).map((function(t){return e.w.config.chart.group===t.group?t.chart:e}))}},{key:"toggleSeries",value:function(e){return this.series.toggleSeries(e)}},{key:"highlightSeriesOnLegendHover",value:function(e,t){return this.series.toggleSeriesOnHover(e,t)}},{key:"showSeries",value:function(e){this.series.showSeries(e)}},{key:"hideSeries",value:function(e){this.series.hideSeries(e)}},{key:"isSeriesHidden",value:function(e){this.series.isSeriesHidden(e)}},{key:"resetSeries",value:function(){var e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0],t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];this.series.resetSeries(e,t)}},{key:"addEventListener",value:function(e,t){this.events.addEventListener(e,t)}},{key:"removeEventListener",value:function(e,t){this.events.removeEventListener(e,t)}},{key:"addXaxisAnnotation",value:function(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:void 0,n=this;i&&(n=i),n.annotations.addXaxisAnnotationExternal(e,t,n)}},{key:"addYaxisAnnotation",value:function(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:void 0,n=this;i&&(n=i),n.annotations.addYaxisAnnotationExternal(e,t,n)}},{key:"addPointAnnotation",value:function(e){var t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:void 0,n=this;i&&(n=i),n.annotations.addPointAnnotationExternal(e,t,n)}},{key:"clearAnnotations",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:void 0,t=this;e&&(t=e),t.annotations.clearAnnotations(t)}},{key:"removeAnnotation",value:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:void 0,i=this;t&&(i=t),i.annotations.removeAnnotation(i,e)}},{key:"getChartArea",value:function(){return this.w.globals.dom.baseEl.querySelector(".apexcharts-inner")}},{key:"getSeriesTotalXRange",value:function(e,t){return this.coreUtils.getSeriesTotalsXRange(e,t)}},{key:"getHighestValueInSeries",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0;return new $(this.ctx).getMinYMaxY(e).highestY}},{key:"getLowestValueInSeries",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:0;return new $(this.ctx).getMinYMaxY(e).lowestY}},{key:"getSeriesTotal",value:function(){return this.w.globals.seriesTotals}},{key:"toggleDataPointSelection",value:function(e,t){return this.updateHelpers.toggleDataPointSelection(e,t)}},{key:"zoomX",value:function(e,t){this.ctx.toolbar.zoomUpdateOptions(e,t)}},{key:"setLocale",value:function(e){this.localization.setCurrentLocaleValues(e)}},{key:"dataURI",value:function(e){return new V(this.ctx).dataURI(e)}},{key:"exportToCSV",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};return new V(this.ctx).exportToCSV(e)}},{key:"paper",value:function(){return this.w.globals.dom.Paper}},{key:"_parentResizeCallback",value:function(){this.w.globals.animationEnded&&this.w.config.chart.redrawOnParentResize&&this._windowResize()}},{key:"_windowResize",value:function(){var e=this;clearTimeout(this.w.globals.resizeTimer),this.w.globals.resizeTimer=window.setTimeout((function(){e.w.globals.resized=!0,e.w.globals.dataChanged=!1,e.ctx.update()}),150)}},{key:"_windowResizeHandler",value:function(){var e=this.w.config.chart.redrawOnWindowResize;"function"==typeof e&&(e=e()),e&&this._windowResize()}}],[{key:"getChartByID",value:function(e){var t=g.escapeString(e);if(Apex._chartInstances){var i=Apex._chartInstances.filter((function(e){return e.id===t}))[0];return i&&i.chart}}},{key:"initOnLoad",value:function(){for(var t=document.querySelectorAll("[data-apexcharts]"),i=0;i<t.length;i++)new e(t[i],JSON.parse(t[i].getAttribute("data-options"))).render()}},{key:"exec",value:function(e,t){var i=this.getChartByID(e);if(i){i.w.globals.isExecCalled=!0;var n=null;if(-1!==i.publicMethods.indexOf(t)){for(var r=arguments.length,a=new Array(r>2?r-2:0),s=2;s<r;s++)a[s-2]=arguments[s];n=i[t].apply(i,a)}return n}}},{key:"merge",value:function(e,t){return g.extend(e,t)}}]),e}();return We})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(e="undefined"!=typeof globalThis?globalThis:e||self).Chart=t()}(this,(function(){"use strict";var e=Object.freeze({__proto__:null,get Colors(){return Pa},get Decimation(){return Na},get Filler(){return Qa},get Legend(){return ns},get SubTitle(){return os},get Title(){return as},get Tooltip(){return ws}});function t(){}const i=(()=>{let e=0;return()=>e++})();function n(e){return null==e}function r(e){if(Array.isArray&&Array.isArray(e))return!0;const t=Object.prototype.toString.call(e);return"[object"===t.slice(0,7)&&"Array]"===t.slice(-6)}function a(e){return null!==e&&"[object Object]"===Object.prototype.toString.call(e)}function s(e){return("number"==typeof e||e instanceof Number)&&isFinite(+e)}function o(e,t){return s(e)?e:t}function l(e,t){return void 0===e?t:e}const c=(e,t)=>"string"==typeof e&&e.endsWith("%")?parseFloat(e)/100:+e/t,u=(e,t)=>"string"==typeof e&&e.endsWith("%")?parseFloat(e)/100*t:+e;function d(e,t,i){if(e&&"function"==typeof e.call)return e.apply(i,t)}function h(e,t,i,n){let s,o,l;if(r(e))if(o=e.length,n)for(s=o-1;s>=0;s--)t.call(i,e[s],s);else for(s=0;s<o;s++)t.call(i,e[s],s);else if(a(e))for(l=Object.keys(e),o=l.length,s=0;s<o;s++)t.call(i,e[l[s]],l[s])}function f(e,t){let i,n,r,a;if(!e||!t||e.length!==t.length)return!1;for(i=0,n=e.length;i<n;++i)if(r=e[i],a=t[i],r.datasetIndex!==a.datasetIndex||r.index!==a.index)return!1;return!0}function p(e){if(r(e))return e.map(p);if(a(e)){const t=Object.create(null),i=Object.keys(e),n=i.length;let r=0;for(;r<n;++r)t[i[r]]=p(e[i[r]]);return t}return e}function m(e){return-1===["__proto__","prototype","constructor"].indexOf(e)}function g(e,t,i,n){if(!m(e))return;const r=t[e],s=i[e];a(r)&&a(s)?v(r,s,n):t[e]=p(s)}function v(e,t,i){const n=r(t)?t:[t],s=n.length;if(!a(e))return e;const o=(i=i||{}).merger||g;let l;for(let t=0;t<s;++t){if(l=n[t],!a(l))continue;const r=Object.keys(l);for(let t=0,n=r.length;t<n;++t)o(r[t],e,l,i)}return e}function y(e,t){return v(e,t,{merger:b})}function b(e,t,i){if(!m(e))return;const n=t[e],r=i[e];a(n)&&a(r)?y(n,r):Object.prototype.hasOwnProperty.call(t,e)||(t[e]=p(r))}const x={"":e=>e,x:e=>e.x,y:e=>e.y};function _(e){const t=e.split("."),i=[];let n="";for(const e of t)n+=e,n.endsWith("\\")?n=n.slice(0,-1)+".":(i.push(n),n="");return i}function w(e,t){const i=x[t]||(x[t]=function(e){const t=_(e);return e=>{for(const i of t){if(""===i)break;e=e&&e[i]}return e}}(t));return i(e)}function k(e){return e.charAt(0).toUpperCase()+e.slice(1)}const M=e=>void 0!==e,S=e=>"function"==typeof e,A=(e,t)=>{if(e.size!==t.size)return!1;for(const i of e)if(!t.has(i))return!1;return!0};function L(e){return"mouseup"===e.type||"click"===e.type||"contextmenu"===e.type}const T=Math.PI,C=2*T,D=C+T,E=Number.POSITIVE_INFINITY,O=T/180,P=T/2,Y=T/4,I=2*T/3,N=Math.log10,j=Math.sign;function H(e,t,i){return Math.abs(e-t)<i}function F(e){const t=Math.round(e);e=H(e,t,e/1e3)?t:e;const i=Math.pow(10,Math.floor(N(e))),n=e/i;return(n<=1?1:n<=2?2:n<=5?5:10)*i}function R(e){const t=[],i=Math.sqrt(e);let n;for(n=1;n<i;n++)e%n==0&&(t.push(n),t.push(e/n));return i===(0|i)&&t.push(i),t.sort(((e,t)=>e-t)).pop(),t}function z(e){return!isNaN(parseFloat(e))&&isFinite(e)}function B(e,t){const i=Math.round(e);return i-t<=e&&i+t>=e}function V(e,t,i){let n,r,a;for(n=0,r=e.length;n<r;n++)a=e[n][i],isNaN(a)||(t.min=Math.min(t.min,a),t.max=Math.max(t.max,a))}function W(e){return e*(T/180)}function U(e){return e*(180/T)}function q(e){if(!s(e))return;let t=1,i=0;for(;Math.round(e*t)/t!==e;)t*=10,i++;return i}function $(e,t){const i=t.x-e.x,n=t.y-e.y,r=Math.sqrt(i*i+n*n);let a=Math.atan2(n,i);return a<-.5*T&&(a+=C),{angle:a,distance:r}}function X(e,t){return Math.sqrt(Math.pow(t.x-e.x,2)+Math.pow(t.y-e.y,2))}function G(e,t){return(e-t+D)%C-T}function Z(e){return(e%C+C)%C}function K(e,t,i,n){const r=Z(e),a=Z(t),s=Z(i),o=Z(a-r),l=Z(s-r),c=Z(r-a),u=Z(r-s);return r===a||r===s||n&&a===s||o>l&&c<u}function J(e,t,i){return Math.max(t,Math.min(i,e))}function Q(e){return J(e,-32768,32767)}function ee(e,t,i,n=1e-6){return e>=Math.min(t,i)-n&&e<=Math.max(t,i)+n}function te(e,t,i){i=i||(i=>e[i]<t);let n,r=e.length-1,a=0;for(;r-a>1;)n=a+r>>1,i(n)?a=n:r=n;return{lo:a,hi:r}}const ie=(e,t,i,n)=>te(e,i,n?n=>{const r=e[n][t];return r<i||r===i&&e[n+1][t]===i}:n=>e[n][t]<i),ne=(e,t,i)=>te(e,i,(n=>e[n][t]>=i));function re(e,t,i){let n=0,r=e.length;for(;n<r&&e[n]<t;)n++;for(;r>n&&e[r-1]>i;)r--;return n>0||r<e.length?e.slice(n,r):e}const ae=["push","pop","shift","splice","unshift"];function se(e,t){e._chartjs?e._chartjs.listeners.push(t):(Object.defineProperty(e,"_chartjs",{configurable:!0,enumerable:!1,value:{listeners:[t]}}),ae.forEach((t=>{const i="_onData"+k(t),n=e[t];Object.defineProperty(e,t,{configurable:!0,enumerable:!1,value(...t){const r=n.apply(this,t);return e._chartjs.listeners.forEach((e=>{"function"==typeof e[i]&&e[i](...t)})),r}})})))}function oe(e,t){const i=e._chartjs;if(!i)return;const n=i.listeners,r=n.indexOf(t);-1!==r&&n.splice(r,1),n.length>0||(ae.forEach((t=>{delete e[t]})),delete e._chartjs)}function le(e){const t=new Set(e);return t.size===e.length?e:Array.from(t)}const ce="undefined"==typeof window?function(e){return e()}:window.requestAnimationFrame;function ue(e,t){let i=[],n=!1;return function(...r){i=r,n||(n=!0,ce.call(window,(()=>{n=!1,e.apply(t,i)})))}}function de(e,t){let i;return function(...n){return t?(clearTimeout(i),i=setTimeout(e,t,n)):e.apply(this,n),t}}const he=e=>"start"===e?"left":"end"===e?"right":"center",fe=(e,t,i)=>"start"===e?t:"end"===e?i:(t+i)/2,pe=(e,t,i,n)=>e===(n?"left":"right")?i:"center"===e?(t+i)/2:t;function me(e,t,i){const n=t.length;let r=0,a=n;if(e._sorted){const{iScale:s,_parsed:o}=e,l=s.axis,{min:c,max:u,minDefined:d,maxDefined:h}=s.getUserBounds();d&&(r=J(Math.min(ie(o,l,c).lo,i?n:ie(t,l,s.getPixelForValue(c)).lo),0,n-1)),a=h?J(Math.max(ie(o,s.axis,u,!0).hi+1,i?0:ie(t,l,s.getPixelForValue(u),!0).hi+1),r,n)-r:n-r}return{start:r,count:a}}function ge(e){const{xScale:t,yScale:i,_scaleRanges:n}=e,r={xmin:t.min,xmax:t.max,ymin:i.min,ymax:i.max};if(!n)return e._scaleRanges=r,!0;const a=n.xmin!==t.min||n.xmax!==t.max||n.ymin!==i.min||n.ymax!==i.max;return Object.assign(n,r),a}var ve=new class{constructor(){this._request=null,this._charts=new Map,this._running=!1,this._lastDate=void 0}_notify(e,t,i,n){const r=t.listeners[n],a=t.duration;r.forEach((n=>n({chart:e,initial:t.initial,numSteps:a,currentStep:Math.min(i-t.start,a)})))}_refresh(){this._request||(this._running=!0,this._request=ce.call(window,(()=>{this._update(),this._request=null,this._running&&this._refresh()})))}_update(e=Date.now()){let t=0;this._charts.forEach(((i,n)=>{if(!i.running||!i.items.length)return;const r=i.items;let a,s=r.length-1,o=!1;for(;s>=0;--s)a=r[s],a._active?(a._total>i.duration&&(i.duration=a._total),a.tick(e),o=!0):(r[s]=r[r.length-1],r.pop());o&&(n.draw(),this._notify(n,i,e,"progress")),r.length||(i.running=!1,this._notify(n,i,e,"complete"),i.initial=!1),t+=r.length})),this._lastDate=e,0===t&&(this._running=!1)}_getAnims(e){const t=this._charts;let i=t.get(e);return i||(i={running:!1,initial:!0,items:[],listeners:{complete:[],progress:[]}},t.set(e,i)),i}listen(e,t,i){this._getAnims(e).listeners[t].push(i)}add(e,t){t&&t.length&&this._getAnims(e).items.push(...t)}has(e){return this._getAnims(e).items.length>0}start(e){const t=this._charts.get(e);t&&(t.running=!0,t.start=Date.now(),t.duration=t.items.reduce(((e,t)=>Math.max(e,t._duration)),0),this._refresh())}running(e){if(!this._running)return!1;const t=this._charts.get(e);return!!(t&&t.running&&t.items.length)}stop(e){const t=this._charts.get(e);if(!t||!t.items.length)return;const i=t.items;let n=i.length-1;for(;n>=0;--n)i[n].cancel();t.items=[],this._notify(e,t,Date.now(),"complete")}remove(e){return this._charts.delete(e)}};
/*!
 * @kurkle/color v0.3.2
 * https://github.com/kurkle/color#readme
 * (c) 2023 Jukka Kurkela
 * Released under the MIT License
 */function ye(e){return e+.5|0}const be=(e,t,i)=>Math.max(Math.min(e,i),t);function xe(e){return be(ye(2.55*e),0,255)}function _e(e){return be(ye(255*e),0,255)}function we(e){return be(ye(e/2.55)/100,0,1)}function ke(e){return be(ye(100*e),0,100)}const Me={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,A:10,B:11,C:12,D:13,E:14,F:15,a:10,b:11,c:12,d:13,e:14,f:15},Se=[..."0123456789ABCDEF"],Ae=e=>Se[15&e],Le=e=>Se[(240&e)>>4]+Se[15&e],Te=e=>(240&e)>>4==(15&e);const Ce=/^(hsla?|hwb|hsv)\(\s*([-+.e\d]+)(?:deg)?[\s,]+([-+.e\d]+)%[\s,]+([-+.e\d]+)%(?:[\s,]+([-+.e\d]+)(%)?)?\s*\)$/;function De(e,t,i){const n=t*Math.min(i,1-i),r=(t,r=(t+e/30)%12)=>i-n*Math.max(Math.min(r-3,9-r,1),-1);return[r(0),r(8),r(4)]}function Ee(e,t,i){const n=(n,r=(n+e/60)%6)=>i-i*t*Math.max(Math.min(r,4-r,1),0);return[n(5),n(3),n(1)]}function Oe(e,t,i){const n=De(e,1,.5);let r;for(t+i>1&&(r=1/(t+i),t*=r,i*=r),r=0;r<3;r++)n[r]*=1-t-i,n[r]+=t;return n}function Pe(e){const t=e.r/255,i=e.g/255,n=e.b/255,r=Math.max(t,i,n),a=Math.min(t,i,n),s=(r+a)/2;let o,l,c;return r!==a&&(c=r-a,l=s>.5?c/(2-r-a):c/(r+a),o=function(e,t,i,n,r){return e===r?(t-i)/n+(t<i?6:0):t===r?(i-e)/n+2:(e-t)/n+4}(t,i,n,c,r),o=60*o+.5),[0|o,l||0,s]}function Ye(e,t,i,n){return(Array.isArray(t)?e(t[0],t[1],t[2]):e(t,i,n)).map(_e)}function Ie(e,t,i){return Ye(De,e,t,i)}function Ne(e){return(e%360+360)%360}const je={x:"dark",Z:"light",Y:"re",X:"blu",W:"gr",V:"medium",U:"slate",A:"ee",T:"ol",S:"or",B:"ra",C:"lateg",D:"ights",R:"in",Q:"turquois",E:"hi",P:"ro",O:"al",N:"le",M:"de",L:"yello",F:"en",K:"ch",G:"arks",H:"ea",I:"ightg",J:"wh"},He={OiceXe:"f0f8ff",antiquewEte:"faebd7",aqua:"ffff",aquamarRe:"7fffd4",azuY:"f0ffff",beige:"f5f5dc",bisque:"ffe4c4",black:"0",blanKedOmond:"ffebcd",Xe:"ff",XeviTet:"8a2be2",bPwn:"a52a2a",burlywood:"deb887",caMtXe:"5f9ea0",KartYuse:"7fff00",KocTate:"d2691e",cSO:"ff7f50",cSnflowerXe:"6495ed",cSnsilk:"fff8dc",crimson:"dc143c",cyan:"ffff",xXe:"8b",xcyan:"8b8b",xgTMnPd:"b8860b",xWay:"a9a9a9",xgYF:"6400",xgYy:"a9a9a9",xkhaki:"bdb76b",xmagFta:"8b008b",xTivegYF:"556b2f",xSange:"ff8c00",xScEd:"9932cc",xYd:"8b0000",xsOmon:"e9967a",xsHgYF:"8fbc8f",xUXe:"483d8b",xUWay:"2f4f4f",xUgYy:"2f4f4f",xQe:"ced1",xviTet:"9400d3",dAppRk:"ff1493",dApskyXe:"bfff",dimWay:"696969",dimgYy:"696969",dodgerXe:"1e90ff",fiYbrick:"b22222",flSOwEte:"fffaf0",foYstWAn:"228b22",fuKsia:"ff00ff",gaRsbSo:"dcdcdc",ghostwEte:"f8f8ff",gTd:"ffd700",gTMnPd:"daa520",Way:"808080",gYF:"8000",gYFLw:"adff2f",gYy:"808080",honeyMw:"f0fff0",hotpRk:"ff69b4",RdianYd:"cd5c5c",Rdigo:"4b0082",ivSy:"fffff0",khaki:"f0e68c",lavFMr:"e6e6fa",lavFMrXsh:"fff0f5",lawngYF:"7cfc00",NmoncEffon:"fffacd",ZXe:"add8e6",ZcSO:"f08080",Zcyan:"e0ffff",ZgTMnPdLw:"fafad2",ZWay:"d3d3d3",ZgYF:"90ee90",ZgYy:"d3d3d3",ZpRk:"ffb6c1",ZsOmon:"ffa07a",ZsHgYF:"20b2aa",ZskyXe:"87cefa",ZUWay:"778899",ZUgYy:"778899",ZstAlXe:"b0c4de",ZLw:"ffffe0",lime:"ff00",limegYF:"32cd32",lRF:"faf0e6",magFta:"ff00ff",maPon:"800000",VaquamarRe:"66cdaa",VXe:"cd",VScEd:"ba55d3",VpurpN:"9370db",VsHgYF:"3cb371",VUXe:"7b68ee",VsprRggYF:"fa9a",VQe:"48d1cc",VviTetYd:"c71585",midnightXe:"191970",mRtcYam:"f5fffa",mistyPse:"ffe4e1",moccasR:"ffe4b5",navajowEte:"ffdead",navy:"80",Tdlace:"fdf5e6",Tive:"808000",TivedBb:"6b8e23",Sange:"ffa500",SangeYd:"ff4500",ScEd:"da70d6",pOegTMnPd:"eee8aa",pOegYF:"98fb98",pOeQe:"afeeee",pOeviTetYd:"db7093",papayawEp:"ffefd5",pHKpuff:"ffdab9",peru:"cd853f",pRk:"ffc0cb",plum:"dda0dd",powMrXe:"b0e0e6",purpN:"800080",YbeccapurpN:"663399",Yd:"ff0000",Psybrown:"bc8f8f",PyOXe:"4169e1",saddNbPwn:"8b4513",sOmon:"fa8072",sandybPwn:"f4a460",sHgYF:"2e8b57",sHshell:"fff5ee",siFna:"a0522d",silver:"c0c0c0",skyXe:"87ceeb",UXe:"6a5acd",UWay:"708090",UgYy:"708090",snow:"fffafa",sprRggYF:"ff7f",stAlXe:"4682b4",tan:"d2b48c",teO:"8080",tEstN:"d8bfd8",tomato:"ff6347",Qe:"40e0d0",viTet:"ee82ee",JHt:"f5deb3",wEte:"ffffff",wEtesmoke:"f5f5f5",Lw:"ffff00",LwgYF:"9acd32"};let Fe;const Re=/^rgba?\(\s*([-+.\d]+)(%)?[\s,]+([-+.e\d]+)(%)?[\s,]+([-+.e\d]+)(%)?(?:[\s,/]+([-+.e\d]+)(%)?)?\s*\)$/,ze=e=>e<=.0031308?12.92*e:1.055*Math.pow(e,1/2.4)-.055,Be=e=>e<=.04045?e/12.92:Math.pow((e+.055)/1.055,2.4);function Ve(e,t,i){if(e){let n=Pe(e);n[t]=Math.max(0,Math.min(n[t]+n[t]*i,0===t?360:1)),n=Ie(n),e.r=n[0],e.g=n[1],e.b=n[2]}}function We(e,t){return e?Object.assign(t||{},e):e}function Ue(e){var t={r:0,g:0,b:0,a:255};return Array.isArray(e)?e.length>=3&&(t={r:e[0],g:e[1],b:e[2],a:255},e.length>3&&(t.a=_e(e[3]))):(t=We(e,{r:0,g:0,b:0,a:1})).a=_e(t.a),t}function qe(e){return"r"===e.charAt(0)?function(e){const t=Re.exec(e);let i,n,r,a=255;if(t){if(t[7]!==i){const e=+t[7];a=t[8]?xe(e):be(255*e,0,255)}return i=+t[1],n=+t[3],r=+t[5],i=255&(t[2]?xe(i):be(i,0,255)),n=255&(t[4]?xe(n):be(n,0,255)),r=255&(t[6]?xe(r):be(r,0,255)),{r:i,g:n,b:r,a:a}}}(e):function(e){const t=Ce.exec(e);let i,n=255;if(!t)return;t[5]!==i&&(n=t[6]?xe(+t[5]):_e(+t[5]));const r=Ne(+t[2]),a=+t[3]/100,s=+t[4]/100;return i="hwb"===t[1]?function(e,t,i){return Ye(Oe,e,t,i)}(r,a,s):"hsv"===t[1]?function(e,t,i){return Ye(Ee,e,t,i)}(r,a,s):Ie(r,a,s),{r:i[0],g:i[1],b:i[2],a:n}}(e)}class $e{constructor(e){if(e instanceof $e)return e;const t=typeof e;let i;var n,r,a;"object"===t?i=Ue(e):"string"===t&&(a=(n=e).length,"#"===n[0]&&(4===a||5===a?r={r:255&17*Me[n[1]],g:255&17*Me[n[2]],b:255&17*Me[n[3]],a:5===a?17*Me[n[4]]:255}:7!==a&&9!==a||(r={r:Me[n[1]]<<4|Me[n[2]],g:Me[n[3]]<<4|Me[n[4]],b:Me[n[5]]<<4|Me[n[6]],a:9===a?Me[n[7]]<<4|Me[n[8]]:255})),i=r||function(e){Fe||(Fe=function(){const e={},t=Object.keys(He),i=Object.keys(je);let n,r,a,s,o;for(n=0;n<t.length;n++){for(s=o=t[n],r=0;r<i.length;r++)a=i[r],o=o.replace(a,je[a]);a=parseInt(He[s],16),e[o]=[a>>16&255,a>>8&255,255&a]}return e}(),Fe.transparent=[0,0,0,0]);const t=Fe[e.toLowerCase()];return t&&{r:t[0],g:t[1],b:t[2],a:4===t.length?t[3]:255}}(e)||qe(e)),this._rgb=i,this._valid=!!i}get valid(){return this._valid}get rgb(){var e=We(this._rgb);return e&&(e.a=we(e.a)),e}set rgb(e){this._rgb=Ue(e)}rgbString(){return this._valid?(e=this._rgb)&&(e.a<255?`rgba(${e.r}, ${e.g}, ${e.b}, ${we(e.a)})`:`rgb(${e.r}, ${e.g}, ${e.b})`):void 0;var e}hexString(){return this._valid?function(e){var t=(e=>Te(e.r)&&Te(e.g)&&Te(e.b)&&Te(e.a))(e)?Ae:Le;return e?"#"+t(e.r)+t(e.g)+t(e.b)+((e,t)=>e<255?t(e):"")(e.a,t):void 0}(this._rgb):void 0}hslString(){return this._valid?function(e){if(!e)return;const t=Pe(e),i=t[0],n=ke(t[1]),r=ke(t[2]);return e.a<255?`hsla(${i}, ${n}%, ${r}%, ${we(e.a)})`:`hsl(${i}, ${n}%, ${r}%)`}(this._rgb):void 0}mix(e,t){if(e){const i=this.rgb,n=e.rgb;let r;const a=t===r?.5:t,s=2*a-1,o=i.a-n.a,l=((s*o==-1?s:(s+o)/(1+s*o))+1)/2;r=1-l,i.r=255&l*i.r+r*n.r+.5,i.g=255&l*i.g+r*n.g+.5,i.b=255&l*i.b+r*n.b+.5,i.a=a*i.a+(1-a)*n.a,this.rgb=i}return this}interpolate(e,t){return e&&(this._rgb=function(e,t,i){const n=Be(we(e.r)),r=Be(we(e.g)),a=Be(we(e.b));return{r:_e(ze(n+i*(Be(we(t.r))-n))),g:_e(ze(r+i*(Be(we(t.g))-r))),b:_e(ze(a+i*(Be(we(t.b))-a))),a:e.a+i*(t.a-e.a)}}(this._rgb,e._rgb,t)),this}clone(){return new $e(this.rgb)}alpha(e){return this._rgb.a=_e(e),this}clearer(e){return this._rgb.a*=1-e,this}greyscale(){const e=this._rgb,t=ye(.3*e.r+.59*e.g+.11*e.b);return e.r=e.g=e.b=t,this}opaquer(e){return this._rgb.a*=1+e,this}negate(){const e=this._rgb;return e.r=255-e.r,e.g=255-e.g,e.b=255-e.b,this}lighten(e){return Ve(this._rgb,2,e),this}darken(e){return Ve(this._rgb,2,-e),this}saturate(e){return Ve(this._rgb,1,e),this}desaturate(e){return Ve(this._rgb,1,-e),this}rotate(e){return function(e,t){var i=Pe(e);i[0]=Ne(i[0]+t),i=Ie(i),e.r=i[0],e.g=i[1],e.b=i[2]}(this._rgb,e),this}}function Xe(e){if(e&&"object"==typeof e){const t=e.toString();return"[object CanvasPattern]"===t||"[object CanvasGradient]"===t}return!1}function Ge(e){return Xe(e)?e:new $e(e)}function Ze(e){return Xe(e)?e:new $e(e).saturate(.5).darken(.1).hexString()}const Ke=["x","y","borderWidth","radius","tension"],Je=["color","borderColor","backgroundColor"],Qe=new Map;function et(e,t,i){return function(e,t){t=t||{};const i=e+JSON.stringify(t);let n=Qe.get(i);return n||(n=new Intl.NumberFormat(e,t),Qe.set(i,n)),n}(t,i).format(e)}const tt={values:e=>r(e)?e:""+e,numeric(e,t,i){if(0===e)return"0";const n=this.chart.options.locale;let r,a=e;if(i.length>1){const t=Math.max(Math.abs(i[0].value),Math.abs(i[i.length-1].value));(t<1e-4||t>1e15)&&(r="scientific"),a=function(e,t){let i=t.length>3?t[2].value-t[1].value:t[1].value-t[0].value;return Math.abs(i)>=1&&e!==Math.floor(e)&&(i=e-Math.floor(e)),i}(e,i)}const s=N(Math.abs(a)),o=isNaN(s)?1:Math.max(Math.min(-1*Math.floor(s),20),0),l={notation:r,minimumFractionDigits:o,maximumFractionDigits:o};return Object.assign(l,this.options.ticks.format),et(e,n,l)},logarithmic(e,t,i){if(0===e)return"0";const n=i[t].significand||e/Math.pow(10,Math.floor(N(e)));return[1,2,3,5,10,15].includes(n)||t>.8*i.length?tt.numeric.call(this,e,t,i):""}};var it={formatters:tt};const nt=Object.create(null),rt=Object.create(null);function at(e,t){if(!t)return e;const i=t.split(".");for(let t=0,n=i.length;t<n;++t){const n=i[t];e=e[n]||(e[n]=Object.create(null))}return e}function st(e,t,i){return"string"==typeof t?v(at(e,t),i):v(at(e,""),t)}var ot=new class{constructor(e,t){this.animation=void 0,this.backgroundColor="rgba(0,0,0,0.1)",this.borderColor="rgba(0,0,0,0.1)",this.color="#666",this.datasets={},this.devicePixelRatio=e=>e.chart.platform.getDevicePixelRatio(),this.elements={},this.events=["mousemove","mouseout","click","touchstart","touchmove"],this.font={family:"'Helvetica Neue', 'Helvetica', 'Arial', sans-serif",size:12,style:"normal",lineHeight:1.2,weight:null},this.hover={},this.hoverBackgroundColor=(e,t)=>Ze(t.backgroundColor),this.hoverBorderColor=(e,t)=>Ze(t.borderColor),this.hoverColor=(e,t)=>Ze(t.color),this.indexAxis="x",this.interaction={mode:"nearest",intersect:!0,includeInvisible:!1},this.maintainAspectRatio=!0,this.onHover=null,this.onClick=null,this.parsing=!0,this.plugins={},this.responsive=!0,this.scale=void 0,this.scales={},this.showLine=!0,this.drawActiveElementsOnTop=!0,this.describe(e),this.apply(t)}set(e,t){return st(this,e,t)}get(e){return at(this,e)}describe(e,t){return st(rt,e,t)}override(e,t){return st(nt,e,t)}route(e,t,i,n){const r=at(this,e),s=at(this,i),o="_"+t;Object.defineProperties(r,{[o]:{value:r[t],writable:!0},[t]:{enumerable:!0,get(){const e=this[o],t=s[n];return a(e)?Object.assign({},t,e):l(e,t)},set(e){this[o]=e}}})}apply(e){e.forEach((e=>e(this)))}}({_scriptable:e=>!e.startsWith("on"),_indexable:e=>"events"!==e,hover:{_fallback:"interaction"},interaction:{_scriptable:!1,_indexable:!1}},[function(e){e.set("animation",{delay:void 0,duration:1e3,easing:"easeOutQuart",fn:void 0,from:void 0,loop:void 0,to:void 0,type:void 0}),e.describe("animation",{_fallback:!1,_indexable:!1,_scriptable:e=>"onProgress"!==e&&"onComplete"!==e&&"fn"!==e}),e.set("animations",{colors:{type:"color",properties:Je},numbers:{type:"number",properties:Ke}}),e.describe("animations",{_fallback:"animation"}),e.set("transitions",{active:{animation:{duration:400}},resize:{animation:{duration:0}},show:{animations:{colors:{from:"transparent"},visible:{type:"boolean",duration:0}}},hide:{animations:{colors:{to:"transparent"},visible:{type:"boolean",easing:"linear",fn:e=>0|e}}}})},function(e){e.set("layout",{autoPadding:!0,padding:{top:0,right:0,bottom:0,left:0}})},function(e){e.set("scale",{display:!0,offset:!1,reverse:!1,beginAtZero:!1,bounds:"ticks",clip:!0,grace:0,grid:{display:!0,lineWidth:1,drawOnChartArea:!0,drawTicks:!0,tickLength:8,tickWidth:(e,t)=>t.lineWidth,tickColor:(e,t)=>t.color,offset:!1},border:{display:!0,dash:[],dashOffset:0,width:1},title:{display:!1,text:"",padding:{top:4,bottom:4}},ticks:{minRotation:0,maxRotation:50,mirror:!1,textStrokeWidth:0,textStrokeColor:"",padding:3,display:!0,autoSkip:!0,autoSkipPadding:3,labelOffset:0,callback:it.formatters.values,minor:{},major:{},align:"center",crossAlign:"near",showLabelBackdrop:!1,backdropColor:"rgba(255, 255, 255, 0.75)",backdropPadding:2}}),e.route("scale.ticks","color","","color"),e.route("scale.grid","color","","borderColor"),e.route("scale.border","color","","borderColor"),e.route("scale.title","color","","color"),e.describe("scale",{_fallback:!1,_scriptable:e=>!e.startsWith("before")&&!e.startsWith("after")&&"callback"!==e&&"parser"!==e,_indexable:e=>"borderDash"!==e&&"tickBorderDash"!==e&&"dash"!==e}),e.describe("scales",{_fallback:"scale"}),e.describe("scale.ticks",{_scriptable:e=>"backdropPadding"!==e&&"callback"!==e,_indexable:e=>"backdropPadding"!==e})}]);function lt(){return"undefined"!=typeof window&&"undefined"!=typeof document}function ct(e){let t=e.parentNode;return t&&"[object ShadowRoot]"===t.toString()&&(t=t.host),t}function ut(e,t,i){let n;return"string"==typeof e?(n=parseInt(e,10),-1!==e.indexOf("%")&&(n=n/100*t.parentNode[i])):n=e,n}const dt=e=>e.ownerDocument.defaultView.getComputedStyle(e,null);function ht(e,t){return dt(e).getPropertyValue(t)}const ft=["top","right","bottom","left"];function pt(e,t,i){const n={};i=i?"-"+i:"";for(let r=0;r<4;r++){const a=ft[r];n[a]=parseFloat(e[t+"-"+a+i])||0}return n.width=n.left+n.right,n.height=n.top+n.bottom,n}const mt=(e,t,i)=>(e>0||t>0)&&(!i||!i.shadowRoot);function gt(e,t){if("native"in e)return e;const{canvas:i,currentDevicePixelRatio:n}=t,r=dt(i),a="border-box"===r.boxSizing,s=pt(r,"padding"),o=pt(r,"border","width"),{x:l,y:c,box:u}=function(e,t){const i=e.touches,n=i&&i.length?i[0]:e,{offsetX:r,offsetY:a}=n;let s,o,l=!1;if(mt(r,a,e.target))s=r,o=a;else{const e=t.getBoundingClientRect();s=n.clientX-e.left,o=n.clientY-e.top,l=!0}return{x:s,y:o,box:l}}(e,i),d=s.left+(u&&o.left),h=s.top+(u&&o.top);let{width:f,height:p}=t;return a&&(f-=s.width+o.width,p-=s.height+o.height),{x:Math.round((l-d)/f*i.width/n),y:Math.round((c-h)/p*i.height/n)}}const vt=e=>Math.round(10*e)/10;function yt(e,t,i,n){const r=dt(e),a=pt(r,"margin"),s=ut(r.maxWidth,e,"clientWidth")||E,o=ut(r.maxHeight,e,"clientHeight")||E,l=function(e,t,i){let n,r;if(void 0===t||void 0===i){const a=e&&ct(e);if(a){const e=a.getBoundingClientRect(),s=dt(a),o=pt(s,"border","width"),l=pt(s,"padding");t=e.width-l.width-o.width,i=e.height-l.height-o.height,n=ut(s.maxWidth,a,"clientWidth"),r=ut(s.maxHeight,a,"clientHeight")}else t=e.clientWidth,i=e.clientHeight}return{width:t,height:i,maxWidth:n||E,maxHeight:r||E}}(e,t,i);let{width:c,height:u}=l;if("content-box"===r.boxSizing){const e=pt(r,"border","width"),t=pt(r,"padding");c-=t.width+e.width,u-=t.height+e.height}return c=Math.max(0,c-a.width),u=Math.max(0,n?c/n:u-a.height),c=vt(Math.min(c,s,l.maxWidth)),u=vt(Math.min(u,o,l.maxHeight)),c&&!u&&(u=vt(c/2)),(void 0!==t||void 0!==i)&&n&&l.height&&u>l.height&&(u=l.height,c=vt(Math.floor(u*n))),{width:c,height:u}}function bt(e,t,i){const n=t||1,r=Math.floor(e.height*n),a=Math.floor(e.width*n);e.height=Math.floor(e.height),e.width=Math.floor(e.width);const s=e.canvas;return s.style&&(i||!s.style.height&&!s.style.width)&&(s.style.height=`${e.height}px`,s.style.width=`${e.width}px`),(e.currentDevicePixelRatio!==n||s.height!==r||s.width!==a)&&(e.currentDevicePixelRatio=n,s.height=r,s.width=a,e.ctx.setTransform(n,0,0,n,0,0),!0)}const xt=function(){let e=!1;try{const t={get passive(){return e=!0,!1}};lt()&&(window.addEventListener("test",null,t),window.removeEventListener("test",null,t))}catch(e){}return e}();function _t(e,t){const i=ht(e,t),n=i&&i.match(/^(\d+)(\.\d+)?px$/);return n?+n[1]:void 0}function wt(e){return!e||n(e.size)||n(e.family)?null:(e.style?e.style+" ":"")+(e.weight?e.weight+" ":"")+e.size+"px "+e.family}function kt(e,t,i,n,r){let a=t[r];return a||(a=t[r]=e.measureText(r).width,i.push(r)),a>n&&(n=a),n}function Mt(e,t,i,n){let a=(n=n||{}).data=n.data||{},s=n.garbageCollect=n.garbageCollect||[];n.font!==t&&(a=n.data={},s=n.garbageCollect=[],n.font=t),e.save(),e.font=t;let o=0;const l=i.length;let c,u,d,h,f;for(c=0;c<l;c++)if(h=i[c],null==h||r(h)){if(r(h))for(u=0,d=h.length;u<d;u++)f=h[u],null==f||r(f)||(o=kt(e,a,s,o,f))}else o=kt(e,a,s,o,h);e.restore();const p=s.length/2;if(p>i.length){for(c=0;c<p;c++)delete a[s[c]];s.splice(0,p)}return o}function St(e,t,i){const n=e.currentDevicePixelRatio,r=0!==i?Math.max(i/2,.5):0;return Math.round((t-r)*n)/n+r}function At(e,t){(t||e)&&((t=t||e.getContext("2d")).save(),t.resetTransform(),t.clearRect(0,0,e.width,e.height),t.restore())}function Lt(e,t,i,n){Tt(e,t,i,n,null)}function Tt(e,t,i,n,r){let a,s,o,l,c,u,d,h;const f=t.pointStyle,p=t.rotation,m=t.radius;let g=(p||0)*O;if(f&&"object"==typeof f&&(a=f.toString(),"[object HTMLImageElement]"===a||"[object HTMLCanvasElement]"===a))return e.save(),e.translate(i,n),e.rotate(g),e.drawImage(f,-f.width/2,-f.height/2,f.width,f.height),void e.restore();if(!(isNaN(m)||m<=0)){switch(e.beginPath(),f){default:r?e.ellipse(i,n,r/2,m,0,0,C):e.arc(i,n,m,0,C),e.closePath();break;case"triangle":u=r?r/2:m,e.moveTo(i+Math.sin(g)*u,n-Math.cos(g)*m),g+=I,e.lineTo(i+Math.sin(g)*u,n-Math.cos(g)*m),g+=I,e.lineTo(i+Math.sin(g)*u,n-Math.cos(g)*m),e.closePath();break;case"rectRounded":c=.516*m,l=m-c,s=Math.cos(g+Y)*l,d=Math.cos(g+Y)*(r?r/2-c:l),o=Math.sin(g+Y)*l,h=Math.sin(g+Y)*(r?r/2-c:l),e.arc(i-d,n-o,c,g-T,g-P),e.arc(i+h,n-s,c,g-P,g),e.arc(i+d,n+o,c,g,g+P),e.arc(i-h,n+s,c,g+P,g+T),e.closePath();break;case"rect":if(!p){l=Math.SQRT1_2*m,u=r?r/2:l,e.rect(i-u,n-l,2*u,2*l);break}g+=Y;case"rectRot":d=Math.cos(g)*(r?r/2:m),s=Math.cos(g)*m,o=Math.sin(g)*m,h=Math.sin(g)*(r?r/2:m),e.moveTo(i-d,n-o),e.lineTo(i+h,n-s),e.lineTo(i+d,n+o),e.lineTo(i-h,n+s),e.closePath();break;case"crossRot":g+=Y;case"cross":d=Math.cos(g)*(r?r/2:m),s=Math.cos(g)*m,o=Math.sin(g)*m,h=Math.sin(g)*(r?r/2:m),e.moveTo(i-d,n-o),e.lineTo(i+d,n+o),e.moveTo(i+h,n-s),e.lineTo(i-h,n+s);break;case"star":d=Math.cos(g)*(r?r/2:m),s=Math.cos(g)*m,o=Math.sin(g)*m,h=Math.sin(g)*(r?r/2:m),e.moveTo(i-d,n-o),e.lineTo(i+d,n+o),e.moveTo(i+h,n-s),e.lineTo(i-h,n+s),g+=Y,d=Math.cos(g)*(r?r/2:m),s=Math.cos(g)*m,o=Math.sin(g)*m,h=Math.sin(g)*(r?r/2:m),e.moveTo(i-d,n-o),e.lineTo(i+d,n+o),e.moveTo(i+h,n-s),e.lineTo(i-h,n+s);break;case"line":s=r?r/2:Math.cos(g)*m,o=Math.sin(g)*m,e.moveTo(i-s,n-o),e.lineTo(i+s,n+o);break;case"dash":e.moveTo(i,n),e.lineTo(i+Math.cos(g)*(r?r/2:m),n+Math.sin(g)*m);break;case!1:e.closePath()}e.fill(),t.borderWidth>0&&e.stroke()}}function Ct(e,t,i){return i=i||.5,!t||e&&e.x>t.left-i&&e.x<t.right+i&&e.y>t.top-i&&e.y<t.bottom+i}function Dt(e,t){e.save(),e.beginPath(),e.rect(t.left,t.top,t.right-t.left,t.bottom-t.top),e.clip()}function Et(e){e.restore()}function Ot(e,t,i,n,r){if(!t)return e.lineTo(i.x,i.y);if("middle"===r){const n=(t.x+i.x)/2;e.lineTo(n,t.y),e.lineTo(n,i.y)}else"after"===r!=!!n?e.lineTo(t.x,i.y):e.lineTo(i.x,t.y);e.lineTo(i.x,i.y)}function Pt(e,t,i,n){if(!t)return e.lineTo(i.x,i.y);e.bezierCurveTo(n?t.cp1x:t.cp2x,n?t.cp1y:t.cp2y,n?i.cp2x:i.cp1x,n?i.cp2y:i.cp1y,i.x,i.y)}function Yt(e,t,i,n,r){if(r.strikethrough||r.underline){const a=e.measureText(n),s=t-a.actualBoundingBoxLeft,o=t+a.actualBoundingBoxRight,l=i-a.actualBoundingBoxAscent,c=i+a.actualBoundingBoxDescent,u=r.strikethrough?(l+c)/2:c;e.strokeStyle=e.fillStyle,e.beginPath(),e.lineWidth=r.decorationWidth||2,e.moveTo(s,u),e.lineTo(o,u),e.stroke()}}function It(e,t){const i=e.fillStyle;e.fillStyle=t.color,e.fillRect(t.left,t.top,t.width,t.height),e.fillStyle=i}function Nt(e,t,i,a,s,o={}){const l=r(t)?t:[t],c=o.strokeWidth>0&&""!==o.strokeColor;let u,d;for(e.save(),e.font=s.string,function(e,t){t.translation&&e.translate(t.translation[0],t.translation[1]),n(t.rotation)||e.rotate(t.rotation),t.color&&(e.fillStyle=t.color),t.textAlign&&(e.textAlign=t.textAlign),t.textBaseline&&(e.textBaseline=t.textBaseline)}(e,o),u=0;u<l.length;++u)d=l[u],o.backdrop&&It(e,o.backdrop),c&&(o.strokeColor&&(e.strokeStyle=o.strokeColor),n(o.strokeWidth)||(e.lineWidth=o.strokeWidth),e.strokeText(d,i,a,o.maxWidth)),e.fillText(d,i,a,o.maxWidth),Yt(e,i,a,d,o),a+=Number(s.lineHeight);e.restore()}function jt(e,t){const{x:i,y:n,w:r,h:a,radius:s}=t;e.arc(i+s.topLeft,n+s.topLeft,s.topLeft,1.5*T,T,!0),e.lineTo(i,n+a-s.bottomLeft),e.arc(i+s.bottomLeft,n+a-s.bottomLeft,s.bottomLeft,T,P,!0),e.lineTo(i+r-s.bottomRight,n+a),e.arc(i+r-s.bottomRight,n+a-s.bottomRight,s.bottomRight,P,0,!0),e.lineTo(i+r,n+s.topRight),e.arc(i+r-s.topRight,n+s.topRight,s.topRight,0,-P,!0),e.lineTo(i+s.topLeft,n)}function Ht(e,t=[""],i,n,r=(()=>e[0])){const a=i||e;void 0===n&&(n=Gt("_fallback",e));const s={[Symbol.toStringTag]:"Object",_cacheable:!0,_scopes:e,_rootScopes:a,_fallback:n,_getTarget:r,override:i=>Ht([i,...e],t,a,n)};return new Proxy(s,{deleteProperty:(t,i)=>(delete t[i],delete t._keys,delete e[0][i],!0),get:(i,n)=>Vt(i,n,(()=>function(e,t,i,n){let r;for(const a of t)if(r=Gt(zt(a,e),i),void 0!==r)return Bt(e,r)?$t(i,n,e,r):r}(n,t,e,i))),getOwnPropertyDescriptor:(e,t)=>Reflect.getOwnPropertyDescriptor(e._scopes[0],t),getPrototypeOf:()=>Reflect.getPrototypeOf(e[0]),has:(e,t)=>Zt(e).includes(t),ownKeys:e=>Zt(e),set(e,t,i){const n=e._storage||(e._storage=r());return e[t]=n[t]=i,delete e._keys,!0}})}function Ft(e,t,i,n){const s={_cacheable:!1,_proxy:e,_context:t,_subProxy:i,_stack:new Set,_descriptors:Rt(e,n),setContext:t=>Ft(e,t,i,n),override:r=>Ft(e.override(r),t,i,n)};return new Proxy(s,{deleteProperty:(t,i)=>(delete t[i],delete e[i],!0),get:(e,t,i)=>Vt(e,t,(()=>function(e,t,i){const{_proxy:n,_context:s,_subProxy:o,_descriptors:l}=e;let c=n[t];return S(c)&&l.isScriptable(t)&&(c=function(e,t,i,n){const{_proxy:r,_context:a,_subProxy:s,_stack:o}=i;if(o.has(e))throw new Error("Recursion detected: "+Array.from(o).join("->")+"->"+e);o.add(e);let l=t(a,s||n);return o.delete(e),Bt(e,l)&&(l=$t(r._scopes,r,e,l)),l}(t,c,e,i)),r(c)&&c.length&&(c=function(e,t,i,n){const{_proxy:r,_context:s,_subProxy:o,_descriptors:l}=i;if(void 0!==s.index&&n(e))return t[s.index%t.length];if(a(t[0])){const i=t,n=r._scopes.filter((e=>e!==i));t=[];for(const a of i){const i=$t(n,r,e,a);t.push(Ft(i,s,o&&o[e],l))}}return t}(t,c,e,l.isIndexable)),Bt(t,c)&&(c=Ft(c,s,o&&o[t],l)),c}(e,t,i))),getOwnPropertyDescriptor:(t,i)=>t._descriptors.allKeys?Reflect.has(e,i)?{enumerable:!0,configurable:!0}:void 0:Reflect.getOwnPropertyDescriptor(e,i),getPrototypeOf:()=>Reflect.getPrototypeOf(e),has:(t,i)=>Reflect.has(e,i),ownKeys:()=>Reflect.ownKeys(e),set:(t,i,n)=>(e[i]=n,delete t[i],!0)})}function Rt(e,t={scriptable:!0,indexable:!0}){const{_scriptable:i=t.scriptable,_indexable:n=t.indexable,_allKeys:r=t.allKeys}=e;return{allKeys:r,scriptable:i,indexable:n,isScriptable:S(i)?i:()=>i,isIndexable:S(n)?n:()=>n}}const zt=(e,t)=>e?e+k(t):t,Bt=(e,t)=>a(t)&&"adapters"!==e&&(null===Object.getPrototypeOf(t)||t.constructor===Object);function Vt(e,t,i){if(Object.prototype.hasOwnProperty.call(e,t)||"constructor"===t)return e[t];const n=i();return e[t]=n,n}function Wt(e,t,i){return S(e)?e(t,i):e}const Ut=(e,t)=>!0===e?t:"string"==typeof e?w(t,e):void 0;function qt(e,t,i,n,r){for(const a of t){const t=Ut(i,a);if(t){e.add(t);const a=Wt(t._fallback,i,r);if(void 0!==a&&a!==i&&a!==n)return a}else if(!1===t&&void 0!==n&&i!==n)return null}return!1}function $t(e,t,i,n){const s=t._rootScopes,o=Wt(t._fallback,i,n),l=[...e,...s],c=new Set;c.add(n);let u=Xt(c,l,i,o||i,n);return null!==u&&(void 0===o||o===i||(u=Xt(c,l,o,u,n),null!==u))&&Ht(Array.from(c),[""],s,o,(()=>function(e,t,i){const n=e._getTarget();t in n||(n[t]={});const s=n[t];return r(s)&&a(i)?i:s||{}}(t,i,n)))}function Xt(e,t,i,n,r){for(;i;)i=qt(e,t,i,n,r);return i}function Gt(e,t){for(const i of t){if(!i)continue;const t=i[e];if(void 0!==t)return t}}function Zt(e){let t=e._keys;return t||(t=e._keys=function(e){const t=new Set;for(const i of e)for(const e of Object.keys(i).filter((e=>!e.startsWith("_"))))t.add(e);return Array.from(t)}(e._scopes)),t}function Kt(e,t,i,n){const{iScale:r}=e,{key:a="r"}=this._parsing,s=new Array(n);let o,l,c,u;for(o=0,l=n;o<l;++o)c=o+i,u=t[c],s[o]={r:r.parse(w(u,a),c)};return s}const Jt=Number.EPSILON||1e-14,Qt=(e,t)=>t<e.length&&!e[t].skip&&e[t],ei=e=>"x"===e?"y":"x";function ti(e,t,i,n){const r=e.skip?t:e,a=t,s=i.skip?t:i,o=X(a,r),l=X(s,a);let c=o/(o+l),u=l/(o+l);c=isNaN(c)?0:c,u=isNaN(u)?0:u;const d=n*c,h=n*u;return{previous:{x:a.x-d*(s.x-r.x),y:a.y-d*(s.y-r.y)},next:{x:a.x+h*(s.x-r.x),y:a.y+h*(s.y-r.y)}}}function ii(e,t="x"){const i=ei(t),n=e.length,r=Array(n).fill(0),a=Array(n);let s,o,l,c=Qt(e,0);for(s=0;s<n;++s)if(o=l,l=c,c=Qt(e,s+1),l){if(c){const e=c[t]-l[t];r[s]=0!==e?(c[i]-l[i])/e:0}a[s]=o?c?j(r[s-1])!==j(r[s])?0:(r[s-1]+r[s])/2:r[s-1]:r[s]}!function(e,t,i){const n=e.length;let r,a,s,o,l,c=Qt(e,0);for(let u=0;u<n-1;++u)l=c,c=Qt(e,u+1),l&&c&&(H(t[u],0,Jt)?i[u]=i[u+1]=0:(r=i[u]/t[u],a=i[u+1]/t[u],o=Math.pow(r,2)+Math.pow(a,2),o<=9||(s=3/Math.sqrt(o),i[u]=r*s*t[u],i[u+1]=a*s*t[u])))}(e,r,a),function(e,t,i="x"){const n=ei(i),r=e.length;let a,s,o,l=Qt(e,0);for(let c=0;c<r;++c){if(s=o,o=l,l=Qt(e,c+1),!o)continue;const r=o[i],u=o[n];s&&(a=(r-s[i])/3,o[`cp1${i}`]=r-a,o[`cp1${n}`]=u-a*t[c]),l&&(a=(l[i]-r)/3,o[`cp2${i}`]=r+a,o[`cp2${n}`]=u+a*t[c])}}(e,a,t)}function ni(e,t,i){return Math.max(Math.min(e,i),t)}function ri(e,t,i,n,r){let a,s,o,l;if(t.spanGaps&&(e=e.filter((e=>!e.skip))),"monotone"===t.cubicInterpolationMode)ii(e,r);else{let i=n?e[e.length-1]:e[0];for(a=0,s=e.length;a<s;++a)o=e[a],l=ti(i,o,e[Math.min(a+1,s-(n?0:1))%s],t.tension),o.cp1x=l.previous.x,o.cp1y=l.previous.y,o.cp2x=l.next.x,o.cp2y=l.next.y,i=o}t.capBezierPoints&&function(e,t){let i,n,r,a,s,o=Ct(e[0],t);for(i=0,n=e.length;i<n;++i)s=a,a=o,o=i<n-1&&Ct(e[i+1],t),a&&(r=e[i],s&&(r.cp1x=ni(r.cp1x,t.left,t.right),r.cp1y=ni(r.cp1y,t.top,t.bottom)),o&&(r.cp2x=ni(r.cp2x,t.left,t.right),r.cp2y=ni(r.cp2y,t.top,t.bottom)))}(e,i)}const ai=e=>0===e||1===e,si=(e,t,i)=>-Math.pow(2,10*(e-=1))*Math.sin((e-t)*C/i),oi=(e,t,i)=>Math.pow(2,-10*e)*Math.sin((e-t)*C/i)+1,li={linear:e=>e,easeInQuad:e=>e*e,easeOutQuad:e=>-e*(e-2),easeInOutQuad:e=>(e/=.5)<1?.5*e*e:-.5*(--e*(e-2)-1),easeInCubic:e=>e*e*e,easeOutCubic:e=>(e-=1)*e*e+1,easeInOutCubic:e=>(e/=.5)<1?.5*e*e*e:.5*((e-=2)*e*e+2),easeInQuart:e=>e*e*e*e,easeOutQuart:e=>-((e-=1)*e*e*e-1),easeInOutQuart:e=>(e/=.5)<1?.5*e*e*e*e:-.5*((e-=2)*e*e*e-2),easeInQuint:e=>e*e*e*e*e,easeOutQuint:e=>(e-=1)*e*e*e*e+1,easeInOutQuint:e=>(e/=.5)<1?.5*e*e*e*e*e:.5*((e-=2)*e*e*e*e+2),easeInSine:e=>1-Math.cos(e*P),easeOutSine:e=>Math.sin(e*P),easeInOutSine:e=>-.5*(Math.cos(T*e)-1),easeInExpo:e=>0===e?0:Math.pow(2,10*(e-1)),easeOutExpo:e=>1===e?1:1-Math.pow(2,-10*e),easeInOutExpo:e=>ai(e)?e:e<.5?.5*Math.pow(2,10*(2*e-1)):.5*(2-Math.pow(2,-10*(2*e-1))),easeInCirc:e=>e>=1?e:-(Math.sqrt(1-e*e)-1),easeOutCirc:e=>Math.sqrt(1-(e-=1)*e),easeInOutCirc:e=>(e/=.5)<1?-.5*(Math.sqrt(1-e*e)-1):.5*(Math.sqrt(1-(e-=2)*e)+1),easeInElastic:e=>ai(e)?e:si(e,.075,.3),easeOutElastic:e=>ai(e)?e:oi(e,.075,.3),easeInOutElastic(e){const t=.1125;return ai(e)?e:e<.5?.5*si(2*e,t,.45):.5+.5*oi(2*e-1,t,.45)},easeInBack(e){const t=1.70158;return e*e*((t+1)*e-t)},easeOutBack(e){const t=1.70158;return(e-=1)*e*((t+1)*e+t)+1},easeInOutBack(e){let t=1.70158;return(e/=.5)<1?e*e*((1+(t*=1.525))*e-t)*.5:.5*((e-=2)*e*((1+(t*=1.525))*e+t)+2)},easeInBounce:e=>1-li.easeOutBounce(1-e),easeOutBounce(e){const t=7.5625,i=2.75;return e<1/i?t*e*e:e<2/i?t*(e-=1.5/i)*e+.75:e<2.5/i?t*(e-=2.25/i)*e+.9375:t*(e-=2.625/i)*e+.984375},easeInOutBounce:e=>e<.5?.5*li.easeInBounce(2*e):.5*li.easeOutBounce(2*e-1)+.5};function ci(e,t,i,n){return{x:e.x+i*(t.x-e.x),y:e.y+i*(t.y-e.y)}}function ui(e,t,i,n){return{x:e.x+i*(t.x-e.x),y:"middle"===n?i<.5?e.y:t.y:"after"===n?i<1?e.y:t.y:i>0?t.y:e.y}}function di(e,t,i,n){const r={x:e.cp2x,y:e.cp2y},a={x:t.cp1x,y:t.cp1y},s=ci(e,r,i),o=ci(r,a,i),l=ci(a,t,i),c=ci(s,o,i),u=ci(o,l,i);return ci(c,u,i)}const hi=/^(normal|(\d+(?:\.\d+)?)(px|em|%)?)$/,fi=/^(normal|italic|initial|inherit|unset|(oblique( -?[0-9]?[0-9]deg)?))$/;function pi(e,t){const i=(""+e).match(hi);if(!i||"normal"===i[1])return 1.2*t;switch(e=+i[2],i[3]){case"px":return e;case"%":e/=100}return t*e}const mi=e=>+e||0;function gi(e,t){const i={},n=a(t),r=n?Object.keys(t):t,s=a(e)?n?i=>l(e[i],e[t[i]]):t=>e[t]:()=>e;for(const e of r)i[e]=mi(s(e));return i}function vi(e){return gi(e,{top:"y",right:"x",bottom:"y",left:"x"})}function yi(e){return gi(e,["topLeft","topRight","bottomLeft","bottomRight"])}function bi(e){const t=vi(e);return t.width=t.left+t.right,t.height=t.top+t.bottom,t}function xi(e,t){e=e||{},t=t||ot.font;let i=l(e.size,t.size);"string"==typeof i&&(i=parseInt(i,10));let n=l(e.style,t.style);n&&!(""+n).match(fi)&&(console.warn('Invalid font style specified: "'+n+'"'),n=void 0);const r={family:l(e.family,t.family),lineHeight:pi(l(e.lineHeight,t.lineHeight),i),size:i,style:n,weight:l(e.weight,t.weight),string:""};return r.string=wt(r),r}function _i(e,t,i,n){let a,s,o,l=!0;for(a=0,s=e.length;a<s;++a)if(o=e[a],void 0!==o&&(void 0!==t&&"function"==typeof o&&(o=o(t),l=!1),void 0!==i&&r(o)&&(o=o[i%o.length],l=!1),void 0!==o))return n&&!l&&(n.cacheable=!1),o}function wi(e,t,i){const{min:n,max:r}=e,a=u(t,(r-n)/2),s=(e,t)=>i&&0===e?0:e+t;return{min:s(n,-Math.abs(a)),max:s(r,a)}}function ki(e,t){return Object.assign(Object.create(e),t)}function Mi(e,t,i){return e?function(e,t){return{x:i=>e+e+t-i,setWidth(e){t=e},textAlign:e=>"center"===e?e:"right"===e?"left":"right",xPlus:(e,t)=>e-t,leftForLtr:(e,t)=>e-t}}(t,i):{x:e=>e,setWidth(e){},textAlign:e=>e,xPlus:(e,t)=>e+t,leftForLtr:(e,t)=>e}}function Si(e,t){let i,n;"ltr"!==t&&"rtl"!==t||(i=e.canvas.style,n=[i.getPropertyValue("direction"),i.getPropertyPriority("direction")],i.setProperty("direction",t,"important"),e.prevTextDirection=n)}function Ai(e,t){void 0!==t&&(delete e.prevTextDirection,e.canvas.style.setProperty("direction",t[0],t[1]))}function Li(e){return"angle"===e?{between:K,compare:G,normalize:Z}:{between:ee,compare:(e,t)=>e-t,normalize:e=>e}}function Ti({start:e,end:t,count:i,loop:n,style:r}){return{start:e%i,end:t%i,loop:n&&(t-e+1)%i==0,style:r}}function Ci(e,t,i){if(!i)return[e];const{property:n,start:r,end:a}=i,s=t.length,{compare:o,between:l,normalize:c}=Li(n),{start:u,end:d,loop:h,style:f}=function(e,t,i){const{property:n,start:r,end:a}=i,{between:s,normalize:o}=Li(n),l=t.length;let c,u,{start:d,end:h,loop:f}=e;if(f){for(d+=l,h+=l,c=0,u=l;c<u&&s(o(t[d%l][n]),r,a);++c)d--,h--;d%=l,h%=l}return h<d&&(h+=l),{start:d,end:h,loop:f,style:e.style}}(e,t,i),p=[];let m,g,v,y=!1,b=null;for(let e=u,i=u;e<=d;++e)g=t[e%s],g.skip||(m=c(g[n]),m!==v&&(y=l(m,r,a),null===b&&(y||l(r,v,m)&&0!==o(r,v))&&(b=0===o(m,r)?e:i),null!==b&&(!y||0===o(a,m)||l(a,v,m))&&(p.push(Ti({start:b,end:e,loop:h,count:s,style:f})),b=null),i=e,v=m));return null!==b&&p.push(Ti({start:b,end:d,loop:h,count:s,style:f})),p}function Di(e,t){const i=[],n=e.segments;for(let r=0;r<n.length;r++){const a=Ci(n[r],e.points,t);a.length&&i.push(...a)}return i}function Ei(e,t){const i=e.points,n=e.options.spanGaps,r=i.length;if(!r)return[];const a=!!e._loop,{start:s,end:o}=function(e,t,i,n){let r=0,a=t-1;if(i&&!n)for(;r<t&&!e[r].skip;)r++;for(;r<t&&e[r].skip;)r++;for(r%=t,i&&(a+=r);a>r&&e[a%t].skip;)a--;return a%=t,{start:r,end:a}}(i,r,a,n);return Oi(e,!0===n?[{start:s,end:o,loop:a}]:function(e,t,i,n){const r=e.length,a=[];let s,o=t,l=e[t];for(s=t+1;s<=i;++s){const i=e[s%r];i.skip||i.stop?l.skip||(n=!1,a.push({start:t%r,end:(s-1)%r,loop:n}),t=o=i.stop?s:null):(o=s,l.skip&&(t=s)),l=i}return null!==o&&a.push({start:t%r,end:o%r,loop:n}),a}(i,s,o<s?o+r:o,!!e._fullLoop&&0===s&&o===r-1),i,t)}function Oi(e,t,i,n){return n&&n.setContext&&i?function(e,t,i,n){const r=e._chart.getContext(),a=Pi(e.options),{_datasetIndex:s,options:{spanGaps:o}}=e,l=i.length,c=[];let u=a,d=t[0].start,h=d;function f(e,t,n,r){const a=o?-1:1;if(e!==t){for(e+=l;i[e%l].skip;)e-=a;for(;i[t%l].skip;)t+=a;e%l!=t%l&&(c.push({start:e%l,end:t%l,loop:n,style:r}),u=r,d=t%l)}}for(const e of t){d=o?d:e.start;let t,a=i[d%l];for(h=d+1;h<=e.end;h++){const o=i[h%l];t=Pi(n.setContext(ki(r,{type:"segment",p0:a,p1:o,p0DataIndex:(h-1)%l,p1DataIndex:h%l,datasetIndex:s}))),Yi(t,u)&&f(d,h-1,e.loop,u),a=o,u=t}d<h-1&&f(d,h-1,e.loop,u)}return c}(e,t,i,n):t}function Pi(e){return{backgroundColor:e.backgroundColor,borderCapStyle:e.borderCapStyle,borderDash:e.borderDash,borderDashOffset:e.borderDashOffset,borderJoinStyle:e.borderJoinStyle,borderWidth:e.borderWidth,borderColor:e.borderColor}}function Yi(e,t){if(!t)return!1;const i=[],n=function(e,t){return Xe(t)?(i.includes(t)||i.push(t),i.indexOf(t)):t};return JSON.stringify(e,n)!==JSON.stringify(t,n)}var Ii=Object.freeze({__proto__:null,HALF_PI:P,INFINITY:E,PI:T,PITAU:D,QUARTER_PI:Y,RAD_PER_DEG:O,TAU:C,TWO_THIRDS_PI:I,_addGrace:wi,_alignPixel:St,_alignStartEnd:fe,_angleBetween:K,_angleDiff:G,_arrayUnique:le,_attachContext:Ft,_bezierCurveTo:Pt,_bezierInterpolation:di,_boundSegment:Ci,_boundSegments:Di,_capitalize:k,_computeSegments:Ei,_createResolver:Ht,_decimalPlaces:q,_deprecated:function(e,t,i,n){void 0!==t&&console.warn(e+': "'+i+'" is deprecated. Please use "'+n+'" instead')},_descriptors:Rt,_elementsEqual:f,_factorize:R,_filterBetween:re,_getParentNode:ct,_getStartAndCountOfVisiblePoints:me,_int16Range:Q,_isBetween:ee,_isClickEvent:L,_isDomSupported:lt,_isPointInArea:Ct,_limitValue:J,_longestText:Mt,_lookup:te,_lookupByKey:ie,_measureText:kt,_merger:g,_mergerIf:b,_normalizeAngle:Z,_parseObjectDataRadialScale:Kt,_pointInLine:ci,_readValueToProps:gi,_rlookupByKey:ne,_scaleRangesChanged:ge,_setMinAndMaxByKey:V,_splitKey:_,_steppedInterpolation:ui,_steppedLineTo:Ot,_textX:pe,_toLeftRightCenter:he,_updateBezierControlPoints:ri,addRoundedRectPath:jt,almostEquals:H,almostWhole:B,callback:d,clearCanvas:At,clipArea:Dt,clone:p,color:Ge,createContext:ki,debounce:de,defined:M,distanceBetweenPoints:X,drawPoint:Lt,drawPointLegend:Tt,each:h,easingEffects:li,finiteOrDefault:o,fontString:function(e,t,i){return t+" "+e+"px "+i},formatNumber:et,getAngleFromPoint:$,getHoverColor:Ze,getMaximumSize:yt,getRelativePosition:gt,getRtlAdapter:Mi,getStyle:ht,isArray:r,isFinite:s,isFunction:S,isNullOrUndef:n,isNumber:z,isObject:a,isPatternOrGradient:Xe,listenArrayEvents:se,log10:N,merge:v,mergeIf:y,niceNum:F,noop:t,overrideTextDirection:Si,readUsedSize:_t,renderText:Nt,requestAnimFrame:ce,resolve:_i,resolveObjectKey:w,restoreTextDirection:Ai,retinaScale:bt,setsEqual:A,sign:j,splineCurve:ti,splineCurveMonotone:ii,supportsEventListenerOptions:xt,throttled:ue,toDegrees:U,toDimension:u,toFont:xi,toFontString:wt,toLineHeight:pi,toPadding:bi,toPercentage:c,toRadians:W,toTRBL:vi,toTRBLCorners:yi,uid:i,unclipArea:Et,unlistenArrayEvents:oe,valueOrDefault:l});function Ni(e,t,i,n){const{controller:r,data:a,_sorted:s}=e,o=r._cachedMeta.iScale;if(o&&t===o.axis&&"r"!==t&&s&&a.length){const e=o._reversePixels?ne:ie;if(!n)return e(a,t,i);if(r._sharedOptions){const n=a[0],r="function"==typeof n.getRange&&n.getRange(t);if(r){const n=e(a,t,i-r),s=e(a,t,i+r);return{lo:n.lo,hi:s.hi}}}}return{lo:0,hi:a.length-1}}function ji(e,t,i,n,r){const a=e.getSortedVisibleDatasetMetas(),s=i[t];for(let e=0,i=a.length;e<i;++e){const{index:i,data:o}=a[e],{lo:l,hi:c}=Ni(a[e],t,s,r);for(let e=l;e<=c;++e){const t=o[e];t.skip||n(t,i,e)}}}function Hi(e,t,i,n,r){const a=[];return r||e.isPointInArea(t)?(ji(e,i,t,(function(i,s,o){(r||Ct(i,e.chartArea,0))&&i.inRange(t.x,t.y,n)&&a.push({element:i,datasetIndex:s,index:o})}),!0),a):a}function Fi(e,t,i,n,r,a){return a||e.isPointInArea(t)?"r"!==i||n?function(e,t,i,n,r,a){let s=[];const o=function(e){const t=-1!==e.indexOf("x"),i=-1!==e.indexOf("y");return function(e,n){const r=t?Math.abs(e.x-n.x):0,a=i?Math.abs(e.y-n.y):0;return Math.sqrt(Math.pow(r,2)+Math.pow(a,2))}}(i);let l=Number.POSITIVE_INFINITY;return ji(e,i,t,(function(i,c,u){const d=i.inRange(t.x,t.y,r);if(n&&!d)return;const h=i.getCenterPoint(r);if(!a&&!e.isPointInArea(h)&&!d)return;const f=o(t,h);f<l?(s=[{element:i,datasetIndex:c,index:u}],l=f):f===l&&s.push({element:i,datasetIndex:c,index:u})})),s}(e,t,i,n,r,a):function(e,t,i,n){let r=[];return ji(e,i,t,(function(e,i,a){const{startAngle:s,endAngle:o}=e.getProps(["startAngle","endAngle"],n),{angle:l}=$(e,{x:t.x,y:t.y});K(l,s,o)&&r.push({element:e,datasetIndex:i,index:a})})),r}(e,t,i,r):[]}function Ri(e,t,i,n,r){const a=[],s="x"===i?"inXRange":"inYRange";let o=!1;return ji(e,i,t,((e,n,l)=>{e[s](t[i],r)&&(a.push({element:e,datasetIndex:n,index:l}),o=o||e.inRange(t.x,t.y,r))})),n&&!o?[]:a}var zi={evaluateInteractionItems:ji,modes:{index(e,t,i,n){const r=gt(t,e),a=i.axis||"x",s=i.includeInvisible||!1,o=i.intersect?Hi(e,r,a,n,s):Fi(e,r,a,!1,n,s),l=[];return o.length?(e.getSortedVisibleDatasetMetas().forEach((e=>{const t=o[0].index,i=e.data[t];i&&!i.skip&&l.push({element:i,datasetIndex:e.index,index:t})})),l):[]},dataset(e,t,i,n){const r=gt(t,e),a=i.axis||"xy",s=i.includeInvisible||!1;let o=i.intersect?Hi(e,r,a,n,s):Fi(e,r,a,!1,n,s);if(o.length>0){const t=o[0].datasetIndex,i=e.getDatasetMeta(t).data;o=[];for(let e=0;e<i.length;++e)o.push({element:i[e],datasetIndex:t,index:e})}return o},point:(e,t,i,n)=>Hi(e,gt(t,e),i.axis||"xy",n,i.includeInvisible||!1),nearest(e,t,i,n){const r=gt(t,e),a=i.axis||"xy",s=i.includeInvisible||!1;return Fi(e,r,a,i.intersect,n,s)},x:(e,t,i,n)=>Ri(e,gt(t,e),"x",i.intersect,n),y:(e,t,i,n)=>Ri(e,gt(t,e),"y",i.intersect,n)}};const Bi=["left","top","right","bottom"];function Vi(e,t){return e.filter((e=>e.pos===t))}function Wi(e,t){return e.filter((e=>-1===Bi.indexOf(e.pos)&&e.box.axis===t))}function Ui(e,t){return e.sort(((e,i)=>{const n=t?i:e,r=t?e:i;return n.weight===r.weight?n.index-r.index:n.weight-r.weight}))}function qi(e,t,i,n){return Math.max(e[i],t[i])+Math.max(e[n],t[n])}function $i(e,t){e.top=Math.max(e.top,t.top),e.left=Math.max(e.left,t.left),e.bottom=Math.max(e.bottom,t.bottom),e.right=Math.max(e.right,t.right)}function Xi(e,t,i,n){const{pos:r,box:s}=i,o=e.maxPadding;if(!a(r)){i.size&&(e[r]-=i.size);const t=n[i.stack]||{size:0,count:1};t.size=Math.max(t.size,i.horizontal?s.height:s.width),i.size=t.size/t.count,e[r]+=i.size}s.getPadding&&$i(o,s.getPadding());const l=Math.max(0,t.outerWidth-qi(o,e,"left","right")),c=Math.max(0,t.outerHeight-qi(o,e,"top","bottom")),u=l!==e.w,d=c!==e.h;return e.w=l,e.h=c,i.horizontal?{same:u,other:d}:{same:d,other:u}}function Gi(e,t){const i=t.maxPadding;return function(e){const n={left:0,top:0,right:0,bottom:0};return e.forEach((e=>{n[e]=Math.max(t[e],i[e])})),n}(e?["left","right"]:["top","bottom"])}function Zi(e,t,i,n){const r=[];let a,s,o,l,c,u;for(a=0,s=e.length,c=0;a<s;++a){o=e[a],l=o.box,l.update(o.width||t.w,o.height||t.h,Gi(o.horizontal,t));const{same:s,other:d}=Xi(t,i,o,n);c|=s&&r.length,u=u||d,l.fullSize||r.push(o)}return c&&Zi(r,t,i,n)||u}function Ki(e,t,i,n,r){e.top=i,e.left=t,e.right=t+n,e.bottom=i+r,e.width=n,e.height=r}function Ji(e,t,i,n){const r=i.padding;let{x:a,y:s}=t;for(const o of e){const e=o.box,l=n[o.stack]||{count:1,placed:0,weight:1},c=o.stackWeight/l.weight||1;if(o.horizontal){const n=t.w*c,a=l.size||e.height;M(l.start)&&(s=l.start),e.fullSize?Ki(e,r.left,s,i.outerWidth-r.right-r.left,a):Ki(e,t.left+l.placed,s,n,a),l.start=s,l.placed+=n,s=e.bottom}else{const n=t.h*c,s=l.size||e.width;M(l.start)&&(a=l.start),e.fullSize?Ki(e,a,r.top,s,i.outerHeight-r.bottom-r.top):Ki(e,a,t.top+l.placed,s,n),l.start=a,l.placed+=n,a=e.right}}t.x=a,t.y=s}var Qi={addBox(e,t){e.boxes||(e.boxes=[]),t.fullSize=t.fullSize||!1,t.position=t.position||"top",t.weight=t.weight||0,t._layers=t._layers||function(){return[{z:0,draw(e){t.draw(e)}}]},e.boxes.push(t)},removeBox(e,t){const i=e.boxes?e.boxes.indexOf(t):-1;-1!==i&&e.boxes.splice(i,1)},configure(e,t,i){t.fullSize=i.fullSize,t.position=i.position,t.weight=i.weight},update(e,t,i,n){if(!e)return;const r=bi(e.options.layout.padding),a=Math.max(t-r.width,0),s=Math.max(i-r.height,0),o=function(e){const t=function(e){const t=[];let i,n,r,a,s,o;for(i=0,n=(e||[]).length;i<n;++i)r=e[i],({position:a,options:{stack:s,stackWeight:o=1}}=r),t.push({index:i,box:r,pos:a,horizontal:r.isHorizontal(),weight:r.weight,stack:s&&a+s,stackWeight:o});return t}(e),i=Ui(t.filter((e=>e.box.fullSize)),!0),n=Ui(Vi(t,"left"),!0),r=Ui(Vi(t,"right")),a=Ui(Vi(t,"top"),!0),s=Ui(Vi(t,"bottom")),o=Wi(t,"x"),l=Wi(t,"y");return{fullSize:i,leftAndTop:n.concat(a),rightAndBottom:r.concat(l).concat(s).concat(o),chartArea:Vi(t,"chartArea"),vertical:n.concat(r).concat(l),horizontal:a.concat(s).concat(o)}}(e.boxes),l=o.vertical,c=o.horizontal;h(e.boxes,(e=>{"function"==typeof e.beforeLayout&&e.beforeLayout()}));const u=l.reduce(((e,t)=>t.box.options&&!1===t.box.options.display?e:e+1),0)||1,d=Object.freeze({outerWidth:t,outerHeight:i,padding:r,availableWidth:a,availableHeight:s,vBoxMaxWidth:a/2/u,hBoxMaxHeight:s/2}),f=Object.assign({},r);$i(f,bi(n));const p=Object.assign({maxPadding:f,w:a,h:s,x:r.left,y:r.top},r),m=function(e,t){const i=function(e){const t={};for(const i of e){const{stack:e,pos:n,stackWeight:r}=i;if(!e||!Bi.includes(n))continue;const a=t[e]||(t[e]={count:0,placed:0,weight:0,size:0});a.count++,a.weight+=r}return t}(e),{vBoxMaxWidth:n,hBoxMaxHeight:r}=t;let a,s,o;for(a=0,s=e.length;a<s;++a){o=e[a];const{fullSize:s}=o.box,l=i[o.stack],c=l&&o.stackWeight/l.weight;o.horizontal?(o.width=c?c*n:s&&t.availableWidth,o.height=r):(o.width=n,o.height=c?c*r:s&&t.availableHeight)}return i}(l.concat(c),d);Zi(o.fullSize,p,d,m),Zi(l,p,d,m),Zi(c,p,d,m)&&Zi(l,p,d,m),function(e){const t=e.maxPadding;function i(i){const n=Math.max(t[i]-e[i],0);return e[i]+=n,n}e.y+=i("top"),e.x+=i("left"),i("right"),i("bottom")}(p),Ji(o.leftAndTop,p,d,m),p.x+=p.w,p.y+=p.h,Ji(o.rightAndBottom,p,d,m),e.chartArea={left:p.left,top:p.top,right:p.left+p.w,bottom:p.top+p.h,height:p.h,width:p.w},h(o.chartArea,(t=>{const i=t.box;Object.assign(i,e.chartArea),i.update(p.w,p.h,{left:0,top:0,right:0,bottom:0})}))}};class en{acquireContext(e,t){}releaseContext(e){return!1}addEventListener(e,t,i){}removeEventListener(e,t,i){}getDevicePixelRatio(){return 1}getMaximumSize(e,t,i,n){return t=Math.max(0,t||e.width),i=i||e.height,{width:t,height:Math.max(0,n?Math.floor(t/n):i)}}isAttached(e){return!0}updateConfig(e){}}class tn extends en{acquireContext(e){return e&&e.getContext&&e.getContext("2d")||null}updateConfig(e){e.options.animation=!1}}const nn="$chartjs",rn={touchstart:"mousedown",touchmove:"mousemove",touchend:"mouseup",pointerenter:"mouseenter",pointerdown:"mousedown",pointermove:"mousemove",pointerup:"mouseup",pointerleave:"mouseout",pointerout:"mouseout"},an=e=>null===e||""===e,sn=!!xt&&{passive:!0};function on(e,t,i){e&&e.canvas&&e.canvas.removeEventListener(t,i,sn)}function ln(e,t){for(const i of e)if(i===t||i.contains(t))return!0}function cn(e,t,i){const n=e.canvas,r=new MutationObserver((e=>{let t=!1;for(const i of e)t=t||ln(i.addedNodes,n),t=t&&!ln(i.removedNodes,n);t&&i()}));return r.observe(document,{childList:!0,subtree:!0}),r}function un(e,t,i){const n=e.canvas,r=new MutationObserver((e=>{let t=!1;for(const i of e)t=t||ln(i.removedNodes,n),t=t&&!ln(i.addedNodes,n);t&&i()}));return r.observe(document,{childList:!0,subtree:!0}),r}const dn=new Map;let hn=0;function fn(){const e=window.devicePixelRatio;e!==hn&&(hn=e,dn.forEach(((t,i)=>{i.currentDevicePixelRatio!==e&&t()})))}function pn(e,t,i){const n=e.canvas,r=n&&ct(n);if(!r)return;const a=ue(((e,t)=>{const n=r.clientWidth;i(e,t),n<r.clientWidth&&i()}),window),s=new ResizeObserver((e=>{const t=e[0],i=t.contentRect.width,n=t.contentRect.height;0===i&&0===n||a(i,n)}));return s.observe(r),function(e,t){dn.size||window.addEventListener("resize",fn),dn.set(e,t)}(e,a),s}function mn(e,t,i){i&&i.disconnect(),"resize"===t&&function(e){dn.delete(e),dn.size||window.removeEventListener("resize",fn)}(e)}function gn(e,t,i){const n=e.canvas,r=ue((t=>{null!==e.ctx&&i(function(e,t){const i=rn[e.type]||e.type,{x:n,y:r}=gt(e,t);return{type:i,chart:t,native:e,x:void 0!==n?n:null,y:void 0!==r?r:null}}(t,e))}),e);return function(e,t,i){e&&e.addEventListener(t,i,sn)}(n,t,r),r}class vn extends en{acquireContext(e,t){const i=e&&e.getContext&&e.getContext("2d");return i&&i.canvas===e?(function(e,t){const i=e.style,n=e.getAttribute("height"),r=e.getAttribute("width");if(e[nn]={initial:{height:n,width:r,style:{display:i.display,height:i.height,width:i.width}}},i.display=i.display||"block",i.boxSizing=i.boxSizing||"border-box",an(r)){const t=_t(e,"width");void 0!==t&&(e.width=t)}if(an(n))if(""===e.style.height)e.height=e.width/(t||2);else{const t=_t(e,"height");void 0!==t&&(e.height=t)}}(e,t),i):null}releaseContext(e){const t=e.canvas;if(!t[nn])return!1;const i=t[nn].initial;["height","width"].forEach((e=>{const r=i[e];n(r)?t.removeAttribute(e):t.setAttribute(e,r)}));const r=i.style||{};return Object.keys(r).forEach((e=>{t.style[e]=r[e]})),t.width=t.width,delete t[nn],!0}addEventListener(e,t,i){this.removeEventListener(e,t);const n=e.$proxies||(e.$proxies={}),r={attach:cn,detach:un,resize:pn}[t]||gn;n[t]=r(e,t,i)}removeEventListener(e,t){const i=e.$proxies||(e.$proxies={}),n=i[t];n&&(({attach:mn,detach:mn,resize:mn}[t]||on)(e,t,n),i[t]=void 0)}getDevicePixelRatio(){return window.devicePixelRatio}getMaximumSize(e,t,i,n){return yt(e,t,i,n)}isAttached(e){const t=e&&ct(e);return!(!t||!t.isConnected)}}function yn(e){return!lt()||"undefined"!=typeof OffscreenCanvas&&e instanceof OffscreenCanvas?tn:vn}var bn=Object.freeze({__proto__:null,BasePlatform:en,BasicPlatform:tn,DomPlatform:vn,_detectPlatform:yn});const xn="transparent",_n={boolean:(e,t,i)=>i>.5?t:e,color(e,t,i){const n=Ge(e||xn),r=n.valid&&Ge(t||xn);return r&&r.valid?r.mix(n,i).hexString():t},number:(e,t,i)=>e+(t-e)*i};class wn{constructor(e,t,i,n){const r=t[i];n=_i([e.to,n,r,e.from]);const a=_i([e.from,r,n]);this._active=!0,this._fn=e.fn||_n[e.type||typeof a],this._easing=li[e.easing]||li.linear,this._start=Math.floor(Date.now()+(e.delay||0)),this._duration=this._total=Math.floor(e.duration),this._loop=!!e.loop,this._target=t,this._prop=i,this._from=a,this._to=n,this._promises=void 0}active(){return this._active}update(e,t,i){if(this._active){this._notify(!1);const n=this._target[this._prop],r=i-this._start,a=this._duration-r;this._start=i,this._duration=Math.floor(Math.max(a,e.duration)),this._total+=r,this._loop=!!e.loop,this._to=_i([e.to,t,n,e.from]),this._from=_i([e.from,n,t])}}cancel(){this._active&&(this.tick(Date.now()),this._active=!1,this._notify(!1))}tick(e){const t=e-this._start,i=this._duration,n=this._prop,r=this._from,a=this._loop,s=this._to;let o;if(this._active=r!==s&&(a||t<i),!this._active)return this._target[n]=s,void this._notify(!0);t<0?this._target[n]=r:(o=t/i%2,o=a&&o>1?2-o:o,o=this._easing(Math.min(1,Math.max(0,o))),this._target[n]=this._fn(r,s,o))}wait(){const e=this._promises||(this._promises=[]);return new Promise(((t,i)=>{e.push({res:t,rej:i})}))}_notify(e){const t=e?"res":"rej",i=this._promises||[];for(let e=0;e<i.length;e++)i[e][t]()}}class kn{constructor(e,t){this._chart=e,this._properties=new Map,this.configure(t)}configure(e){if(!a(e))return;const t=Object.keys(ot.animation),i=this._properties;Object.getOwnPropertyNames(e).forEach((n=>{const s=e[n];if(!a(s))return;const o={};for(const e of t)o[e]=s[e];(r(s.properties)&&s.properties||[n]).forEach((e=>{e!==n&&i.has(e)||i.set(e,o)}))}))}_animateOptions(e,t){const i=t.options,n=function(e,t){if(!t)return;let i=e.options;if(i)return i.$shared&&(e.options=i=Object.assign({},i,{$shared:!1,$animations:{}})),i;e.options=t}(e,i);if(!n)return[];const r=this._createAnimations(n,i);return i.$shared&&function(e,t){const i=[],n=Object.keys(t);for(let t=0;t<n.length;t++){const r=e[n[t]];r&&r.active()&&i.push(r.wait())}return Promise.all(i)}(e.options.$animations,i).then((()=>{e.options=i}),(()=>{})),r}_createAnimations(e,t){const i=this._properties,n=[],r=e.$animations||(e.$animations={}),a=Object.keys(t),s=Date.now();let o;for(o=a.length-1;o>=0;--o){const l=a[o];if("$"===l.charAt(0))continue;if("options"===l){n.push(...this._animateOptions(e,t));continue}const c=t[l];let u=r[l];const d=i.get(l);if(u){if(d&&u.active()){u.update(d,c,s);continue}u.cancel()}d&&d.duration?(r[l]=u=new wn(d,e,l,c),n.push(u)):e[l]=c}return n}update(e,t){if(0===this._properties.size)return void Object.assign(e,t);const i=this._createAnimations(e,t);return i.length?(ve.add(this._chart,i),!0):void 0}}function Mn(e,t){const i=e&&e.options||{},n=i.reverse,r=void 0===i.min?t:0,a=void 0===i.max?t:0;return{start:n?a:r,end:n?r:a}}function Sn(e,t){const i=[],n=e._getSortedDatasetMetas(t);let r,a;for(r=0,a=n.length;r<a;++r)i.push(n[r].index);return i}function An(e,t,i,n={}){const r=e.keys,a="single"===n.mode;let o,l,c,u;if(null!==t){for(o=0,l=r.length;o<l;++o){if(c=+r[o],c===i){if(n.all)continue;break}u=e.values[c],s(u)&&(a||0===t||j(t)===j(u))&&(t+=u)}return t}}function Ln(e,t){const i=e&&e.options.stacked;return i||void 0===i&&void 0!==t.stack}function Tn(e,t,i){const n=e[t]||(e[t]={});return n[i]||(n[i]={})}function Cn(e,t,i,n){for(const r of t.getMatchingVisibleMetas(n).reverse()){const t=e[r.index];if(i&&t>0||!i&&t<0)return r.index}return null}function Dn(e,t){const{chart:i,_cachedMeta:n}=e,r=i._stacks||(i._stacks={}),{iScale:a,vScale:s,index:o}=n,l=a.axis,c=s.axis,u=function(e,t,i){return`${e.id}.${t.id}.${i.stack||i.type}`}(a,s,n),d=t.length;let h;for(let e=0;e<d;++e){const i=t[e],{[l]:a,[c]:d}=i;h=(i._stacks||(i._stacks={}))[c]=Tn(r,u,a),h[o]=d,h._top=Cn(h,s,!0,n.type),h._bottom=Cn(h,s,!1,n.type),(h._visualValues||(h._visualValues={}))[o]=d}}function En(e,t){const i=e.scales;return Object.keys(i).filter((e=>i[e].axis===t)).shift()}function On(e,t){const i=e.controller.index,n=e.vScale&&e.vScale.axis;if(n){t=t||e._parsed;for(const e of t){const t=e._stacks;if(!t||void 0===t[n]||void 0===t[n][i])return;delete t[n][i],void 0!==t[n]._visualValues&&void 0!==t[n]._visualValues[i]&&delete t[n]._visualValues[i]}}}const Pn=e=>"reset"===e||"none"===e,Yn=(e,t)=>t?e:Object.assign({},e);class In{static defaults={};static datasetElementType=null;static dataElementType=null;constructor(e,t){this.chart=e,this._ctx=e.ctx,this.index=t,this._cachedDataOpts={},this._cachedMeta=this.getMeta(),this._type=this._cachedMeta.type,this.options=void 0,this._parsing=!1,this._data=void 0,this._objectData=void 0,this._sharedOptions=void 0,this._drawStart=void 0,this._drawCount=void 0,this.enableOptionSharing=!1,this.supportsDecimation=!1,this.$context=void 0,this._syncList=[],this.datasetElementType=new.target.datasetElementType,this.dataElementType=new.target.dataElementType,this.initialize()}initialize(){const e=this._cachedMeta;this.configure(),this.linkScales(),e._stacked=Ln(e.vScale,e),this.addElements(),this.options.fill&&!this.chart.isPluginEnabled("filler")&&console.warn("Tried to use the 'fill' option without the 'Filler' plugin enabled. Please import and register the 'Filler' plugin and make sure it is not disabled in the options")}updateIndex(e){this.index!==e&&On(this._cachedMeta),this.index=e}linkScales(){const e=this.chart,t=this._cachedMeta,i=this.getDataset(),n=(e,t,i,n)=>"x"===e?t:"r"===e?n:i,r=t.xAxisID=l(i.xAxisID,En(e,"x")),a=t.yAxisID=l(i.yAxisID,En(e,"y")),s=t.rAxisID=l(i.rAxisID,En(e,"r")),o=t.indexAxis,c=t.iAxisID=n(o,r,a,s),u=t.vAxisID=n(o,a,r,s);t.xScale=this.getScaleForId(r),t.yScale=this.getScaleForId(a),t.rScale=this.getScaleForId(s),t.iScale=this.getScaleForId(c),t.vScale=this.getScaleForId(u)}getDataset(){return this.chart.data.datasets[this.index]}getMeta(){return this.chart.getDatasetMeta(this.index)}getScaleForId(e){return this.chart.scales[e]}_getOtherScale(e){const t=this._cachedMeta;return e===t.iScale?t.vScale:t.iScale}reset(){this._update("reset")}_destroy(){const e=this._cachedMeta;this._data&&oe(this._data,this),e._stacked&&On(e)}_dataCheck(){const e=this.getDataset(),t=e.data||(e.data=[]),i=this._data;if(a(t)){const e=this._cachedMeta;this._data=function(e,t){const{iScale:i,vScale:n}=t,r="x"===i.axis?"x":"y",a="x"===n.axis?"x":"y",s=Object.keys(e),o=new Array(s.length);let l,c,u;for(l=0,c=s.length;l<c;++l)u=s[l],o[l]={[r]:u,[a]:e[u]};return o}(t,e)}else if(i!==t){if(i){oe(i,this);const e=this._cachedMeta;On(e),e._parsed=[]}t&&Object.isExtensible(t)&&se(t,this),this._syncList=[],this._data=t}}addElements(){const e=this._cachedMeta;this._dataCheck(),this.datasetElementType&&(e.dataset=new this.datasetElementType)}buildOrUpdateElements(e){const t=this._cachedMeta,i=this.getDataset();let n=!1;this._dataCheck();const r=t._stacked;t._stacked=Ln(t.vScale,t),t.stack!==i.stack&&(n=!0,On(t),t.stack=i.stack),this._resyncElements(e),(n||r!==t._stacked)&&Dn(this,t._parsed)}configure(){const e=this.chart.config,t=e.datasetScopeKeys(this._type),i=e.getOptionScopes(this.getDataset(),t,!0);this.options=e.createResolver(i,this.getContext()),this._parsing=this.options.parsing,this._cachedDataOpts={}}parse(e,t){const{_cachedMeta:i,_data:n}=this,{iScale:s,_stacked:o}=i,l=s.axis;let c,u,d,h=0===e&&t===n.length||i._sorted,f=e>0&&i._parsed[e-1];if(!1===this._parsing)i._parsed=n,i._sorted=!0,d=n;else{d=r(n[e])?this.parseArrayData(i,n,e,t):a(n[e])?this.parseObjectData(i,n,e,t):this.parsePrimitiveData(i,n,e,t);const s=()=>null===u[l]||f&&u[l]<f[l];for(c=0;c<t;++c)i._parsed[c+e]=u=d[c],h&&(s()&&(h=!1),f=u);i._sorted=h}o&&Dn(this,d)}parsePrimitiveData(e,t,i,n){const{iScale:r,vScale:a}=e,s=r.axis,o=a.axis,l=r.getLabels(),c=r===a,u=new Array(n);let d,h,f;for(d=0,h=n;d<h;++d)f=d+i,u[d]={[s]:c||r.parse(l[f],f),[o]:a.parse(t[f],f)};return u}parseArrayData(e,t,i,n){const{xScale:r,yScale:a}=e,s=new Array(n);let o,l,c,u;for(o=0,l=n;o<l;++o)c=o+i,u=t[c],s[o]={x:r.parse(u[0],c),y:a.parse(u[1],c)};return s}parseObjectData(e,t,i,n){const{xScale:r,yScale:a}=e,{xAxisKey:s="x",yAxisKey:o="y"}=this._parsing,l=new Array(n);let c,u,d,h;for(c=0,u=n;c<u;++c)d=c+i,h=t[d],l[c]={x:r.parse(w(h,s),d),y:a.parse(w(h,o),d)};return l}getParsed(e){return this._cachedMeta._parsed[e]}getDataElement(e){return this._cachedMeta.data[e]}applyStack(e,t,i){const n=this.chart,r=this._cachedMeta,a=t[e.axis];return An({keys:Sn(n,!0),values:t._stacks[e.axis]._visualValues},a,r.index,{mode:i})}updateRangeFromParsed(e,t,i,n){const r=i[t.axis];let a=null===r?NaN:r;const s=n&&i._stacks[t.axis];n&&s&&(n.values=s,a=An(n,r,this._cachedMeta.index)),e.min=Math.min(e.min,a),e.max=Math.max(e.max,a)}getMinMax(e,t){const i=this._cachedMeta,n=i._parsed,r=i._sorted&&e===i.iScale,a=n.length,o=this._getOtherScale(e),l=((e,t,i)=>e&&!t.hidden&&t._stacked&&{keys:Sn(i,!0),values:null})(t,i,this.chart),c={min:Number.POSITIVE_INFINITY,max:Number.NEGATIVE_INFINITY},{min:u,max:d}=function(e){const{min:t,max:i,minDefined:n,maxDefined:r}=e.getUserBounds();return{min:n?t:Number.NEGATIVE_INFINITY,max:r?i:Number.POSITIVE_INFINITY}}(o);let h,f;function p(){f=n[h];const t=f[o.axis];return!s(f[e.axis])||u>t||d<t}for(h=0;h<a&&(p()||(this.updateRangeFromParsed(c,e,f,l),!r));++h);if(r)for(h=a-1;h>=0;--h)if(!p()){this.updateRangeFromParsed(c,e,f,l);break}return c}getAllParsedValues(e){const t=this._cachedMeta._parsed,i=[];let n,r,a;for(n=0,r=t.length;n<r;++n)a=t[n][e.axis],s(a)&&i.push(a);return i}getMaxOverflow(){return!1}getLabelAndValue(e){const t=this._cachedMeta,i=t.iScale,n=t.vScale,r=this.getParsed(e);return{label:i?""+i.getLabelForValue(r[i.axis]):"",value:n?""+n.getLabelForValue(r[n.axis]):""}}_update(e){const t=this._cachedMeta;this.update(e||"default"),t._clip=function(e){let t,i,n,r;return a(e)?(t=e.top,i=e.right,n=e.bottom,r=e.left):t=i=n=r=e,{top:t,right:i,bottom:n,left:r,disabled:!1===e}}(l(this.options.clip,function(e,t,i){if(!1===i)return!1;const n=Mn(e,i),r=Mn(t,i);return{top:r.end,right:n.end,bottom:r.start,left:n.start}}(t.xScale,t.yScale,this.getMaxOverflow())))}update(e){}draw(){const e=this._ctx,t=this.chart,i=this._cachedMeta,n=i.data||[],r=t.chartArea,a=[],s=this._drawStart||0,o=this._drawCount||n.length-s,l=this.options.drawActiveElementsOnTop;let c;for(i.dataset&&i.dataset.draw(e,r,s,o),c=s;c<s+o;++c){const t=n[c];t.hidden||(t.active&&l?a.push(t):t.draw(e,r))}for(c=0;c<a.length;++c)a[c].draw(e,r)}getStyle(e,t){const i=t?"active":"default";return void 0===e&&this._cachedMeta.dataset?this.resolveDatasetElementOptions(i):this.resolveDataElementOptions(e||0,i)}getContext(e,t,i){const n=this.getDataset();let r;if(e>=0&&e<this._cachedMeta.data.length){const t=this._cachedMeta.data[e];r=t.$context||(t.$context=function(e,t,i){return ki(e,{active:!1,dataIndex:t,parsed:void 0,raw:void 0,element:i,index:t,mode:"default",type:"data"})}(this.getContext(),e,t)),r.parsed=this.getParsed(e),r.raw=n.data[e],r.index=r.dataIndex=e}else r=this.$context||(this.$context=function(e,t){return ki(e,{active:!1,dataset:void 0,datasetIndex:t,index:t,mode:"default",type:"dataset"})}(this.chart.getContext(),this.index)),r.dataset=n,r.index=r.datasetIndex=this.index;return r.active=!!t,r.mode=i,r}resolveDatasetElementOptions(e){return this._resolveElementOptions(this.datasetElementType.id,e)}resolveDataElementOptions(e,t){return this._resolveElementOptions(this.dataElementType.id,t,e)}_resolveElementOptions(e,t="default",i){const n="active"===t,r=this._cachedDataOpts,a=e+"-"+t,s=r[a],o=this.enableOptionSharing&&M(i);if(s)return Yn(s,o);const l=this.chart.config,c=l.datasetElementScopeKeys(this._type,e),u=n?[`${e}Hover`,"hover",e,""]:[e,""],d=l.getOptionScopes(this.getDataset(),c),h=Object.keys(ot.elements[e]),f=l.resolveNamedOptions(d,h,(()=>this.getContext(i,n,t)),u);return f.$shared&&(f.$shared=o,r[a]=Object.freeze(Yn(f,o))),f}_resolveAnimations(e,t,i){const n=this.chart,r=this._cachedDataOpts,a=`animation-${t}`,s=r[a];if(s)return s;let o;if(!1!==n.options.animation){const n=this.chart.config,r=n.datasetAnimationScopeKeys(this._type,t),a=n.getOptionScopes(this.getDataset(),r);o=n.createResolver(a,this.getContext(e,i,t))}const l=new kn(n,o&&o.animations);return o&&o._cacheable&&(r[a]=Object.freeze(l)),l}getSharedOptions(e){if(e.$shared)return this._sharedOptions||(this._sharedOptions=Object.assign({},e))}includeOptions(e,t){return!t||Pn(e)||this.chart._animationsDisabled}_getSharedOptions(e,t){const i=this.resolveDataElementOptions(e,t),n=this._sharedOptions,r=this.getSharedOptions(i),a=this.includeOptions(t,r)||r!==n;return this.updateSharedOptions(r,t,i),{sharedOptions:r,includeOptions:a}}updateElement(e,t,i,n){Pn(n)?Object.assign(e,i):this._resolveAnimations(t,n).update(e,i)}updateSharedOptions(e,t,i){e&&!Pn(t)&&this._resolveAnimations(void 0,t).update(e,i)}_setStyle(e,t,i,n){e.active=n;const r=this.getStyle(t,n);this._resolveAnimations(t,i,n).update(e,{options:!n&&this.getSharedOptions(r)||r})}removeHoverStyle(e,t,i){this._setStyle(e,i,"active",!1)}setHoverStyle(e,t,i){this._setStyle(e,i,"active",!0)}_removeDatasetHoverStyle(){const e=this._cachedMeta.dataset;e&&this._setStyle(e,void 0,"active",!1)}_setDatasetHoverStyle(){const e=this._cachedMeta.dataset;e&&this._setStyle(e,void 0,"active",!0)}_resyncElements(e){const t=this._data,i=this._cachedMeta.data;for(const[e,t,i]of this._syncList)this[e](t,i);this._syncList=[];const n=i.length,r=t.length,a=Math.min(r,n);a&&this.parse(0,a),r>n?this._insertElements(n,r-n,e):r<n&&this._removeElements(r,n-r)}_insertElements(e,t,i=!0){const n=this._cachedMeta,r=n.data,a=e+t;let s;const o=e=>{for(e.length+=t,s=e.length-1;s>=a;s--)e[s]=e[s-t]};for(o(r),s=e;s<a;++s)r[s]=new this.dataElementType;this._parsing&&o(n._parsed),this.parse(e,t),i&&this.updateElements(r,e,t,"reset")}updateElements(e,t,i,n){}_removeElements(e,t){const i=this._cachedMeta;if(this._parsing){const n=i._parsed.splice(e,t);i._stacked&&On(i,n)}i.data.splice(e,t)}_sync(e){if(this._parsing)this._syncList.push(e);else{const[t,i,n]=e;this[t](i,n)}this.chart._dataChanges.push([this.index,...e])}_onDataPush(){const e=arguments.length;this._sync(["_insertElements",this.getDataset().data.length-e,e])}_onDataPop(){this._sync(["_removeElements",this._cachedMeta.data.length-1,1])}_onDataShift(){this._sync(["_removeElements",0,1])}_onDataSplice(e,t){t&&this._sync(["_removeElements",e,t]);const i=arguments.length-2;i&&this._sync(["_insertElements",e,i])}_onDataUnshift(){this._sync(["_insertElements",0,arguments.length])}}class Nn{static defaults={};static defaultRoutes=void 0;x;y;active=!1;options;$animations;tooltipPosition(e){const{x:t,y:i}=this.getProps(["x","y"],e);return{x:t,y:i}}hasValue(){return z(this.x)&&z(this.y)}getProps(e,t){const i=this.$animations;if(!t||!i)return this;const n={};return e.forEach((e=>{n[e]=i[e]&&i[e].active()?i[e]._to:this[e]})),n}}function jn(e,t){const i=e.options.ticks,r=function(e){const t=e.options.offset,i=e._tickSize(),n=e._length/i+(t?0:1),r=e._maxLength/i;return Math.floor(Math.min(n,r))}(e),a=Math.min(i.maxTicksLimit||r,r),s=i.major.enabled?function(e){const t=[];let i,n;for(i=0,n=e.length;i<n;i++)e[i].major&&t.push(i);return t}(t):[],o=s.length,l=s[0],c=s[o-1],u=[];if(o>a)return function(e,t,i,n){let r,a=0,s=i[0];for(n=Math.ceil(n),r=0;r<e.length;r++)r===s&&(t.push(e[r]),a++,s=i[a*n])}(t,u,s,o/a),u;const d=function(e,t,i){const n=function(e){const t=e.length;let i,n;if(t<2)return!1;for(n=e[0],i=1;i<t;++i)if(e[i]-e[i-1]!==n)return!1;return n}(e),r=t.length/i;if(!n)return Math.max(r,1);const a=R(n);for(let e=0,t=a.length-1;e<t;e++){const t=a[e];if(t>r)return t}return Math.max(r,1)}(s,t,a);if(o>0){let e,i;const r=o>1?Math.round((c-l)/(o-1)):null;for(Hn(t,u,d,n(r)?0:l-r,l),e=0,i=o-1;e<i;e++)Hn(t,u,d,s[e],s[e+1]);return Hn(t,u,d,c,n(r)?t.length:c+r),u}return Hn(t,u,d),u}function Hn(e,t,i,n,r){const a=l(n,0),s=Math.min(l(r,e.length),e.length);let o,c,u,d=0;for(i=Math.ceil(i),r&&(o=r-n,i=o/Math.floor(o/i)),u=a;u<0;)d++,u=Math.round(a+d*i);for(c=Math.max(a,0);c<s;c++)c===u&&(t.push(e[c]),d++,u=Math.round(a+d*i))}const Fn=(e,t,i)=>"top"===t||"left"===t?e[t]+i:e[t]-i,Rn=(e,t)=>Math.min(t||e,e);function zn(e,t){const i=[],n=e.length/t,r=e.length;let a=0;for(;a<r;a+=n)i.push(e[Math.floor(a)]);return i}function Bn(e,t,i){const n=e.ticks.length,r=Math.min(t,n-1),a=e._startPixel,s=e._endPixel,o=1e-6;let l,c=e.getPixelForTick(r);if(!(i&&(l=1===n?Math.max(c-a,s-c):0===t?(e.getPixelForTick(1)-c)/2:(c-e.getPixelForTick(r-1))/2,c+=r<t?l:-l,c<a-o||c>s+o)))return c}function Vn(e){return e.drawTicks?e.tickLength:0}function Wn(e,t){if(!e.display)return 0;const i=xi(e.font,t),n=bi(e.padding);return(r(e.text)?e.text.length:1)*i.lineHeight+n.height}function Un(e,t,i){let n=he(e);return(i&&"right"!==t||!i&&"right"===t)&&(n=(e=>"left"===e?"right":"right"===e?"left":e)(n)),n}class qn extends Nn{constructor(e){super(),this.id=e.id,this.type=e.type,this.options=void 0,this.ctx=e.ctx,this.chart=e.chart,this.top=void 0,this.bottom=void 0,this.left=void 0,this.right=void 0,this.width=void 0,this.height=void 0,this._margins={left:0,right:0,top:0,bottom:0},this.maxWidth=void 0,this.maxHeight=void 0,this.paddingTop=void 0,this.paddingBottom=void 0,this.paddingLeft=void 0,this.paddingRight=void 0,this.axis=void 0,this.labelRotation=void 0,this.min=void 0,this.max=void 0,this._range=void 0,this.ticks=[],this._gridLineItems=null,this._labelItems=null,this._labelSizes=null,this._length=0,this._maxLength=0,this._longestTextCache={},this._startPixel=void 0,this._endPixel=void 0,this._reversePixels=!1,this._userMax=void 0,this._userMin=void 0,this._suggestedMax=void 0,this._suggestedMin=void 0,this._ticksLength=0,this._borderValue=0,this._cache={},this._dataLimitsCached=!1,this.$context=void 0}init(e){this.options=e.setContext(this.getContext()),this.axis=e.axis,this._userMin=this.parse(e.min),this._userMax=this.parse(e.max),this._suggestedMin=this.parse(e.suggestedMin),this._suggestedMax=this.parse(e.suggestedMax)}parse(e,t){return e}getUserBounds(){let{_userMin:e,_userMax:t,_suggestedMin:i,_suggestedMax:n}=this;return e=o(e,Number.POSITIVE_INFINITY),t=o(t,Number.NEGATIVE_INFINITY),i=o(i,Number.POSITIVE_INFINITY),n=o(n,Number.NEGATIVE_INFINITY),{min:o(e,i),max:o(t,n),minDefined:s(e),maxDefined:s(t)}}getMinMax(e){let t,{min:i,max:n,minDefined:r,maxDefined:a}=this.getUserBounds();if(r&&a)return{min:i,max:n};const s=this.getMatchingVisibleMetas();for(let o=0,l=s.length;o<l;++o)t=s[o].controller.getMinMax(this,e),r||(i=Math.min(i,t.min)),a||(n=Math.max(n,t.max));return i=a&&i>n?n:i,n=r&&i>n?i:n,{min:o(i,o(n,i)),max:o(n,o(i,n))}}getPadding(){return{left:this.paddingLeft||0,top:this.paddingTop||0,right:this.paddingRight||0,bottom:this.paddingBottom||0}}getTicks(){return this.ticks}getLabels(){const e=this.chart.data;return this.options.labels||(this.isHorizontal()?e.xLabels:e.yLabels)||e.labels||[]}getLabelItems(e=this.chart.chartArea){return this._labelItems||(this._labelItems=this._computeLabelItems(e))}beforeLayout(){this._cache={},this._dataLimitsCached=!1}beforeUpdate(){d(this.options.beforeUpdate,[this])}update(e,t,i){const{beginAtZero:n,grace:r,ticks:a}=this.options,s=a.sampleSize;this.beforeUpdate(),this.maxWidth=e,this.maxHeight=t,this._margins=i=Object.assign({left:0,right:0,top:0,bottom:0},i),this.ticks=null,this._labelSizes=null,this._gridLineItems=null,this._labelItems=null,this.beforeSetDimensions(),this.setDimensions(),this.afterSetDimensions(),this._maxLength=this.isHorizontal()?this.width+i.left+i.right:this.height+i.top+i.bottom,this._dataLimitsCached||(this.beforeDataLimits(),this.determineDataLimits(),this.afterDataLimits(),this._range=wi(this,r,n),this._dataLimitsCached=!0),this.beforeBuildTicks(),this.ticks=this.buildTicks()||[],this.afterBuildTicks();const o=s<this.ticks.length;this._convertTicksToLabels(o?zn(this.ticks,s):this.ticks),this.configure(),this.beforeCalculateLabelRotation(),this.calculateLabelRotation(),this.afterCalculateLabelRotation(),a.display&&(a.autoSkip||"auto"===a.source)&&(this.ticks=jn(this,this.ticks),this._labelSizes=null,this.afterAutoSkip()),o&&this._convertTicksToLabels(this.ticks),this.beforeFit(),this.fit(),this.afterFit(),this.afterUpdate()}configure(){let e,t,i=this.options.reverse;this.isHorizontal()?(e=this.left,t=this.right):(e=this.top,t=this.bottom,i=!i),this._startPixel=e,this._endPixel=t,this._reversePixels=i,this._length=t-e,this._alignToPixels=this.options.alignToPixels}afterUpdate(){d(this.options.afterUpdate,[this])}beforeSetDimensions(){d(this.options.beforeSetDimensions,[this])}setDimensions(){this.isHorizontal()?(this.width=this.maxWidth,this.left=0,this.right=this.width):(this.height=this.maxHeight,this.top=0,this.bottom=this.height),this.paddingLeft=0,this.paddingTop=0,this.paddingRight=0,this.paddingBottom=0}afterSetDimensions(){d(this.options.afterSetDimensions,[this])}_callHooks(e){this.chart.notifyPlugins(e,this.getContext()),d(this.options[e],[this])}beforeDataLimits(){this._callHooks("beforeDataLimits")}determineDataLimits(){}afterDataLimits(){this._callHooks("afterDataLimits")}beforeBuildTicks(){this._callHooks("beforeBuildTicks")}buildTicks(){return[]}afterBuildTicks(){this._callHooks("afterBuildTicks")}beforeTickToLabelConversion(){d(this.options.beforeTickToLabelConversion,[this])}generateTickLabels(e){const t=this.options.ticks;let i,n,r;for(i=0,n=e.length;i<n;i++)r=e[i],r.label=d(t.callback,[r.value,i,e],this)}afterTickToLabelConversion(){d(this.options.afterTickToLabelConversion,[this])}beforeCalculateLabelRotation(){d(this.options.beforeCalculateLabelRotation,[this])}calculateLabelRotation(){const e=this.options,t=e.ticks,i=Rn(this.ticks.length,e.ticks.maxTicksLimit),n=t.minRotation||0,r=t.maxRotation;let a,s,o,l=n;if(!this._isVisible()||!t.display||n>=r||i<=1||!this.isHorizontal())return void(this.labelRotation=n);const c=this._getLabelSizes(),u=c.widest.width,d=c.highest.height,h=J(this.chart.width-u,0,this.maxWidth);a=e.offset?this.maxWidth/i:h/(i-1),u+6>a&&(a=h/(i-(e.offset?.5:1)),s=this.maxHeight-Vn(e.grid)-t.padding-Wn(e.title,this.chart.options.font),o=Math.sqrt(u*u+d*d),l=U(Math.min(Math.asin(J((c.highest.height+6)/a,-1,1)),Math.asin(J(s/o,-1,1))-Math.asin(J(d/o,-1,1)))),l=Math.max(n,Math.min(r,l))),this.labelRotation=l}afterCalculateLabelRotation(){d(this.options.afterCalculateLabelRotation,[this])}afterAutoSkip(){}beforeFit(){d(this.options.beforeFit,[this])}fit(){const e={width:0,height:0},{chart:t,options:{ticks:i,title:n,grid:r}}=this,a=this._isVisible(),s=this.isHorizontal();if(a){const a=Wn(n,t.options.font);if(s?(e.width=this.maxWidth,e.height=Vn(r)+a):(e.height=this.maxHeight,e.width=Vn(r)+a),i.display&&this.ticks.length){const{first:t,last:n,widest:r,highest:a}=this._getLabelSizes(),o=2*i.padding,l=W(this.labelRotation),c=Math.cos(l),u=Math.sin(l);if(s){const t=i.mirror?0:u*r.width+c*a.height;e.height=Math.min(this.maxHeight,e.height+t+o)}else{const t=i.mirror?0:c*r.width+u*a.height;e.width=Math.min(this.maxWidth,e.width+t+o)}this._calculatePadding(t,n,u,c)}}this._handleMargins(),s?(this.width=this._length=t.width-this._margins.left-this._margins.right,this.height=e.height):(this.width=e.width,this.height=this._length=t.height-this._margins.top-this._margins.bottom)}_calculatePadding(e,t,i,n){const{ticks:{align:r,padding:a},position:s}=this.options,o=0!==this.labelRotation,l="top"!==s&&"x"===this.axis;if(this.isHorizontal()){const s=this.getPixelForTick(0)-this.left,c=this.right-this.getPixelForTick(this.ticks.length-1);let u=0,d=0;o?l?(u=n*e.width,d=i*t.height):(u=i*e.height,d=n*t.width):"start"===r?d=t.width:"end"===r?u=e.width:"inner"!==r&&(u=e.width/2,d=t.width/2),this.paddingLeft=Math.max((u-s+a)*this.width/(this.width-s),0),this.paddingRight=Math.max((d-c+a)*this.width/(this.width-c),0)}else{let i=t.height/2,n=e.height/2;"start"===r?(i=0,n=e.height):"end"===r&&(i=t.height,n=0),this.paddingTop=i+a,this.paddingBottom=n+a}}_handleMargins(){this._margins&&(this._margins.left=Math.max(this.paddingLeft,this._margins.left),this._margins.top=Math.max(this.paddingTop,this._margins.top),this._margins.right=Math.max(this.paddingRight,this._margins.right),this._margins.bottom=Math.max(this.paddingBottom,this._margins.bottom))}afterFit(){d(this.options.afterFit,[this])}isHorizontal(){const{axis:e,position:t}=this.options;return"top"===t||"bottom"===t||"x"===e}isFullSize(){return this.options.fullSize}_convertTicksToLabels(e){let t,i;for(this.beforeTickToLabelConversion(),this.generateTickLabels(e),t=0,i=e.length;t<i;t++)n(e[t].label)&&(e.splice(t,1),i--,t--);this.afterTickToLabelConversion()}_getLabelSizes(){let e=this._labelSizes;if(!e){const t=this.options.ticks.sampleSize;let i=this.ticks;t<i.length&&(i=zn(i,t)),this._labelSizes=e=this._computeLabelSizes(i,i.length,this.options.ticks.maxTicksLimit)}return e}_computeLabelSizes(e,t,i){const{ctx:a,_longestTextCache:s}=this,o=[],l=[],c=Math.floor(t/Rn(t,i));let u,d,f,p,m,g,v,y,b,x,_,w=0,k=0;for(u=0;u<t;u+=c){if(p=e[u].label,m=this._resolveTickFontOptions(u),a.font=g=m.string,v=s[g]=s[g]||{data:{},gc:[]},y=m.lineHeight,b=x=0,n(p)||r(p)){if(r(p))for(d=0,f=p.length;d<f;++d)_=p[d],n(_)||r(_)||(b=kt(a,v.data,v.gc,b,_),x+=y)}else b=kt(a,v.data,v.gc,b,p),x=y;o.push(b),l.push(x),w=Math.max(b,w),k=Math.max(x,k)}!function(e,t){h(e,(e=>{const i=e.gc,n=i.length/2;let r;if(n>t){for(r=0;r<n;++r)delete e.data[i[r]];i.splice(0,n)}}))}(s,t);const M=o.indexOf(w),S=l.indexOf(k),A=e=>({width:o[e]||0,height:l[e]||0});return{first:A(0),last:A(t-1),widest:A(M),highest:A(S),widths:o,heights:l}}getLabelForValue(e){return e}getPixelForValue(e,t){return NaN}getValueForPixel(e){}getPixelForTick(e){const t=this.ticks;return e<0||e>t.length-1?null:this.getPixelForValue(t[e].value)}getPixelForDecimal(e){this._reversePixels&&(e=1-e);const t=this._startPixel+e*this._length;return Q(this._alignToPixels?St(this.chart,t,0):t)}getDecimalForPixel(e){const t=(e-this._startPixel)/this._length;return this._reversePixels?1-t:t}getBasePixel(){return this.getPixelForValue(this.getBaseValue())}getBaseValue(){const{min:e,max:t}=this;return e<0&&t<0?t:e>0&&t>0?e:0}getContext(e){const t=this.ticks||[];if(e>=0&&e<t.length){const i=t[e];return i.$context||(i.$context=function(e,t,i){return ki(e,{tick:i,index:t,type:"tick"})}(this.getContext(),e,i))}return this.$context||(this.$context=ki(this.chart.getContext(),{scale:this,type:"scale"}))}_tickSize(){const e=this.options.ticks,t=W(this.labelRotation),i=Math.abs(Math.cos(t)),n=Math.abs(Math.sin(t)),r=this._getLabelSizes(),a=e.autoSkipPadding||0,s=r?r.widest.width+a:0,o=r?r.highest.height+a:0;return this.isHorizontal()?o*i>s*n?s/i:o/n:o*n<s*i?o/i:s/n}_isVisible(){const e=this.options.display;return"auto"!==e?!!e:this.getMatchingVisibleMetas().length>0}_computeGridLineItems(e){const t=this.axis,i=this.chart,n=this.options,{grid:r,position:s,border:o}=n,c=r.offset,u=this.isHorizontal(),d=this.ticks.length+(c?1:0),h=Vn(r),f=[],p=o.setContext(this.getContext()),m=p.display?p.width:0,g=m/2,v=function(e){return St(i,e,m)};let y,b,x,_,w,k,M,S,A,L,T,C;if("top"===s)y=v(this.bottom),k=this.bottom-h,S=y-g,L=v(e.top)+g,C=e.bottom;else if("bottom"===s)y=v(this.top),L=e.top,C=v(e.bottom)-g,k=y+g,S=this.top+h;else if("left"===s)y=v(this.right),w=this.right-h,M=y-g,A=v(e.left)+g,T=e.right;else if("right"===s)y=v(this.left),A=e.left,T=v(e.right)-g,w=y+g,M=this.left+h;else if("x"===t){if("center"===s)y=v((e.top+e.bottom)/2+.5);else if(a(s)){const e=Object.keys(s)[0],t=s[e];y=v(this.chart.scales[e].getPixelForValue(t))}L=e.top,C=e.bottom,k=y+g,S=k+h}else if("y"===t){if("center"===s)y=v((e.left+e.right)/2);else if(a(s)){const e=Object.keys(s)[0],t=s[e];y=v(this.chart.scales[e].getPixelForValue(t))}w=y-g,M=w-h,A=e.left,T=e.right}const D=l(n.ticks.maxTicksLimit,d),E=Math.max(1,Math.ceil(d/D));for(b=0;b<d;b+=E){const e=this.getContext(b),t=r.setContext(e),n=o.setContext(e),a=t.lineWidth,s=t.color,l=n.dash||[],d=n.dashOffset,h=t.tickWidth,p=t.tickColor,m=t.tickBorderDash||[],g=t.tickBorderDashOffset;x=Bn(this,b,c),void 0!==x&&(_=St(i,x,a),u?w=M=A=T=_:k=S=L=C=_,f.push({tx1:w,ty1:k,tx2:M,ty2:S,x1:A,y1:L,x2:T,y2:C,width:a,color:s,borderDash:l,borderDashOffset:d,tickWidth:h,tickColor:p,tickBorderDash:m,tickBorderDashOffset:g}))}return this._ticksLength=d,this._borderValue=y,f}_computeLabelItems(e){const t=this.axis,i=this.options,{position:n,ticks:s}=i,o=this.isHorizontal(),l=this.ticks,{align:c,crossAlign:u,padding:d,mirror:h}=s,f=Vn(i.grid),p=f+d,m=h?-d:p,g=-W(this.labelRotation),v=[];let y,b,x,_,w,k,M,S,A,L,T,C,D="middle";if("top"===n)k=this.bottom-m,M=this._getXAxisLabelAlignment();else if("bottom"===n)k=this.top+m,M=this._getXAxisLabelAlignment();else if("left"===n){const e=this._getYAxisLabelAlignment(f);M=e.textAlign,w=e.x}else if("right"===n){const e=this._getYAxisLabelAlignment(f);M=e.textAlign,w=e.x}else if("x"===t){if("center"===n)k=(e.top+e.bottom)/2+p;else if(a(n)){const e=Object.keys(n)[0],t=n[e];k=this.chart.scales[e].getPixelForValue(t)+p}M=this._getXAxisLabelAlignment()}else if("y"===t){if("center"===n)w=(e.left+e.right)/2-p;else if(a(n)){const e=Object.keys(n)[0],t=n[e];w=this.chart.scales[e].getPixelForValue(t)}M=this._getYAxisLabelAlignment(f).textAlign}"y"===t&&("start"===c?D="top":"end"===c&&(D="bottom"));const E=this._getLabelSizes();for(y=0,b=l.length;y<b;++y){x=l[y],_=x.label;const e=s.setContext(this.getContext(y));S=this.getPixelForTick(y)+s.labelOffset,A=this._resolveTickFontOptions(y),L=A.lineHeight,T=r(_)?_.length:1;const t=T/2,i=e.color,a=e.textStrokeColor,c=e.textStrokeWidth;let d,f=M;if(o?(w=S,"inner"===M&&(f=y===b-1?this.options.reverse?"left":"right":0===y?this.options.reverse?"right":"left":"center"),C="top"===n?"near"===u||0!==g?-T*L+L/2:"center"===u?-E.highest.height/2-t*L+L:-E.highest.height+L/2:"near"===u||0!==g?L/2:"center"===u?E.highest.height/2-t*L:E.highest.height-T*L,h&&(C*=-1),0===g||e.showLabelBackdrop||(w+=L/2*Math.sin(g))):(k=S,C=(1-T)*L/2),e.showLabelBackdrop){const t=bi(e.backdropPadding),i=E.heights[y],n=E.widths[y];let r=C-t.top,a=0-t.left;switch(D){case"middle":r-=i/2;break;case"bottom":r-=i}switch(M){case"center":a-=n/2;break;case"right":a-=n;break;case"inner":y===b-1?a-=n:y>0&&(a-=n/2)}d={left:a,top:r,width:n+t.width,height:i+t.height,color:e.backdropColor}}v.push({label:_,font:A,textOffset:C,options:{rotation:g,color:i,strokeColor:a,strokeWidth:c,textAlign:f,textBaseline:D,translation:[w,k],backdrop:d}})}return v}_getXAxisLabelAlignment(){const{position:e,ticks:t}=this.options;if(-W(this.labelRotation))return"top"===e?"left":"right";let i="center";return"start"===t.align?i="left":"end"===t.align?i="right":"inner"===t.align&&(i="inner"),i}_getYAxisLabelAlignment(e){const{position:t,ticks:{crossAlign:i,mirror:n,padding:r}}=this.options,a=e+r,s=this._getLabelSizes().widest.width;let o,l;return"left"===t?n?(l=this.right+r,"near"===i?o="left":"center"===i?(o="center",l+=s/2):(o="right",l+=s)):(l=this.right-a,"near"===i?o="right":"center"===i?(o="center",l-=s/2):(o="left",l=this.left)):"right"===t?n?(l=this.left+r,"near"===i?o="right":"center"===i?(o="center",l-=s/2):(o="left",l-=s)):(l=this.left+a,"near"===i?o="left":"center"===i?(o="center",l+=s/2):(o="right",l=this.right)):o="right",{textAlign:o,x:l}}_computeLabelArea(){if(this.options.ticks.mirror)return;const e=this.chart,t=this.options.position;return"left"===t||"right"===t?{top:0,left:this.left,bottom:e.height,right:this.right}:"top"===t||"bottom"===t?{top:this.top,left:0,bottom:this.bottom,right:e.width}:void 0}drawBackground(){const{ctx:e,options:{backgroundColor:t},left:i,top:n,width:r,height:a}=this;t&&(e.save(),e.fillStyle=t,e.fillRect(i,n,r,a),e.restore())}getLineWidthForValue(e){const t=this.options.grid;if(!this._isVisible()||!t.display)return 0;const i=this.ticks.findIndex((t=>t.value===e));return i>=0?t.setContext(this.getContext(i)).lineWidth:0}drawGrid(e){const t=this.options.grid,i=this.ctx,n=this._gridLineItems||(this._gridLineItems=this._computeGridLineItems(e));let r,a;const s=(e,t,n)=>{n.width&&n.color&&(i.save(),i.lineWidth=n.width,i.strokeStyle=n.color,i.setLineDash(n.borderDash||[]),i.lineDashOffset=n.borderDashOffset,i.beginPath(),i.moveTo(e.x,e.y),i.lineTo(t.x,t.y),i.stroke(),i.restore())};if(t.display)for(r=0,a=n.length;r<a;++r){const e=n[r];t.drawOnChartArea&&s({x:e.x1,y:e.y1},{x:e.x2,y:e.y2},e),t.drawTicks&&s({x:e.tx1,y:e.ty1},{x:e.tx2,y:e.ty2},{color:e.tickColor,width:e.tickWidth,borderDash:e.tickBorderDash,borderDashOffset:e.tickBorderDashOffset})}}drawBorder(){const{chart:e,ctx:t,options:{border:i,grid:n}}=this,r=i.setContext(this.getContext()),a=i.display?r.width:0;if(!a)return;const s=n.setContext(this.getContext(0)).lineWidth,o=this._borderValue;let l,c,u,d;this.isHorizontal()?(l=St(e,this.left,a)-a/2,c=St(e,this.right,s)+s/2,u=d=o):(u=St(e,this.top,a)-a/2,d=St(e,this.bottom,s)+s/2,l=c=o),t.save(),t.lineWidth=r.width,t.strokeStyle=r.color,t.beginPath(),t.moveTo(l,u),t.lineTo(c,d),t.stroke(),t.restore()}drawLabels(e){if(!this.options.ticks.display)return;const t=this.ctx,i=this._computeLabelArea();i&&Dt(t,i);const n=this.getLabelItems(e);for(const e of n){const i=e.options,n=e.font;Nt(t,e.label,0,e.textOffset,n,i)}i&&Et(t)}drawTitle(){const{ctx:e,options:{position:t,title:i,reverse:n}}=this;if(!i.display)return;const s=xi(i.font),o=bi(i.padding),l=i.align;let c=s.lineHeight/2;"bottom"===t||"center"===t||a(t)?(c+=o.bottom,r(i.text)&&(c+=s.lineHeight*(i.text.length-1))):c+=o.top;const{titleX:u,titleY:d,maxWidth:h,rotation:f}=function(e,t,i,n){const{top:r,left:s,bottom:o,right:l,chart:c}=e,{chartArea:u,scales:d}=c;let h,f,p,m=0;const g=o-r,v=l-s;if(e.isHorizontal()){if(f=fe(n,s,l),a(i)){const e=Object.keys(i)[0],n=i[e];p=d[e].getPixelForValue(n)+g-t}else p="center"===i?(u.bottom+u.top)/2+g-t:Fn(e,i,t);h=l-s}else{if(a(i)){const e=Object.keys(i)[0],n=i[e];f=d[e].getPixelForValue(n)-v+t}else f="center"===i?(u.left+u.right)/2-v+t:Fn(e,i,t);p=fe(n,o,r),m="left"===i?-P:P}return{titleX:f,titleY:p,maxWidth:h,rotation:m}}(this,c,t,l);Nt(e,i.text,0,0,s,{color:i.color,maxWidth:h,rotation:f,textAlign:Un(l,t,n),textBaseline:"middle",translation:[u,d]})}draw(e){this._isVisible()&&(this.drawBackground(),this.drawGrid(e),this.drawBorder(),this.drawTitle(),this.drawLabels(e))}_layers(){const e=this.options,t=e.ticks&&e.ticks.z||0,i=l(e.grid&&e.grid.z,-1),n=l(e.border&&e.border.z,0);return this._isVisible()&&this.draw===qn.prototype.draw?[{z:i,draw:e=>{this.drawBackground(),this.drawGrid(e),this.drawTitle()}},{z:n,draw:()=>{this.drawBorder()}},{z:t,draw:e=>{this.drawLabels(e)}}]:[{z:t,draw:e=>{this.draw(e)}}]}getMatchingVisibleMetas(e){const t=this.chart.getSortedVisibleDatasetMetas(),i=this.axis+"AxisID",n=[];let r,a;for(r=0,a=t.length;r<a;++r){const a=t[r];a[i]!==this.id||e&&a.type!==e||n.push(a)}return n}_resolveTickFontOptions(e){return xi(this.options.ticks.setContext(this.getContext(e)).font)}_maxDigits(){const e=this._resolveTickFontOptions(0).lineHeight;return(this.isHorizontal()?this.width:this.height)/e}}class $n{constructor(e,t,i){this.type=e,this.scope=t,this.override=i,this.items=Object.create(null)}isForType(e){return Object.prototype.isPrototypeOf.call(this.type.prototype,e.prototype)}register(e){const t=Object.getPrototypeOf(e);let i;(function(e){return"id"in e&&"defaults"in e})(t)&&(i=this.register(t));const n=this.items,r=e.id,a=this.scope+"."+r;if(!r)throw new Error("class does not have id: "+e);return r in n||(n[r]=e,function(e,t,i){const n=v(Object.create(null),[i?ot.get(i):{},ot.get(t),e.defaults]);ot.set(t,n),e.defaultRoutes&&function(e,t){Object.keys(t).forEach((i=>{const n=i.split("."),r=n.pop(),a=[e].concat(n).join("."),s=t[i].split("."),o=s.pop(),l=s.join(".");ot.route(a,r,l,o)}))}(t,e.defaultRoutes),e.descriptors&&ot.describe(t,e.descriptors)}(e,a,i),this.override&&ot.override(e.id,e.overrides)),a}get(e){return this.items[e]}unregister(e){const t=this.items,i=e.id,n=this.scope;i in t&&delete t[i],n&&i in ot[n]&&(delete ot[n][i],this.override&&delete nt[i])}}var Xn=new class{constructor(){this.controllers=new $n(In,"datasets",!0),this.elements=new $n(Nn,"elements"),this.plugins=new $n(Object,"plugins"),this.scales=new $n(qn,"scales"),this._typedRegistries=[this.controllers,this.scales,this.elements]}add(...e){this._each("register",e)}remove(...e){this._each("unregister",e)}addControllers(...e){this._each("register",e,this.controllers)}addElements(...e){this._each("register",e,this.elements)}addPlugins(...e){this._each("register",e,this.plugins)}addScales(...e){this._each("register",e,this.scales)}getController(e){return this._get(e,this.controllers,"controller")}getElement(e){return this._get(e,this.elements,"element")}getPlugin(e){return this._get(e,this.plugins,"plugin")}getScale(e){return this._get(e,this.scales,"scale")}removeControllers(...e){this._each("unregister",e,this.controllers)}removeElements(...e){this._each("unregister",e,this.elements)}removePlugins(...e){this._each("unregister",e,this.plugins)}removeScales(...e){this._each("unregister",e,this.scales)}_each(e,t,i){[...t].forEach((t=>{const n=i||this._getRegistryForType(t);i||n.isForType(t)||n===this.plugins&&t.id?this._exec(e,n,t):h(t,(t=>{const n=i||this._getRegistryForType(t);this._exec(e,n,t)}))}))}_exec(e,t,i){const n=k(e);d(i["before"+n],[],i),t[e](i),d(i["after"+n],[],i)}_getRegistryForType(e){for(let t=0;t<this._typedRegistries.length;t++){const i=this._typedRegistries[t];if(i.isForType(e))return i}return this.plugins}_get(e,t,i){const n=t.get(e);if(void 0===n)throw new Error('"'+e+'" is not a registered '+i+".");return n}};class Gn{constructor(){this._init=[]}notify(e,t,i,n){"beforeInit"===t&&(this._init=this._createDescriptors(e,!0),this._notify(this._init,e,"install"));const r=n?this._descriptors(e).filter(n):this._descriptors(e),a=this._notify(r,e,t,i);return"afterDestroy"===t&&(this._notify(r,e,"stop"),this._notify(this._init,e,"uninstall")),a}_notify(e,t,i,n){n=n||{};for(const r of e){const e=r.plugin;if(!1===d(e[i],[t,n,r.options],e)&&n.cancelable)return!1}return!0}invalidate(){n(this._cache)||(this._oldCache=this._cache,this._cache=void 0)}_descriptors(e){if(this._cache)return this._cache;const t=this._cache=this._createDescriptors(e);return this._notifyStateChanges(e),t}_createDescriptors(e,t){const i=e&&e.config,n=l(i.options&&i.options.plugins,{}),r=function(e){const t={},i=[],n=Object.keys(Xn.plugins.items);for(let e=0;e<n.length;e++)i.push(Xn.getPlugin(n[e]));const r=e.plugins||[];for(let e=0;e<r.length;e++){const n=r[e];-1===i.indexOf(n)&&(i.push(n),t[n.id]=!0)}return{plugins:i,localIds:t}}(i);return!1!==n||t?function(e,{plugins:t,localIds:i},n,r){const a=[],s=e.getContext();for(const o of t){const t=o.id,l=Zn(n[t],r);null!==l&&a.push({plugin:o,options:Kn(e.config,{plugin:o,local:i[t]},l,s)})}return a}(e,r,n,t):[]}_notifyStateChanges(e){const t=this._oldCache||[],i=this._cache,n=(e,t)=>e.filter((e=>!t.some((t=>e.plugin.id===t.plugin.id))));this._notify(n(t,i),e,"stop"),this._notify(n(i,t),e,"start")}}function Zn(e,t){return t||!1!==e?!0===e?{}:e:null}function Kn(e,{plugin:t,local:i},n,r){const a=e.pluginScopeKeys(t),s=e.getOptionScopes(n,a);return i&&t.defaults&&s.push(t.defaults),e.createResolver(s,r,[""],{scriptable:!1,indexable:!1,allKeys:!0})}function Jn(e,t){const i=ot.datasets[e]||{};return((t.datasets||{})[e]||{}).indexAxis||t.indexAxis||i.indexAxis||"x"}function Qn(e){if("x"===e||"y"===e||"r"===e)return e}function er(e,...t){if(Qn(e))return e;for(const n of t){const t=n.axis||("top"===(i=n.position)||"bottom"===i?"x":"left"===i||"right"===i?"y":void 0)||e.length>1&&Qn(e[0].toLowerCase());if(t)return t}var i;throw new Error(`Cannot determine type of '${e}' axis. Please provide 'axis' or 'position' option.`)}function tr(e,t,i){if(i[t+"AxisID"]===e)return{axis:t}}function ir(e){const t=e.options||(e.options={});t.plugins=l(t.plugins,{}),t.scales=function(e,t){const i=nt[e.type]||{scales:{}},n=t.scales||{},r=Jn(e.type,t),s=Object.create(null);return Object.keys(n).forEach((t=>{const o=n[t];if(!a(o))return console.error(`Invalid scale configuration for scale: ${t}`);if(o._proxy)return console.warn(`Ignoring resolver passed as options for scale: ${t}`);const l=er(t,o,function(e,t){if(t.data&&t.data.datasets){const i=t.data.datasets.filter((t=>t.xAxisID===e||t.yAxisID===e));if(i.length)return tr(e,"x",i[0])||tr(e,"y",i[0])}return{}}(t,e),ot.scales[o.type]),c=function(e,t){return e===t?"_index_":"_value_"}(l,r),u=i.scales||{};s[t]=y(Object.create(null),[{axis:l},o,u[l],u[c]])})),e.data.datasets.forEach((i=>{const r=i.type||e.type,a=i.indexAxis||Jn(r,t),o=(nt[r]||{}).scales||{};Object.keys(o).forEach((e=>{const t=function(e,t){let i=e;return"_index_"===e?i=t:"_value_"===e&&(i="x"===t?"y":"x"),i}(e,a),r=i[t+"AxisID"]||t;s[r]=s[r]||Object.create(null),y(s[r],[{axis:t},n[r],o[e]])}))})),Object.keys(s).forEach((e=>{const t=s[e];y(t,[ot.scales[t.type],ot.scale])})),s}(e,t)}function nr(e){return(e=e||{}).datasets=e.datasets||[],e.labels=e.labels||[],e}const rr=new Map,ar=new Set;function sr(e,t){let i=rr.get(e);return i||(i=t(),rr.set(e,i),ar.add(i)),i}const or=(e,t,i)=>{const n=w(t,i);void 0!==n&&e.add(n)};class lr{constructor(e){this._config=function(e){return(e=e||{}).data=nr(e.data),ir(e),e}(e),this._scopeCache=new Map,this._resolverCache=new Map}get platform(){return this._config.platform}get type(){return this._config.type}set type(e){this._config.type=e}get data(){return this._config.data}set data(e){this._config.data=nr(e)}get options(){return this._config.options}set options(e){this._config.options=e}get plugins(){return this._config.plugins}update(){const e=this._config;this.clearCache(),ir(e)}clearCache(){this._scopeCache.clear(),this._resolverCache.clear()}datasetScopeKeys(e){return sr(e,(()=>[[`datasets.${e}`,""]]))}datasetAnimationScopeKeys(e,t){return sr(`${e}.transition.${t}`,(()=>[[`datasets.${e}.transitions.${t}`,`transitions.${t}`],[`datasets.${e}`,""]]))}datasetElementScopeKeys(e,t){return sr(`${e}-${t}`,(()=>[[`datasets.${e}.elements.${t}`,`datasets.${e}`,`elements.${t}`,""]]))}pluginScopeKeys(e){const t=e.id;return sr(`${this.type}-plugin-${t}`,(()=>[[`plugins.${t}`,...e.additionalOptionScopes||[]]]))}_cachedScopes(e,t){const i=this._scopeCache;let n=i.get(e);return n&&!t||(n=new Map,i.set(e,n)),n}getOptionScopes(e,t,i){const{options:n,type:r}=this,a=this._cachedScopes(e,i),s=a.get(t);if(s)return s;const o=new Set;t.forEach((t=>{e&&(o.add(e),t.forEach((t=>or(o,e,t)))),t.forEach((e=>or(o,n,e))),t.forEach((e=>or(o,nt[r]||{},e))),t.forEach((e=>or(o,ot,e))),t.forEach((e=>or(o,rt,e)))}));const l=Array.from(o);return 0===l.length&&l.push(Object.create(null)),ar.has(t)&&a.set(t,l),l}chartOptionScopes(){const{options:e,type:t}=this;return[e,nt[t]||{},ot.datasets[t]||{},{type:t},ot,rt]}resolveNamedOptions(e,t,i,n=[""]){const a={$shared:!0},{resolver:s,subPrefixes:o}=cr(this._resolverCache,e,n);let l=s;(function(e,t){const{isScriptable:i,isIndexable:n}=Rt(e);for(const a of t){const t=i(a),s=n(a),o=(s||t)&&e[a];if(t&&(S(o)||ur(o))||s&&r(o))return!0}return!1})(s,t)&&(a.$shared=!1,l=Ft(s,i=S(i)?i():i,this.createResolver(e,i,o)));for(const e of t)a[e]=l[e];return a}createResolver(e,t,i=[""],n){const{resolver:r}=cr(this._resolverCache,e,i);return a(t)?Ft(r,t,void 0,n):r}}function cr(e,t,i){let n=e.get(t);n||(n=new Map,e.set(t,n));const r=i.join();let a=n.get(r);return a||(a={resolver:Ht(t,i),subPrefixes:i.filter((e=>!e.toLowerCase().includes("hover")))},n.set(r,a)),a}const ur=e=>a(e)&&Object.getOwnPropertyNames(e).some((t=>S(e[t]))),dr=["top","bottom","left","right","chartArea"];function hr(e,t){return"top"===e||"bottom"===e||-1===dr.indexOf(e)&&"x"===t}function fr(e,t){return function(i,n){return i[e]===n[e]?i[t]-n[t]:i[e]-n[e]}}function pr(e){const t=e.chart,i=t.options.animation;t.notifyPlugins("afterRender"),d(i&&i.onComplete,[e],t)}function mr(e){const t=e.chart,i=t.options.animation;d(i&&i.onProgress,[e],t)}function gr(e){return lt()&&"string"==typeof e?e=document.getElementById(e):e&&e.length&&(e=e[0]),e&&e.canvas&&(e=e.canvas),e}const vr={},yr=e=>{const t=gr(e);return Object.values(vr).filter((e=>e.canvas===t)).pop()};function br(e,t,i){const n=Object.keys(e);for(const r of n){const n=+r;if(n>=t){const a=e[r];delete e[r],(i>0||n>t)&&(e[n+i]=a)}}}function xr(e,t,i){return e.options.clip?e[i]:t[i]}class _r{static defaults=ot;static instances=vr;static overrides=nt;static registry=Xn;static version="4.4.3";static getChart=yr;static register(...e){Xn.add(...e),wr()}static unregister(...e){Xn.remove(...e),wr()}constructor(e,t){const n=this.config=new lr(t),r=gr(e),a=yr(r);if(a)throw new Error("Canvas is already in use. Chart with ID '"+a.id+"' must be destroyed before the canvas with ID '"+a.canvas.id+"' can be reused.");const s=n.createResolver(n.chartOptionScopes(),this.getContext());this.platform=new(n.platform||yn(r)),this.platform.updateConfig(n);const o=this.platform.acquireContext(r,s.aspectRatio),l=o&&o.canvas,c=l&&l.height,u=l&&l.width;this.id=i(),this.ctx=o,this.canvas=l,this.width=u,this.height=c,this._options=s,this._aspectRatio=this.aspectRatio,this._layers=[],this._metasets=[],this._stacks=void 0,this.boxes=[],this.currentDevicePixelRatio=void 0,this.chartArea=void 0,this._active=[],this._lastEvent=void 0,this._listeners={},this._responsiveListeners=void 0,this._sortedMetasets=[],this.scales={},this._plugins=new Gn,this.$proxies={},this._hiddenIndices={},this.attached=!1,this._animationsDisabled=void 0,this.$context=void 0,this._doResize=de((e=>this.update(e)),s.resizeDelay||0),this._dataChanges=[],vr[this.id]=this,o&&l?(ve.listen(this,"complete",pr),ve.listen(this,"progress",mr),this._initialize(),this.attached&&this.update()):console.error("Failed to create chart: can't acquire context from the given item")}get aspectRatio(){const{options:{aspectRatio:e,maintainAspectRatio:t},width:i,height:r,_aspectRatio:a}=this;return n(e)?t&&a?a:r?i/r:null:e}get data(){return this.config.data}set data(e){this.config.data=e}get options(){return this._options}set options(e){this.config.options=e}get registry(){return Xn}_initialize(){return this.notifyPlugins("beforeInit"),this.options.responsive?this.resize():bt(this,this.options.devicePixelRatio),this.bindEvents(),this.notifyPlugins("afterInit"),this}clear(){return At(this.canvas,this.ctx),this}stop(){return ve.stop(this),this}resize(e,t){ve.running(this)?this._resizeBeforeDraw={width:e,height:t}:this._resize(e,t)}_resize(e,t){const i=this.options,n=this.canvas,r=i.maintainAspectRatio&&this.aspectRatio,a=this.platform.getMaximumSize(n,e,t,r),s=i.devicePixelRatio||this.platform.getDevicePixelRatio(),o=this.width?"resize":"attach";this.width=a.width,this.height=a.height,this._aspectRatio=this.aspectRatio,bt(this,s,!0)&&(this.notifyPlugins("resize",{size:a}),d(i.onResize,[this,a],this),this.attached&&this._doResize(o)&&this.render())}ensureScalesHaveIDs(){h(this.options.scales||{},((e,t)=>{e.id=t}))}buildOrUpdateScales(){const e=this.options,t=e.scales,i=this.scales,n=Object.keys(i).reduce(((e,t)=>(e[t]=!1,e)),{});let r=[];t&&(r=r.concat(Object.keys(t).map((e=>{const i=t[e],n=er(e,i),r="r"===n,a="x"===n;return{options:i,dposition:r?"chartArea":a?"bottom":"left",dtype:r?"radialLinear":a?"category":"linear"}})))),h(r,(t=>{const r=t.options,a=r.id,s=er(a,r),o=l(r.type,t.dtype);void 0!==r.position&&hr(r.position,s)===hr(t.dposition)||(r.position=t.dposition),n[a]=!0;let c=null;a in i&&i[a].type===o?c=i[a]:(c=new(Xn.getScale(o))({id:a,type:o,ctx:this.ctx,chart:this}),i[c.id]=c),c.init(r,e)})),h(n,((e,t)=>{e||delete i[t]})),h(i,(e=>{Qi.configure(this,e,e.options),Qi.addBox(this,e)}))}_updateMetasets(){const e=this._metasets,t=this.data.datasets.length,i=e.length;if(e.sort(((e,t)=>e.index-t.index)),i>t){for(let e=t;e<i;++e)this._destroyDatasetMeta(e);e.splice(t,i-t)}this._sortedMetasets=e.slice(0).sort(fr("order","index"))}_removeUnreferencedMetasets(){const{_metasets:e,data:{datasets:t}}=this;e.length>t.length&&delete this._stacks,e.forEach(((e,i)=>{0===t.filter((t=>t===e._dataset)).length&&this._destroyDatasetMeta(i)}))}buildOrUpdateControllers(){const e=[],t=this.data.datasets;let i,n;for(this._removeUnreferencedMetasets(),i=0,n=t.length;i<n;i++){const n=t[i];let r=this.getDatasetMeta(i);const a=n.type||this.config.type;if(r.type&&r.type!==a&&(this._destroyDatasetMeta(i),r=this.getDatasetMeta(i)),r.type=a,r.indexAxis=n.indexAxis||Jn(a,this.options),r.order=n.order||0,r.index=i,r.label=""+n.label,r.visible=this.isDatasetVisible(i),r.controller)r.controller.updateIndex(i),r.controller.linkScales();else{const t=Xn.getController(a),{datasetElementType:n,dataElementType:s}=ot.datasets[a];Object.assign(t,{dataElementType:Xn.getElement(s),datasetElementType:n&&Xn.getElement(n)}),r.controller=new t(this,i),e.push(r.controller)}}return this._updateMetasets(),e}_resetElements(){h(this.data.datasets,((e,t)=>{this.getDatasetMeta(t).controller.reset()}),this)}reset(){this._resetElements(),this.notifyPlugins("reset")}update(e){const t=this.config;t.update();const i=this._options=t.createResolver(t.chartOptionScopes(),this.getContext()),n=this._animationsDisabled=!i.animation;if(this._updateScales(),this._checkEventBindings(),this._updateHiddenIndices(),this._plugins.invalidate(),!1===this.notifyPlugins("beforeUpdate",{mode:e,cancelable:!0}))return;const r=this.buildOrUpdateControllers();this.notifyPlugins("beforeElementsUpdate");let a=0;for(let e=0,t=this.data.datasets.length;e<t;e++){const{controller:t}=this.getDatasetMeta(e),i=!n&&-1===r.indexOf(t);t.buildOrUpdateElements(i),a=Math.max(+t.getMaxOverflow(),a)}a=this._minPadding=i.layout.autoPadding?a:0,this._updateLayout(a),n||h(r,(e=>{e.reset()})),this._updateDatasets(e),this.notifyPlugins("afterUpdate",{mode:e}),this._layers.sort(fr("z","_idx"));const{_active:s,_lastEvent:o}=this;o?this._eventHandler(o,!0):s.length&&this._updateHoverStyles(s,s,!0),this.render()}_updateScales(){h(this.scales,(e=>{Qi.removeBox(this,e)})),this.ensureScalesHaveIDs(),this.buildOrUpdateScales()}_checkEventBindings(){const e=this.options,t=new Set(Object.keys(this._listeners)),i=new Set(e.events);A(t,i)&&!!this._responsiveListeners===e.responsive||(this.unbindEvents(),this.bindEvents())}_updateHiddenIndices(){const{_hiddenIndices:e}=this,t=this._getUniformDataChanges()||[];for(const{method:i,start:n,count:r}of t)br(e,n,"_removeElements"===i?-r:r)}_getUniformDataChanges(){const e=this._dataChanges;if(!e||!e.length)return;this._dataChanges=[];const t=this.data.datasets.length,i=t=>new Set(e.filter((e=>e[0]===t)).map(((e,t)=>t+","+e.splice(1).join(",")))),n=i(0);for(let e=1;e<t;e++)if(!A(n,i(e)))return;return Array.from(n).map((e=>e.split(","))).map((e=>({method:e[1],start:+e[2],count:+e[3]})))}_updateLayout(e){if(!1===this.notifyPlugins("beforeLayout",{cancelable:!0}))return;Qi.update(this,this.width,this.height,e);const t=this.chartArea,i=t.width<=0||t.height<=0;this._layers=[],h(this.boxes,(e=>{i&&"chartArea"===e.position||(e.configure&&e.configure(),this._layers.push(...e._layers()))}),this),this._layers.forEach(((e,t)=>{e._idx=t})),this.notifyPlugins("afterLayout")}_updateDatasets(e){if(!1!==this.notifyPlugins("beforeDatasetsUpdate",{mode:e,cancelable:!0})){for(let e=0,t=this.data.datasets.length;e<t;++e)this.getDatasetMeta(e).controller.configure();for(let t=0,i=this.data.datasets.length;t<i;++t)this._updateDataset(t,S(e)?e({datasetIndex:t}):e);this.notifyPlugins("afterDatasetsUpdate",{mode:e})}}_updateDataset(e,t){const i=this.getDatasetMeta(e),n={meta:i,index:e,mode:t,cancelable:!0};!1!==this.notifyPlugins("beforeDatasetUpdate",n)&&(i.controller._update(t),n.cancelable=!1,this.notifyPlugins("afterDatasetUpdate",n))}render(){!1!==this.notifyPlugins("beforeRender",{cancelable:!0})&&(ve.has(this)?this.attached&&!ve.running(this)&&ve.start(this):(this.draw(),pr({chart:this})))}draw(){let e;if(this._resizeBeforeDraw){const{width:e,height:t}=this._resizeBeforeDraw;this._resize(e,t),this._resizeBeforeDraw=null}if(this.clear(),this.width<=0||this.height<=0)return;if(!1===this.notifyPlugins("beforeDraw",{cancelable:!0}))return;const t=this._layers;for(e=0;e<t.length&&t[e].z<=0;++e)t[e].draw(this.chartArea);for(this._drawDatasets();e<t.length;++e)t[e].draw(this.chartArea);this.notifyPlugins("afterDraw")}_getSortedDatasetMetas(e){const t=this._sortedMetasets,i=[];let n,r;for(n=0,r=t.length;n<r;++n){const r=t[n];e&&!r.visible||i.push(r)}return i}getSortedVisibleDatasetMetas(){return this._getSortedDatasetMetas(!0)}_drawDatasets(){if(!1===this.notifyPlugins("beforeDatasetsDraw",{cancelable:!0}))return;const e=this.getSortedVisibleDatasetMetas();for(let t=e.length-1;t>=0;--t)this._drawDataset(e[t]);this.notifyPlugins("afterDatasetsDraw")}_drawDataset(e){const t=this.ctx,i=e._clip,n=!i.disabled,r=function(e,t){const{xScale:i,yScale:n}=e;return i&&n?{left:xr(i,t,"left"),right:xr(i,t,"right"),top:xr(n,t,"top"),bottom:xr(n,t,"bottom")}:t}(e,this.chartArea),a={meta:e,index:e.index,cancelable:!0};!1!==this.notifyPlugins("beforeDatasetDraw",a)&&(n&&Dt(t,{left:!1===i.left?0:r.left-i.left,right:!1===i.right?this.width:r.right+i.right,top:!1===i.top?0:r.top-i.top,bottom:!1===i.bottom?this.height:r.bottom+i.bottom}),e.controller.draw(),n&&Et(t),a.cancelable=!1,this.notifyPlugins("afterDatasetDraw",a))}isPointInArea(e){return Ct(e,this.chartArea,this._minPadding)}getElementsAtEventForMode(e,t,i,n){const r=zi.modes[t];return"function"==typeof r?r(this,e,i,n):[]}getDatasetMeta(e){const t=this.data.datasets[e],i=this._metasets;let n=i.filter((e=>e&&e._dataset===t)).pop();return n||(n={type:null,data:[],dataset:null,controller:null,hidden:null,xAxisID:null,yAxisID:null,order:t&&t.order||0,index:e,_dataset:t,_parsed:[],_sorted:!1},i.push(n)),n}getContext(){return this.$context||(this.$context=ki(null,{chart:this,type:"chart"}))}getVisibleDatasetCount(){return this.getSortedVisibleDatasetMetas().length}isDatasetVisible(e){const t=this.data.datasets[e];if(!t)return!1;const i=this.getDatasetMeta(e);return"boolean"==typeof i.hidden?!i.hidden:!t.hidden}setDatasetVisibility(e,t){this.getDatasetMeta(e).hidden=!t}toggleDataVisibility(e){this._hiddenIndices[e]=!this._hiddenIndices[e]}getDataVisibility(e){return!this._hiddenIndices[e]}_updateVisibility(e,t,i){const n=i?"show":"hide",r=this.getDatasetMeta(e),a=r.controller._resolveAnimations(void 0,n);M(t)?(r.data[t].hidden=!i,this.update()):(this.setDatasetVisibility(e,i),a.update(r,{visible:i}),this.update((t=>t.datasetIndex===e?n:void 0)))}hide(e,t){this._updateVisibility(e,t,!1)}show(e,t){this._updateVisibility(e,t,!0)}_destroyDatasetMeta(e){const t=this._metasets[e];t&&t.controller&&t.controller._destroy(),delete this._metasets[e]}_stop(){let e,t;for(this.stop(),ve.remove(this),e=0,t=this.data.datasets.length;e<t;++e)this._destroyDatasetMeta(e)}destroy(){this.notifyPlugins("beforeDestroy");const{canvas:e,ctx:t}=this;this._stop(),this.config.clearCache(),e&&(this.unbindEvents(),At(e,t),this.platform.releaseContext(t),this.canvas=null,this.ctx=null),delete vr[this.id],this.notifyPlugins("afterDestroy")}toBase64Image(...e){return this.canvas.toDataURL(...e)}bindEvents(){this.bindUserEvents(),this.options.responsive?this.bindResponsiveEvents():this.attached=!0}bindUserEvents(){const e=this._listeners,t=this.platform,i=(i,n)=>{t.addEventListener(this,i,n),e[i]=n},n=(e,t,i)=>{e.offsetX=t,e.offsetY=i,this._eventHandler(e)};h(this.options.events,(e=>i(e,n)))}bindResponsiveEvents(){this._responsiveListeners||(this._responsiveListeners={});const e=this._responsiveListeners,t=this.platform,i=(i,n)=>{t.addEventListener(this,i,n),e[i]=n},n=(i,n)=>{e[i]&&(t.removeEventListener(this,i,n),delete e[i])},r=(e,t)=>{this.canvas&&this.resize(e,t)};let a;const s=()=>{n("attach",s),this.attached=!0,this.resize(),i("resize",r),i("detach",a)};a=()=>{this.attached=!1,n("resize",r),this._stop(),this._resize(0,0),i("attach",s)},t.isAttached(this.canvas)?s():a()}unbindEvents(){h(this._listeners,((e,t)=>{this.platform.removeEventListener(this,t,e)})),this._listeners={},h(this._responsiveListeners,((e,t)=>{this.platform.removeEventListener(this,t,e)})),this._responsiveListeners=void 0}updateHoverStyle(e,t,i){const n=i?"set":"remove";let r,a,s,o;for("dataset"===t&&(r=this.getDatasetMeta(e[0].datasetIndex),r.controller["_"+n+"DatasetHoverStyle"]()),s=0,o=e.length;s<o;++s){a=e[s];const t=a&&this.getDatasetMeta(a.datasetIndex).controller;t&&t[n+"HoverStyle"](a.element,a.datasetIndex,a.index)}}getActiveElements(){return this._active||[]}setActiveElements(e){const t=this._active||[],i=e.map((({datasetIndex:e,index:t})=>{const i=this.getDatasetMeta(e);if(!i)throw new Error("No dataset found at index "+e);return{datasetIndex:e,element:i.data[t],index:t}}));!f(i,t)&&(this._active=i,this._lastEvent=null,this._updateHoverStyles(i,t))}notifyPlugins(e,t,i){return this._plugins.notify(this,e,t,i)}isPluginEnabled(e){return 1===this._plugins._cache.filter((t=>t.plugin.id===e)).length}_updateHoverStyles(e,t,i){const n=this.options.hover,r=(e,t)=>e.filter((e=>!t.some((t=>e.datasetIndex===t.datasetIndex&&e.index===t.index)))),a=r(t,e),s=i?e:r(e,t);a.length&&this.updateHoverStyle(a,n.mode,!1),s.length&&n.mode&&this.updateHoverStyle(s,n.mode,!0)}_eventHandler(e,t){const i={event:e,replay:t,cancelable:!0,inChartArea:this.isPointInArea(e)},n=t=>(t.options.events||this.options.events).includes(e.native.type);if(!1===this.notifyPlugins("beforeEvent",i,n))return;const r=this._handleEvent(e,t,i.inChartArea);return i.cancelable=!1,this.notifyPlugins("afterEvent",i,n),(r||i.changed)&&this.render(),this}_handleEvent(e,t,i){const{_active:n=[],options:r}=this,a=t,s=this._getActiveElements(e,n,i,a),o=L(e),l=function(e,t,i,n){return i&&"mouseout"!==e.type?n?t:e:null}(e,this._lastEvent,i,o);i&&(this._lastEvent=null,d(r.onHover,[e,s,this],this),o&&d(r.onClick,[e,s,this],this));const c=!f(s,n);return(c||t)&&(this._active=s,this._updateHoverStyles(s,n,t)),this._lastEvent=l,c}_getActiveElements(e,t,i,n){if("mouseout"===e.type)return[];if(!i)return t;const r=this.options.hover;return this.getElementsAtEventForMode(e,r.mode,r,n)}}function wr(){return h(_r.instances,(e=>e._plugins.invalidate()))}function kr(){throw new Error("This method is not implemented: Check that a complete date adapter is provided.")}class Mr{static override(e){Object.assign(Mr.prototype,e)}options;constructor(e){this.options=e||{}}init(){}formats(){return kr()}parse(){return kr()}format(){return kr()}add(){return kr()}diff(){return kr()}startOf(){return kr()}endOf(){return kr()}}var Sr={_date:Mr};function Ar(e){const t=e.iScale,i=function(e,t){if(!e._cache.$bar){const i=e.getMatchingVisibleMetas(t);let n=[];for(let t=0,r=i.length;t<r;t++)n=n.concat(i[t].controller.getAllParsedValues(e));e._cache.$bar=le(n.sort(((e,t)=>e-t)))}return e._cache.$bar}(t,e.type);let n,r,a,s,o=t._length;const l=()=>{32767!==a&&-32768!==a&&(M(s)&&(o=Math.min(o,Math.abs(a-s)||o)),s=a)};for(n=0,r=i.length;n<r;++n)a=t.getPixelForValue(i[n]),l();for(s=void 0,n=0,r=t.ticks.length;n<r;++n)a=t.getPixelForTick(n),l();return o}function Lr(e,t,i,n){return r(e)?function(e,t,i,n){const r=i.parse(e[0],n),a=i.parse(e[1],n),s=Math.min(r,a),o=Math.max(r,a);let l=s,c=o;Math.abs(s)>Math.abs(o)&&(l=o,c=s),t[i.axis]=c,t._custom={barStart:l,barEnd:c,start:r,end:a,min:s,max:o}}(e,t,i,n):t[i.axis]=i.parse(e,n),t}function Tr(e,t,i,n){const r=e.iScale,a=e.vScale,s=r.getLabels(),o=r===a,l=[];let c,u,d,h;for(c=i,u=i+n;c<u;++c)h=t[c],d={},d[r.axis]=o||r.parse(s[c],c),l.push(Lr(h,d,a,c));return l}function Cr(e){return e&&void 0!==e.barStart&&void 0!==e.barEnd}function Dr(e,t,i,n){let r=t.borderSkipped;const a={};if(!r)return void(e.borderSkipped=a);if(!0===r)return void(e.borderSkipped={top:!0,right:!0,bottom:!0,left:!0});const{start:s,end:o,reverse:l,top:c,bottom:u}=function(e){let t,i,n,r,a;return e.horizontal?(t=e.base>e.x,i="left",n="right"):(t=e.base<e.y,i="bottom",n="top"),t?(r="end",a="start"):(r="start",a="end"),{start:i,end:n,reverse:t,top:r,bottom:a}}(e);"middle"===r&&i&&(e.enableBorderRadius=!0,(i._top||0)===n?r=c:(i._bottom||0)===n?r=u:(a[Er(u,s,o,l)]=!0,r=c)),a[Er(r,s,o,l)]=!0,e.borderSkipped=a}function Er(e,t,i,n){var r,a,s;return n?(s=i,e=Or(e=(r=e)===(a=t)?s:r===s?a:r,i,t)):e=Or(e,t,i),e}function Or(e,t,i){return"start"===e?t:"end"===e?i:e}function Pr(e,{inflateAmount:t},i){e.inflateAmount="auto"===t?1===i?.33:0:t}class Yr extends In{static id="doughnut";static defaults={datasetElementType:!1,dataElementType:"arc",animation:{animateRotate:!0,animateScale:!1},animations:{numbers:{type:"number",properties:["circumference","endAngle","innerRadius","outerRadius","startAngle","x","y","offset","borderWidth","spacing"]}},cutout:"50%",rotation:0,circumference:360,radius:"100%",spacing:0,indexAxis:"r"};static descriptors={_scriptable:e=>"spacing"!==e,_indexable:e=>"spacing"!==e&&!e.startsWith("borderDash")&&!e.startsWith("hoverBorderDash")};static overrides={aspectRatio:1,plugins:{legend:{labels:{generateLabels(e){const t=e.data;if(t.labels.length&&t.datasets.length){const{labels:{pointStyle:i,color:n}}=e.legend.options;return t.labels.map(((t,r)=>{const a=e.getDatasetMeta(0).controller.getStyle(r);return{text:t,fillStyle:a.backgroundColor,strokeStyle:a.borderColor,fontColor:n,lineWidth:a.borderWidth,pointStyle:i,hidden:!e.getDataVisibility(r),index:r}}))}return[]}},onClick(e,t,i){i.chart.toggleDataVisibility(t.index),i.chart.update()}}}};constructor(e,t){super(e,t),this.enableOptionSharing=!0,this.innerRadius=void 0,this.outerRadius=void 0,this.offsetX=void 0,this.offsetY=void 0}linkScales(){}parse(e,t){const i=this.getDataset().data,n=this._cachedMeta;if(!1===this._parsing)n._parsed=i;else{let r,s,o=e=>+i[e];if(a(i[e])){const{key:e="value"}=this._parsing;o=t=>+w(i[t],e)}for(r=e,s=e+t;r<s;++r)n._parsed[r]=o(r)}}_getRotation(){return W(this.options.rotation-90)}_getCircumference(){return W(this.options.circumference)}_getRotationExtents(){let e=C,t=-C;for(let i=0;i<this.chart.data.datasets.length;++i)if(this.chart.isDatasetVisible(i)&&this.chart.getDatasetMeta(i).type===this._type){const n=this.chart.getDatasetMeta(i).controller,r=n._getRotation(),a=n._getCircumference();e=Math.min(e,r),t=Math.max(t,r+a)}return{rotation:e,circumference:t-e}}update(e){const t=this.chart,{chartArea:i}=t,n=this._cachedMeta,r=n.data,a=this.getMaxBorderWidth()+this.getMaxOffset(r)+this.options.spacing,s=Math.max((Math.min(i.width,i.height)-a)/2,0),o=Math.min(c(this.options.cutout,s),1),l=this._getRingWeight(this.index),{circumference:d,rotation:h}=this._getRotationExtents(),{ratioX:f,ratioY:p,offsetX:m,offsetY:g}=function(e,t,i){let n=1,r=1,a=0,s=0;if(t<C){const o=e,l=o+t,c=Math.cos(o),u=Math.sin(o),d=Math.cos(l),h=Math.sin(l),f=(e,t,n)=>K(e,o,l,!0)?1:Math.max(t,t*i,n,n*i),p=(e,t,n)=>K(e,o,l,!0)?-1:Math.min(t,t*i,n,n*i),m=f(0,c,d),g=f(P,u,h),v=p(T,c,d),y=p(T+P,u,h);n=(m-v)/2,r=(g-y)/2,a=-(m+v)/2,s=-(g+y)/2}return{ratioX:n,ratioY:r,offsetX:a,offsetY:s}}(h,d,o),v=(i.width-a)/f,y=(i.height-a)/p,b=Math.max(Math.min(v,y)/2,0),x=u(this.options.radius,b),_=(x-Math.max(x*o,0))/this._getVisibleDatasetWeightTotal();this.offsetX=m*x,this.offsetY=g*x,n.total=this.calculateTotal(),this.outerRadius=x-_*this._getRingWeightOffset(this.index),this.innerRadius=Math.max(this.outerRadius-_*l,0),this.updateElements(r,0,r.length,e)}_circumference(e,t){const i=this.options,n=this._cachedMeta,r=this._getCircumference();return t&&i.animation.animateRotate||!this.chart.getDataVisibility(e)||null===n._parsed[e]||n.data[e].hidden?0:this.calculateCircumference(n._parsed[e]*r/C)}updateElements(e,t,i,n){const r="reset"===n,a=this.chart,s=a.chartArea,o=a.options.animation,l=(s.left+s.right)/2,c=(s.top+s.bottom)/2,u=r&&o.animateScale,d=u?0:this.innerRadius,h=u?0:this.outerRadius,{sharedOptions:f,includeOptions:p}=this._getSharedOptions(t,n);let m,g=this._getRotation();for(m=0;m<t;++m)g+=this._circumference(m,r);for(m=t;m<t+i;++m){const t=this._circumference(m,r),i=e[m],a={x:l+this.offsetX,y:c+this.offsetY,startAngle:g,endAngle:g+t,circumference:t,outerRadius:h,innerRadius:d};p&&(a.options=f||this.resolveDataElementOptions(m,i.active?"active":n)),g+=t,this.updateElement(i,m,a,n)}}calculateTotal(){const e=this._cachedMeta,t=e.data;let i,n=0;for(i=0;i<t.length;i++){const r=e._parsed[i];null===r||isNaN(r)||!this.chart.getDataVisibility(i)||t[i].hidden||(n+=Math.abs(r))}return n}calculateCircumference(e){const t=this._cachedMeta.total;return t>0&&!isNaN(e)?C*(Math.abs(e)/t):0}getLabelAndValue(e){const t=this._cachedMeta,i=this.chart,n=i.data.labels||[],r=et(t._parsed[e],i.options.locale);return{label:n[e]||"",value:r}}getMaxBorderWidth(e){let t=0;const i=this.chart;let n,r,a,s,o;if(!e)for(n=0,r=i.data.datasets.length;n<r;++n)if(i.isDatasetVisible(n)){a=i.getDatasetMeta(n),e=a.data,s=a.controller;break}if(!e)return 0;for(n=0,r=e.length;n<r;++n)o=s.resolveDataElementOptions(n),"inner"!==o.borderAlign&&(t=Math.max(t,o.borderWidth||0,o.hoverBorderWidth||0));return t}getMaxOffset(e){let t=0;for(let i=0,n=e.length;i<n;++i){const e=this.resolveDataElementOptions(i);t=Math.max(t,e.offset||0,e.hoverOffset||0)}return t}_getRingWeightOffset(e){let t=0;for(let i=0;i<e;++i)this.chart.isDatasetVisible(i)&&(t+=this._getRingWeight(i));return t}_getRingWeight(e){return Math.max(l(this.chart.data.datasets[e].weight,1),0)}_getVisibleDatasetWeightTotal(){return this._getRingWeightOffset(this.chart.data.datasets.length)||1}}class Ir extends In{static id="polarArea";static defaults={dataElementType:"arc",animation:{animateRotate:!0,animateScale:!0},animations:{numbers:{type:"number",properties:["x","y","startAngle","endAngle","innerRadius","outerRadius"]}},indexAxis:"r",startAngle:0};static overrides={aspectRatio:1,plugins:{legend:{labels:{generateLabels(e){const t=e.data;if(t.labels.length&&t.datasets.length){const{labels:{pointStyle:i,color:n}}=e.legend.options;return t.labels.map(((t,r)=>{const a=e.getDatasetMeta(0).controller.getStyle(r);return{text:t,fillStyle:a.backgroundColor,strokeStyle:a.borderColor,fontColor:n,lineWidth:a.borderWidth,pointStyle:i,hidden:!e.getDataVisibility(r),index:r}}))}return[]}},onClick(e,t,i){i.chart.toggleDataVisibility(t.index),i.chart.update()}}},scales:{r:{type:"radialLinear",angleLines:{display:!1},beginAtZero:!0,grid:{circular:!0},pointLabels:{display:!1},startAngle:0}}};constructor(e,t){super(e,t),this.innerRadius=void 0,this.outerRadius=void 0}getLabelAndValue(e){const t=this._cachedMeta,i=this.chart,n=i.data.labels||[],r=et(t._parsed[e].r,i.options.locale);return{label:n[e]||"",value:r}}parseObjectData(e,t,i,n){return Kt.bind(this)(e,t,i,n)}update(e){const t=this._cachedMeta.data;this._updateRadius(),this.updateElements(t,0,t.length,e)}getMinMax(){const e=this._cachedMeta,t={min:Number.POSITIVE_INFINITY,max:Number.NEGATIVE_INFINITY};return e.data.forEach(((e,i)=>{const n=this.getParsed(i).r;!isNaN(n)&&this.chart.getDataVisibility(i)&&(n<t.min&&(t.min=n),n>t.max&&(t.max=n))})),t}_updateRadius(){const e=this.chart,t=e.chartArea,i=e.options,n=Math.min(t.right-t.left,t.bottom-t.top),r=Math.max(n/2,0),a=(r-Math.max(i.cutoutPercentage?r/100*i.cutoutPercentage:1,0))/e.getVisibleDatasetCount();this.outerRadius=r-a*this.index,this.innerRadius=this.outerRadius-a}updateElements(e,t,i,n){const r="reset"===n,a=this.chart,s=a.options.animation,o=this._cachedMeta.rScale,l=o.xCenter,c=o.yCenter,u=o.getIndexAngle(0)-.5*T;let d,h=u;const f=360/this.countVisibleElements();for(d=0;d<t;++d)h+=this._computeAngle(d,n,f);for(d=t;d<t+i;d++){const t=e[d];let i=h,p=h+this._computeAngle(d,n,f),m=a.getDataVisibility(d)?o.getDistanceFromCenterForValue(this.getParsed(d).r):0;h=p,r&&(s.animateScale&&(m=0),s.animateRotate&&(i=p=u));const g={x:l,y:c,innerRadius:0,outerRadius:m,startAngle:i,endAngle:p,options:this.resolveDataElementOptions(d,t.active?"active":n)};this.updateElement(t,d,g,n)}}countVisibleElements(){const e=this._cachedMeta;let t=0;return e.data.forEach(((e,i)=>{!isNaN(this.getParsed(i).r)&&this.chart.getDataVisibility(i)&&t++})),t}_computeAngle(e,t,i){return this.chart.getDataVisibility(e)?W(this.resolveDataElementOptions(e,t).angle||i):0}}var Nr=Object.freeze({__proto__:null,BarController:class extends In{static id="bar";static defaults={datasetElementType:!1,dataElementType:"bar",categoryPercentage:.8,barPercentage:.9,grouped:!0,animations:{numbers:{type:"number",properties:["x","y","base","width","height"]}}};static overrides={scales:{_index_:{type:"category",offset:!0,grid:{offset:!0}},_value_:{type:"linear",beginAtZero:!0}}};parsePrimitiveData(e,t,i,n){return Tr(e,t,i,n)}parseArrayData(e,t,i,n){return Tr(e,t,i,n)}parseObjectData(e,t,i,n){const{iScale:r,vScale:a}=e,{xAxisKey:s="x",yAxisKey:o="y"}=this._parsing,l="x"===r.axis?s:o,c="x"===a.axis?s:o,u=[];let d,h,f,p;for(d=i,h=i+n;d<h;++d)p=t[d],f={},f[r.axis]=r.parse(w(p,l),d),u.push(Lr(w(p,c),f,a,d));return u}updateRangeFromParsed(e,t,i,n){super.updateRangeFromParsed(e,t,i,n);const r=i._custom;r&&t===this._cachedMeta.vScale&&(e.min=Math.min(e.min,r.min),e.max=Math.max(e.max,r.max))}getMaxOverflow(){return 0}getLabelAndValue(e){const t=this._cachedMeta,{iScale:i,vScale:n}=t,r=this.getParsed(e),a=r._custom,s=Cr(a)?"["+a.start+", "+a.end+"]":""+n.getLabelForValue(r[n.axis]);return{label:""+i.getLabelForValue(r[i.axis]),value:s}}initialize(){this.enableOptionSharing=!0,super.initialize(),this._cachedMeta.stack=this.getDataset().stack}update(e){const t=this._cachedMeta;this.updateElements(t.data,0,t.data.length,e)}updateElements(e,t,i,r){const a="reset"===r,{index:s,_cachedMeta:{vScale:o}}=this,l=o.getBasePixel(),c=o.isHorizontal(),u=this._getRuler(),{sharedOptions:d,includeOptions:h}=this._getSharedOptions(t,r);for(let f=t;f<t+i;f++){const t=this.getParsed(f),i=a||n(t[o.axis])?{base:l,head:l}:this._calculateBarValuePixels(f),p=this._calculateBarIndexPixels(f,u),m=(t._stacks||{})[o.axis],g={horizontal:c,base:i.base,enableBorderRadius:!m||Cr(t._custom)||s===m._top||s===m._bottom,x:c?i.head:p.center,y:c?p.center:i.head,height:c?p.size:Math.abs(i.size),width:c?Math.abs(i.size):p.size};h&&(g.options=d||this.resolveDataElementOptions(f,e[f].active?"active":r));const v=g.options||e[f].options;Dr(g,v,m,s),Pr(g,v,u.ratio),this.updateElement(e[f],f,g,r)}}_getStacks(e,t){const{iScale:i}=this._cachedMeta,r=i.getMatchingVisibleMetas(this._type).filter((e=>e.controller.options.grouped)),a=i.options.stacked,s=[],o=e=>{const i=e.controller.getParsed(t),r=i&&i[e.vScale.axis];if(n(r)||isNaN(r))return!0};for(const i of r)if((void 0===t||!o(i))&&((!1===a||-1===s.indexOf(i.stack)||void 0===a&&void 0===i.stack)&&s.push(i.stack),i.index===e))break;return s.length||s.push(void 0),s}_getStackCount(e){return this._getStacks(void 0,e).length}_getStackIndex(e,t,i){const n=this._getStacks(e,i),r=void 0!==t?n.indexOf(t):-1;return-1===r?n.length-1:r}_getRuler(){const e=this.options,t=this._cachedMeta,i=t.iScale,n=[];let r,a;for(r=0,a=t.data.length;r<a;++r)n.push(i.getPixelForValue(this.getParsed(r)[i.axis],r));const s=e.barThickness;return{min:s||Ar(t),pixels:n,start:i._startPixel,end:i._endPixel,stackCount:this._getStackCount(),scale:i,grouped:e.grouped,ratio:s?1:e.categoryPercentage*e.barPercentage}}_calculateBarValuePixels(e){const{_cachedMeta:{vScale:t,_stacked:i,index:r},options:{base:a,minBarLength:s}}=this,o=a||0,l=this.getParsed(e),c=l._custom,u=Cr(c);let d,h,f=l[t.axis],p=0,m=i?this.applyStack(t,l,i):f;m!==f&&(p=m-f,m=f),u&&(f=c.barStart,m=c.barEnd-c.barStart,0!==f&&j(f)!==j(c.barEnd)&&(p=0),p+=f);const g=n(a)||u?p:a;let v=t.getPixelForValue(g);if(d=this.chart.getDataVisibility(e)?t.getPixelForValue(p+m):v,h=d-v,Math.abs(h)<s){h=function(e,t,i){return 0!==e?j(e):(t.isHorizontal()?1:-1)*(t.min>=i?1:-1)}(h,t,o)*s,f===o&&(v-=h/2);const e=t.getPixelForDecimal(0),n=t.getPixelForDecimal(1),a=Math.min(e,n),c=Math.max(e,n);v=Math.max(Math.min(v,c),a),d=v+h,i&&!u&&(l._stacks[t.axis]._visualValues[r]=t.getValueForPixel(d)-t.getValueForPixel(v))}if(v===t.getPixelForValue(o)){const e=j(h)*t.getLineWidthForValue(o)/2;v+=e,h-=e}return{size:h,base:v,head:d,center:d+h/2}}_calculateBarIndexPixels(e,t){const i=t.scale,r=this.options,a=r.skipNull,s=l(r.maxBarThickness,1/0);let o,c;if(t.grouped){const i=a?this._getStackCount(e):t.stackCount,l="flex"===r.barThickness?function(e,t,i,n){const r=t.pixels,a=r[e];let s=e>0?r[e-1]:null,o=e<r.length-1?r[e+1]:null;const l=i.categoryPercentage;null===s&&(s=a-(null===o?t.end-t.start:o-a)),null===o&&(o=a+a-s);const c=a-(a-Math.min(s,o))/2*l;return{chunk:Math.abs(o-s)/2*l/n,ratio:i.barPercentage,start:c}}(e,t,r,i):function(e,t,i,r){const a=i.barThickness;let s,o;return n(a)?(s=t.min*i.categoryPercentage,o=i.barPercentage):(s=a*r,o=1),{chunk:s/r,ratio:o,start:t.pixels[e]-s/2}}(e,t,r,i),u=this._getStackIndex(this.index,this._cachedMeta.stack,a?e:void 0);o=l.start+l.chunk*u+l.chunk/2,c=Math.min(s,l.chunk*l.ratio)}else o=i.getPixelForValue(this.getParsed(e)[i.axis],e),c=Math.min(s,t.min*t.ratio);return{base:o-c/2,head:o+c/2,center:o,size:c}}draw(){const e=this._cachedMeta,t=e.vScale,i=e.data,n=i.length;let r=0;for(;r<n;++r)null===this.getParsed(r)[t.axis]||i[r].hidden||i[r].draw(this._ctx)}},BubbleController:class extends In{static id="bubble";static defaults={datasetElementType:!1,dataElementType:"point",animations:{numbers:{type:"number",properties:["x","y","borderWidth","radius"]}}};static overrides={scales:{x:{type:"linear"},y:{type:"linear"}}};initialize(){this.enableOptionSharing=!0,super.initialize()}parsePrimitiveData(e,t,i,n){const r=super.parsePrimitiveData(e,t,i,n);for(let e=0;e<r.length;e++)r[e]._custom=this.resolveDataElementOptions(e+i).radius;return r}parseArrayData(e,t,i,n){const r=super.parseArrayData(e,t,i,n);for(let e=0;e<r.length;e++){const n=t[i+e];r[e]._custom=l(n[2],this.resolveDataElementOptions(e+i).radius)}return r}parseObjectData(e,t,i,n){const r=super.parseObjectData(e,t,i,n);for(let e=0;e<r.length;e++){const n=t[i+e];r[e]._custom=l(n&&n.r&&+n.r,this.resolveDataElementOptions(e+i).radius)}return r}getMaxOverflow(){const e=this._cachedMeta.data;let t=0;for(let i=e.length-1;i>=0;--i)t=Math.max(t,e[i].size(this.resolveDataElementOptions(i))/2);return t>0&&t}getLabelAndValue(e){const t=this._cachedMeta,i=this.chart.data.labels||[],{xScale:n,yScale:r}=t,a=this.getParsed(e),s=n.getLabelForValue(a.x),o=r.getLabelForValue(a.y),l=a._custom;return{label:i[e]||"",value:"("+s+", "+o+(l?", "+l:"")+")"}}update(e){const t=this._cachedMeta.data;this.updateElements(t,0,t.length,e)}updateElements(e,t,i,n){const r="reset"===n,{iScale:a,vScale:s}=this._cachedMeta,{sharedOptions:o,includeOptions:l}=this._getSharedOptions(t,n),c=a.axis,u=s.axis;for(let d=t;d<t+i;d++){const t=e[d],i=!r&&this.getParsed(d),h={},f=h[c]=r?a.getPixelForDecimal(.5):a.getPixelForValue(i[c]),p=h[u]=r?s.getBasePixel():s.getPixelForValue(i[u]);h.skip=isNaN(f)||isNaN(p),l&&(h.options=o||this.resolveDataElementOptions(d,t.active?"active":n),r&&(h.options.radius=0)),this.updateElement(t,d,h,n)}}resolveDataElementOptions(e,t){const i=this.getParsed(e);let n=super.resolveDataElementOptions(e,t);n.$shared&&(n=Object.assign({},n,{$shared:!1}));const r=n.radius;return"active"!==t&&(n.radius=0),n.radius+=l(i&&i._custom,r),n}},DoughnutController:Yr,LineController:class extends In{static id="line";static defaults={datasetElementType:"line",dataElementType:"point",showLine:!0,spanGaps:!1};static overrides={scales:{_index_:{type:"category"},_value_:{type:"linear"}}};initialize(){this.enableOptionSharing=!0,this.supportsDecimation=!0,super.initialize()}update(e){const t=this._cachedMeta,{dataset:i,data:n=[],_dataset:r}=t,a=this.chart._animationsDisabled;let{start:s,count:o}=me(t,n,a);this._drawStart=s,this._drawCount=o,ge(t)&&(s=0,o=n.length),i._chart=this.chart,i._datasetIndex=this.index,i._decimated=!!r._decimated,i.points=n;const l=this.resolveDatasetElementOptions(e);this.options.showLine||(l.borderWidth=0),l.segment=this.options.segment,this.updateElement(i,void 0,{animated:!a,options:l},e),this.updateElements(n,s,o,e)}updateElements(e,t,i,r){const a="reset"===r,{iScale:s,vScale:o,_stacked:l,_dataset:c}=this._cachedMeta,{sharedOptions:u,includeOptions:d}=this._getSharedOptions(t,r),h=s.axis,f=o.axis,{spanGaps:p,segment:m}=this.options,g=z(p)?p:Number.POSITIVE_INFINITY,v=this.chart._animationsDisabled||a||"none"===r,y=t+i,b=e.length;let x=t>0&&this.getParsed(t-1);for(let i=0;i<b;++i){const p=e[i],b=v?p:{};if(i<t||i>=y){b.skip=!0;continue}const _=this.getParsed(i),w=n(_[f]),k=b[h]=s.getPixelForValue(_[h],i),M=b[f]=a||w?o.getBasePixel():o.getPixelForValue(l?this.applyStack(o,_,l):_[f],i);b.skip=isNaN(k)||isNaN(M)||w,b.stop=i>0&&Math.abs(_[h]-x[h])>g,m&&(b.parsed=_,b.raw=c.data[i]),d&&(b.options=u||this.resolveDataElementOptions(i,p.active?"active":r)),v||this.updateElement(p,i,b,r),x=_}}getMaxOverflow(){const e=this._cachedMeta,t=e.dataset,i=t.options&&t.options.borderWidth||0,n=e.data||[];if(!n.length)return i;const r=n[0].size(this.resolveDataElementOptions(0)),a=n[n.length-1].size(this.resolveDataElementOptions(n.length-1));return Math.max(i,r,a)/2}draw(){const e=this._cachedMeta;e.dataset.updateControlPoints(this.chart.chartArea,e.iScale.axis),super.draw()}},PieController:class extends Yr{static id="pie";static defaults={cutout:0,rotation:0,circumference:360,radius:"100%"}},PolarAreaController:Ir,RadarController:class extends In{static id="radar";static defaults={datasetElementType:"line",dataElementType:"point",indexAxis:"r",showLine:!0,elements:{line:{fill:"start"}}};static overrides={aspectRatio:1,scales:{r:{type:"radialLinear"}}};getLabelAndValue(e){const t=this._cachedMeta.vScale,i=this.getParsed(e);return{label:t.getLabels()[e],value:""+t.getLabelForValue(i[t.axis])}}parseObjectData(e,t,i,n){return Kt.bind(this)(e,t,i,n)}update(e){const t=this._cachedMeta,i=t.dataset,n=t.data||[],r=t.iScale.getLabels();if(i.points=n,"resize"!==e){const t=this.resolveDatasetElementOptions(e);this.options.showLine||(t.borderWidth=0);const a={_loop:!0,_fullLoop:r.length===n.length,options:t};this.updateElement(i,void 0,a,e)}this.updateElements(n,0,n.length,e)}updateElements(e,t,i,n){const r=this._cachedMeta.rScale,a="reset"===n;for(let s=t;s<t+i;s++){const t=e[s],i=this.resolveDataElementOptions(s,t.active?"active":n),o=r.getPointPositionForValue(s,this.getParsed(s).r),l=a?r.xCenter:o.x,c=a?r.yCenter:o.y,u={x:l,y:c,angle:o.angle,skip:isNaN(l)||isNaN(c),options:i};this.updateElement(t,s,u,n)}}},ScatterController:class extends In{static id="scatter";static defaults={datasetElementType:!1,dataElementType:"point",showLine:!1,fill:!1};static overrides={interaction:{mode:"point"},scales:{x:{type:"linear"},y:{type:"linear"}}};getLabelAndValue(e){const t=this._cachedMeta,i=this.chart.data.labels||[],{xScale:n,yScale:r}=t,a=this.getParsed(e),s=n.getLabelForValue(a.x),o=r.getLabelForValue(a.y);return{label:i[e]||"",value:"("+s+", "+o+")"}}update(e){const t=this._cachedMeta,{data:i=[]}=t,n=this.chart._animationsDisabled;let{start:r,count:a}=me(t,i,n);if(this._drawStart=r,this._drawCount=a,ge(t)&&(r=0,a=i.length),this.options.showLine){this.datasetElementType||this.addElements();const{dataset:r,_dataset:a}=t;r._chart=this.chart,r._datasetIndex=this.index,r._decimated=!!a._decimated,r.points=i;const s=this.resolveDatasetElementOptions(e);s.segment=this.options.segment,this.updateElement(r,void 0,{animated:!n,options:s},e)}else this.datasetElementType&&(delete t.dataset,this.datasetElementType=!1);this.updateElements(i,r,a,e)}addElements(){const{showLine:e}=this.options;!this.datasetElementType&&e&&(this.datasetElementType=this.chart.registry.getElement("line")),super.addElements()}updateElements(e,t,i,r){const a="reset"===r,{iScale:s,vScale:o,_stacked:l,_dataset:c}=this._cachedMeta,u=this.resolveDataElementOptions(t,r),d=this.getSharedOptions(u),h=this.includeOptions(r,d),f=s.axis,p=o.axis,{spanGaps:m,segment:g}=this.options,v=z(m)?m:Number.POSITIVE_INFINITY,y=this.chart._animationsDisabled||a||"none"===r;let b=t>0&&this.getParsed(t-1);for(let u=t;u<t+i;++u){const t=e[u],i=this.getParsed(u),m=y?t:{},x=n(i[p]),_=m[f]=s.getPixelForValue(i[f],u),w=m[p]=a||x?o.getBasePixel():o.getPixelForValue(l?this.applyStack(o,i,l):i[p],u);m.skip=isNaN(_)||isNaN(w)||x,m.stop=u>0&&Math.abs(i[f]-b[f])>v,g&&(m.parsed=i,m.raw=c.data[u]),h&&(m.options=d||this.resolveDataElementOptions(u,t.active?"active":r)),y||this.updateElement(t,u,m,r),b=i}this.updateSharedOptions(d,r,u)}getMaxOverflow(){const e=this._cachedMeta,t=e.data||[];if(!this.options.showLine){let e=0;for(let i=t.length-1;i>=0;--i)e=Math.max(e,t[i].size(this.resolveDataElementOptions(i))/2);return e>0&&e}const i=e.dataset,n=i.options&&i.options.borderWidth||0;if(!t.length)return n;const r=t[0].size(this.resolveDataElementOptions(0)),a=t[t.length-1].size(this.resolveDataElementOptions(t.length-1));return Math.max(n,r,a)/2}}});function jr(e,t,i,n){return{x:i+e*Math.cos(t),y:n+e*Math.sin(t)}}function Hr(e,t,i,n,r,a){const{x:s,y:o,startAngle:l,pixelMargin:c,innerRadius:u}=t,d=Math.max(t.outerRadius+n+i-c,0),h=u>0?u+n+i+c:0;let f=0;const p=r-l;if(n){const e=((u>0?u-n:0)+(d>0?d-n:0))/2;f=(p-(0!==e?p*e/(e+n):p))/2}const m=(p-Math.max(.001,p*d-i/T)/d)/2,g=l+m+f,v=r-m-f,{outerStart:y,outerEnd:b,innerStart:x,innerEnd:_}=function(e,t,i,n){const r=gi(e.options.borderRadius,["outerStart","outerEnd","innerStart","innerEnd"]),a=(i-t)/2,s=Math.min(a,n*t/2),o=e=>{const t=(i-Math.min(a,e))*n/2;return J(e,0,Math.min(a,t))};return{outerStart:o(r.outerStart),outerEnd:o(r.outerEnd),innerStart:J(r.innerStart,0,s),innerEnd:J(r.innerEnd,0,s)}}(t,h,d,v-g),w=d-y,k=d-b,M=g+y/w,S=v-b/k,A=h+x,L=h+_,C=g+x/A,D=v-_/L;if(e.beginPath(),a){const t=(M+S)/2;if(e.arc(s,o,d,M,t),e.arc(s,o,d,t,S),b>0){const t=jr(k,S,s,o);e.arc(t.x,t.y,b,S,v+P)}const i=jr(L,v,s,o);if(e.lineTo(i.x,i.y),_>0){const t=jr(L,D,s,o);e.arc(t.x,t.y,_,v+P,D+Math.PI)}const n=(v-_/h+(g+x/h))/2;if(e.arc(s,o,h,v-_/h,n,!0),e.arc(s,o,h,n,g+x/h,!0),x>0){const t=jr(A,C,s,o);e.arc(t.x,t.y,x,C+Math.PI,g-P)}const r=jr(w,g,s,o);if(e.lineTo(r.x,r.y),y>0){const t=jr(w,M,s,o);e.arc(t.x,t.y,y,g-P,M)}}else{e.moveTo(s,o);const t=Math.cos(M)*d+s,i=Math.sin(M)*d+o;e.lineTo(t,i);const n=Math.cos(S)*d+s,r=Math.sin(S)*d+o;e.lineTo(n,r)}e.closePath()}function Fr(e,t,i=t){e.lineCap=l(i.borderCapStyle,t.borderCapStyle),e.setLineDash(l(i.borderDash,t.borderDash)),e.lineDashOffset=l(i.borderDashOffset,t.borderDashOffset),e.lineJoin=l(i.borderJoinStyle,t.borderJoinStyle),e.lineWidth=l(i.borderWidth,t.borderWidth),e.strokeStyle=l(i.borderColor,t.borderColor)}function Rr(e,t,i){e.lineTo(i.x,i.y)}function zr(e,t,i={}){const n=e.length,{start:r=0,end:a=n-1}=i,{start:s,end:o}=t,l=Math.max(r,s),c=Math.min(a,o),u=r<s&&a<s||r>o&&a>o;return{count:n,start:l,loop:t.loop,ilen:c<l&&!u?n+c-l:c-l}}function Br(e,t,i,n){const{points:r,options:a}=t,{count:s,start:o,loop:l,ilen:c}=zr(r,i,n),u=function(e){return e.stepped?Ot:e.tension||"monotone"===e.cubicInterpolationMode?Pt:Rr}(a);let d,h,f,{move:p=!0,reverse:m}=n||{};for(d=0;d<=c;++d)h=r[(o+(m?c-d:d))%s],h.skip||(p?(e.moveTo(h.x,h.y),p=!1):u(e,f,h,m,a.stepped),f=h);return l&&(h=r[(o+(m?c:0))%s],u(e,f,h,m,a.stepped)),!!l}function Vr(e,t,i,n){const r=t.points,{count:a,start:s,ilen:o}=zr(r,i,n),{move:l=!0,reverse:c}=n||{};let u,d,h,f,p,m,g=0,v=0;const y=e=>(s+(c?o-e:e))%a,b=()=>{f!==p&&(e.lineTo(g,p),e.lineTo(g,f),e.lineTo(g,m))};for(l&&(d=r[y(0)],e.moveTo(d.x,d.y)),u=0;u<=o;++u){if(d=r[y(u)],d.skip)continue;const t=d.x,i=d.y,n=0|t;n===h?(i<f?f=i:i>p&&(p=i),g=(v*g+t)/++v):(b(),e.lineTo(t,i),h=n,v=0,f=p=i),m=i}b()}function Wr(e){const t=e.options,i=t.borderDash&&t.borderDash.length;return e._decimated||e._loop||t.tension||"monotone"===t.cubicInterpolationMode||t.stepped||i?Br:Vr}const Ur="function"==typeof Path2D;class qr extends Nn{static id="line";static defaults={borderCapStyle:"butt",borderDash:[],borderDashOffset:0,borderJoinStyle:"miter",borderWidth:3,capBezierPoints:!0,cubicInterpolationMode:"default",fill:!1,spanGaps:!1,stepped:!1,tension:0};static defaultRoutes={backgroundColor:"backgroundColor",borderColor:"borderColor"};static descriptors={_scriptable:!0,_indexable:e=>"borderDash"!==e&&"fill"!==e};constructor(e){super(),this.animated=!0,this.options=void 0,this._chart=void 0,this._loop=void 0,this._fullLoop=void 0,this._path=void 0,this._points=void 0,this._segments=void 0,this._decimated=!1,this._pointsUpdated=!1,this._datasetIndex=void 0,e&&Object.assign(this,e)}updateControlPoints(e,t){const i=this.options;if((i.tension||"monotone"===i.cubicInterpolationMode)&&!i.stepped&&!this._pointsUpdated){const n=i.spanGaps?this._loop:this._fullLoop;ri(this._points,i,e,n,t),this._pointsUpdated=!0}}set points(e){this._points=e,delete this._segments,delete this._path,this._pointsUpdated=!1}get points(){return this._points}get segments(){return this._segments||(this._segments=Ei(this,this.options.segment))}first(){const e=this.segments,t=this.points;return e.length&&t[e[0].start]}last(){const e=this.segments,t=this.points,i=e.length;return i&&t[e[i-1].end]}interpolate(e,t){const i=this.options,n=e[t],r=this.points,a=Di(this,{property:t,start:n,end:n});if(!a.length)return;const s=[],o=function(e){return e.stepped?ui:e.tension||"monotone"===e.cubicInterpolationMode?di:ci}(i);let l,c;for(l=0,c=a.length;l<c;++l){const{start:c,end:u}=a[l],d=r[c],h=r[u];if(d===h){s.push(d);continue}const f=o(d,h,Math.abs((n-d[t])/(h[t]-d[t])),i.stepped);f[t]=e[t],s.push(f)}return 1===s.length?s[0]:s}pathSegment(e,t,i){return Wr(this)(e,this,t,i)}path(e,t,i){const n=this.segments,r=Wr(this);let a=this._loop;t=t||0,i=i||this.points.length-t;for(const s of n)a&=r(e,this,s,{start:t,end:t+i-1});return!!a}draw(e,t,i,n){const r=this.options||{};(this.points||[]).length&&r.borderWidth&&(e.save(),function(e,t,i,n){Ur&&!t.options.segment?function(e,t,i,n){let r=t._path;r||(r=t._path=new Path2D,t.path(r,i,n)&&r.closePath()),Fr(e,t.options),e.stroke(r)}(e,t,i,n):function(e,t,i,n){const{segments:r,options:a}=t,s=Wr(t);for(const o of r)Fr(e,a,o.style),e.beginPath(),s(e,t,o,{start:i,end:i+n-1})&&e.closePath(),e.stroke()}(e,t,i,n)}(e,this,i,n),e.restore()),this.animated&&(this._pointsUpdated=!1,this._path=void 0)}}function $r(e,t,i,n){const r=e.options,{[i]:a}=e.getProps([i],n);return Math.abs(t-a)<r.radius+r.hitRadius}function Xr(e,t){const{x:i,y:n,base:r,width:a,height:s}=e.getProps(["x","y","base","width","height"],t);let o,l,c,u,d;return e.horizontal?(d=s/2,o=Math.min(i,r),l=Math.max(i,r),c=n-d,u=n+d):(d=a/2,o=i-d,l=i+d,c=Math.min(n,r),u=Math.max(n,r)),{left:o,top:c,right:l,bottom:u}}function Gr(e,t,i,n){return e?0:J(t,i,n)}function Zr(e){const t=Xr(e),i=t.right-t.left,n=t.bottom-t.top,r=function(e,t,i){const n=e.options.borderWidth,r=e.borderSkipped,a=vi(n);return{t:Gr(r.top,a.top,0,i),r:Gr(r.right,a.right,0,t),b:Gr(r.bottom,a.bottom,0,i),l:Gr(r.left,a.left,0,t)}}(e,i/2,n/2),s=function(e,t,i){const{enableBorderRadius:n}=e.getProps(["enableBorderRadius"]),r=e.options.borderRadius,s=yi(r),o=Math.min(t,i),l=e.borderSkipped,c=n||a(r);return{topLeft:Gr(!c||l.top||l.left,s.topLeft,0,o),topRight:Gr(!c||l.top||l.right,s.topRight,0,o),bottomLeft:Gr(!c||l.bottom||l.left,s.bottomLeft,0,o),bottomRight:Gr(!c||l.bottom||l.right,s.bottomRight,0,o)}}(e,i/2,n/2);return{outer:{x:t.left,y:t.top,w:i,h:n,radius:s},inner:{x:t.left+r.l,y:t.top+r.t,w:i-r.l-r.r,h:n-r.t-r.b,radius:{topLeft:Math.max(0,s.topLeft-Math.max(r.t,r.l)),topRight:Math.max(0,s.topRight-Math.max(r.t,r.r)),bottomLeft:Math.max(0,s.bottomLeft-Math.max(r.b,r.l)),bottomRight:Math.max(0,s.bottomRight-Math.max(r.b,r.r))}}}}function Kr(e,t,i,n){const r=null===t,a=null===i,s=e&&!(r&&a)&&Xr(e,n);return s&&(r||ee(t,s.left,s.right))&&(a||ee(i,s.top,s.bottom))}function Jr(e,t){e.rect(t.x,t.y,t.w,t.h)}function Qr(e,t,i={}){const n=e.x!==i.x?-t:0,r=e.y!==i.y?-t:0,a=(e.x+e.w!==i.x+i.w?t:0)-n,s=(e.y+e.h!==i.y+i.h?t:0)-r;return{x:e.x+n,y:e.y+r,w:e.w+a,h:e.h+s,radius:e.radius}}var ea=Object.freeze({__proto__:null,ArcElement:class extends Nn{static id="arc";static defaults={borderAlign:"center",borderColor:"#fff",borderDash:[],borderDashOffset:0,borderJoinStyle:void 0,borderRadius:0,borderWidth:2,offset:0,spacing:0,angle:void 0,circular:!0};static defaultRoutes={backgroundColor:"backgroundColor"};static descriptors={_scriptable:!0,_indexable:e=>"borderDash"!==e};circumference;endAngle;fullCircles;innerRadius;outerRadius;pixelMargin;startAngle;constructor(e){super(),this.options=void 0,this.circumference=void 0,this.startAngle=void 0,this.endAngle=void 0,this.innerRadius=void 0,this.outerRadius=void 0,this.pixelMargin=0,this.fullCircles=0,e&&Object.assign(this,e)}inRange(e,t,i){const n=this.getProps(["x","y"],i),{angle:r,distance:a}=$(n,{x:e,y:t}),{startAngle:s,endAngle:o,innerRadius:c,outerRadius:u,circumference:d}=this.getProps(["startAngle","endAngle","innerRadius","outerRadius","circumference"],i),h=(this.options.spacing+this.options.borderWidth)/2,f=l(d,o-s)>=C||K(r,s,o),p=ee(a,c+h,u+h);return f&&p}getCenterPoint(e){const{x:t,y:i,startAngle:n,endAngle:r,innerRadius:a,outerRadius:s}=this.getProps(["x","y","startAngle","endAngle","innerRadius","outerRadius"],e),{offset:o,spacing:l}=this.options,c=(n+r)/2,u=(a+s+l+o)/2;return{x:t+Math.cos(c)*u,y:i+Math.sin(c)*u}}tooltipPosition(e){return this.getCenterPoint(e)}draw(e){const{options:t,circumference:i}=this,n=(t.offset||0)/4,r=(t.spacing||0)/2,a=t.circular;if(this.pixelMargin="inner"===t.borderAlign?.33:0,this.fullCircles=i>C?Math.floor(i/C):0,0===i||this.innerRadius<0||this.outerRadius<0)return;e.save();const s=(this.startAngle+this.endAngle)/2;e.translate(Math.cos(s)*n,Math.sin(s)*n);const o=n*(1-Math.sin(Math.min(T,i||0)));e.fillStyle=t.backgroundColor,e.strokeStyle=t.borderColor,function(e,t,i,n,r){const{fullCircles:a,startAngle:s,circumference:o}=t;let l=t.endAngle;if(a){Hr(e,t,i,n,l,r);for(let t=0;t<a;++t)e.fill();isNaN(o)||(l=s+(o%C||C))}Hr(e,t,i,n,l,r),e.fill()}(e,this,o,r,a),function(e,t,i,n,r){const{fullCircles:a,startAngle:s,circumference:o,options:l}=t,{borderWidth:c,borderJoinStyle:u,borderDash:d,borderDashOffset:h}=l,f="inner"===l.borderAlign;if(!c)return;e.setLineDash(d||[]),e.lineDashOffset=h,f?(e.lineWidth=2*c,e.lineJoin=u||"round"):(e.lineWidth=c,e.lineJoin=u||"bevel");let p=t.endAngle;if(a){Hr(e,t,i,n,p,r);for(let t=0;t<a;++t)e.stroke();isNaN(o)||(p=s+(o%C||C))}f&&function(e,t,i){const{startAngle:n,pixelMargin:r,x:a,y:s,outerRadius:o,innerRadius:l}=t;let c=r/o;e.beginPath(),e.arc(a,s,o,n-c,i+c),l>r?(c=r/l,e.arc(a,s,l,i+c,n-c,!0)):e.arc(a,s,r,i+P,n-P),e.closePath(),e.clip()}(e,t,p),a||(Hr(e,t,i,n,p,r),e.stroke())}(e,this,o,r,a),e.restore()}},BarElement:class extends Nn{static id="bar";static defaults={borderSkipped:"start",borderWidth:0,borderRadius:0,inflateAmount:"auto",pointStyle:void 0};static defaultRoutes={backgroundColor:"backgroundColor",borderColor:"borderColor"};constructor(e){super(),this.options=void 0,this.horizontal=void 0,this.base=void 0,this.width=void 0,this.height=void 0,this.inflateAmount=void 0,e&&Object.assign(this,e)}draw(e){const{inflateAmount:t,options:{borderColor:i,backgroundColor:n}}=this,{inner:r,outer:a}=Zr(this),s=(o=a.radius).topLeft||o.topRight||o.bottomLeft||o.bottomRight?jt:Jr;var o;e.save(),a.w===r.w&&a.h===r.h||(e.beginPath(),s(e,Qr(a,t,r)),e.clip(),s(e,Qr(r,-t,a)),e.fillStyle=i,e.fill("evenodd")),e.beginPath(),s(e,Qr(r,t)),e.fillStyle=n,e.fill(),e.restore()}inRange(e,t,i){return Kr(this,e,t,i)}inXRange(e,t){return Kr(this,e,null,t)}inYRange(e,t){return Kr(this,null,e,t)}getCenterPoint(e){const{x:t,y:i,base:n,horizontal:r}=this.getProps(["x","y","base","horizontal"],e);return{x:r?(t+n)/2:t,y:r?i:(i+n)/2}}getRange(e){return"x"===e?this.width/2:this.height/2}},LineElement:qr,PointElement:class extends Nn{static id="point";parsed;skip;stop;static defaults={borderWidth:1,hitRadius:1,hoverBorderWidth:1,hoverRadius:4,pointStyle:"circle",radius:3,rotation:0};static defaultRoutes={backgroundColor:"backgroundColor",borderColor:"borderColor"};constructor(e){super(),this.options=void 0,this.parsed=void 0,this.skip=void 0,this.stop=void 0,e&&Object.assign(this,e)}inRange(e,t,i){const n=this.options,{x:r,y:a}=this.getProps(["x","y"],i);return Math.pow(e-r,2)+Math.pow(t-a,2)<Math.pow(n.hitRadius+n.radius,2)}inXRange(e,t){return $r(this,e,"x",t)}inYRange(e,t){return $r(this,e,"y",t)}getCenterPoint(e){const{x:t,y:i}=this.getProps(["x","y"],e);return{x:t,y:i}}size(e){let t=(e=e||this.options||{}).radius||0;return t=Math.max(t,t&&e.hoverRadius||0),2*(t+(t&&e.borderWidth||0))}draw(e,t){const i=this.options;this.skip||i.radius<.1||!Ct(this,t,this.size(i)/2)||(e.strokeStyle=i.borderColor,e.lineWidth=i.borderWidth,e.fillStyle=i.backgroundColor,Lt(e,i,this.x,this.y))}getRange(){const e=this.options||{};return e.radius+e.hitRadius}}});function ta(e){const t=this.getLabels();return e>=0&&e<t.length?t[e]:e}function ia(e,t,{horizontal:i,minRotation:n}){const r=W(n),a=(i?Math.sin(r):Math.cos(r))||.001,s=.75*t*(""+e).length;return Math.min(t/a,s)}class na extends qn{constructor(e){super(e),this.start=void 0,this.end=void 0,this._startValue=void 0,this._endValue=void 0,this._valueRange=0}parse(e,t){return n(e)||("number"==typeof e||e instanceof Number)&&!isFinite(+e)?null:+e}handleTickRangeOptions(){const{beginAtZero:e}=this.options,{minDefined:t,maxDefined:i}=this.getUserBounds();let{min:n,max:r}=this;const a=e=>n=t?n:e,s=e=>r=i?r:e;if(e){const e=j(n),t=j(r);e<0&&t<0?s(0):e>0&&t>0&&a(0)}if(n===r){let t=0===r?1:Math.abs(.05*r);s(r+t),e||a(n-t)}this.min=n,this.max=r}getTickLimit(){const e=this.options.ticks;let t,{maxTicksLimit:i,stepSize:n}=e;return n?(t=Math.ceil(this.max/n)-Math.floor(this.min/n)+1,t>1e3&&(console.warn(`scales.${this.id}.ticks.stepSize: ${n} would result generating up to ${t} ticks. Limiting to 1000.`),t=1e3)):(t=this.computeTickLimit(),i=i||11),i&&(t=Math.min(i,t)),t}computeTickLimit(){return Number.POSITIVE_INFINITY}buildTicks(){const e=this.options,t=e.ticks;let i=this.getTickLimit();i=Math.max(2,i);const r=function(e,t){const i=[],{bounds:r,step:a,min:s,max:o,precision:l,count:c,maxTicks:u,maxDigits:d,includeBounds:h}=e,f=a||1,p=u-1,{min:m,max:g}=t,v=!n(s),y=!n(o),b=!n(c),x=(g-m)/(d+1);let _,w,k,M,S=F((g-m)/p/f)*f;if(S<1e-14&&!v&&!y)return[{value:m},{value:g}];M=Math.ceil(g/S)-Math.floor(m/S),M>p&&(S=F(M*S/p/f)*f),n(l)||(_=Math.pow(10,l),S=Math.ceil(S*_)/_),"ticks"===r?(w=Math.floor(m/S)*S,k=Math.ceil(g/S)*S):(w=m,k=g),v&&y&&a&&B((o-s)/a,S/1e3)?(M=Math.round(Math.min((o-s)/S,u)),S=(o-s)/M,w=s,k=o):b?(w=v?s:w,k=y?o:k,M=c-1,S=(k-w)/M):(M=(k-w)/S,M=H(M,Math.round(M),S/1e3)?Math.round(M):Math.ceil(M));const A=Math.max(q(S),q(w));_=Math.pow(10,n(l)?A:l),w=Math.round(w*_)/_,k=Math.round(k*_)/_;let L=0;for(v&&(h&&w!==s?(i.push({value:s}),w<s&&L++,H(Math.round((w+L*S)*_)/_,s,ia(s,x,e))&&L++):w<s&&L++);L<M;++L){const e=Math.round((w+L*S)*_)/_;if(y&&e>o)break;i.push({value:e})}return y&&h&&k!==o?i.length&&H(i[i.length-1].value,o,ia(o,x,e))?i[i.length-1].value=o:i.push({value:o}):y&&k!==o||i.push({value:k}),i}({maxTicks:i,bounds:e.bounds,min:e.min,max:e.max,precision:t.precision,step:t.stepSize,count:t.count,maxDigits:this._maxDigits(),horizontal:this.isHorizontal(),minRotation:t.minRotation||0,includeBounds:!1!==t.includeBounds},this._range||this);return"ticks"===e.bounds&&V(r,this,"value"),e.reverse?(r.reverse(),this.start=this.max,this.end=this.min):(this.start=this.min,this.end=this.max),r}configure(){const e=this.ticks;let t=this.min,i=this.max;if(super.configure(),this.options.offset&&e.length){const n=(i-t)/Math.max(e.length-1,1)/2;t-=n,i+=n}this._startValue=t,this._endValue=i,this._valueRange=i-t}getLabelForValue(e){return et(e,this.chart.options.locale,this.options.ticks.format)}}class ra extends na{static id="linear";static defaults={ticks:{callback:it.formatters.numeric}};determineDataLimits(){const{min:e,max:t}=this.getMinMax(!0);this.min=s(e)?e:0,this.max=s(t)?t:1,this.handleTickRangeOptions()}computeTickLimit(){const e=this.isHorizontal(),t=e?this.width:this.height,i=W(this.options.ticks.minRotation),n=(e?Math.sin(i):Math.cos(i))||.001,r=this._resolveTickFontOptions(0);return Math.ceil(t/Math.min(40,r.lineHeight/n))}getPixelForValue(e){return null===e?NaN:this.getPixelForDecimal((e-this._startValue)/this._valueRange)}getValueForPixel(e){return this._startValue+this.getDecimalForPixel(e)*this._valueRange}}const aa=e=>Math.floor(N(e)),sa=(e,t)=>Math.pow(10,aa(e)+t);function oa(e){return 1==e/Math.pow(10,aa(e))}function la(e,t,i){const n=Math.pow(10,i),r=Math.floor(e/n);return Math.ceil(t/n)-r}class ca extends qn{static id="logarithmic";static defaults={ticks:{callback:it.formatters.logarithmic,major:{enabled:!0}}};constructor(e){super(e),this.start=void 0,this.end=void 0,this._startValue=void 0,this._valueRange=0}parse(e,t){const i=na.prototype.parse.apply(this,[e,t]);if(0!==i)return s(i)&&i>0?i:null;this._zero=!0}determineDataLimits(){const{min:e,max:t}=this.getMinMax(!0);this.min=s(e)?Math.max(0,e):null,this.max=s(t)?Math.max(0,t):null,this.options.beginAtZero&&(this._zero=!0),this._zero&&this.min!==this._suggestedMin&&!s(this._userMin)&&(this.min=e===sa(this.min,0)?sa(this.min,-1):sa(this.min,0)),this.handleTickRangeOptions()}handleTickRangeOptions(){const{minDefined:e,maxDefined:t}=this.getUserBounds();let i=this.min,n=this.max;const r=t=>i=e?i:t,a=e=>n=t?n:e;i===n&&(i<=0?(r(1),a(10)):(r(sa(i,-1)),a(sa(n,1)))),i<=0&&r(sa(n,-1)),n<=0&&a(sa(i,1)),this.min=i,this.max=n}buildTicks(){const e=this.options,t=function(e,{min:t,max:i}){t=o(e.min,t);const n=[],r=aa(t);let a=function(e,t){let i=aa(t-e);for(;la(e,t,i)>10;)i++;for(;la(e,t,i)<10;)i--;return Math.min(i,aa(e))}(t,i),s=a<0?Math.pow(10,Math.abs(a)):1;const l=Math.pow(10,a),c=r>a?Math.pow(10,r):0,u=Math.round((t-c)*s)/s,d=Math.floor((t-c)/l/10)*l*10;let h=Math.floor((u-d)/Math.pow(10,a)),f=o(e.min,Math.round((c+d+h*Math.pow(10,a))*s)/s);for(;f<i;)n.push({value:f,major:oa(f),significand:h}),h>=10?h=h<15?15:20:h++,h>=20&&(a++,h=2,s=a>=0?1:s),f=Math.round((c+d+h*Math.pow(10,a))*s)/s;const p=o(e.max,f);return n.push({value:p,major:oa(p),significand:h}),n}({min:this._userMin,max:this._userMax},this);return"ticks"===e.bounds&&V(t,this,"value"),e.reverse?(t.reverse(),this.start=this.max,this.end=this.min):(this.start=this.min,this.end=this.max),t}getLabelForValue(e){return void 0===e?"0":et(e,this.chart.options.locale,this.options.ticks.format)}configure(){const e=this.min;super.configure(),this._startValue=N(e),this._valueRange=N(this.max)-N(e)}getPixelForValue(e){return void 0!==e&&0!==e||(e=this.min),null===e||isNaN(e)?NaN:this.getPixelForDecimal(e===this.min?0:(N(e)-this._startValue)/this._valueRange)}getValueForPixel(e){const t=this.getDecimalForPixel(e);return Math.pow(10,this._startValue+t*this._valueRange)}}function ua(e){const t=e.ticks;if(t.display&&e.display){const e=bi(t.backdropPadding);return l(t.font&&t.font.size,ot.font.size)+e.height}return 0}function da(e,t,i,n,r){return e===n||e===r?{start:t-i/2,end:t+i/2}:e<n||e>r?{start:t-i,end:t}:{start:t,end:t+i}}function ha(e,t,i,n,r){const a=Math.abs(Math.sin(i)),s=Math.abs(Math.cos(i));let o=0,l=0;n.start<t.l?(o=(t.l-n.start)/a,e.l=Math.min(e.l,t.l-o)):n.end>t.r&&(o=(n.end-t.r)/a,e.r=Math.max(e.r,t.r+o)),r.start<t.t?(l=(t.t-r.start)/s,e.t=Math.min(e.t,t.t-l)):r.end>t.b&&(l=(r.end-t.b)/s,e.b=Math.max(e.b,t.b+l))}function fa(e,t,i){const n=e.drawingArea,{extra:r,additionalAngle:a,padding:s,size:o}=i,l=e.getPointPosition(t,n+r+s,a),c=Math.round(U(Z(l.angle+P))),u=function(e,t,i){return 90===i||270===i?e-=t/2:(i>270||i<90)&&(e-=t),e}(l.y,o.h,c),d=function(e){return 0===e||180===e?"center":e<180?"left":"right"}(c),h=function(e,t,i){return"right"===i?e-=t:"center"===i&&(e-=t/2),e}(l.x,o.w,d);return{visible:!0,x:l.x,y:u,textAlign:d,left:h,top:u,right:h+o.w,bottom:u+o.h}}function pa(e,t){if(!t)return!0;const{left:i,top:n,right:r,bottom:a}=e;return!(Ct({x:i,y:n},t)||Ct({x:i,y:a},t)||Ct({x:r,y:n},t)||Ct({x:r,y:a},t))}function ma(e,t,i){const{left:r,top:a,right:s,bottom:o}=i,{backdropColor:l}=t;if(!n(l)){const i=yi(t.borderRadius),n=bi(t.backdropPadding);e.fillStyle=l;const c=r-n.left,u=a-n.top,d=s-r+n.width,h=o-a+n.height;Object.values(i).some((e=>0!==e))?(e.beginPath(),jt(e,{x:c,y:u,w:d,h:h,radius:i}),e.fill()):e.fillRect(c,u,d,h)}}function ga(e,t,i,n){const{ctx:r}=e;if(i)r.arc(e.xCenter,e.yCenter,t,0,C);else{let i=e.getPointPosition(0,t);r.moveTo(i.x,i.y);for(let a=1;a<n;a++)i=e.getPointPosition(a,t),r.lineTo(i.x,i.y)}}class va extends na{static id="radialLinear";static defaults={display:!0,animate:!0,position:"chartArea",angleLines:{display:!0,lineWidth:1,borderDash:[],borderDashOffset:0},grid:{circular:!1},startAngle:0,ticks:{showLabelBackdrop:!0,callback:it.formatters.numeric},pointLabels:{backdropColor:void 0,backdropPadding:2,display:!0,font:{size:10},callback:e=>e,padding:5,centerPointLabels:!1}};static defaultRoutes={"angleLines.color":"borderColor","pointLabels.color":"color","ticks.color":"color"};static descriptors={angleLines:{_fallback:"grid"}};constructor(e){super(e),this.xCenter=void 0,this.yCenter=void 0,this.drawingArea=void 0,this._pointLabels=[],this._pointLabelItems=[]}setDimensions(){const e=this._padding=bi(ua(this.options)/2),t=this.width=this.maxWidth-e.width,i=this.height=this.maxHeight-e.height;this.xCenter=Math.floor(this.left+t/2+e.left),this.yCenter=Math.floor(this.top+i/2+e.top),this.drawingArea=Math.floor(Math.min(t,i)/2)}determineDataLimits(){const{min:e,max:t}=this.getMinMax(!1);this.min=s(e)&&!isNaN(e)?e:0,this.max=s(t)&&!isNaN(t)?t:0,this.handleTickRangeOptions()}computeTickLimit(){return Math.ceil(this.drawingArea/ua(this.options))}generateTickLabels(e){na.prototype.generateTickLabels.call(this,e),this._pointLabels=this.getLabels().map(((e,t)=>{const i=d(this.options.pointLabels.callback,[e,t],this);return i||0===i?i:""})).filter(((e,t)=>this.chart.getDataVisibility(t)))}fit(){const e=this.options;e.display&&e.pointLabels.display?function(e){const t={l:e.left+e._padding.left,r:e.right-e._padding.right,t:e.top+e._padding.top,b:e.bottom-e._padding.bottom},i=Object.assign({},t),n=[],a=[],s=e._pointLabels.length,o=e.options.pointLabels,l=o.centerPointLabels?T/s:0;for(let h=0;h<s;h++){const s=o.setContext(e.getPointLabelContext(h));a[h]=s.padding;const f=e.getPointPosition(h,e.drawingArea+a[h],l),p=xi(s.font),m=(c=e.ctx,u=p,d=r(d=e._pointLabels[h])?d:[d],{w:Mt(c,u.string,d),h:d.length*u.lineHeight});n[h]=m;const g=Z(e.getIndexAngle(h)+l),v=Math.round(U(g));ha(i,t,g,da(v,f.x,m.w,0,180),da(v,f.y,m.h,90,270))}var c,u,d;e.setCenterPoint(t.l-i.l,i.r-t.r,t.t-i.t,i.b-t.b),e._pointLabelItems=function(e,t,i){const n=[],r=e._pointLabels.length,a=e.options,{centerPointLabels:s,display:o}=a.pointLabels,l={extra:ua(a)/2,additionalAngle:s?T/r:0};let c;for(let a=0;a<r;a++){l.padding=i[a],l.size=t[a];const r=fa(e,a,l);n.push(r),"auto"===o&&(r.visible=pa(r,c),r.visible&&(c=r))}return n}(e,n,a)}(this):this.setCenterPoint(0,0,0,0)}setCenterPoint(e,t,i,n){this.xCenter+=Math.floor((e-t)/2),this.yCenter+=Math.floor((i-n)/2),this.drawingArea-=Math.min(this.drawingArea/2,Math.max(e,t,i,n))}getIndexAngle(e){return Z(e*(C/(this._pointLabels.length||1))+W(this.options.startAngle||0))}getDistanceFromCenterForValue(e){if(n(e))return NaN;const t=this.drawingArea/(this.max-this.min);return this.options.reverse?(this.max-e)*t:(e-this.min)*t}getValueForDistanceFromCenter(e){if(n(e))return NaN;const t=e/(this.drawingArea/(this.max-this.min));return this.options.reverse?this.max-t:this.min+t}getPointLabelContext(e){const t=this._pointLabels||[];if(e>=0&&e<t.length){const i=t[e];return function(e,t,i){return ki(e,{label:i,index:t,type:"pointLabel"})}(this.getContext(),e,i)}}getPointPosition(e,t,i=0){const n=this.getIndexAngle(e)-P+i;return{x:Math.cos(n)*t+this.xCenter,y:Math.sin(n)*t+this.yCenter,angle:n}}getPointPositionForValue(e,t){return this.getPointPosition(e,this.getDistanceFromCenterForValue(t))}getBasePosition(e){return this.getPointPositionForValue(e||0,this.getBaseValue())}getPointLabelPosition(e){const{left:t,top:i,right:n,bottom:r}=this._pointLabelItems[e];return{left:t,top:i,right:n,bottom:r}}drawBackground(){const{backgroundColor:e,grid:{circular:t}}=this.options;if(e){const i=this.ctx;i.save(),i.beginPath(),ga(this,this.getDistanceFromCenterForValue(this._endValue),t,this._pointLabels.length),i.closePath(),i.fillStyle=e,i.fill(),i.restore()}}drawGrid(){const e=this.ctx,t=this.options,{angleLines:i,grid:n,border:r}=t,a=this._pointLabels.length;let s,o,l;if(t.pointLabels.display&&function(e,t){const{ctx:i,options:{pointLabels:n}}=e;for(let r=t-1;r>=0;r--){const t=e._pointLabelItems[r];if(!t.visible)continue;const a=n.setContext(e.getPointLabelContext(r));ma(i,a,t);const s=xi(a.font),{x:o,y:l,textAlign:c}=t;Nt(i,e._pointLabels[r],o,l+s.lineHeight/2,s,{color:a.color,textAlign:c,textBaseline:"middle"})}}(this,a),n.display&&this.ticks.forEach(((e,t)=>{if(0!==t||0===t&&this.min<0){o=this.getDistanceFromCenterForValue(e.value);const i=this.getContext(t),s=n.setContext(i),l=r.setContext(i);!function(e,t,i,n,r){const a=e.ctx,s=t.circular,{color:o,lineWidth:l}=t;!s&&!n||!o||!l||i<0||(a.save(),a.strokeStyle=o,a.lineWidth=l,a.setLineDash(r.dash),a.lineDashOffset=r.dashOffset,a.beginPath(),ga(e,i,s,n),a.closePath(),a.stroke(),a.restore())}(this,s,o,a,l)}})),i.display){for(e.save(),s=a-1;s>=0;s--){const n=i.setContext(this.getPointLabelContext(s)),{color:r,lineWidth:a}=n;a&&r&&(e.lineWidth=a,e.strokeStyle=r,e.setLineDash(n.borderDash),e.lineDashOffset=n.borderDashOffset,o=this.getDistanceFromCenterForValue(t.ticks.reverse?this.min:this.max),l=this.getPointPosition(s,o),e.beginPath(),e.moveTo(this.xCenter,this.yCenter),e.lineTo(l.x,l.y),e.stroke())}e.restore()}}drawBorder(){}drawLabels(){const e=this.ctx,t=this.options,i=t.ticks;if(!i.display)return;const n=this.getIndexAngle(0);let r,a;e.save(),e.translate(this.xCenter,this.yCenter),e.rotate(n),e.textAlign="center",e.textBaseline="middle",this.ticks.forEach(((n,s)=>{if(0===s&&this.min>=0&&!t.reverse)return;const o=i.setContext(this.getContext(s)),l=xi(o.font);if(r=this.getDistanceFromCenterForValue(this.ticks[s].value),o.showLabelBackdrop){e.font=l.string,a=e.measureText(n.label).width,e.fillStyle=o.backdropColor;const t=bi(o.backdropPadding);e.fillRect(-a/2-t.left,-r-l.size/2-t.top,a+t.width,l.size+t.height)}Nt(e,n.label,0,-r,l,{color:o.color,strokeColor:o.textStrokeColor,strokeWidth:o.textStrokeWidth})})),e.restore()}drawTitle(){}}const ya={millisecond:{common:!0,size:1,steps:1e3},second:{common:!0,size:1e3,steps:60},minute:{common:!0,size:6e4,steps:60},hour:{common:!0,size:36e5,steps:24},day:{common:!0,size:864e5,steps:30},week:{common:!1,size:6048e5,steps:4},month:{common:!0,size:2628e6,steps:12},quarter:{common:!1,size:7884e6,steps:4},year:{common:!0,size:3154e7}},ba=Object.keys(ya);function xa(e,t){return e-t}function _a(e,t){if(n(t))return null;const i=e._adapter,{parser:r,round:a,isoWeekday:o}=e._parseOpts;let l=t;return"function"==typeof r&&(l=r(l)),s(l)||(l="string"==typeof r?i.parse(l,r):i.parse(l)),null===l?null:(a&&(l="week"!==a||!z(o)&&!0!==o?i.startOf(l,a):i.startOf(l,"isoWeek",o)),+l)}function wa(e,t,i,n){const r=ba.length;for(let a=ba.indexOf(e);a<r-1;++a){const e=ya[ba[a]],r=e.steps?e.steps:Number.MAX_SAFE_INTEGER;if(e.common&&Math.ceil((i-t)/(r*e.size))<=n)return ba[a]}return ba[r-1]}function ka(e,t,i){if(i){if(i.length){const{lo:n,hi:r}=te(i,t);e[i[n]>=t?i[n]:i[r]]=!0}}else e[t]=!0}function Ma(e,t,i){const n=[],r={},a=t.length;let s,o;for(s=0;s<a;++s)o=t[s],r[o]=s,n.push({value:o,major:!1});return 0!==a&&i?function(e,t,i,n){const r=e._adapter,a=+r.startOf(t[0].value,n),s=t[t.length-1].value;let o,l;for(o=a;o<=s;o=+r.add(o,1,n))l=i[o],l>=0&&(t[l].major=!0);return t}(e,n,r,i):n}class Sa extends qn{static id="time";static defaults={bounds:"data",adapters:{},time:{parser:!1,unit:!1,round:!1,isoWeekday:!1,minUnit:"millisecond",displayFormats:{}},ticks:{source:"auto",callback:!1,major:{enabled:!1}}};constructor(e){super(e),this._cache={data:[],labels:[],all:[]},this._unit="day",this._majorUnit=void 0,this._offsets={},this._normalized=!1,this._parseOpts=void 0}init(e,t={}){const i=e.time||(e.time={}),n=this._adapter=new Sr._date(e.adapters.date);n.init(t),y(i.displayFormats,n.formats()),this._parseOpts={parser:i.parser,round:i.round,isoWeekday:i.isoWeekday},super.init(e),this._normalized=t.normalized}parse(e,t){return void 0===e?null:_a(this,e)}beforeLayout(){super.beforeLayout(),this._cache={data:[],labels:[],all:[]}}determineDataLimits(){const e=this.options,t=this._adapter,i=e.time.unit||"day";let{min:n,max:r,minDefined:a,maxDefined:o}=this.getUserBounds();function l(e){a||isNaN(e.min)||(n=Math.min(n,e.min)),o||isNaN(e.max)||(r=Math.max(r,e.max))}a&&o||(l(this._getLabelBounds()),"ticks"===e.bounds&&"labels"===e.ticks.source||l(this.getMinMax(!1))),n=s(n)&&!isNaN(n)?n:+t.startOf(Date.now(),i),r=s(r)&&!isNaN(r)?r:+t.endOf(Date.now(),i)+1,this.min=Math.min(n,r-1),this.max=Math.max(n+1,r)}_getLabelBounds(){const e=this.getLabelTimestamps();let t=Number.POSITIVE_INFINITY,i=Number.NEGATIVE_INFINITY;return e.length&&(t=e[0],i=e[e.length-1]),{min:t,max:i}}buildTicks(){const e=this.options,t=e.time,i=e.ticks,n="labels"===i.source?this.getLabelTimestamps():this._generate();"ticks"===e.bounds&&n.length&&(this.min=this._userMin||n[0],this.max=this._userMax||n[n.length-1]);const r=this.min,a=re(n,r,this.max);return this._unit=t.unit||(i.autoSkip?wa(t.minUnit,this.min,this.max,this._getLabelCapacity(r)):function(e,t,i,n,r){for(let a=ba.length-1;a>=ba.indexOf(i);a--){const i=ba[a];if(ya[i].common&&e._adapter.diff(r,n,i)>=t-1)return i}return ba[i?ba.indexOf(i):0]}(this,a.length,t.minUnit,this.min,this.max)),this._majorUnit=i.major.enabled&&"year"!==this._unit?function(e){for(let t=ba.indexOf(e)+1,i=ba.length;t<i;++t)if(ya[ba[t]].common)return ba[t]}(this._unit):void 0,this.initOffsets(n),e.reverse&&a.reverse(),Ma(this,a,this._majorUnit)}afterAutoSkip(){this.options.offsetAfterAutoskip&&this.initOffsets(this.ticks.map((e=>+e.value)))}initOffsets(e=[]){let t,i,n=0,r=0;this.options.offset&&e.length&&(t=this.getDecimalForValue(e[0]),n=1===e.length?1-t:(this.getDecimalForValue(e[1])-t)/2,i=this.getDecimalForValue(e[e.length-1]),r=1===e.length?i:(i-this.getDecimalForValue(e[e.length-2]))/2);const a=e.length<3?.5:.25;n=J(n,0,a),r=J(r,0,a),this._offsets={start:n,end:r,factor:1/(n+1+r)}}_generate(){const e=this._adapter,t=this.min,i=this.max,n=this.options,r=n.time,a=r.unit||wa(r.minUnit,t,i,this._getLabelCapacity(t)),s=l(n.ticks.stepSize,1),o="week"===a&&r.isoWeekday,c=z(o)||!0===o,u={};let d,h,f=t;if(c&&(f=+e.startOf(f,"isoWeek",o)),f=+e.startOf(f,c?"day":a),e.diff(i,t,a)>1e5*s)throw new Error(t+" and "+i+" are too far apart with stepSize of "+s+" "+a);const p="data"===n.ticks.source&&this.getDataTimestamps();for(d=f,h=0;d<i;d=+e.add(d,s,a),h++)ka(u,d,p);return d!==i&&"ticks"!==n.bounds&&1!==h||ka(u,d,p),Object.keys(u).sort(xa).map((e=>+e))}getLabelForValue(e){const t=this._adapter,i=this.options.time;return i.tooltipFormat?t.format(e,i.tooltipFormat):t.format(e,i.displayFormats.datetime)}format(e,t){const i=this.options.time.displayFormats,n=this._unit,r=t||i[n];return this._adapter.format(e,r)}_tickFormatFunction(e,t,i,n){const r=this.options,a=r.ticks.callback;if(a)return d(a,[e,t,i],this);const s=r.time.displayFormats,o=this._unit,l=this._majorUnit,c=o&&s[o],u=l&&s[l],h=i[t],f=l&&u&&h&&h.major;return this._adapter.format(e,n||(f?u:c))}generateTickLabels(e){let t,i,n;for(t=0,i=e.length;t<i;++t)n=e[t],n.label=this._tickFormatFunction(n.value,t,e)}getDecimalForValue(e){return null===e?NaN:(e-this.min)/(this.max-this.min)}getPixelForValue(e){const t=this._offsets,i=this.getDecimalForValue(e);return this.getPixelForDecimal((t.start+i)*t.factor)}getValueForPixel(e){const t=this._offsets,i=this.getDecimalForPixel(e)/t.factor-t.end;return this.min+i*(this.max-this.min)}_getLabelSize(e){const t=this.options.ticks,i=this.ctx.measureText(e).width,n=W(this.isHorizontal()?t.maxRotation:t.minRotation),r=Math.cos(n),a=Math.sin(n),s=this._resolveTickFontOptions(0).size;return{w:i*r+s*a,h:i*a+s*r}}_getLabelCapacity(e){const t=this.options.time,i=t.displayFormats,n=i[t.unit]||i.millisecond,r=this._tickFormatFunction(e,0,Ma(this,[e],this._majorUnit),n),a=this._getLabelSize(r),s=Math.floor(this.isHorizontal()?this.width/a.w:this.height/a.h)-1;return s>0?s:1}getDataTimestamps(){let e,t,i=this._cache.data||[];if(i.length)return i;const n=this.getMatchingVisibleMetas();if(this._normalized&&n.length)return this._cache.data=n[0].controller.getAllParsedValues(this);for(e=0,t=n.length;e<t;++e)i=i.concat(n[e].controller.getAllParsedValues(this));return this._cache.data=this.normalize(i)}getLabelTimestamps(){const e=this._cache.labels||[];let t,i;if(e.length)return e;const n=this.getLabels();for(t=0,i=n.length;t<i;++t)e.push(_a(this,n[t]));return this._cache.labels=this._normalized?e:this.normalize(e)}normalize(e){return le(e.sort(xa))}}function Aa(e,t,i){let n,r,a,s,o=0,l=e.length-1;i?(t>=e[o].pos&&t<=e[l].pos&&({lo:o,hi:l}=ie(e,"pos",t)),({pos:n,time:a}=e[o]),({pos:r,time:s}=e[l])):(t>=e[o].time&&t<=e[l].time&&({lo:o,hi:l}=ie(e,"time",t)),({time:n,pos:a}=e[o]),({time:r,pos:s}=e[l]));const c=r-n;return c?a+(s-a)*(t-n)/c:a}var La=Object.freeze({__proto__:null,CategoryScale:class extends qn{static id="category";static defaults={ticks:{callback:ta}};constructor(e){super(e),this._startValue=void 0,this._valueRange=0,this._addedLabels=[]}init(e){const t=this._addedLabels;if(t.length){const e=this.getLabels();for(const{index:i,label:n}of t)e[i]===n&&e.splice(i,1);this._addedLabels=[]}super.init(e)}parse(e,t){if(n(e))return null;const i=this.getLabels();return((e,t)=>null===e?null:J(Math.round(e),0,t))(t=isFinite(t)&&i[t]===e?t:function(e,t,i,n){const r=e.indexOf(t);return-1===r?((e,t,i,n)=>("string"==typeof t?(i=e.push(t)-1,n.unshift({index:i,label:t})):isNaN(t)&&(i=null),i))(e,t,i,n):r!==e.lastIndexOf(t)?i:r}(i,e,l(t,e),this._addedLabels),i.length-1)}determineDataLimits(){const{minDefined:e,maxDefined:t}=this.getUserBounds();let{min:i,max:n}=this.getMinMax(!0);"ticks"===this.options.bounds&&(e||(i=0),t||(n=this.getLabels().length-1)),this.min=i,this.max=n}buildTicks(){const e=this.min,t=this.max,i=this.options.offset,n=[];let r=this.getLabels();r=0===e&&t===r.length-1?r:r.slice(e,t+1),this._valueRange=Math.max(r.length-(i?0:1),1),this._startValue=this.min-(i?.5:0);for(let i=e;i<=t;i++)n.push({value:i});return n}getLabelForValue(e){return ta.call(this,e)}configure(){super.configure(),this.isHorizontal()||(this._reversePixels=!this._reversePixels)}getPixelForValue(e){return"number"!=typeof e&&(e=this.parse(e)),null===e?NaN:this.getPixelForDecimal((e-this._startValue)/this._valueRange)}getPixelForTick(e){const t=this.ticks;return e<0||e>t.length-1?null:this.getPixelForValue(t[e].value)}getValueForPixel(e){return Math.round(this._startValue+this.getDecimalForPixel(e)*this._valueRange)}getBasePixel(){return this.bottom}},LinearScale:ra,LogarithmicScale:ca,RadialLinearScale:va,TimeScale:Sa,TimeSeriesScale:class extends Sa{static id="timeseries";static defaults=Sa.defaults;constructor(e){super(e),this._table=[],this._minPos=void 0,this._tableRange=void 0}initOffsets(){const e=this._getTimestampsForTable(),t=this._table=this.buildLookupTable(e);this._minPos=Aa(t,this.min),this._tableRange=Aa(t,this.max)-this._minPos,super.initOffsets(e)}buildLookupTable(e){const{min:t,max:i}=this,n=[],r=[];let a,s,o,l,c;for(a=0,s=e.length;a<s;++a)l=e[a],l>=t&&l<=i&&n.push(l);if(n.length<2)return[{time:t,pos:0},{time:i,pos:1}];for(a=0,s=n.length;a<s;++a)c=n[a+1],o=n[a-1],l=n[a],Math.round((c+o)/2)!==l&&r.push({time:l,pos:a/(s-1)});return r}_generate(){const e=this.min,t=this.max;let i=super.getDataTimestamps();return i.includes(e)&&i.length||i.splice(0,0,e),i.includes(t)&&1!==i.length||i.push(t),i.sort(((e,t)=>e-t))}_getTimestampsForTable(){let e=this._cache.all||[];if(e.length)return e;const t=this.getDataTimestamps(),i=this.getLabelTimestamps();return e=t.length&&i.length?this.normalize(t.concat(i)):t.length?t:i,e=this._cache.all=e,e}getDecimalForValue(e){return(Aa(this._table,e)-this._minPos)/this._tableRange}getValueForPixel(e){const t=this._offsets,i=this.getDecimalForPixel(e)/t.factor-t.end;return Aa(this._table,i*this._tableRange+this._minPos,!0)}}});const Ta=["rgb(54, 162, 235)","rgb(255, 99, 132)","rgb(255, 159, 64)","rgb(255, 205, 86)","rgb(75, 192, 192)","rgb(153, 102, 255)","rgb(201, 203, 207)"],Ca=Ta.map((e=>e.replace("rgb(","rgba(").replace(")",", 0.5)")));function Da(e){return Ta[e%Ta.length]}function Ea(e){return Ca[e%Ca.length]}function Oa(e){let t;for(t in e)if(e[t].borderColor||e[t].backgroundColor)return!0;return!1}var Pa={id:"colors",defaults:{enabled:!0,forceOverride:!1},beforeLayout(e,t,i){if(!i.enabled)return;const{data:{datasets:n},options:r}=e.config,{elements:a}=r;if(!i.forceOverride&&(Oa(n)||(s=r)&&(s.borderColor||s.backgroundColor)||a&&Oa(a)))return;var s;const o=function(e){let t=0;return(i,n)=>{const r=e.getDatasetMeta(n).controller;r instanceof Yr?t=function(e,t){return e.backgroundColor=e.data.map((()=>Da(t++))),t}(i,t):r instanceof Ir?t=function(e,t){return e.backgroundColor=e.data.map((()=>Ea(t++))),t}(i,t):r&&(t=function(e,t){return e.borderColor=Da(t),e.backgroundColor=Ea(t),++t}(i,t))}}(e);n.forEach(o)}};function Ya(e){if(e._decimated){const t=e._data;delete e._decimated,delete e._data,Object.defineProperty(e,"data",{configurable:!0,enumerable:!0,writable:!0,value:t})}}function Ia(e){e.data.datasets.forEach((e=>{Ya(e)}))}var Na={id:"decimation",defaults:{algorithm:"min-max",enabled:!1},beforeElementsUpdate:(e,t,i)=>{if(!i.enabled)return void Ia(e);const r=e.width;e.data.datasets.forEach(((t,a)=>{const{_data:s,indexAxis:o}=t,l=e.getDatasetMeta(a),c=s||t.data;if("y"===_i([o,e.options.indexAxis]))return;if(!l.controller.supportsDecimation)return;const u=e.scales[l.xAxisID];if("linear"!==u.type&&"time"!==u.type)return;if(e.options.parsing)return;let d,{start:h,count:f}=function(e,t){const i=t.length;let n,r=0;const{iScale:a}=e,{min:s,max:o,minDefined:l,maxDefined:c}=a.getUserBounds();return l&&(r=J(ie(t,a.axis,s).lo,0,i-1)),n=c?J(ie(t,a.axis,o).hi+1,r,i)-r:i-r,{start:r,count:n}}(l,c);if(f<=(i.threshold||4*r))Ya(t);else{switch(n(s)&&(t._data=c,delete t.data,Object.defineProperty(t,"data",{configurable:!0,enumerable:!0,get:function(){return this._decimated},set:function(e){this._data=e}})),i.algorithm){case"lttb":d=function(e,t,i,n,r){const a=r.samples||n;if(a>=i)return e.slice(t,t+i);const s=[],o=(i-2)/(a-2);let l=0;const c=t+i-1;let u,d,h,f,p,m=t;for(s[l++]=e[m],u=0;u<a-2;u++){let n,r=0,a=0;const c=Math.floor((u+1)*o)+1+t,g=Math.min(Math.floor((u+2)*o)+1,i)+t,v=g-c;for(n=c;n<g;n++)r+=e[n].x,a+=e[n].y;r/=v,a/=v;const y=Math.floor(u*o)+1+t,b=Math.min(Math.floor((u+1)*o)+1,i)+t,{x:x,y:_}=e[m];for(h=f=-1,n=y;n<b;n++)f=.5*Math.abs((x-r)*(e[n].y-_)-(x-e[n].x)*(a-_)),f>h&&(h=f,d=e[n],p=n);s[l++]=d,m=p}return s[l++]=e[c],s}(c,h,f,r,i);break;case"min-max":d=function(e,t,i,r){let a,s,o,l,c,u,d,h,f,p,m=0,g=0;const v=[],y=t+i-1,b=e[t].x,x=e[y].x-b;for(a=t;a<t+i;++a){s=e[a],o=(s.x-b)/x*r,l=s.y;const t=0|o;if(t===c)l<f?(f=l,u=a):l>p&&(p=l,d=a),m=(g*m+s.x)/++g;else{const i=a-1;if(!n(u)&&!n(d)){const t=Math.min(u,d),n=Math.max(u,d);t!==h&&t!==i&&v.push({...e[t],x:m}),n!==h&&n!==i&&v.push({...e[n],x:m})}a>0&&i!==h&&v.push(e[i]),v.push(s),c=t,g=0,f=p=l,u=d=h=a}}return v}(c,h,f,r);break;default:throw new Error(`Unsupported decimation algorithm '${i.algorithm}'`)}t._decimated=d}}))},destroy(e){Ia(e)}};function ja(e,t,i,n){if(n)return;let r=t[e],a=i[e];return"angle"===e&&(r=Z(r),a=Z(a)),{property:e,start:r,end:a}}function Ha(e,t,i){for(;t>e;t--){const e=i[t];if(!isNaN(e.x)&&!isNaN(e.y))break}return t}function Fa(e,t,i,n){return e&&t?n(e[i],t[i]):e?e[i]:t?t[i]:0}function Ra(e,t){let i=[],n=!1;return r(e)?(n=!0,i=e):i=function(e,t){const{x:i=null,y:n=null}=e||{},r=t.points,a=[];return t.segments.forEach((({start:e,end:t})=>{t=Ha(e,t,r);const s=r[e],o=r[t];null!==n?(a.push({x:s.x,y:n}),a.push({x:o.x,y:n})):null!==i&&(a.push({x:i,y:s.y}),a.push({x:i,y:o.y}))})),a}(e,t),i.length?new qr({points:i,options:{tension:0},_loop:n,_fullLoop:n}):null}function za(e){return e&&!1!==e.fill}function Ba(e,t,i){let n=e[t].fill;const r=[t];let a;if(!i)return n;for(;!1!==n&&-1===r.indexOf(n);){if(!s(n))return n;if(a=e[n],!a)return!1;if(a.visible)return n;r.push(n),n=a.fill}return!1}function Va(e,t,i){const n=function(e){const t=e.options,i=t.fill;let n=l(i&&i.target,i);return void 0===n&&(n=!!t.backgroundColor),!1!==n&&null!==n&&(!0===n?"origin":n)}(e);if(a(n))return!isNaN(n.value)&&n;let r=parseFloat(n);return s(r)&&Math.floor(r)===r?function(e,t,i,n){return"-"!==e&&"+"!==e||(i=t+i),!(i===t||i<0||i>=n)&&i}(n[0],t,r,i):["origin","start","end","stack","shape"].indexOf(n)>=0&&n}function Wa(e,t,i){const n=[];for(let r=0;r<i.length;r++){const a=i[r],{first:s,last:o,point:l}=Ua(a,t,"x");if(!(!l||s&&o))if(s)n.unshift(l);else if(e.push(l),!o)break}e.push(...n)}function Ua(e,t,i){const n=e.interpolate(t,i);if(!n)return{};const r=n[i],a=e.segments,s=e.points;let o=!1,l=!1;for(let e=0;e<a.length;e++){const t=a[e],n=s[t.start][i],c=s[t.end][i];if(ee(r,n,c)){o=r===n,l=r===c;break}}return{first:o,last:l,point:n}}class qa{constructor(e){this.x=e.x,this.y=e.y,this.radius=e.radius}pathSegment(e,t,i){const{x:n,y:r,radius:a}=this;return t=t||{start:0,end:C},e.arc(n,r,a,t.end,t.start,!0),!i.bounds}interpolate(e){const{x:t,y:i,radius:n}=this,r=e.angle;return{x:t+Math.cos(r)*n,y:i+Math.sin(r)*n,angle:r}}}function $a(e){const{chart:t,fill:i,line:n}=e;if(s(i))return function(e,t){const i=e.getDatasetMeta(t);return i&&e.isDatasetVisible(t)?i.dataset:null}(t,i);if("stack"===i)return function(e){const{scale:t,index:i,line:n}=e,r=[],a=n.segments,s=n.points,o=function(e,t){const i=[],n=e.getMatchingVisibleMetas("line");for(let e=0;e<n.length;e++){const r=n[e];if(r.index===t)break;r.hidden||i.unshift(r.dataset)}return i}(t,i);o.push(Ra({x:null,y:t.bottom},n));for(let e=0;e<a.length;e++){const t=a[e];for(let e=t.start;e<=t.end;e++)Wa(r,s[e],o)}return new qr({points:r,options:{}})}(e);if("shape"===i)return!0;const r=function(e){return(e.scale||{}).getPointPositionForValue?function(e){const{scale:t,fill:i}=e,n=t.options,r=t.getLabels().length,s=n.reverse?t.max:t.min,o=function(e,t,i){let n;return n="start"===e?i:"end"===e?t.options.reverse?t.min:t.max:a(e)?e.value:t.getBaseValue(),n}(i,t,s),l=[];if(n.grid.circular){const e=t.getPointPositionForValue(0,s);return new qa({x:e.x,y:e.y,radius:t.getDistanceFromCenterForValue(o)})}for(let e=0;e<r;++e)l.push(t.getPointPositionForValue(e,o));return l}(e):function(e){const{scale:t={},fill:i}=e,n=function(e,t){let i=null;return"start"===e?i=t.bottom:"end"===e?i=t.top:a(e)?i=t.getPixelForValue(e.value):t.getBasePixel&&(i=t.getBasePixel()),i}(i,t);if(s(n)){const e=t.isHorizontal();return{x:e?n:null,y:e?null:n}}return null}(e)}(e);return r instanceof qa?r:Ra(r,n)}function Xa(e,t,i){const n=$a(t),{line:r,scale:a,axis:s}=t,o=r.options,l=o.fill,c=o.backgroundColor,{above:u=c,below:d=c}=l||{};n&&r.points.length&&(Dt(e,i),function(e,t){const{line:i,target:n,above:r,below:a,area:s,scale:o}=t,l=i._loop?"angle":t.axis;e.save(),"x"===l&&a!==r&&(Ga(e,n,s.top),Za(e,{line:i,target:n,color:r,scale:o,property:l}),e.restore(),e.save(),Ga(e,n,s.bottom)),Za(e,{line:i,target:n,color:a,scale:o,property:l}),e.restore()}(e,{line:r,target:n,above:u,below:d,area:i,scale:a,axis:s}),Et(e))}function Ga(e,t,i){const{segments:n,points:r}=t;let a=!0,s=!1;e.beginPath();for(const o of n){const{start:n,end:l}=o,c=r[n],u=r[Ha(n,l,r)];a?(e.moveTo(c.x,c.y),a=!1):(e.lineTo(c.x,i),e.lineTo(c.x,c.y)),s=!!t.pathSegment(e,o,{move:s}),s?e.closePath():e.lineTo(u.x,i)}e.lineTo(t.first().x,i),e.closePath(),e.clip()}function Za(e,t){const{line:i,target:n,property:r,color:a,scale:s}=t,o=function(e,t,i){const n=e.segments,r=e.points,a=t.points,s=[];for(const e of n){let{start:n,end:o}=e;o=Ha(n,o,r);const l=ja(i,r[n],r[o],e.loop);if(!t.segments){s.push({source:e,target:l,start:r[n],end:r[o]});continue}const c=Di(t,l);for(const t of c){const n=ja(i,a[t.start],a[t.end],t.loop),o=Ci(e,r,n);for(const e of o)s.push({source:e,target:t,start:{[i]:Fa(l,n,"start",Math.max)},end:{[i]:Fa(l,n,"end",Math.min)}})}}return s}(i,n,r);for(const{source:t,target:l,start:c,end:u}of o){const{style:{backgroundColor:o=a}={}}=t,d=!0!==n;e.save(),e.fillStyle=o,Ka(e,s,d&&ja(r,c,u)),e.beginPath();const h=!!i.pathSegment(e,t);let f;if(d){h?e.closePath():Ja(e,n,u,r);const t=!!n.pathSegment(e,l,{move:h,reverse:!0});f=h&&t,f||Ja(e,n,c,r)}e.closePath(),e.fill(f?"evenodd":"nonzero"),e.restore()}}function Ka(e,t,i){const{top:n,bottom:r}=t.chart.chartArea,{property:a,start:s,end:o}=i||{};"x"===a&&(e.beginPath(),e.rect(s,n,o-s,r-n),e.clip())}function Ja(e,t,i,n){const r=t.interpolate(i,n);r&&e.lineTo(r.x,r.y)}var Qa={id:"filler",afterDatasetsUpdate(e,t,i){const n=(e.data.datasets||[]).length,r=[];let a,s,o,l;for(s=0;s<n;++s)a=e.getDatasetMeta(s),o=a.dataset,l=null,o&&o.options&&o instanceof qr&&(l={visible:e.isDatasetVisible(s),index:s,fill:Va(o,s,n),chart:e,axis:a.controller.options.indexAxis,scale:a.vScale,line:o}),a.$filler=l,r.push(l);for(s=0;s<n;++s)l=r[s],l&&!1!==l.fill&&(l.fill=Ba(r,s,i.propagate))},beforeDraw(e,t,i){const n="beforeDraw"===i.drawTime,r=e.getSortedVisibleDatasetMetas(),a=e.chartArea;for(let t=r.length-1;t>=0;--t){const i=r[t].$filler;i&&(i.line.updateControlPoints(a,i.axis),n&&i.fill&&Xa(e.ctx,i,a))}},beforeDatasetsDraw(e,t,i){if("beforeDatasetsDraw"!==i.drawTime)return;const n=e.getSortedVisibleDatasetMetas();for(let t=n.length-1;t>=0;--t){const i=n[t].$filler;za(i)&&Xa(e.ctx,i,e.chartArea)}},beforeDatasetDraw(e,t,i){const n=t.meta.$filler;za(n)&&"beforeDatasetDraw"===i.drawTime&&Xa(e.ctx,n,e.chartArea)},defaults:{propagate:!0,drawTime:"beforeDatasetDraw"}};const es=(e,t)=>{let{boxHeight:i=t,boxWidth:n=t}=e;return e.usePointStyle&&(i=Math.min(i,t),n=e.pointStyleWidth||Math.min(n,t)),{boxWidth:n,boxHeight:i,itemHeight:Math.max(t,i)}};class ts extends Nn{constructor(e){super(),this._added=!1,this.legendHitBoxes=[],this._hoveredItem=null,this.doughnutMode=!1,this.chart=e.chart,this.options=e.options,this.ctx=e.ctx,this.legendItems=void 0,this.columnSizes=void 0,this.lineWidths=void 0,this.maxHeight=void 0,this.maxWidth=void 0,this.top=void 0,this.bottom=void 0,this.left=void 0,this.right=void 0,this.height=void 0,this.width=void 0,this._margins=void 0,this.position=void 0,this.weight=void 0,this.fullSize=void 0}update(e,t,i){this.maxWidth=e,this.maxHeight=t,this._margins=i,this.setDimensions(),this.buildLabels(),this.fit()}setDimensions(){this.isHorizontal()?(this.width=this.maxWidth,this.left=this._margins.left,this.right=this.width):(this.height=this.maxHeight,this.top=this._margins.top,this.bottom=this.height)}buildLabels(){const e=this.options.labels||{};let t=d(e.generateLabels,[this.chart],this)||[];e.filter&&(t=t.filter((t=>e.filter(t,this.chart.data)))),e.sort&&(t=t.sort(((t,i)=>e.sort(t,i,this.chart.data)))),this.options.reverse&&t.reverse(),this.legendItems=t}fit(){const{options:e,ctx:t}=this;if(!e.display)return void(this.width=this.height=0);const i=e.labels,n=xi(i.font),r=n.size,a=this._computeTitleHeight(),{boxWidth:s,itemHeight:o}=es(i,r);let l,c;t.font=n.string,this.isHorizontal()?(l=this.maxWidth,c=this._fitRows(a,r,s,o)+10):(c=this.maxHeight,l=this._fitCols(a,n,s,o)+10),this.width=Math.min(l,e.maxWidth||this.maxWidth),this.height=Math.min(c,e.maxHeight||this.maxHeight)}_fitRows(e,t,i,n){const{ctx:r,maxWidth:a,options:{labels:{padding:s}}}=this,o=this.legendHitBoxes=[],l=this.lineWidths=[0],c=n+s;let u=e;r.textAlign="left",r.textBaseline="middle";let d=-1,h=-c;return this.legendItems.forEach(((e,f)=>{const p=i+t/2+r.measureText(e.text).width;(0===f||l[l.length-1]+p+2*s>a)&&(u+=c,l[l.length-(f>0?0:1)]=0,h+=c,d++),o[f]={left:0,top:h,row:d,width:p,height:n},l[l.length-1]+=p+s})),u}_fitCols(e,t,i,n){const{ctx:r,maxHeight:a,options:{labels:{padding:s}}}=this,o=this.legendHitBoxes=[],l=this.columnSizes=[],c=a-e;let u=s,d=0,h=0,f=0,p=0;return this.legendItems.forEach(((e,a)=>{const{itemWidth:m,itemHeight:g}=function(e,t,i,n,r){const a=function(e,t,i,n){let r=e.text;return r&&"string"!=typeof r&&(r=r.reduce(((e,t)=>e.length>t.length?e:t))),t+i.size/2+n.measureText(r).width}(n,e,t,i),s=function(e,t,i){let n=e;return"string"!=typeof t.text&&(n=is(t,i)),n}(r,n,t.lineHeight);return{itemWidth:a,itemHeight:s}}(i,t,r,e,n);a>0&&h+g+2*s>c&&(u+=d+s,l.push({width:d,height:h}),f+=d+s,p++,d=h=0),o[a]={left:f,top:h,col:p,width:m,height:g},d=Math.max(d,m),h+=g+s})),u+=d,l.push({width:d,height:h}),u}adjustHitBoxes(){if(!this.options.display)return;const e=this._computeTitleHeight(),{legendHitBoxes:t,options:{align:i,labels:{padding:n},rtl:r}}=this,a=Mi(r,this.left,this.width);if(this.isHorizontal()){let r=0,s=fe(i,this.left+n,this.right-this.lineWidths[r]);for(const o of t)r!==o.row&&(r=o.row,s=fe(i,this.left+n,this.right-this.lineWidths[r])),o.top+=this.top+e+n,o.left=a.leftForLtr(a.x(s),o.width),s+=o.width+n}else{let r=0,s=fe(i,this.top+e+n,this.bottom-this.columnSizes[r].height);for(const o of t)o.col!==r&&(r=o.col,s=fe(i,this.top+e+n,this.bottom-this.columnSizes[r].height)),o.top=s,o.left+=this.left+n,o.left=a.leftForLtr(a.x(o.left),o.width),s+=o.height+n}}isHorizontal(){return"top"===this.options.position||"bottom"===this.options.position}draw(){if(this.options.display){const e=this.ctx;Dt(e,this),this._draw(),Et(e)}}_draw(){const{options:e,columnSizes:t,lineWidths:i,ctx:n}=this,{align:r,labels:a}=e,s=ot.color,o=Mi(e.rtl,this.left,this.width),c=xi(a.font),{padding:u}=a,d=c.size,h=d/2;let f;this.drawTitle(),n.textAlign=o.textAlign("left"),n.textBaseline="middle",n.lineWidth=.5,n.font=c.string;const{boxWidth:p,boxHeight:m,itemHeight:g}=es(a,d),v=this.isHorizontal(),y=this._computeTitleHeight();f=v?{x:fe(r,this.left+u,this.right-i[0]),y:this.top+u+y,line:0}:{x:this.left+u,y:fe(r,this.top+y+u,this.bottom-t[0].height),line:0},Si(this.ctx,e.textDirection);const b=g+u;this.legendItems.forEach(((x,_)=>{n.strokeStyle=x.fontColor,n.fillStyle=x.fontColor;const w=n.measureText(x.text).width,k=o.textAlign(x.textAlign||(x.textAlign=a.textAlign)),M=p+h+w;let S=f.x,A=f.y;if(o.setWidth(this.width),v?_>0&&S+M+u>this.right&&(A=f.y+=b,f.line++,S=f.x=fe(r,this.left+u,this.right-i[f.line])):_>0&&A+b>this.bottom&&(S=f.x=S+t[f.line].width+u,f.line++,A=f.y=fe(r,this.top+y+u,this.bottom-t[f.line].height)),function(e,t,i){if(isNaN(p)||p<=0||isNaN(m)||m<0)return;n.save();const r=l(i.lineWidth,1);if(n.fillStyle=l(i.fillStyle,s),n.lineCap=l(i.lineCap,"butt"),n.lineDashOffset=l(i.lineDashOffset,0),n.lineJoin=l(i.lineJoin,"miter"),n.lineWidth=r,n.strokeStyle=l(i.strokeStyle,s),n.setLineDash(l(i.lineDash,[])),a.usePointStyle){const s={radius:m*Math.SQRT2/2,pointStyle:i.pointStyle,rotation:i.rotation,borderWidth:r},l=o.xPlus(e,p/2);Tt(n,s,l,t+h,a.pointStyleWidth&&p)}else{const a=t+Math.max((d-m)/2,0),s=o.leftForLtr(e,p),l=yi(i.borderRadius);n.beginPath(),Object.values(l).some((e=>0!==e))?jt(n,{x:s,y:a,w:p,h:m,radius:l}):n.rect(s,a,p,m),n.fill(),0!==r&&n.stroke()}n.restore()}(o.x(S),A,x),S=pe(k,S+p+h,v?S+M:this.right,e.rtl),function(e,t,i){Nt(n,i.text,e,t+g/2,c,{strikethrough:i.hidden,textAlign:o.textAlign(i.textAlign)})}(o.x(S),A,x),v)f.x+=M+u;else if("string"!=typeof x.text){const e=c.lineHeight;f.y+=is(x,e)+u}else f.y+=b})),Ai(this.ctx,e.textDirection)}drawTitle(){const e=this.options,t=e.title,i=xi(t.font),n=bi(t.padding);if(!t.display)return;const r=Mi(e.rtl,this.left,this.width),a=this.ctx,s=t.position,o=i.size/2,l=n.top+o;let c,u=this.left,d=this.width;if(this.isHorizontal())d=Math.max(...this.lineWidths),c=this.top+l,u=fe(e.align,u,this.right-d);else{const t=this.columnSizes.reduce(((e,t)=>Math.max(e,t.height)),0);c=l+fe(e.align,this.top,this.bottom-t-e.labels.padding-this._computeTitleHeight())}const h=fe(s,u,u+d);a.textAlign=r.textAlign(he(s)),a.textBaseline="middle",a.strokeStyle=t.color,a.fillStyle=t.color,a.font=i.string,Nt(a,t.text,h,c,i)}_computeTitleHeight(){const e=this.options.title,t=xi(e.font),i=bi(e.padding);return e.display?t.lineHeight+i.height:0}_getLegendItemAt(e,t){let i,n,r;if(ee(e,this.left,this.right)&&ee(t,this.top,this.bottom))for(r=this.legendHitBoxes,i=0;i<r.length;++i)if(n=r[i],ee(e,n.left,n.left+n.width)&&ee(t,n.top,n.top+n.height))return this.legendItems[i];return null}handleEvent(e){const t=this.options;if(!function(e,t){return!("mousemove"!==e&&"mouseout"!==e||!t.onHover&&!t.onLeave)||!(!t.onClick||"click"!==e&&"mouseup"!==e)}(e.type,t))return;const i=this._getLegendItemAt(e.x,e.y);if("mousemove"===e.type||"mouseout"===e.type){const a=this._hoveredItem,s=(r=i,null!==(n=a)&&null!==r&&n.datasetIndex===r.datasetIndex&&n.index===r.index);a&&!s&&d(t.onLeave,[e,a,this],this),this._hoveredItem=i,i&&!s&&d(t.onHover,[e,i,this],this)}else i&&d(t.onClick,[e,i,this],this);var n,r}}function is(e,t){return t*(e.text?e.text.length:0)}var ns={id:"legend",_element:ts,start(e,t,i){const n=e.legend=new ts({ctx:e.ctx,options:i,chart:e});Qi.configure(e,n,i),Qi.addBox(e,n)},stop(e){Qi.removeBox(e,e.legend),delete e.legend},beforeUpdate(e,t,i){const n=e.legend;Qi.configure(e,n,i),n.options=i},afterUpdate(e){const t=e.legend;t.buildLabels(),t.adjustHitBoxes()},afterEvent(e,t){t.replay||e.legend.handleEvent(t.event)},defaults:{display:!0,position:"top",align:"center",fullSize:!0,reverse:!1,weight:1e3,onClick(e,t,i){const n=t.datasetIndex,r=i.chart;r.isDatasetVisible(n)?(r.hide(n),t.hidden=!0):(r.show(n),t.hidden=!1)},onHover:null,onLeave:null,labels:{color:e=>e.chart.options.color,boxWidth:40,padding:10,generateLabels(e){const t=e.data.datasets,{labels:{usePointStyle:i,pointStyle:n,textAlign:r,color:a,useBorderRadius:s,borderRadius:o}}=e.legend.options;return e._getSortedDatasetMetas().map((e=>{const l=e.controller.getStyle(i?0:void 0),c=bi(l.borderWidth);return{text:t[e.index].label,fillStyle:l.backgroundColor,fontColor:a,hidden:!e.visible,lineCap:l.borderCapStyle,lineDash:l.borderDash,lineDashOffset:l.borderDashOffset,lineJoin:l.borderJoinStyle,lineWidth:(c.width+c.height)/4,strokeStyle:l.borderColor,pointStyle:n||l.pointStyle,rotation:l.rotation,textAlign:r||l.textAlign,borderRadius:s&&(o||l.borderRadius),datasetIndex:e.index}}),this)}},title:{color:e=>e.chart.options.color,display:!1,position:"center",text:""}},descriptors:{_scriptable:e=>!e.startsWith("on"),labels:{_scriptable:e=>!["generateLabels","filter","sort"].includes(e)}}};class rs extends Nn{constructor(e){super(),this.chart=e.chart,this.options=e.options,this.ctx=e.ctx,this._padding=void 0,this.top=void 0,this.bottom=void 0,this.left=void 0,this.right=void 0,this.width=void 0,this.height=void 0,this.position=void 0,this.weight=void 0,this.fullSize=void 0}update(e,t){const i=this.options;if(this.left=0,this.top=0,!i.display)return void(this.width=this.height=this.right=this.bottom=0);this.width=this.right=e,this.height=this.bottom=t;const n=r(i.text)?i.text.length:1;this._padding=bi(i.padding);const a=n*xi(i.font).lineHeight+this._padding.height;this.isHorizontal()?this.height=a:this.width=a}isHorizontal(){const e=this.options.position;return"top"===e||"bottom"===e}_drawArgs(e){const{top:t,left:i,bottom:n,right:r,options:a}=this,s=a.align;let o,l,c,u=0;return this.isHorizontal()?(l=fe(s,i,r),c=t+e,o=r-i):("left"===a.position?(l=i+e,c=fe(s,n,t),u=-.5*T):(l=r-e,c=fe(s,t,n),u=.5*T),o=n-t),{titleX:l,titleY:c,maxWidth:o,rotation:u}}draw(){const e=this.ctx,t=this.options;if(!t.display)return;const i=xi(t.font),n=i.lineHeight/2+this._padding.top,{titleX:r,titleY:a,maxWidth:s,rotation:o}=this._drawArgs(n);Nt(e,t.text,0,0,i,{color:t.color,maxWidth:s,rotation:o,textAlign:he(t.align),textBaseline:"middle",translation:[r,a]})}}var as={id:"title",_element:rs,start(e,t,i){!function(e,t){const i=new rs({ctx:e.ctx,options:t,chart:e});Qi.configure(e,i,t),Qi.addBox(e,i),e.titleBlock=i}(e,i)},stop(e){const t=e.titleBlock;Qi.removeBox(e,t),delete e.titleBlock},beforeUpdate(e,t,i){const n=e.titleBlock;Qi.configure(e,n,i),n.options=i},defaults:{align:"center",display:!1,font:{weight:"bold"},fullSize:!0,padding:10,position:"top",text:"",weight:2e3},defaultRoutes:{color:"color"},descriptors:{_scriptable:!0,_indexable:!1}};const ss=new WeakMap;var os={id:"subtitle",start(e,t,i){const n=new rs({ctx:e.ctx,options:i,chart:e});Qi.configure(e,n,i),Qi.addBox(e,n),ss.set(e,n)},stop(e){Qi.removeBox(e,ss.get(e)),ss.delete(e)},beforeUpdate(e,t,i){const n=ss.get(e);Qi.configure(e,n,i),n.options=i},defaults:{align:"center",display:!1,font:{weight:"normal"},fullSize:!0,padding:0,position:"top",text:"",weight:1500},defaultRoutes:{color:"color"},descriptors:{_scriptable:!0,_indexable:!1}};const ls={average(e){if(!e.length)return!1;let t,i,n=new Set,r=0,a=0;for(t=0,i=e.length;t<i;++t){const i=e[t].element;if(i&&i.hasValue()){const e=i.tooltipPosition();n.add(e.x),r+=e.y,++a}}return{x:[...n].reduce(((e,t)=>e+t))/n.size,y:r/a}},nearest(e,t){if(!e.length)return!1;let i,n,r,a=t.x,s=t.y,o=Number.POSITIVE_INFINITY;for(i=0,n=e.length;i<n;++i){const n=e[i].element;if(n&&n.hasValue()){const e=X(t,n.getCenterPoint());e<o&&(o=e,r=n)}}if(r){const e=r.tooltipPosition();a=e.x,s=e.y}return{x:a,y:s}}};function cs(e,t){return t&&(r(t)?Array.prototype.push.apply(e,t):e.push(t)),e}function us(e){return("string"==typeof e||e instanceof String)&&e.indexOf("\n")>-1?e.split("\n"):e}function ds(e,t){const{element:i,datasetIndex:n,index:r}=t,a=e.getDatasetMeta(n).controller,{label:s,value:o}=a.getLabelAndValue(r);return{chart:e,label:s,parsed:a.getParsed(r),raw:e.data.datasets[n].data[r],formattedValue:o,dataset:a.getDataset(),dataIndex:r,datasetIndex:n,element:i}}function hs(e,t){const i=e.chart.ctx,{body:n,footer:r,title:a}=e,{boxWidth:s,boxHeight:o}=t,l=xi(t.bodyFont),c=xi(t.titleFont),u=xi(t.footerFont),d=a.length,f=r.length,p=n.length,m=bi(t.padding);let g=m.height,v=0,y=n.reduce(((e,t)=>e+t.before.length+t.lines.length+t.after.length),0);y+=e.beforeBody.length+e.afterBody.length,d&&(g+=d*c.lineHeight+(d-1)*t.titleSpacing+t.titleMarginBottom),y&&(g+=p*(t.displayColors?Math.max(o,l.lineHeight):l.lineHeight)+(y-p)*l.lineHeight+(y-1)*t.bodySpacing),f&&(g+=t.footerMarginTop+f*u.lineHeight+(f-1)*t.footerSpacing);let b=0;const x=function(e){v=Math.max(v,i.measureText(e).width+b)};return i.save(),i.font=c.string,h(e.title,x),i.font=l.string,h(e.beforeBody.concat(e.afterBody),x),b=t.displayColors?s+2+t.boxPadding:0,h(n,(e=>{h(e.before,x),h(e.lines,x),h(e.after,x)})),b=0,i.font=u.string,h(e.footer,x),i.restore(),v+=m.width,{width:v,height:g}}function fs(e,t,i,n){const{x:r,width:a}=i,{width:s,chartArea:{left:o,right:l}}=e;let c="center";return"center"===n?c=r<=(o+l)/2?"left":"right":r<=a/2?c="left":r>=s-a/2&&(c="right"),function(e,t,i,n){const{x:r,width:a}=n,s=i.caretSize+i.caretPadding;return"left"===e&&r+a+s>t.width||"right"===e&&r-a-s<0||void 0}(c,e,t,i)&&(c="center"),c}function ps(e,t,i){const n=i.yAlign||t.yAlign||function(e,t){const{y:i,height:n}=t;return i<n/2?"top":i>e.height-n/2?"bottom":"center"}(e,i);return{xAlign:i.xAlign||t.xAlign||fs(e,t,i,n),yAlign:n}}function ms(e,t,i,n){const{caretSize:r,caretPadding:a,cornerRadius:s}=e,{xAlign:o,yAlign:l}=i,c=r+a,{topLeft:u,topRight:d,bottomLeft:h,bottomRight:f}=yi(s);let p=function(e,t){let{x:i,width:n}=e;return"right"===t?i-=n:"center"===t&&(i-=n/2),i}(t,o);const m=function(e,t,i){let{y:n,height:r}=e;return"top"===t?n+=i:n-="bottom"===t?r+i:r/2,n}(t,l,c);return"center"===l?"left"===o?p+=c:"right"===o&&(p-=c):"left"===o?p-=Math.max(u,h)+r:"right"===o&&(p+=Math.max(d,f)+r),{x:J(p,0,n.width-t.width),y:J(m,0,n.height-t.height)}}function gs(e,t,i){const n=bi(i.padding);return"center"===t?e.x+e.width/2:"right"===t?e.x+e.width-n.right:e.x+n.left}function vs(e){return cs([],us(e))}function ys(e,t){const i=t&&t.dataset&&t.dataset.tooltip&&t.dataset.tooltip.callbacks;return i?e.override(i):e}const bs={beforeTitle:t,title(e){if(e.length>0){const t=e[0],i=t.chart.data.labels,n=i?i.length:0;if(this&&this.options&&"dataset"===this.options.mode)return t.dataset.label||"";if(t.label)return t.label;if(n>0&&t.dataIndex<n)return i[t.dataIndex]}return""},afterTitle:t,beforeBody:t,beforeLabel:t,label(e){if(this&&this.options&&"dataset"===this.options.mode)return e.label+": "+e.formattedValue||e.formattedValue;let t=e.dataset.label||"";t&&(t+=": ");const i=e.formattedValue;return n(i)||(t+=i),t},labelColor(e){const t=e.chart.getDatasetMeta(e.datasetIndex).controller.getStyle(e.dataIndex);return{borderColor:t.borderColor,backgroundColor:t.backgroundColor,borderWidth:t.borderWidth,borderDash:t.borderDash,borderDashOffset:t.borderDashOffset,borderRadius:0}},labelTextColor(){return this.options.bodyColor},labelPointStyle(e){const t=e.chart.getDatasetMeta(e.datasetIndex).controller.getStyle(e.dataIndex);return{pointStyle:t.pointStyle,rotation:t.rotation}},afterLabel:t,afterBody:t,beforeFooter:t,footer:t,afterFooter:t};function xs(e,t,i,n){const r=e[t].call(i,n);return void 0===r?bs[t].call(i,n):r}class _s extends Nn{static positioners=ls;constructor(e){super(),this.opacity=0,this._active=[],this._eventPosition=void 0,this._size=void 0,this._cachedAnimations=void 0,this._tooltipItems=[],this.$animations=void 0,this.$context=void 0,this.chart=e.chart,this.options=e.options,this.dataPoints=void 0,this.title=void 0,this.beforeBody=void 0,this.body=void 0,this.afterBody=void 0,this.footer=void 0,this.xAlign=void 0,this.yAlign=void 0,this.x=void 0,this.y=void 0,this.height=void 0,this.width=void 0,this.caretX=void 0,this.caretY=void 0,this.labelColors=void 0,this.labelPointStyles=void 0,this.labelTextColors=void 0}initialize(e){this.options=e,this._cachedAnimations=void 0,this.$context=void 0}_resolveAnimations(){const e=this._cachedAnimations;if(e)return e;const t=this.chart,i=this.options.setContext(this.getContext()),n=i.enabled&&t.options.animation&&i.animations,r=new kn(this.chart,n);return n._cacheable&&(this._cachedAnimations=Object.freeze(r)),r}getContext(){return this.$context||(this.$context=ki(this.chart.getContext(),{tooltip:this,tooltipItems:this._tooltipItems,type:"tooltip"}))}getTitle(e,t){const{callbacks:i}=t,n=xs(i,"beforeTitle",this,e),r=xs(i,"title",this,e),a=xs(i,"afterTitle",this,e);let s=[];return s=cs(s,us(n)),s=cs(s,us(r)),s=cs(s,us(a)),s}getBeforeBody(e,t){return vs(xs(t.callbacks,"beforeBody",this,e))}getBody(e,t){const{callbacks:i}=t,n=[];return h(e,(e=>{const t={before:[],lines:[],after:[]},r=ys(i,e);cs(t.before,us(xs(r,"beforeLabel",this,e))),cs(t.lines,xs(r,"label",this,e)),cs(t.after,us(xs(r,"afterLabel",this,e))),n.push(t)})),n}getAfterBody(e,t){return vs(xs(t.callbacks,"afterBody",this,e))}getFooter(e,t){const{callbacks:i}=t,n=xs(i,"beforeFooter",this,e),r=xs(i,"footer",this,e),a=xs(i,"afterFooter",this,e);let s=[];return s=cs(s,us(n)),s=cs(s,us(r)),s=cs(s,us(a)),s}_createItems(e){const t=this._active,i=this.chart.data,n=[],r=[],a=[];let s,o,l=[];for(s=0,o=t.length;s<o;++s)l.push(ds(this.chart,t[s]));return e.filter&&(l=l.filter(((t,n,r)=>e.filter(t,n,r,i)))),e.itemSort&&(l=l.sort(((t,n)=>e.itemSort(t,n,i)))),h(l,(t=>{const i=ys(e.callbacks,t);n.push(xs(i,"labelColor",this,t)),r.push(xs(i,"labelPointStyle",this,t)),a.push(xs(i,"labelTextColor",this,t))})),this.labelColors=n,this.labelPointStyles=r,this.labelTextColors=a,this.dataPoints=l,l}update(e,t){const i=this.options.setContext(this.getContext()),n=this._active;let r,a=[];if(n.length){const e=ls[i.position].call(this,n,this._eventPosition);a=this._createItems(i),this.title=this.getTitle(a,i),this.beforeBody=this.getBeforeBody(a,i),this.body=this.getBody(a,i),this.afterBody=this.getAfterBody(a,i),this.footer=this.getFooter(a,i);const t=this._size=hs(this,i),s=Object.assign({},e,t),o=ps(this.chart,i,s),l=ms(i,s,o,this.chart);this.xAlign=o.xAlign,this.yAlign=o.yAlign,r={opacity:1,x:l.x,y:l.y,width:t.width,height:t.height,caretX:e.x,caretY:e.y}}else 0!==this.opacity&&(r={opacity:0});this._tooltipItems=a,this.$context=void 0,r&&this._resolveAnimations().update(this,r),e&&i.external&&i.external.call(this,{chart:this.chart,tooltip:this,replay:t})}drawCaret(e,t,i,n){const r=this.getCaretPosition(e,i,n);t.lineTo(r.x1,r.y1),t.lineTo(r.x2,r.y2),t.lineTo(r.x3,r.y3)}getCaretPosition(e,t,i){const{xAlign:n,yAlign:r}=this,{caretSize:a,cornerRadius:s}=i,{topLeft:o,topRight:l,bottomLeft:c,bottomRight:u}=yi(s),{x:d,y:h}=e,{width:f,height:p}=t;let m,g,v,y,b,x;return"center"===r?(b=h+p/2,"left"===n?(m=d,g=m-a,y=b+a,x=b-a):(m=d+f,g=m+a,y=b-a,x=b+a),v=m):(g="left"===n?d+Math.max(o,c)+a:"right"===n?d+f-Math.max(l,u)-a:this.caretX,"top"===r?(y=h,b=y-a,m=g-a,v=g+a):(y=h+p,b=y+a,m=g+a,v=g-a),x=y),{x1:m,x2:g,x3:v,y1:y,y2:b,y3:x}}drawTitle(e,t,i){const n=this.title,r=n.length;let a,s,o;if(r){const l=Mi(i.rtl,this.x,this.width);for(e.x=gs(this,i.titleAlign,i),t.textAlign=l.textAlign(i.titleAlign),t.textBaseline="middle",a=xi(i.titleFont),s=i.titleSpacing,t.fillStyle=i.titleColor,t.font=a.string,o=0;o<r;++o)t.fillText(n[o],l.x(e.x),e.y+a.lineHeight/2),e.y+=a.lineHeight+s,o+1===r&&(e.y+=i.titleMarginBottom-s)}}_drawColorBox(e,t,i,n,r){const s=this.labelColors[i],o=this.labelPointStyles[i],{boxHeight:l,boxWidth:c}=r,u=xi(r.bodyFont),d=gs(this,"left",r),h=n.x(d),f=l<u.lineHeight?(u.lineHeight-l)/2:0,p=t.y+f;if(r.usePointStyle){const t={radius:Math.min(c,l)/2,pointStyle:o.pointStyle,rotation:o.rotation,borderWidth:1},i=n.leftForLtr(h,c)+c/2,a=p+l/2;e.strokeStyle=r.multiKeyBackground,e.fillStyle=r.multiKeyBackground,Lt(e,t,i,a),e.strokeStyle=s.borderColor,e.fillStyle=s.backgroundColor,Lt(e,t,i,a)}else{e.lineWidth=a(s.borderWidth)?Math.max(...Object.values(s.borderWidth)):s.borderWidth||1,e.strokeStyle=s.borderColor,e.setLineDash(s.borderDash||[]),e.lineDashOffset=s.borderDashOffset||0;const t=n.leftForLtr(h,c),i=n.leftForLtr(n.xPlus(h,1),c-2),o=yi(s.borderRadius);Object.values(o).some((e=>0!==e))?(e.beginPath(),e.fillStyle=r.multiKeyBackground,jt(e,{x:t,y:p,w:c,h:l,radius:o}),e.fill(),e.stroke(),e.fillStyle=s.backgroundColor,e.beginPath(),jt(e,{x:i,y:p+1,w:c-2,h:l-2,radius:o}),e.fill()):(e.fillStyle=r.multiKeyBackground,e.fillRect(t,p,c,l),e.strokeRect(t,p,c,l),e.fillStyle=s.backgroundColor,e.fillRect(i,p+1,c-2,l-2))}e.fillStyle=this.labelTextColors[i]}drawBody(e,t,i){const{body:n}=this,{bodySpacing:r,bodyAlign:a,displayColors:s,boxHeight:o,boxWidth:l,boxPadding:c}=i,u=xi(i.bodyFont);let d=u.lineHeight,f=0;const p=Mi(i.rtl,this.x,this.width),m=function(i){t.fillText(i,p.x(e.x+f),e.y+d/2),e.y+=d+r},g=p.textAlign(a);let v,y,b,x,_,w,k;for(t.textAlign=a,t.textBaseline="middle",t.font=u.string,e.x=gs(this,g,i),t.fillStyle=i.bodyColor,h(this.beforeBody,m),f=s&&"right"!==g?"center"===a?l/2+c:l+2+c:0,x=0,w=n.length;x<w;++x){for(v=n[x],y=this.labelTextColors[x],t.fillStyle=y,h(v.before,m),b=v.lines,s&&b.length&&(this._drawColorBox(t,e,x,p,i),d=Math.max(u.lineHeight,o)),_=0,k=b.length;_<k;++_)m(b[_]),d=u.lineHeight;h(v.after,m)}f=0,d=u.lineHeight,h(this.afterBody,m),e.y-=r}drawFooter(e,t,i){const n=this.footer,r=n.length;let a,s;if(r){const o=Mi(i.rtl,this.x,this.width);for(e.x=gs(this,i.footerAlign,i),e.y+=i.footerMarginTop,t.textAlign=o.textAlign(i.footerAlign),t.textBaseline="middle",a=xi(i.footerFont),t.fillStyle=i.footerColor,t.font=a.string,s=0;s<r;++s)t.fillText(n[s],o.x(e.x),e.y+a.lineHeight/2),e.y+=a.lineHeight+i.footerSpacing}}drawBackground(e,t,i,n){const{xAlign:r,yAlign:a}=this,{x:s,y:o}=e,{width:l,height:c}=i,{topLeft:u,topRight:d,bottomLeft:h,bottomRight:f}=yi(n.cornerRadius);t.fillStyle=n.backgroundColor,t.strokeStyle=n.borderColor,t.lineWidth=n.borderWidth,t.beginPath(),t.moveTo(s+u,o),"top"===a&&this.drawCaret(e,t,i,n),t.lineTo(s+l-d,o),t.quadraticCurveTo(s+l,o,s+l,o+d),"center"===a&&"right"===r&&this.drawCaret(e,t,i,n),t.lineTo(s+l,o+c-f),t.quadraticCurveTo(s+l,o+c,s+l-f,o+c),"bottom"===a&&this.drawCaret(e,t,i,n),t.lineTo(s+h,o+c),t.quadraticCurveTo(s,o+c,s,o+c-h),"center"===a&&"left"===r&&this.drawCaret(e,t,i,n),t.lineTo(s,o+u),t.quadraticCurveTo(s,o,s+u,o),t.closePath(),t.fill(),n.borderWidth>0&&t.stroke()}_updateAnimationTarget(e){const t=this.chart,i=this.$animations,n=i&&i.x,r=i&&i.y;if(n||r){const i=ls[e.position].call(this,this._active,this._eventPosition);if(!i)return;const a=this._size=hs(this,e),s=Object.assign({},i,this._size),o=ps(t,e,s),l=ms(e,s,o,t);n._to===l.x&&r._to===l.y||(this.xAlign=o.xAlign,this.yAlign=o.yAlign,this.width=a.width,this.height=a.height,this.caretX=i.x,this.caretY=i.y,this._resolveAnimations().update(this,l))}}_willRender(){return!!this.opacity}draw(e){const t=this.options.setContext(this.getContext());let i=this.opacity;if(!i)return;this._updateAnimationTarget(t);const n={width:this.width,height:this.height},r={x:this.x,y:this.y};i=Math.abs(i)<.001?0:i;const a=bi(t.padding),s=this.title.length||this.beforeBody.length||this.body.length||this.afterBody.length||this.footer.length;t.enabled&&s&&(e.save(),e.globalAlpha=i,this.drawBackground(r,e,n,t),Si(e,t.textDirection),r.y+=a.top,this.drawTitle(r,e,t),this.drawBody(r,e,t),this.drawFooter(r,e,t),Ai(e,t.textDirection),e.restore())}getActiveElements(){return this._active||[]}setActiveElements(e,t){const i=this._active,n=e.map((({datasetIndex:e,index:t})=>{const i=this.chart.getDatasetMeta(e);if(!i)throw new Error("Cannot find a dataset at index "+e);return{datasetIndex:e,element:i.data[t],index:t}})),r=!f(i,n),a=this._positionChanged(n,t);(r||a)&&(this._active=n,this._eventPosition=t,this._ignoreReplayEvents=!0,this.update(!0))}handleEvent(e,t,i=!0){if(t&&this._ignoreReplayEvents)return!1;this._ignoreReplayEvents=!1;const n=this.options,r=this._active||[],a=this._getActiveElements(e,r,t,i),s=this._positionChanged(a,e),o=t||!f(a,r)||s;return o&&(this._active=a,(n.enabled||n.external)&&(this._eventPosition={x:e.x,y:e.y},this.update(!0,t))),o}_getActiveElements(e,t,i,n){const r=this.options;if("mouseout"===e.type)return[];if(!n)return t.filter((e=>this.chart.data.datasets[e.datasetIndex]&&void 0!==this.chart.getDatasetMeta(e.datasetIndex).controller.getParsed(e.index)));const a=this.chart.getElementsAtEventForMode(e,r.mode,r,i);return r.reverse&&a.reverse(),a}_positionChanged(e,t){const{caretX:i,caretY:n,options:r}=this,a=ls[r.position].call(this,e,t);return!1!==a&&(i!==a.x||n!==a.y)}}var ws={id:"tooltip",_element:_s,positioners:ls,afterInit(e,t,i){i&&(e.tooltip=new _s({chart:e,options:i}))},beforeUpdate(e,t,i){e.tooltip&&e.tooltip.initialize(i)},reset(e,t,i){e.tooltip&&e.tooltip.initialize(i)},afterDraw(e){const t=e.tooltip;if(t&&t._willRender()){const i={tooltip:t};if(!1===e.notifyPlugins("beforeTooltipDraw",{...i,cancelable:!0}))return;t.draw(e.ctx),e.notifyPlugins("afterTooltipDraw",i)}},afterEvent(e,t){if(e.tooltip){const i=t.replay;e.tooltip.handleEvent(t.event,i,t.inChartArea)&&(t.changed=!0)}},defaults:{enabled:!0,external:null,position:"average",backgroundColor:"rgba(0,0,0,0.8)",titleColor:"#fff",titleFont:{weight:"bold"},titleSpacing:2,titleMarginBottom:6,titleAlign:"left",bodyColor:"#fff",bodySpacing:2,bodyFont:{},bodyAlign:"left",footerColor:"#fff",footerSpacing:2,footerMarginTop:6,footerFont:{weight:"bold"},footerAlign:"left",padding:6,caretPadding:2,caretSize:5,cornerRadius:6,boxHeight:(e,t)=>t.bodyFont.size,boxWidth:(e,t)=>t.bodyFont.size,multiKeyBackground:"#fff",displayColors:!0,boxPadding:0,borderColor:"rgba(0,0,0,0)",borderWidth:0,animation:{duration:400,easing:"easeOutQuart"},animations:{numbers:{type:"number",properties:["x","y","width","height","caretX","caretY"]},opacity:{easing:"linear",duration:200}},callbacks:bs},defaultRoutes:{bodyFont:"font",footerFont:"font",titleFont:"font"},descriptors:{_scriptable:e=>"filter"!==e&&"itemSort"!==e&&"external"!==e,_indexable:!1,callbacks:{_scriptable:!1,_indexable:!1},animation:{_fallback:!1},animations:{_fallback:"animation"}},additionalOptionScopes:["interaction"]};return _r.register(Nr,La,ea,e),_r.helpers={...Ii},_r._adapters=Sr,_r.Animation=wn,_r.Animations=kn,_r.animator=ve,_r.controllers=Xn.controllers.items,_r.DatasetController=In,_r.Element=Nn,_r.elements=ea,_r.Interaction=zi,_r.layouts=Qi,_r.platforms=bn,_r.Scale=qn,_r.Ticks=it,Object.assign(_r,Nr,La,ea,e,bn),_r.Chart=_r,"undefined"!=typeof window&&(window.Chart=_r),_r})),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports):"function"==typeof define&&define.amd?define(["exports"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).countUp={})}(this,(function(e){"use strict";var t=function(){return t=Object.assign||function(e){for(var t,i=1,n=arguments.length;i<n;i++)for(var r in t=arguments[i])Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r]);return e},t.apply(this,arguments)},i=function(){function e(e,i,n){var r=this;this.endVal=i,this.options=n,this.version="2.8.0",this.defaults={startVal:0,decimalPlaces:0,duration:2,useEasing:!0,useGrouping:!0,useIndianSeparators:!1,smartEasingThreshold:999,smartEasingAmount:333,separator:",",decimal:".",prefix:"",suffix:"",enableScrollSpy:!1,scrollSpyDelay:200,scrollSpyOnce:!1},this.finalEndVal=null,this.useEasing=!0,this.countDown=!1,this.error="",this.startVal=0,this.paused=!0,this.once=!1,this.count=function(e){r.startTime||(r.startTime=e);var t=e-r.startTime;r.remaining=r.duration-t,r.useEasing?r.countDown?r.frameVal=r.startVal-r.easingFn(t,0,r.startVal-r.endVal,r.duration):r.frameVal=r.easingFn(t,r.startVal,r.endVal-r.startVal,r.duration):r.frameVal=r.startVal+(r.endVal-r.startVal)*(t/r.duration);var i=r.countDown?r.frameVal<r.endVal:r.frameVal>r.endVal;r.frameVal=i?r.endVal:r.frameVal,r.frameVal=Number(r.frameVal.toFixed(r.options.decimalPlaces)),r.printValue(r.frameVal),t<r.duration?r.rAF=requestAnimationFrame(r.count):null!==r.finalEndVal?r.update(r.finalEndVal):r.options.onCompleteCallback&&r.options.onCompleteCallback()},this.formatNumber=function(e){var t,i,n,a,s=e<0?"-":"";t=Math.abs(e).toFixed(r.options.decimalPlaces);var o=(t+="").split(".");if(i=o[0],n=o.length>1?r.options.decimal+o[1]:"",r.options.useGrouping){a="";for(var l=3,c=0,u=0,d=i.length;u<d;++u)r.options.useIndianSeparators&&4===u&&(l=2,c=1),0!==u&&c%l==0&&(a=r.options.separator+a),c++,a=i[d-u-1]+a;i=a}return r.options.numerals&&r.options.numerals.length&&(i=i.replace(/[0-9]/g,(function(e){return r.options.numerals[+e]})),n=n.replace(/[0-9]/g,(function(e){return r.options.numerals[+e]}))),s+r.options.prefix+i+n+r.options.suffix},this.easeOutExpo=function(e,t,i,n){return i*(1-Math.pow(2,-10*e/n))*1024/1023+t},this.options=t(t({},this.defaults),n),this.formattingFn=this.options.formattingFn?this.options.formattingFn:this.formatNumber,this.easingFn=this.options.easingFn?this.options.easingFn:this.easeOutExpo,this.startVal=this.validateValue(this.options.startVal),this.frameVal=this.startVal,this.endVal=this.validateValue(i),this.options.decimalPlaces=Math.max(this.options.decimalPlaces),this.resetDuration(),this.options.separator=String(this.options.separator),this.useEasing=this.options.useEasing,""===this.options.separator&&(this.options.useGrouping=!1),this.el="string"==typeof e?document.getElementById(e):e,this.el?this.printValue(this.startVal):this.error="[CountUp] target is null or undefined","undefined"!=typeof window&&this.options.enableScrollSpy&&(this.error?console.error(this.error,e):(window.onScrollFns=window.onScrollFns||[],window.onScrollFns.push((function(){return r.handleScroll(r)})),window.onscroll=function(){window.onScrollFns.forEach((function(e){return e()}))},this.handleScroll(this)))}return e.prototype.handleScroll=function(e){if(e&&window&&!e.once){var t=window.innerHeight+window.scrollY,i=e.el.getBoundingClientRect(),n=i.top+window.pageYOffset,r=i.top+i.height+window.pageYOffset;r<t&&r>window.scrollY&&e.paused?(e.paused=!1,setTimeout((function(){return e.start()}),e.options.scrollSpyDelay),e.options.scrollSpyOnce&&(e.once=!0)):(window.scrollY>r||n>t)&&!e.paused&&e.reset()}},e.prototype.determineDirectionAndSmartEasing=function(){var e=this.finalEndVal?this.finalEndVal:this.endVal;this.countDown=this.startVal>e;var t=e-this.startVal;if(Math.abs(t)>this.options.smartEasingThreshold&&this.options.useEasing){this.finalEndVal=e;var i=this.countDown?1:-1;this.endVal=e+i*this.options.smartEasingAmount,this.duration=this.duration/2}else this.endVal=e,this.finalEndVal=null;null!==this.finalEndVal?this.useEasing=!1:this.useEasing=this.options.useEasing},e.prototype.start=function(e){this.error||(this.options.onStartCallback&&this.options.onStartCallback(),e&&(this.options.onCompleteCallback=e),this.duration>0?(this.determineDirectionAndSmartEasing(),this.paused=!1,this.rAF=requestAnimationFrame(this.count)):this.printValue(this.endVal))},e.prototype.pauseResume=function(){this.paused?(this.startTime=null,this.duration=this.remaining,this.startVal=this.frameVal,this.determineDirectionAndSmartEasing(),this.rAF=requestAnimationFrame(this.count)):cancelAnimationFrame(this.rAF),this.paused=!this.paused},e.prototype.reset=function(){cancelAnimationFrame(this.rAF),this.paused=!0,this.resetDuration(),this.startVal=this.validateValue(this.options.startVal),this.frameVal=this.startVal,this.printValue(this.startVal)},e.prototype.update=function(e){cancelAnimationFrame(this.rAF),this.startTime=null,this.endVal=this.validateValue(e),this.endVal!==this.frameVal&&(this.startVal=this.frameVal,null==this.finalEndVal&&this.resetDuration(),this.finalEndVal=null,this.determineDirectionAndSmartEasing(),this.rAF=requestAnimationFrame(this.count))},e.prototype.printValue=function(e){var t;if(this.el){var i=this.formattingFn(e);(null===(t=this.options.plugin)||void 0===t?void 0:t.render)?this.options.plugin.render(this.el,i):"INPUT"===this.el.tagName?this.el.value=i:"text"===this.el.tagName||"tspan"===this.el.tagName?this.el.textContent=i:this.el.innerHTML=i}},e.prototype.ensureNumber=function(e){return"number"==typeof e&&!isNaN(e)},e.prototype.validateValue=function(e){var t=Number(e);return this.ensureNumber(t)?t:(this.error="[CountUp] invalid start or end value: ".concat(e),null)},e.prototype.resetDuration=function(){this.startTime=null,this.duration=1e3*Number(this.options.duration),this.remaining=this.duration},e}();e.CountUp=i,Object.defineProperty(e,"__esModule",{value:!0})})),function(e){function t(){for(var e=0;e<w.length;e++)w[e][0](w[e][1]);w=[],m=!1}function i(e,i){w.push([e,i]),m||(m=!0,_(t,0))}function n(e){var t=(i=e.owner).state_,i=i.data_,n=e[t];if(e=e.then,"function"==typeof n){t=y;try{i=n(i)}catch(t){o(e,t)}}r(e,i)||(t===y&&a(e,i),t===b&&o(e,i))}function r(e,t){var i;try{if(e===t)throw new TypeError("A promises callback cannot return that same promise.");if(t&&("function"==typeof t||"object"==typeof t)){var n=t.then;if("function"==typeof n)return n.call(t,(function(n){i||(i=!0,t!==n?a(e,n):s(e,n))}),(function(t){i||(i=!0,o(e,t))})),!0}}catch(t){return i||o(e,t),!0}return!1}function a(e,t){e!==t&&r(e,t)||s(e,t)}function s(e,t){e.state_===g&&(e.state_=v,e.data_=t,i(c,e))}function o(e,t){e.state_===g&&(e.state_=v,e.data_=t,i(u,e))}function l(e){var t=e.then_;for(e.then_=void 0,e=0;e<t.length;e++)n(t[e])}function c(e){e.state_=y,l(e)}function u(e){e.state_=b,l(e)}function d(e){if("function"!=typeof e)throw new TypeError("Promise constructor takes a function argument");if(!1==this instanceof d)throw new TypeError("Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.");this.then_=[],function(e,t){function i(e){o(t,e)}try{e((function(e){a(t,e)}),i)}catch(e){i(e)}}(e,this)}var h,f=e.Promise,p=f&&"resolve"in f&&"reject"in f&&"all"in f&&"race"in f&&(new f((function(e){h=e})),"function"==typeof h);"undefined"!=typeof exports&&exports?(exports.Promise=p?f:d,exports.Polyfill=d):"function"==typeof define&&define.amd?define((function(){return p?f:d})):p||(e.Promise=d);var m,g="pending",v="sealed",y="fulfilled",b="rejected",x=function(){},_="undefined"!=typeof setImmediate?setImmediate:setTimeout,w=[];d.prototype={constructor:d,state_:g,then_:null,data_:void 0,then:function(e,t){var r={owner:this,then:new this.constructor(x),fulfilled:e,rejected:t};return this.state_===y||this.state_===b?i(n,r):this.then_.push(r),r.then},catch:function(e){return this.then(null,e)}},d.all=function(e){if("[object Array]"!==Object.prototype.toString.call(e))throw new TypeError("You must pass an array to Promise.all().");return new this((function(t,i){function n(e){return s++,function(i){a[e]=i,--s||t(a)}}for(var r,a=[],s=0,o=0;o<e.length;o++)(r=e[o])&&"function"==typeof r.then?r.then(n(o),i):a[o]=r;s||t(a)}))},d.race=function(e){if("[object Array]"!==Object.prototype.toString.call(e))throw new TypeError("You must pass an array to Promise.race().");return new this((function(t,i){for(var n,r=0;r<e.length;r++)(n=e[r])&&"function"==typeof n.then?n.then(t,i):t(n)}))},d.resolve=function(e){return e&&"object"==typeof e&&e.constructor===this?e:new this((function(t){t(e)}))},d.reject=function(e){return new this((function(t,i){i(e)}))}}("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this),function(e,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):(e=e||self).Sweetalert2=t()}(this,(function(){"use strict";const e="SweetAlert2:",t=e=>e.charAt(0).toUpperCase()+e.slice(1),i=e=>Array.prototype.slice.call(e),n=t=>{console.warn("".concat(e," ").concat("object"==typeof t?t.join(" "):t))},r=t=>{console.error("".concat(e," ").concat(t))},a=[],s=(e,t)=>{e='"'.concat(e,'" is deprecated and will be removed in the next major release. Please use "').concat(t,'" instead.'),a.includes(e)||(a.push(e),n(e))},o=e=>"function"==typeof e?e():e,l=e=>e&&"function"==typeof e.toPromise,c=e=>l(e)?e.toPromise():Promise.resolve(e),u=e=>e&&Promise.resolve(e)===e,d={title:"",titleText:"",text:"",html:"",footer:"",icon:void 0,iconColor:void 0,iconHtml:void 0,template:void 0,toast:!1,showClass:{popup:"swal2-show",backdrop:"swal2-backdrop-show",icon:"swal2-icon-show"},hideClass:{popup:"swal2-hide",backdrop:"swal2-backdrop-hide",icon:"swal2-icon-hide"},customClass:{},target:"body",color:void 0,backdrop:!0,heightAuto:!0,allowOutsideClick:!0,allowEscapeKey:!0,allowEnterKey:!0,stopKeydownPropagation:!0,keydownListenerCapture:!1,showConfirmButton:!0,showDenyButton:!1,showCancelButton:!1,preConfirm:void 0,preDeny:void 0,confirmButtonText:"OK",confirmButtonAriaLabel:"",confirmButtonColor:void 0,denyButtonText:"No",denyButtonAriaLabel:"",denyButtonColor:void 0,cancelButtonText:"Cancel",cancelButtonAriaLabel:"",cancelButtonColor:void 0,buttonsStyling:!0,reverseButtons:!1,focusConfirm:!0,focusDeny:!1,focusCancel:!1,returnFocus:!0,showCloseButton:!1,closeButtonHtml:"&times;",closeButtonAriaLabel:"Close this dialog",loaderHtml:"",showLoaderOnConfirm:!1,showLoaderOnDeny:!1,imageUrl:void 0,imageWidth:void 0,imageHeight:void 0,imageAlt:"",timer:void 0,timerProgressBar:!1,width:void 0,padding:void 0,background:void 0,input:void 0,inputPlaceholder:"",inputLabel:"",inputValue:"",inputOptions:{},inputAutoTrim:!0,inputAttributes:{},inputValidator:void 0,returnInputValueOnDeny:!1,validationMessage:void 0,grow:!1,position:"center",progressSteps:[],currentProgressStep:void 0,progressStepsDistance:void 0,willOpen:void 0,didOpen:void 0,didRender:void 0,willClose:void 0,didClose:void 0,didDestroy:void 0,scrollbarPadding:!0},h=["allowEscapeKey","allowOutsideClick","background","buttonsStyling","cancelButtonAriaLabel","cancelButtonColor","cancelButtonText","closeButtonAriaLabel","closeButtonHtml","color","confirmButtonAriaLabel","confirmButtonColor","confirmButtonText","currentProgressStep","customClass","denyButtonAriaLabel","denyButtonColor","denyButtonText","didClose","didDestroy","footer","hideClass","html","icon","iconColor","iconHtml","imageAlt","imageHeight","imageUrl","imageWidth","preConfirm","preDeny","progressSteps","returnFocus","reverseButtons","showCancelButton","showCloseButton","showConfirmButton","showDenyButton","text","title","titleText","willClose"],f={},p=["allowOutsideClick","allowEnterKey","backdrop","focusConfirm","focusDeny","focusCancel","returnFocus","heightAuto","keydownListenerCapture"],m=e=>Object.prototype.hasOwnProperty.call(d,e),g=e=>-1!==h.indexOf(e),v=e=>f[e];var y=e=>{const t={};for(const i in e)t[e[i]]="swal2-"+e[i];return t};const b=y(["container","shown","height-auto","iosfix","popup","modal","no-backdrop","no-transition","toast","toast-shown","show","hide","close","title","html-container","actions","confirm","deny","cancel","default-outline","footer","icon","icon-content","image","input","file","range","select","radio","checkbox","label","textarea","inputerror","input-label","validation-message","progress-steps","active-progress-step","progress-step","progress-step-line","loader","loading","styled","top","top-start","top-end","top-left","top-right","center","center-start","center-end","center-left","center-right","bottom","bottom-start","bottom-end","bottom-left","bottom-right","grow-row","grow-column","grow-fullscreen","rtl","timer-progress-bar","timer-progress-bar-container","scrollbar-measure","icon-success","icon-warning","icon-info","icon-question","icon-error"]),x=y(["success","warning","info","question","error"]),_=()=>document.body.querySelector(".".concat(b.container)),w=e=>{const t=_();return t?t.querySelector(e):null},k=e=>w(".".concat(e)),M=()=>k(b.popup),S=()=>k(b.icon),A=()=>k(b.title),L=()=>k(b["html-container"]),T=()=>k(b.image),C=()=>k(b["progress-steps"]),D=()=>k(b["validation-message"]),E=()=>w(".".concat(b.actions," .").concat(b.confirm)),O=()=>w(".".concat(b.actions," .").concat(b.deny)),P=()=>w(".".concat(b.loader)),Y=()=>w(".".concat(b.actions," .").concat(b.cancel)),I=()=>k(b.actions),N=()=>k(b.footer),j=()=>k(b["timer-progress-bar"]),H=()=>k(b.close),F=()=>{const e=i(M().querySelectorAll('[tabindex]:not([tabindex="-1"]):not([tabindex="0"])')).sort(((e,t)=>(e=parseInt(e.getAttribute("tabindex")),(t=parseInt(t.getAttribute("tabindex")))<e?1:e<t?-1:0)));var t=i(M().querySelectorAll('\n  a[href],\n  area[href],\n  input:not([disabled]),\n  select:not([disabled]),\n  textarea:not([disabled]),\n  button:not([disabled]),\n  iframe,\n  object,\n  embed,\n  [tabindex="0"],\n  [contenteditable],\n  audio[controls],\n  video[controls],\n  summary\n')).filter((e=>"-1"!==e.getAttribute("tabindex")));return(e=>{const t=[];for(let i=0;i<e.length;i++)-1===t.indexOf(e[i])&&t.push(e[i]);return t})(e.concat(t)).filter((e=>re(e)))},R=()=>U(document.body,b.shown)&&!U(document.body,b["toast-shown"])&&!U(document.body,b["no-backdrop"]),z=()=>M()&&U(M(),b.toast);function B(e){var t=1<arguments.length&&void 0!==arguments[1]&&arguments[1];const i=j();re(i)&&(t&&(i.style.transition="none",i.style.width="100%"),setTimeout((()=>{i.style.transition="width ".concat(e/1e3,"s linear"),i.style.width="0%"}),10))}const V={previousBodyPadding:null},W=(e,t)=>{if(e.textContent="",t){const n=(new DOMParser).parseFromString(t,"text/html");i(n.querySelector("head").childNodes).forEach((t=>{e.appendChild(t)})),i(n.querySelector("body").childNodes).forEach((t=>{e.appendChild(t)}))}},U=(e,t)=>{if(!t)return!1;var i=t.split(/\s+/);for(let t=0;t<i.length;t++)if(!e.classList.contains(i[t]))return!1;return!0},q=(e,t,r)=>{if(((e,t)=>{i(e.classList).forEach((i=>{Object.values(b).includes(i)||Object.values(x).includes(i)||Object.values(t.showClass).includes(i)||e.classList.remove(i)}))})(e,t),t.customClass&&t.customClass[r]){if("string"!=typeof t.customClass[r]&&!t.customClass[r].forEach)return n("Invalid type of customClass.".concat(r,'! Expected string or iterable object, got "').concat(typeof t.customClass[r],'"'));Z(e,t.customClass[r])}},$=(e,t)=>{if(!t)return null;switch(t){case"select":case"textarea":case"file":return e.querySelector(".".concat(b.popup," > .").concat(b[t]));case"checkbox":return e.querySelector(".".concat(b.popup," > .").concat(b.checkbox," input"));case"radio":return e.querySelector(".".concat(b.popup," > .").concat(b.radio," input:checked"))||e.querySelector(".".concat(b.popup," > .").concat(b.radio," input:first-child"));case"range":return e.querySelector(".".concat(b.popup," > .").concat(b.range," input"));default:return e.querySelector(".".concat(b.popup," > .").concat(b.input))}},X=e=>{var t;e.focus(),"file"!==e.type&&(t=e.value,e.value="",e.value=t)},G=(e,t,i)=>{e&&t&&(t="string"==typeof t?t.split(/\s+/).filter(Boolean):t).forEach((t=>{Array.isArray(e)?e.forEach((e=>{i?e.classList.add(t):e.classList.remove(t)})):i?e.classList.add(t):e.classList.remove(t)}))},Z=(e,t)=>{G(e,t,!0)},K=(e,t)=>{G(e,t,!1)},J=(e,t)=>{var n=i(e.childNodes);for(let e=0;e<n.length;e++)if(U(n[e],t))return n[e]},Q=(e,t,i)=>{(i=i==="".concat(parseInt(i))?parseInt(i):i)||0===parseInt(i)?e.style[t]="number"==typeof i?"".concat(i,"px"):i:e.style.removeProperty(t)},ee=function(e){e.style.display=1<arguments.length&&void 0!==arguments[1]?arguments[1]:"flex"},te=e=>{e.style.display="none"},ie=(e,t,i,n)=>{const r=e.querySelector(t);r&&(r.style[i]=n)},ne=(e,t,i)=>{t?ee(e,i):te(e)},re=e=>!(!e||!(e.offsetWidth||e.offsetHeight||e.getClientRects().length)),ae=e=>!!(e.scrollHeight>e.clientHeight),se=e=>{const t=window.getComputedStyle(e);e=parseFloat(t.getPropertyValue("animation-duration")||"0");var i=parseFloat(t.getPropertyValue("transition-duration")||"0");return 0<e||0<i},oe=()=>"undefined"==typeof window||"undefined"==typeof document,le={},ce=e=>new Promise((t=>{if(!e)return t();var i=window.scrollX,n=window.scrollY;le.restoreFocusTimeout=setTimeout((()=>{le.previousActiveElement&&le.previousActiveElement.focus?(le.previousActiveElement.focus(),le.previousActiveElement=null):document.body&&document.body.focus(),t()}),100),window.scrollTo(i,n)})),ue='\n <div aria-labelledby="'.concat(b.title,'" aria-describedby="').concat(b["html-container"],'" class="').concat(b.popup,'" tabindex="-1">\n   <button type="button" class="').concat(b.close,'"></button>\n   <ul class="').concat(b["progress-steps"],'"></ul>\n   <div class="').concat(b.icon,'"></div>\n   <img class="').concat(b.image,'" />\n   <h2 class="').concat(b.title,'" id="').concat(b.title,'"></h2>\n   <div class="').concat(b["html-container"],'" id="').concat(b["html-container"],'"></div>\n   <input class="').concat(b.input,'" />\n   <input type="file" class="').concat(b.file,'" />\n   <div class="').concat(b.range,'">\n     <input type="range" />\n     <output></output>\n   </div>\n   <select class="').concat(b.select,'"></select>\n   <div class="').concat(b.radio,'"></div>\n   <label for="').concat(b.checkbox,'" class="').concat(b.checkbox,'">\n     <input type="checkbox" />\n     <span class="').concat(b.label,'"></span>\n   </label>\n   <textarea class="').concat(b.textarea,'"></textarea>\n   <div class="').concat(b["validation-message"],'" id="').concat(b["validation-message"],'"></div>\n   <div class="').concat(b.actions,'">\n     <div class="').concat(b.loader,'"></div>\n     <button type="button" class="').concat(b.confirm,'"></button>\n     <button type="button" class="').concat(b.deny,'"></button>\n     <button type="button" class="').concat(b.cancel,'"></button>\n   </div>\n   <div class="').concat(b.footer,'"></div>\n   <div class="').concat(b["timer-progress-bar-container"],'">\n     <div class="').concat(b["timer-progress-bar"],'"></div>\n   </div>\n </div>\n').replace(/(^|\n)\s*/g,""),de=()=>{le.currentInstance.resetValidationMessage()},he=(e,t)=>{if(e instanceof HTMLElement)t.appendChild(e);else if("object"==typeof e){var i=e,n=t;i.jquery?fe(n,i):W(n,i.toString())}else e&&W(t,e)},fe=(e,t)=>{if(e.textContent="",0 in t)for(let i=0;i in t;i++)e.appendChild(t[i].cloneNode(!0));else e.appendChild(t.cloneNode(!0))},pe=(()=>{if(oe())return!1;var e=document.createElement("div"),t={WebkitAnimation:"webkitAnimationEnd",animation:"animationend"};for(const i in t)if(Object.prototype.hasOwnProperty.call(t,i)&&void 0!==e.style[i])return t[i];return!1})();function me(e,i,n){ne(e,n["show".concat(t(i),"Button")],"inline-block"),W(e,n["".concat(i,"ButtonText")]),e.setAttribute("aria-label",n["".concat(i,"ButtonAriaLabel")]),e.className=b[i],q(e,n,"".concat(i,"Button")),Z(e,n["".concat(i,"ButtonClass")])}var ge={awaitingPromise:new WeakMap,promise:new WeakMap,innerParams:new WeakMap,domCache:new WeakMap};const ve=["input","file","range","select","radio","checkbox","textarea"],ye=e=>{for(let i=0;i<e.attributes.length;i++){var t=e.attributes[i].name;["type","value","style"].includes(t)||e.removeAttribute(t)}},be=(e,t)=>{e.placeholder&&!t.inputPlaceholder||(e.placeholder=t.inputPlaceholder)},xe=(e,t,i)=>{if(i.inputLabel){e.id=b.input;const r=document.createElement("label");var n=b["input-label"];r.setAttribute("for",e.id),r.className=n,Z(r,i.customClass.inputLabel),r.innerText=i.inputLabel,t.insertAdjacentElement("beforebegin",r)}},_e=e=>(e=b[e]||b.input,J(M(),e)),we={},ke=(we.text=we.email=we.password=we.number=we.tel=we.url=(e,t)=>("string"==typeof t.inputValue||"number"==typeof t.inputValue?e.value=t.inputValue:u(t.inputValue)||n('Unexpected type of inputValue! Expected "string", "number" or "Promise", got "'.concat(typeof t.inputValue,'"')),xe(e,e,t),be(e,t),e.type=t.input,e),we.file=(e,t)=>(xe(e,e,t),be(e,t),e),we.range=(e,t)=>{const i=e.querySelector("input"),n=e.querySelector("output");return i.value=t.inputValue,i.type=t.input,n.value=t.inputValue,xe(i,e,t),e},we.select=(e,t)=>{if(e.textContent="",t.inputPlaceholder){const i=document.createElement("option");W(i,t.inputPlaceholder),i.value="",i.disabled=!0,i.selected=!0,e.appendChild(i)}return xe(e,e,t),e},we.radio=e=>(e.textContent="",e),we.checkbox=(e,t)=>{const i=$(M(),"checkbox");i.value="1",i.id=b.checkbox,i.checked=Boolean(t.inputValue);var n=e.querySelector("span");return W(n,t.inputPlaceholder),e},we.textarea=(e,t)=>(e.value=t.inputValue,be(e,t),xe(e,e,t),setTimeout((()=>{if("MutationObserver"in window){const t=parseInt(window.getComputedStyle(M()).width);new MutationObserver((()=>{var i=e.offsetWidth+(i=e,parseInt(window.getComputedStyle(i).marginLeft)+parseInt(window.getComputedStyle(i).marginRight));M().style.width=i>t?"".concat(i,"px"):null})).observe(e,{attributes:!0,attributeFilter:["style"]})}})),e),(e,t)=>{const i=L();q(i,t,"htmlContainer"),t.html?(he(t.html,i),ee(i,"block")):t.text?(i.textContent=t.text,ee(i,"block")):te(i),((e,t)=>{const i=M();var n;const a=!(e=ge.innerParams.get(e))||t.input!==e.input;ve.forEach((e=>{var n=b[e];const r=J(i,n);{var s=t.inputAttributes;const i=$(M(),e);if(i){ye(i);for(const e in s)i.setAttribute(e,s[e])}}r.className=n,a&&te(r)})),t.input&&(a&&(e=>{if(!we[e.input])return r('Unexpected type of input! Expected "text", "email", "password", "number", "tel", "select", "radio", "checkbox", "textarea", "file" or "url", got "'.concat(e.input,'"'));const t=_e(e.input),i=we[e.input](t,e);ee(i),setTimeout((()=>{X(i)}))})(t),n=_e((e=t).input),e.customClass&&Z(n,e.customClass.input))})(e,t)}),Me=(e,t)=>{for(const i in x)t.icon!==i&&K(e,x[i]);Z(e,x[t.icon]),Le(e,t),Se(),q(e,t,"icon")},Se=()=>{const e=M();var t=window.getComputedStyle(e).getPropertyValue("background-color");const i=e.querySelectorAll("[class^=swal2-success-circular-line], .swal2-success-fix");for(let e=0;e<i.length;e++)i[e].style.backgroundColor=t},Ae=(e,t)=>{e.textContent="",t.iconHtml?W(e,Te(t.iconHtml)):"success"===t.icon?W(e,'\n  <div class="swal2-success-circular-line-left"></div>\n  <span class="swal2-success-line-tip"></span> <span class="swal2-success-line-long"></span>\n  <div class="swal2-success-ring"></div> <div class="swal2-success-fix"></div>\n  <div class="swal2-success-circular-line-right"></div>\n'):"error"===t.icon?W(e,'\n  <span class="swal2-x-mark">\n    <span class="swal2-x-mark-line-left"></span>\n    <span class="swal2-x-mark-line-right"></span>\n  </span>\n'):W(e,Te({question:"?",warning:"!",info:"i"}[t.icon]))},Le=(e,t)=>{if(t.iconColor){e.style.color=t.iconColor,e.style.borderColor=t.iconColor;for(const i of[".swal2-success-line-tip",".swal2-success-line-long",".swal2-x-mark-line-left",".swal2-x-mark-line-right"])ie(e,i,"backgroundColor",t.iconColor);ie(e,".swal2-success-ring","borderColor",t.iconColor)}},Te=e=>'<div class="'.concat(b["icon-content"],'">').concat(e,"</div>"),Ce=(e,t)=>{((e,t)=>{var i=_();const n=M();t.toast?(Q(i,"width",t.width),n.style.width="100%",n.insertBefore(P(),S())):Q(n,"width",t.width),Q(n,"padding",t.padding),t.color&&(n.style.color=t.color),t.background&&(n.style.background=t.background),te(D()),(i=n).className="".concat(b.popup," ").concat(re(i)?t.showClass.popup:""),t.toast?(Z([document.documentElement,document.body],b["toast-shown"]),Z(i,b.toast)):Z(i,b.modal),q(i,t,"popup"),"string"==typeof t.customClass&&Z(i,t.customClass),t.icon&&Z(i,b["icon-".concat(t.icon)])})(0,t),((e,t)=>{var i,r,a=_();a&&(r=a,"string"==typeof(i=t.backdrop)?r.style.background=i:i||Z([document.documentElement,document.body],b["no-backdrop"]),r=a,(i=t.position)in b?Z(r,b[i]):(n('The "position" parameter is not valid, defaulting to "center"'),Z(r,b.center)),i=a,(r=t.grow)&&"string"==typeof r&&(r="grow-".concat(r))in b&&Z(i,b[r]),q(a,t,"container"))})(0,t),((e,t)=>{const i=C();if(!t.progressSteps||0===t.progressSteps.length)return te(i);ee(i),i.textContent="",t.currentProgressStep>=t.progressSteps.length&&n("Invalid currentProgressStep parameter, it should be less than progressSteps.length (currentProgressStep like JS arrays starts from 0)"),t.progressSteps.forEach(((e,n)=>{var r;r=document.createElement("li"),Z(r,b["progress-step"]),W(r,e),e=r,i.appendChild(e),n===t.currentProgressStep&&Z(e,b["active-progress-step"]),n!==t.progressSteps.length-1&&(r=(e=>{const t=document.createElement("li");return Z(t,b["progress-step-line"]),e.progressStepsDistance&&(t.style.width=e.progressStepsDistance),t})(t),i.appendChild(r))}))})(0,t),((e,t)=>{e=ge.innerParams.get(e);var i=S();e&&t.icon===e.icon?(Ae(i,t),Me(i,t)):t.icon||t.iconHtml?t.icon&&-1===Object.keys(x).indexOf(t.icon)?(r('Unknown icon! Expected "success", "error", "warning", "info" or "question", got "'.concat(t.icon,'"')),te(i)):(ee(i),Ae(i,t),Me(i,t),Z(i,t.showClass.icon)):te(i)})(e,t),((e,t)=>{const i=T();if(!t.imageUrl)return te(i);ee(i,""),i.setAttribute("src",t.imageUrl),i.setAttribute("alt",t.imageAlt),Q(i,"width",t.imageWidth),Q(i,"height",t.imageHeight),i.className=b.image,q(i,t,"image")})(0,t),((e,t)=>{const i=A();ne(i,t.title||t.titleText,"block"),t.title&&he(t.title,i),t.titleText&&(i.innerText=t.titleText),q(i,t,"title")})(0,t),((e,t)=>{const i=H();W(i,t.closeButtonHtml),q(i,t,"closeButton"),ne(i,t.showCloseButton),i.setAttribute("aria-label",t.closeButtonAriaLabel)})(0,t),ke(e,t),((e,t)=>{var i,n,r,a,s,o=I(),l=P();(t.showConfirmButton||t.showDenyButton||t.showCancelButton?ee:te)(o),q(o,t,"actions"),i=l,n=t,r=E(),a=O(),s=Y(),me(r,"confirm",n),me(a,"deny",n),me(s,"cancel",n),function(e,t,i,n){if(!n.buttonsStyling)return K([e,t,i],b.styled);Z([e,t,i],b.styled),n.confirmButtonColor&&(e.style.backgroundColor=n.confirmButtonColor,Z(e,b["default-outline"])),n.denyButtonColor&&(t.style.backgroundColor=n.denyButtonColor,Z(t,b["default-outline"])),n.cancelButtonColor&&(i.style.backgroundColor=n.cancelButtonColor,Z(i,b["default-outline"]))}(r,a,s,n),n.reverseButtons&&(n.toast?(o.insertBefore(s,r),o.insertBefore(a,r)):(o.insertBefore(s,i),o.insertBefore(a,i),o.insertBefore(r,i))),W(l,t.loaderHtml),q(l,t,"loader")})(0,t),((e,t)=>{var i=N();ne(i,t.footer),t.footer&&he(t.footer,i),q(i,t,"footer")})(0,t),"function"==typeof t.didRender&&t.didRender(M())},De=Object.freeze({cancel:"cancel",backdrop:"backdrop",close:"close",esc:"esc",timer:"timer"}),Ee=()=>{i(document.body.children).forEach((e=>{e===_()||e.contains(_())||(e.hasAttribute("aria-hidden")&&e.setAttribute("data-previous-aria-hidden",e.getAttribute("aria-hidden")),e.setAttribute("aria-hidden","true"))}))},Oe=()=>{i(document.body.children).forEach((e=>{e.hasAttribute("data-previous-aria-hidden")?(e.setAttribute("aria-hidden",e.getAttribute("data-previous-aria-hidden")),e.removeAttribute("data-previous-aria-hidden")):e.removeAttribute("aria-hidden")}))},Pe=["swal-title","swal-html","swal-footer"],Ye=(e,t)=>{i(e.attributes).forEach((i=>{-1===t.indexOf(i.name)&&n(['Unrecognized attribute "'.concat(i.name,'" on <').concat(e.tagName.toLowerCase(),">."),"".concat(t.length?"Allowed attributes are: ".concat(t.join(", ")):"To set the value, use HTML within the element.")])}))};var Ie={email:(e,t)=>/^[a-zA-Z0-9.+_-]+@[a-zA-Z0-9.-]+\.[a-zA-Z0-9-]{2,24}$/.test(e)?Promise.resolve():Promise.resolve(t||"Invalid email address"),url:(e,t)=>/^https?:\/\/(www\.)?[-a-zA-Z0-9@:%._+~#=]{1,256}\.[a-z]{2,63}\b([-a-zA-Z0-9@:%_+.~#?&/=]*)$/.test(e)?Promise.resolve():Promise.resolve(t||"Invalid URL")};function Ne(e){(t=e).inputValidator||Object.keys(Ie).forEach((e=>{t.input===e&&(t.inputValidator=Ie[e])})),e.showLoaderOnConfirm&&!e.preConfirm&&n("showLoaderOnConfirm is set to true, but preConfirm is not defined.\nshowLoaderOnConfirm should be used together with preConfirm, see usage example:\nhttps://sweetalert2.github.io/#ajax-request"),(i=e).target&&("string"!=typeof i.target||document.querySelector(i.target))&&("string"==typeof i.target||i.target.appendChild)||(n('Target parameter is not valid, defaulting to "body"'),i.target="body"),"string"==typeof e.title&&(e.title=e.title.split("\n").join("<br />"));var t,i=e;e=(()=>{const e=_();return!!e&&(e.remove(),K([document.documentElement,document.body],[b["no-backdrop"],b["toast-shown"],b["has-column"]]),!0)})();if(oe())r("SweetAlert2 requires document to initialize");else{const t=document.createElement("div"),n=(t.className=b.container,e&&Z(t,b["no-transition"]),W(t,ue),(e=>"string"==typeof e?document.querySelector(e):e)(i.target));n.appendChild(t),(e=>{const t=M();t.setAttribute("role",e.toast?"alert":"dialog"),t.setAttribute("aria-live",e.toast?"polite":"assertive"),e.toast||t.setAttribute("aria-modal","true")})(i),(e=>{"rtl"===window.getComputedStyle(e).direction&&Z(_(),b.rtl)})(n),(()=>{const e=M(),t=J(e,b.input),i=J(e,b.file),n=e.querySelector(".".concat(b.range," input")),r=e.querySelector(".".concat(b.range," output")),a=J(e,b.select),s=e.querySelector(".".concat(b.checkbox," input")),o=J(e,b.textarea);t.oninput=de,i.onchange=de,a.onchange=de,s.onchange=de,o.oninput=de,n.oninput=()=>{de(),r.value=n.value},n.onchange=()=>{de(),n.nextSibling.value=n.value}})()}}class je{constructor(e,t){this.callback=e,this.remaining=t,this.running=!1,this.start()}start(){return this.running||(this.running=!0,this.started=new Date,this.id=setTimeout(this.callback,this.remaining)),this.remaining}stop(){return this.running&&(this.running=!1,clearTimeout(this.id),this.remaining-=(new Date).getTime()-this.started.getTime()),this.remaining}increase(e){var t=this.running;return t&&this.stop(),this.remaining+=e,t&&this.start(),this.remaining}getTimerLeft(){return this.running&&(this.stop(),this.start()),this.remaining}isRunning(){return this.running}}const He=e=>{var t,i=e.target,n=_();return!((t=e).touches&&t.touches.length&&"stylus"===t.touches[0].touchType||(t=e).touches&&1<t.touches.length||i!==n&&(ae(n)||"INPUT"===i.tagName||"TEXTAREA"===i.tagName||ae(L())&&L().contains(i)))},Fe=e=>{const t=M();if(e.target===t){const e=_();t.removeEventListener(pe,Fe),e.style.overflowY="auto"}},Re=(e,t,i)=>{(()=>{if((/iPad|iPhone|iPod/.test(navigator.userAgent)&&!window.MSStream||"MacIntel"===navigator.platform&&1<navigator.maxTouchPoints)&&!U(document.body,b.iosfix)){var e=document.body.scrollTop;document.body.style.top="".concat(-1*e,"px"),Z(document.body,b.iosfix);{const e=_();let t;e.ontouchstart=e=>{t=He(e)},e.ontouchmove=e=>{t&&(e.preventDefault(),e.stopPropagation())}}{const e=navigator.userAgent,t=!!e.match(/iPad/i)||!!e.match(/iPhone/i),i=!!e.match(/WebKit/i);t&&i&&!e.match(/CriOS/i)&&M().scrollHeight>window.innerHeight-44&&(_().style.paddingBottom="".concat(44,"px"))}}})(),t&&"hidden"!==i&&(null===V.previousBodyPadding&&document.body.scrollHeight>window.innerHeight&&(V.previousBodyPadding=parseInt(window.getComputedStyle(document.body).getPropertyValue("padding-right")),document.body.style.paddingRight="".concat(V.previousBodyPadding+(()=>{const e=document.createElement("div");e.className=b["scrollbar-measure"],document.body.appendChild(e);var t=e.getBoundingClientRect().width-e.clientWidth;return document.body.removeChild(e),t})(),"px"))),setTimeout((()=>{e.scrollTop=0}))},ze=e=>{let t=M();t||new Et,t=M();var i=P();if(z())te(S());else{var n=t;const i=I(),r=P();!e&&re(E())&&(e=E()),ee(i),e&&(te(e),r.setAttribute("data-button-to-replace",e.className)),r.parentNode.insertBefore(r,e),Z([n,i],b.loading)}ee(i),t.setAttribute("data-loading",!0),t.setAttribute("aria-busy",!0),t.focus()},Be=(e,t)=>{const i=M(),n=e=>We[t.input](i,Ue(e),t);l(t.inputOptions)||u(t.inputOptions)?(ze(E()),c(t.inputOptions).then((t=>{e.hideLoading(),n(t)}))):"object"==typeof t.inputOptions?n(t.inputOptions):r("Unexpected type of inputOptions! Expected object, Map or Promise, got ".concat(typeof t.inputOptions))},Ve=(e,t)=>{const i=e.getInput();te(i),c(t.inputValue).then((n=>{i.value="number"===t.input?parseFloat(n)||0:"".concat(n),ee(i),i.focus(),e.hideLoading()})).catch((t=>{r("Error in inputValue promise: ".concat(t)),i.value="",ee(i),i.focus(),e.hideLoading()}))},We={select:(e,t,i)=>{const n=J(e,b.select),r=(e,t,n)=>{const r=document.createElement("option");r.value=n,W(r,t),r.selected=qe(n,i.inputValue),e.appendChild(r)};t.forEach((e=>{var t=e[0];const i=e[1];if(Array.isArray(i)){const e=document.createElement("optgroup");e.label=t,e.disabled=!1,n.appendChild(e),i.forEach((t=>r(e,t[1],t[0])))}else r(n,i,t)})),n.focus()},radio:(e,t,i)=>{const n=J(e,b.radio),r=(t.forEach((e=>{var t=e[0];e=e[1];const r=document.createElement("input"),a=document.createElement("label"),s=(r.type="radio",r.name=b.radio,r.value=t,qe(t,i.inputValue)&&(r.checked=!0),document.createElement("span"));W(s,e),s.className=b.label,a.appendChild(r),a.appendChild(s),n.appendChild(a)})),n.querySelectorAll("input"));r.length&&r[0].focus()}},Ue=e=>{const t=[];return"undefined"!=typeof Map&&e instanceof Map?e.forEach(((e,i)=>{let n=e;"object"==typeof n&&(n=Ue(n)),t.push([i,n])})):Object.keys(e).forEach((i=>{let n=e[i];"object"==typeof n&&(n=Ue(n)),t.push([i,n])})),t},qe=(e,t)=>t&&t.toString()===e.toString();function $e(){var e,t=ge.innerParams.get(this);if(t){const i=ge.domCache.get(this);te(i.loader),z()?t.icon&&ee(S()):(e=(t=i).popup.getElementsByClassName(t.loader.getAttribute("data-button-to-replace"))).length?ee(e[0],"inline-block"):!re(E())&&!re(O())&&!re(Y())&&te(t.actions),K([i.popup,i.actions],b.loading),i.popup.removeAttribute("aria-busy"),i.popup.removeAttribute("data-loading"),i.confirmButton.disabled=!1,i.denyButton.disabled=!1,i.cancelButton.disabled=!1}}var Xe={swalPromiseResolve:new WeakMap,swalPromiseReject:new WeakMap};const Ge=()=>E()&&E().click(),Ze=e=>{e.keydownTarget&&e.keydownHandlerAdded&&(e.keydownTarget.removeEventListener("keydown",e.keydownHandler,{capture:e.keydownListenerCapture}),e.keydownHandlerAdded=!1)},Ke=(e,t,i)=>{const n=F();if(n.length)return(t+=i)===n.length?t=0:-1===t&&(t=n.length-1),n[t].focus();M().focus()},Je=["ArrowRight","ArrowDown"],Qe=["ArrowLeft","ArrowUp"];function et(e,t,i,n){z()?rt(e,n):(ce(i).then((()=>rt(e,n))),Ze(le)),/^((?!chrome|android).)*safari/i.test(navigator.userAgent)?(t.setAttribute("style","display:none !important"),t.removeAttribute("class"),t.innerHTML=""):t.remove(),R()&&(null!==V.previousBodyPadding&&(document.body.style.paddingRight="".concat(V.previousBodyPadding,"px"),V.previousBodyPadding=null),(()=>{var e;U(document.body,b.iosfix)&&(e=parseInt(document.body.style.top,10),K(document.body,b.iosfix),document.body.style.top="",document.body.scrollTop=-1*e)})(),Oe()),K([document.documentElement,document.body],[b.shown,b["height-auto"],b["no-backdrop"],b["toast-shown"]])}function tt(e){e=void 0!==(i=e)?Object.assign({isConfirmed:!1,isDenied:!1,isDismissed:!1},i):{isConfirmed:!1,isDenied:!1,isDismissed:!0};const t=Xe.swalPromiseResolve.get(this);var i=(e=>{const t=M();if(!t)return!1;const i=ge.innerParams.get(e);if(!i||U(t,i.hideClass.popup))return!1;K(t,i.showClass.popup),Z(t,i.hideClass.popup);const n=_();return K(n,i.showClass.backdrop),Z(n,i.hideClass.backdrop),nt(e,t,i),!0})(this);this.isAwaitingPromise()?e.isDismissed||(it(this),t(e)):i&&t(e)}const it=e=>{e.isAwaitingPromise()&&(ge.awaitingPromise.delete(e),ge.innerParams.get(e)||e._destroy())},nt=(e,t,i)=>{var n,r,a,s=_(),o=pe&&se(t);"function"==typeof i.willClose&&i.willClose(t),o?(o=e,n=t,t=s,r=i.returnFocus,a=i.didClose,le.swalCloseEventFinishedCallback=et.bind(null,o,t,r,a),n.addEventListener(pe,(function(e){e.target===n&&(le.swalCloseEventFinishedCallback(),delete le.swalCloseEventFinishedCallback)}))):et(e,s,i.returnFocus,i.didClose)},rt=(e,t)=>{setTimeout((()=>{"function"==typeof t&&t.bind(e.params)(),e._destroy()}))};function at(e,t,i){const n=ge.domCache.get(e);t.forEach((e=>{n[e].disabled=i}))}function st(e,t){if(!e)return!1;if("radio"===e.type){const i=e.parentNode.parentNode.querySelectorAll("input");for(let e=0;e<i.length;e++)i[e].disabled=t}else e.disabled=t}const ot=e=>{e.isAwaitingPromise()?(lt(ge,e),ge.awaitingPromise.set(e,!0)):(lt(Xe,e),lt(ge,e))},lt=(e,t)=>{for(const i in e)e[i].delete(t)};y=Object.freeze({hideLoading:$e,disableLoading:$e,getInput:function(e){var t=ge.innerParams.get(e||this);return(e=ge.domCache.get(e||this))?$(e.popup,t.input):null},close:tt,isAwaitingPromise:function(){return!!ge.awaitingPromise.get(this)},rejectPromise:function(e){const t=Xe.swalPromiseReject.get(this);it(this),t&&t(e)},handleAwaitingPromise:it,closePopup:tt,closeModal:tt,closeToast:tt,enableButtons:function(){at(this,["confirmButton","denyButton","cancelButton"],!1)},disableButtons:function(){at(this,["confirmButton","denyButton","cancelButton"],!0)},enableInput:function(){return st(this.getInput(),!1)},disableInput:function(){return st(this.getInput(),!0)},showValidationMessage:function(e){const t=ge.domCache.get(this);var i=ge.innerParams.get(this);W(t.validationMessage,e),t.validationMessage.className=b["validation-message"],i.customClass&&i.customClass.validationMessage&&Z(t.validationMessage,i.customClass.validationMessage),ee(t.validationMessage);const n=this.getInput();n&&(n.setAttribute("aria-invalid",!0),n.setAttribute("aria-describedby",b["validation-message"]),X(n),Z(n,b.inputerror))},resetValidationMessage:function(){var e=ge.domCache.get(this);e.validationMessage&&te(e.validationMessage);const t=this.getInput();t&&(t.removeAttribute("aria-invalid"),t.removeAttribute("aria-describedby"),K(t,b.inputerror))},getProgressSteps:function(){return ge.domCache.get(this).progressSteps},update:function(e){var t=M(),i=ge.innerParams.get(this);if(!t||U(t,i.hideClass.popup))return n("You're trying to update the closed or closing popup, that won't work. Use the update() method in preConfirm parameter or show a new popup.");t=(e=>{const t={};return Object.keys(e).forEach((i=>{g(i)?t[i]=e[i]:n('Invalid parameter to update: "'.concat(i,'". Updatable params are listed here: https://github.com/sweetalert2/sweetalert2/blob/master/src/utils/params.js\n\nIf you think this parameter should be updatable, request it here: https://github.com/sweetalert2/sweetalert2/issues/new?template=02_feature_request.md'))})),t})(e),i=Object.assign({},i,t),Ce(this,i),ge.innerParams.set(this,i),Object.defineProperties(this,{params:{value:Object.assign({},this.params,e),writable:!1,enumerable:!0}})},_destroy:function(){var e=ge.domCache.get(this);const t=ge.innerParams.get(this);t?(e.popup&&le.swalCloseEventFinishedCallback&&(le.swalCloseEventFinishedCallback(),delete le.swalCloseEventFinishedCallback),le.deferDisposalTimer&&(clearTimeout(le.deferDisposalTimer),delete le.deferDisposalTimer),"function"==typeof t.didDestroy&&t.didDestroy(),ot(e=this),delete e.params,delete le.keydownHandler,delete le.keydownTarget,delete le.currentInstance):ot(this)}});const ct=(e,i)=>{var n=ge.innerParams.get(e);if(!n.input)return r('The "input" parameter is needed to be set when using returnInputValueOn'.concat(t(i)));var a=((e,t)=>{const i=e.getInput();if(!i)return null;switch(t.input){case"checkbox":return i.checked?1:0;case"radio":return(n=i).checked?n.value:null;case"file":return(n=i).files.length?null!==n.getAttribute("multiple")?n.files:n.files[0]:null;default:return t.inputAutoTrim?i.value.trim():i.value}var n})(e,n);if(n.inputValidator){var s=e,o=a,l=i;const t=ge.innerParams.get(s);(s.disableInput(),Promise.resolve().then((()=>c(t.inputValidator(o,t.validationMessage))))).then((e=>{s.enableButtons(),s.enableInput(),e?s.showValidationMessage(e):("deny"===l?ut:ft)(s,o)}))}else e.getInput().checkValidity()?("deny"===i?ut:ft)(e,a):(e.enableButtons(),e.showValidationMessage(n.validationMessage))},ut=(e,t)=>{const i=ge.innerParams.get(e||void 0);if(i.showLoaderOnDeny&&ze(O()),i.preDeny){ge.awaitingPromise.set(e||void 0,!0);Promise.resolve().then((()=>c(i.preDeny(t,i.validationMessage)))).then((i=>{!1===i?(e.hideLoading(),it(e)):e.closePopup({isDenied:!0,value:void 0===i?t:i})})).catch((t=>ht(e||void 0,t)))}else e.closePopup({isDenied:!0,value:t})},dt=(e,t)=>{e.closePopup({isConfirmed:!0,value:t})},ht=(e,t)=>{e.rejectPromise(t)},ft=(e,t)=>{const i=ge.innerParams.get(e||void 0);if(i.showLoaderOnConfirm&&ze(),i.preConfirm){e.resetValidationMessage(),ge.awaitingPromise.set(e||void 0,!0);Promise.resolve().then((()=>c(i.preConfirm(t,i.validationMessage)))).then((i=>{re(D())||!1===i?(e.hideLoading(),it(e)):dt(e,void 0===i?t:i)})).catch((t=>ht(e||void 0,t)))}else dt(e,t)};let pt=!1;const mt=e=>e instanceof Element||(e=>"object"==typeof e&&e.jquery)(e),gt=()=>{if(le.timeout){{const t=j();var e=(e=parseInt(window.getComputedStyle(t).width))/(t.style.removeProperty("transition"),t.style.width="100%",parseInt(window.getComputedStyle(t).width))*100;t.style.removeProperty("transition"),t.style.width="".concat(e,"%")}return le.timeout.stop()}},vt=()=>{var e;if(le.timeout)return B(e=le.timeout.start()),e};let yt=!1;const bt={},xt=e=>{for(let i=e.target;i&&i!==document;i=i.parentNode)for(const e in bt){var t=i.getAttribute(e);if(t)return void bt[e].fire({template:t})}};var _t=Object.freeze({isValidParameter:m,isUpdatableParameter:g,isDeprecatedParameter:v,argsToParams:e=>{const t={};return"object"!=typeof e[0]||mt(e[0])?["title","html","icon"].forEach(((i,n)=>{"string"==typeof(n=e[n])||mt(n)?t[i]=n:void 0!==n&&r("Unexpected type of ".concat(i,'! Expected "string" or "Element", got ').concat(typeof n))})):Object.assign(t,e[0]),t},isVisible:()=>re(M()),clickConfirm:Ge,clickDeny:()=>O()&&O().click(),clickCancel:()=>Y()&&Y().click(),getContainer:_,getPopup:M,getTitle:A,getHtmlContainer:L,getImage:T,getIcon:S,getInputLabel:()=>k(b["input-label"]),getCloseButton:H,getActions:I,getConfirmButton:E,getDenyButton:O,getCancelButton:Y,getLoader:P,getFooter:N,getTimerProgressBar:j,getFocusableElements:F,getValidationMessage:D,isLoading:()=>M().hasAttribute("data-loading"),fire:function(){for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];return new this(...t)},mixin:function(e){return class extends(this){_main(t,i){return super._main(t,Object.assign({},e,i))}}},showLoading:ze,enableLoading:ze,getTimerLeft:()=>le.timeout&&le.timeout.getTimerLeft(),stopTimer:gt,resumeTimer:vt,toggleTimer:()=>{var e=le.timeout;return e&&(e.running?gt:vt)()},increaseTimer:e=>{if(le.timeout)return B(e=le.timeout.increase(e),!0),e},isTimerRunning:()=>le.timeout&&le.timeout.isRunning(),bindClickHandler:function(){bt[0<arguments.length&&void 0!==arguments[0]?arguments[0]:"data-swal-template"]=this,yt||(document.body.addEventListener("click",xt),yt=!0)}});let wt;class kt{constructor(){if("undefined"!=typeof window){wt=this;for(var e=arguments.length,t=new Array(e),i=0;i<e;i++)t[i]=arguments[i];var n=Object.freeze(this.constructor.argsToParams(t));n=(Object.defineProperties(this,{params:{value:n,writable:!1,enumerable:!0,configurable:!0}}),this._main(this.params));ge.promise.set(this,n)}}_main(e){var t=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{};(e=>{!e.backdrop&&e.allowOutsideClick&&n('"allowOutsideClick" parameter requires `backdrop` parameter to be set to `true`');for(const i in e)m(t=i)||n('Unknown parameter "'.concat(t,'"')),e.toast&&(t=i,p.includes(t)&&n('The parameter "'.concat(t,'" is incompatible with toasts'))),v(t=i)&&s(t,v(t));var t})(Object.assign({},t,e)),le.currentInstance&&(le.currentInstance._destroy(),R()&&Oe()),le.currentInstance=this,e=St(e,t),Ne(e),Object.freeze(e),le.timeout&&(le.timeout.stop(),delete le.timeout),clearTimeout(le.restoreFocusTimeout),t=At(this);return Ce(this,e),ge.innerParams.set(this,e),Mt(this,t,e)}then(e){return ge.promise.get(this).then(e)}finally(e){return ge.promise.get(this).finally(e)}}const Mt=(e,t,i)=>new Promise(((n,r)=>{const a=t=>{e.closePopup({isDismissed:!0,dismiss:t})};var s,c,d;Xe.swalPromiseResolve.set(e,n),Xe.swalPromiseReject.set(e,r),t.confirmButton.onclick=()=>{var t=e,i=ge.innerParams.get(t);t.disableButtons(),i.input?ct(t,"confirm"):ft(t,!0)},t.denyButton.onclick=()=>{var t=e,i=ge.innerParams.get(t);t.disableButtons(),i.returnInputValueOnDeny?ct(t,"deny"):ut(t,!1)},t.cancelButton.onclick=()=>{var t=a;e.disableButtons(),t(De.cancel)},t.closeButton.onclick=()=>a(De.close),n=e,r=t,d=a,ge.innerParams.get(n).toast?((e,t,i)=>{t.popup.onclick=()=>{var t,n=ge.innerParams.get(e);n&&((t=n).showConfirmButton||t.showDenyButton||t.showCancelButton||t.showCloseButton||n.timer||n.input)||i(De.close)}})(n,r,d):((e=>{e.popup.onmousedown=()=>{e.container.onmouseup=function(t){e.container.onmouseup=void 0,t.target===e.container&&(pt=!0)}}})(r),(e=>{e.container.onmousedown=()=>{e.popup.onmouseup=function(t){e.popup.onmouseup=void 0,t.target!==e.popup&&!e.popup.contains(t.target)||(pt=!0)}}})(r),((e,t,i)=>{t.container.onclick=n=>{var r=ge.innerParams.get(e);pt?pt=!1:n.target===t.container&&o(r.allowOutsideClick)&&i(De.backdrop)}})(n,r,d)),s=e,r=i,c=a,Ze(n=le),r.toast||(n.keydownHandler=e=>((e,t,i)=>{var n=ge.innerParams.get(e);if(n&&!t.isComposing&&229!==t.keyCode)if(n.stopKeydownPropagation&&t.stopPropagation(),"Enter"===t.key)l=t,o((r=n).allowEnterKey)&&l.target&&e.getInput()&&l.target.outerHTML===e.getInput().outerHTML&&(["textarea","file"].includes(r.input)||(Ge(),l.preventDefault()));else if("Tab"===t.key){var r=n,a=(e=t).target,s=F();let i=-1;for(let e=0;e<s.length;e++)if(a===s[e]){i=e;break}e.shiftKey?Ke(0,i,-1):Ke(0,i,1),e.stopPropagation(),e.preventDefault()}else if([...Je,...Qe].includes(t.key)){var l=t.key;if([E(),O(),Y()].includes(document.activeElement)){var c=Je.includes(l)?"nextElementSibling":"previousElementSibling";let e=document.activeElement;for(let t=0;t<I().children.length;t++){if(!(e=e[c]))return;if(re(e)&&e instanceof HTMLButtonElement)break}e instanceof HTMLButtonElement&&e.focus()}}else"Escape"===t.key&&(e=t,t=n,n=i,o(t.allowEscapeKey)&&(e.preventDefault(),n(De.esc)))})(s,e,c),n.keydownTarget=r.keydownListenerCapture?window:M(),n.keydownListenerCapture=r.keydownListenerCapture,n.keydownTarget.addEventListener("keydown",n.keydownHandler,{capture:n.keydownListenerCapture}),n.keydownHandlerAdded=!0),d=e,"select"===(r=i).input||"radio"===r.input?Be(d,r):["text","email","number","tel","textarea"].includes(r.input)&&(l(r.inputValue)||u(r.inputValue))&&(ze(E()),Ve(d,r));{var h=i;const e=_(),t=M();"function"==typeof h.willOpen&&h.willOpen(t),n=window.getComputedStyle(document.body).overflowY,((e,t,i)=>{Z(e,i.showClass.backdrop),t.style.setProperty("opacity","0","important"),ee(t,"grid"),setTimeout((()=>{Z(t,i.showClass.popup),t.style.removeProperty("opacity")}),10),Z([document.documentElement,document.body],b.shown),i.heightAuto&&i.backdrop&&!i.toast&&Z([document.documentElement,document.body],b["height-auto"])})(e,t,h),setTimeout((()=>{((e,t)=>{pe&&se(t)?(e.style.overflowY="hidden",t.addEventListener(pe,Fe)):e.style.overflowY="auto"})(e,t)}),10),R()&&(Re(e,h.scrollbarPadding,n),Ee()),z()||le.previousActiveElement||(le.previousActiveElement=document.activeElement),"function"==typeof h.didOpen&&setTimeout((()=>h.didOpen(t))),K(e,b["no-transition"])}Lt(le,i,a),Tt(t,i),setTimeout((()=>{t.container.scrollTop=0}))})),St=(e,r)=>{var a=(e=>(e="string"==typeof e.template?document.querySelector(e.template):e.template)?((e=>{const t=Pe.concat(["swal-param","swal-button","swal-image","swal-icon","swal-input","swal-input-option"]);i(e.children).forEach((e=>{e=e.tagName.toLowerCase(),-1===t.indexOf(e)&&n("Unrecognized element <".concat(e,">"))}))})(e=e.content),e=Object.assign((e=>{const t={};return i(e.querySelectorAll("swal-param")).forEach((e=>{Ye(e,["name","value"]);var i=e.getAttribute("name");e=e.getAttribute("value"),"boolean"==typeof d[i]&&"false"===e&&(t[i]=!1),"object"==typeof d[i]&&(t[i]=JSON.parse(e))})),t})(e),(e=>{const n={};return i(e.querySelectorAll("swal-button")).forEach((e=>{Ye(e,["type","color","aria-label"]);var i=e.getAttribute("type");n["".concat(i,"ButtonText")]=e.innerHTML,n["show".concat(t(i),"Button")]=!0,e.hasAttribute("color")&&(n["".concat(i,"ButtonColor")]=e.getAttribute("color")),e.hasAttribute("aria-label")&&(n["".concat(i,"ButtonAriaLabel")]=e.getAttribute("aria-label"))})),n})(e),(e=>{const t={},i=e.querySelector("swal-image");return i&&(Ye(i,["src","width","height","alt"]),i.hasAttribute("src")&&(t.imageUrl=i.getAttribute("src")),i.hasAttribute("width")&&(t.imageWidth=i.getAttribute("width")),i.hasAttribute("height")&&(t.imageHeight=i.getAttribute("height")),i.hasAttribute("alt")&&(t.imageAlt=i.getAttribute("alt"))),t})(e),(e=>{const t={},i=e.querySelector("swal-icon");return i&&(Ye(i,["type","color"]),i.hasAttribute("type")&&(t.icon=i.getAttribute("type")),i.hasAttribute("color")&&(t.iconColor=i.getAttribute("color")),t.iconHtml=i.innerHTML),t})(e),(e=>{const t={},n=e.querySelector("swal-input");return n&&(Ye(n,["type","label","placeholder","value"]),t.input=n.getAttribute("type")||"text",n.hasAttribute("label")&&(t.inputLabel=n.getAttribute("label")),n.hasAttribute("placeholder")&&(t.inputPlaceholder=n.getAttribute("placeholder")),n.hasAttribute("value")&&(t.inputValue=n.getAttribute("value"))),(e=e.querySelectorAll("swal-input-option")).length&&(t.inputOptions={},i(e).forEach((e=>{Ye(e,["value"]);var i=e.getAttribute("value");e=e.innerHTML,t.inputOptions[i]=e}))),t})(e),((e,t)=>{const i={};for(const n in t){const r=t[n],a=e.querySelector(r);a&&(Ye(a,[]),i[r.replace(/^swal-/,"")]=a.innerHTML.trim())}return i})(e,Pe)),e):{})(e);const s=Object.assign({},d,r,a,e);return s.showClass=Object.assign({},d.showClass,s.showClass),s.hideClass=Object.assign({},d.hideClass,s.hideClass),s},At=e=>{var t={popup:M(),container:_(),actions:I(),confirmButton:E(),denyButton:O(),cancelButton:Y(),loader:P(),closeButton:H(),validationMessage:D(),progressSteps:C()};return ge.domCache.set(e,t),t},Lt=(e,t,i)=>{var n=j();te(n),t.timer&&(e.timeout=new je((()=>{i("timer"),delete e.timeout}),t.timer),t.timerProgressBar&&(ee(n),q(n,t,"timerProgressBar"),setTimeout((()=>{e.timeout&&e.timeout.running&&B(t.timer)}))))},Tt=(e,t)=>{if(!t.toast)return o(t.allowEnterKey)?void(Ct(e,t)||Ke(0,-1,1)):Dt()},Ct=(e,t)=>t.focusDeny&&re(e.denyButton)?(e.denyButton.focus(),!0):t.focusCancel&&re(e.cancelButton)?(e.cancelButton.focus(),!0):!(!t.focusConfirm||!re(e.confirmButton)||(e.confirmButton.focus(),0)),Dt=()=>{document.activeElement instanceof HTMLElement&&"function"==typeof document.activeElement.blur&&document.activeElement.blur()},Et=(Object.assign(kt.prototype,y),Object.assign(kt,_t),Object.keys(y).forEach((e=>{kt[e]=function(){if(wt)return wt[e](...arguments)}})),kt.DismissReason=De,kt.version="11.4.8",kt);return Et.default=Et})),void 0!==this&&this.Sweetalert2&&(this.swal=this.sweetAlert=this.Swal=this.SweetAlert=this.Sweetalert2),swal.mixin({width:400,heightAuto:!1,padding:"2.5rem",buttonsStyling:!1,confirmButtonClass:"btn btn-success",confirmButtonColor:null,cancelButtonClass:"btn btn-secondary",cancelButtonColor:null});